@@ -35,6 +35,7 @@
 #include "audio/decoders/adpcm.h"
 #include "audio/decoders/qdm2.h"
 #include "audio/decoders/raw.h"
+#include "audio/decoders/g711.h"
 
 namespace Audio {
 
@@ -638,14 +639,14 @@ AudioStream *QuickTimeAudioDecoder::AudioSampleDesc::createAudioStream(Common::S
 			flags |= FLAG_STEREO;
 		if (_bitsPerSample == 16)
 			flags |= FLAG_16BITS;
-		uint32 dataSize = stream->size();
-		byte *data = (byte *)malloc(dataSize);
-		stream->read(data, dataSize);
-		delete stream;
-		return makeRawStream(data, dataSize, _sampleRate, flags);
+		return makeRawStream(stream, _sampleRate, flags);
 	} else if (_codecTag == MKTAG('i', 'm', 'a', '4')) {
 		// Riven uses this codec (as do some Myst ME videos)
 		return makeADPCMStream(stream, DisposeAfterUse::YES, stream->size(), kADPCMApple, _sampleRate, _channels, 34);
+	} else if (_codecTag == MKTAG('a', 'l', 'a', 'w')) {
+		return makeALawStream(stream, DisposeAfterUse::YES, _sampleRate, _channels);
+	} else if (_codecTag == MKTAG('u', 'l', 'a', 'w')) {
+		return makeMuLawStream(stream, DisposeAfterUse::YES, _sampleRate, _channels);
 	}
 
 	error("Unsupported audio codec");
