@@ -24,6 +24,8 @@
 #define AUDIO_MILES_MIDIDRIVER_H
 
 #include "audio/mididrv.h"
+#include "audio/mt32gm.h"
+
 #include "common/error.h"
 #include "common/mutex.h"
 #include "common/queue.h"
@@ -31,8 +33,13 @@
 
 namespace Audio {
 
-#define MILES_MIDI_CHANNEL_COUNT 16
-#define MILES_RHYTHM_CHANNEL 9
+/**
+ * @defgroup audio_miles Miles and XMIDI
+ * @ingroup audio
+ *
+ * @brief API for managing XMIDI files used by Miles Sound System.
+ * @{
+ */
 
 // Miles Audio supported controllers for control change messages
 #define MILES_CONTROLLER_SELECT_PATCH_BANK 114
@@ -40,20 +47,7 @@ namespace Audio {
 #define MILES_CONTROLLER_PROTECT_TIMBRE 113
 #define MILES_CONTROLLER_LOCK_CHANNEL 110
 #define MILES_CONTROLLER_PROTECT_CHANNEL 111
-#define MILES_CONTROLLER_BANK_SELECT_MSB 0
-#define MILES_CONTROLLER_BANK_SELECT_LSB 32
-#define MILES_CONTROLLER_MODULATION 1
-#define MILES_CONTROLLER_VOLUME 7
-#define MILES_CONTROLLER_EXPRESSION 11
-#define MILES_CONTROLLER_PANNING 10
-#define MILES_CONTROLLER_SUSTAIN 64
 #define MILES_CONTROLLER_PITCH_RANGE 6
-#define MILES_CONTROLLER_RESET_ALL 121
-#define MILES_CONTROLLER_ALL_NOTES_OFF 123
-#define MILES_CONTROLLER_OMNI_ON 124
-#define MILES_CONTROLLER_OMNI_OFF 125
-#define MILES_CONTROLLER_MONO_ON 126
-#define MILES_CONTROLLER_POLY_ON 127
 #define MILES_CONTROLLER_PATCH_REVERB 59
 #define MILES_CONTROLLER_PATCH_BENDER 60
 #define MILES_CONTROLLER_REVERB_MODE 61
@@ -80,22 +74,6 @@ namespace Audio {
 #define MILES_CONTROLLER_XMIDI_RANGE_BEGIN 110
 #define MILES_CONTROLLER_XMIDI_RANGE_END 120
 
-// Miles Audio actually used 0x4000, because they didn't shift the 2 bytes properly
-#define MILES_PITCHBENDER_DEFAULT 0x2000
-
-// The maximum number of sources sending MIDI data to this driver.
-// This is based on the requirements of the KYRA engine, but can be increased if
-// necessary.
-#define MILES_MAXIMUM_SOURCES 4
-// Maximum number of tracked active notes for the MT-32
-// This is the maximum polyphony of the MT-32 plus some overhead (MIDI data may send
-// more notes than the MT-32 can handle simultaneously).
-#define MILES_MT32_ACTIVE_NOTES 48
-// Maximum number of tracked active notes for GM
-// This is the maximum polyphony of the SC-88 and AWE64 plus some overhead (MIDI data
-// may send more notes than the GM device can handle simultaneously).
-#define MILES_GM_ACTIVE_NOTES 96
-
 #define MILES_MT32_PATCHES_COUNT 128
 #define MILES_MT32_CUSTOMTIMBRE_COUNT 64
 
@@ -104,11 +82,20 @@ namespace Audio {
 #define MILES_MT32_PATCHDATA_PARTIALPARAMETERS_COUNT 4
 #define MILES_MT32_PATCHDATA_TOTAL_SIZE (MILES_MT32_PATCHDATA_COMMONPARAMETER_SIZE + (MILES_MT32_PATCHDATA_PARTIALPARAMETER_SIZE * MILES_MT32_PATCHDATA_PARTIALPARAMETERS_COUNT))
 
+// Some engines using Miles assume a source neutral
+// volume of 256, so use this by default.
+#define MILES_DEFAULT_SOURCE_NEUTRAL_VOLUME 256
+
+enum MilesVersion {
+	MILES_VERSION_2 = 2,
+	MILES_VERSION_3
+};
+
 struct MilesMT32InstrumentEntry {
 	byte bankId;
 	byte patchId;
-	byte commonParameter[MILES_MT32_PATCHDATA_COMMONPARAMETER_SIZE + 1];
-	byte partialParameters[MILES_MT32_PATCHDATA_PARTIALPARAMETERS_COUNT][MILES_MT32_PATCHDATA_PARTIALPARAMETER_SIZE + 1];
+	byte commonParameter[MILES_MT32_PATCHDATA_COMMONPARAMETER_SIZE];
+	byte partialParameters[MILES_MT32_PATCHDATA_PARTIALPARAMETERS_COUNT][MILES_MT32_PATCHDATA_PARTIALPARAMETER_SIZE];
 };
 
 /**
@@ -118,6 +105,8 @@ struct MilesMT32InstrumentEntry {
  */
 class MidiDriver_Miles_Xmidi_Timbres {
 public:
+	virtual ~MidiDriver_Miles_Xmidi_Timbres() { }
+
 	/**
 	 * Processes the timbre chunk specified for a track
 	 * in an XMIDI file. This will load the necessary
@@ -130,28 +119,16 @@ public:
 	 * this process has finished.
 	 */
 	virtual void processXMIDITimbreChunk(const byte *timbreListPtr, uint32 timbreListSize) = 0;
-	virtual ~MidiDriver_Miles_Xmidi_Timbres() { }
 };
 
-class MidiDriver_Miles_Midi : public MidiDriver, public MidiDriver_Miles_Xmidi_Timbres {
+class MidiDriver_Miles_Midi : public MidiDriver_MT32GM, public MidiDriver_Miles_Xmidi_Timbres {
 public:
 	MidiDriver_Miles_Midi(MusicType midiType, MilesMT32InstrumentEntry *instrumentTablePtr, uint16 instrumentTableCount);
-	virtual ~MidiDriver_Miles_Midi();
+	~MidiDriver_Miles_Midi();
 
 public:
-	// MidiDriver
-	int open() override;
-	// Open the Miles driver using the specified MidiDriver instance.
-	int open(MidiDriver *driver, bool nativeMT32);
-	void close() override;
-	bool isOpen() const override { return _isOpen; }
-
-	using MidiDriver_BASE::send;
-	void send(uint32 b) override;
+	using MidiDriver_MT32GM::send;
 	void send(int8 source, uint32 b) override;
-	void sysEx(const byte *msg, uint16 length) override;
-	uint16 sysExNoDelay(const byte *msg, uint16 length) override;
-	void metaEvent(int8 source, byte type, byte *data, uint16 length) override;
 
 	/**
 	 * De-initialize a source. Call this after playing a track or sound effect using this source.
@@ -159,72 +136,20 @@ public:
 	 * from this source.
 	 * Automatically executed when an End Of Track meta event is received.
 	 */
-	void deinitSource(uint8 source);
-	/**
-	 * Set the volume for this source. This will be used to scale the volume values in the MIDI
-	 * data from this source. Expected volume values are 0 - 256.
-	 * Note that source volume remains set for the source number even after deinitializing the
-	 * source. If the same source numbers are consistently used for music and SFX sources, the
-	 * source volume will only need to be set once.
-	 */
-	void setSourceVolume(uint8 source, uint16 volume);
+	void deinitSource(uint8 source) override;
 
 	void stopAllNotes(bool stopSustainedNotes = false) override;
 
-	MidiChannel *allocateChannel() override {
-		if (_driver)
-			return _driver->allocateChannel();
-		return NULL;
-	}
-	MidiChannel *getPercussionChannel() override {
-		if (_driver)
-			return _driver->getPercussionChannel();
-		return NULL;
-	}
+	uint32 property(int prop, uint32 param) override;
 
-	void setTimerCallback(void *timer_param, Common::TimerManager::TimerProc timer_proc) override {
-		_timer_param = timer_param;
-		_timer_proc = timer_proc;
-	}
-
-	void onTimer();
-
-	uint32 getBaseTempo() override {
-		if (_driver) {
-			return _driver->getBaseTempo();
-		}
-		return 1000000 / _baseFreq;
-	}
+	void processXMIDITimbreChunk(const byte *timbreListPtr, uint32 timbreListSize) override;
 
 protected:
-	Common::Mutex _mutex;
-	MidiDriver *_driver;
-	bool _isOpen;
-	// The type of MIDI data supplied to the driver: MT-32 or General MIDI.
-	MusicType _midiType;
-	// True if the MIDI output is an MT-32 (hardware or 100% emulated),
-	// false if the MIDI output is a General MIDI device.
-	bool _nativeMT32;
-	// True if the General MIDI output supports Roland GS for improved MT-32 mapping.
-	bool _enableGS;
-
-	// Bitmask of the MIDI channels in use by the output device
-	uint16 _outputChannelMask;
-
-	int _baseFreq;
-	uint32 _timerRate;
-
-public:
-	void processXMIDITimbreChunk(const byte *timbreListPtr, uint32 timbreListSize) override;
-	bool isReady() override { return _sysExQueue.empty(); }
+	void initControlData() override;
+	void initMidiDevice() override;
+	void applySourceVolume(uint8 source) override;
 
 private:
-	void initMidiDevice();
-
-	void MT32SysEx(const uint32 targetAddress, const byte *dataPtr, bool useSysExQueue = false);
-
-	uint32 calculateSysExTargetAddress(uint32 baseAddress, uint32 index);
-
 	void writeRhythmSetup(byte note, byte customTimbreId);
 	void writePatchTimbre(byte patchId, byte timbreGroup, byte timbreId, bool useSysExQueue = false);
 	void writePatchByte(byte patchId, byte index, byte patchValue);
@@ -236,8 +161,6 @@ private:
 	void setupPatch(byte patchBank, byte patchId, bool useSysExQueue = false);
 	int16 installCustomTimbre(byte patchBank, byte patchId);
 
-	bool isOutputChannelUsed(uint8 outputChannel) { return _outputChannelMask & (1 << outputChannel); }
-
 private:
 	/**
 	 * This stores the values of the MIDI controllers for
@@ -245,42 +168,14 @@ private:
 	 * values while a channel is locked, so they can be
 	 * restored when the channel is unlocked.
 	 */
-	struct MidiChannelControlData {
-		// The source that last sent an event to this channel
-		int8 source;
-		// True if the source volume has been applied to this channel
-		bool sourceVolumeApplied;
-
-		byte program;
-
-		uint16 pitchWheel;
-
-		byte modulation;
-		// The volume specified by the MIDI data
-		byte volume;
-		// The volume scaled using the source volume
-		byte scaledVolume;
-		byte panPosition;
-		byte expression;
-		bool sustain;
-
+	struct MilesMidiChannelControlData : MidiChannelControlData {
 		// Custom timbre data
 		byte   currentPatchBank;
 
 		bool   usingCustomTimbre;
 		byte   currentCustomTimbreId;
 
-		MidiChannelControlData() : source(-1),
-			sourceVolumeApplied(false),
-			program(0),
-			pitchWheel(MILES_PITCHBENDER_DEFAULT),
-			modulation(0),
-			volume(0xFF),
-			scaledVolume(0x64),
-			panPosition(0x40),
-			expression(0x7F),
-			sustain(false),
-			currentPatchBank(0),
+		MilesMidiChannelControlData() : currentPatchBank(0),
 			usingCustomTimbre(false),
 			currentCustomTimbreId(0) { }
 	};
@@ -306,18 +201,20 @@ private:
 		uint8  activeNotes;
 
 		// The MIDI controller values currently used by the channel.
-		MidiChannelControlData currentData;
+		MilesMidiChannelControlData *currentData;
 		// The MIDI controller values set by the sources which are
 		// not currently using the channel because it is locked.
 		// These values will be set on the channel when the channel
 		// is unlocked.
-		MidiChannelControlData unlockData;
+		MilesMidiChannelControlData *unlockData;
 
 		MidiChannelEntry() : locked(false),
 			lockDataChannel(-1),
 			lockProtected(false),
 			protectedSource(-1),
-			activeNotes(0) { }
+			activeNotes(0),
+			currentData(0),
+			unlockData(0) { }
 	};
 
 	/**
@@ -325,12 +222,14 @@ private:
 	 * @param controlData The new MIDI controller value will be set on this MidiChannelControlData
 	 * @param sendMessage True if the message should be sent out to the device
 	 */
-	void controlChange(byte outputChannel, byte controllerNumber, byte controllerValue, int8 source, MidiChannelControlData &controlData, bool sendMessage);
+	void controlChange(byte outputChannel, byte controllerNumber, byte controllerValue, int8 source, MidiChannelControlData &controlData, bool channelLockedByOtherSource = false) override;
+	bool addActiveNote(uint8 outputChannel, uint8 note, int8 source) override;
+	bool removeActiveNote(uint8 outputChannel, uint8 note, int8 source) override;
 	/**
 	 * Removes active notes from the active notes registration on the specified channel.
 	 * @param sustainedNotes True if only sustained notes should be removed; otherwise only regular active notes will be removed
 	 */
-	void removeActiveNotes(uint8 outputChannel, bool sustainedNotes);
+	void removeActiveNotes(uint8 outputChannel, bool sustainedNotes) override;
 	/**
 	 * Find and lock an output channel and reserve it for the specified
 	 * source. The output channel will be mapped to the specified data
@@ -355,7 +254,7 @@ private:
 	 * @param controlData The new program value will be set on this MidiChannelControlData
 	 * @param sendMessage True if the message should be sent out to the device
 	 */
-	void programChange(byte outputChannel, byte patchId, uint8 source, MidiChannelControlData &controlData, bool sendMessage);
+	void programChange(byte outputChannel, byte patchId, int8 source, MidiChannelControlData &controlData, bool channelLockedByOtherSource = false) override;
 
 	void stopNotesOnChannel(uint8 outputChannelNumber);
 
@@ -377,7 +276,7 @@ private:
 	struct MilesMT32SysExQueueEntry {
 		uint32 targetAddress;
 		byte   dataPos;
-		byte   data[MILES_CONTROLLER_SYSEX_QUEUE_SIZE + 1]; // 1 extra byte for terminator
+		byte   data[MILES_CONTROLLER_SYSEX_QUEUE_SIZE];
 
 		MilesMT32SysExQueueEntry() : targetAddress(0),
 			dataPos(0) {
@@ -385,23 +284,11 @@ private:
 		}
 	};
 
-	/**
-	 * This stores data about a specific source of MIDI data.
-	 */
-	struct MidiSource {
-		// The source volume as set by ScummVM (music/SFX volume)
-		uint16 volume;
-		// The mapping of MIDI data channels to output channels
-		// for this source.
-		int8 channelMap[MILES_MIDI_CHANNEL_COUNT];
-
-		MidiSource() : volume(256) {
-			memset(channelMap, 0, sizeof(channelMap));
-		}
-	};
+	// the version of Miles AIL/MSS to emulate
+	MilesVersion _milesVersion;
 
 	// stores information about all MIDI channels
-	MidiChannelEntry _midiChannels[MILES_MIDI_CHANNEL_COUNT];
+	MidiChannelEntry _midiChannels[MIDI_CHANNEL_COUNT];
 
 	// stores information about all custom timbres
 	MidiCustomTimbreEntry _customTimbres[MILES_MT32_CUSTOMTIMBRE_COUNT];
@@ -416,84 +303,14 @@ private:
 
 	// Queues for Miles SysEx controllers
 	MilesMT32SysExQueueEntry _milesSysExQueues[MILES_CONTROLLER_SYSEX_QUEUE_COUNT];
-
-	// MIDI sources sending messages to this driver.
-	MidiSource _sources[MILES_MAXIMUM_SOURCES];
-
-	struct ActiveNote {
-		int8 source;
-		uint8 channel;
-		uint8 note;
-		bool sustain;
-
-		ActiveNote() : source(0x7F),
-			channel(0xFF),
-			note(0xFF),
-			sustain(false) { }
-	};
-
-	// The maximum number of active notes that have to be tracked for this MIDI device.
-	uint8 _maximumActiveNotes;
-	// Tracks the notes being played by the MIDI device.
-	ActiveNote *_activeNotes;
-
-	/**
-	 * Stores data which is to be transmitted as a SysEx message
-	 * to a MIDI device. Neither data nor length should include
-	 * the SysEx start and stop bytes.
-	 */
-	struct SysExData {
-		byte data[270];
-		uint16 length;
-		SysExData() : length(0) {
-			memset(data, 0, sizeof(data));
-		}
-	};
-
-	// The number of microseconds to wait before sending the
-	// next SysEx message.
-	uint32 _sysExDelay;
-
-	/**
-	 * Queue of SysEx messages that must be sent to the
-	 * MIDI device. Used by processXMIDITimbreChunk to
-	 * send SysEx messages before starting playback of
-	 * a track.
-	 *
-	 * Sending other MIDI messages to the driver should
-	 * be suspended until all SysEx messages in the
-	 * queue have been sent to the MIDI device. Use the
-	 * isReady function to check if the driver is ready
-	 * to receive other messages.
-	 */
-	Common::Queue<SysExData> _sysExQueue;
-
-	// Mutex for write access to the SysEx queue.
-	Common::Mutex _sysExQueueMutex;
-
-	// External timer callback
-	void *_timer_param;
-	Common::TimerManager::TimerProc _timer_proc;
-
-public:
-	// Callback hooked up to the driver wrapped by the
-	// Miles MIDI driver object. Executes onTimer and
-	// the external callback set by the
-	// setTimerCallback function.
-	static void timerCallback(void *data) {
-		MidiDriver_Miles_Midi *driver = (MidiDriver_Miles_Midi *) data;
-		driver->onTimer();
-		if (driver->_timer_proc && driver->_timer_param)
-			driver->_timer_proc(driver->_timer_param);
-	}
 };
 
-extern MidiDriver *MidiDriver_Miles_AdLib_create(const Common::String &filenameAdLib, const Common::String &filenameOPL3, Common::SeekableReadStream *streamAdLib = nullptr, Common::SeekableReadStream *streamOPL3 = nullptr);
+extern MidiDriver_Multisource *MidiDriver_Miles_AdLib_create(const Common::String &filenameAdLib, const Common::String &filenameOPL3, Common::SeekableReadStream *streamAdLib = nullptr, Common::SeekableReadStream *streamOPL3 = nullptr);
 
 extern MidiDriver_Miles_Midi *MidiDriver_Miles_MT32_create(const Common::String &instrumentDataFilename);
 
 extern MidiDriver_Miles_Midi *MidiDriver_Miles_MIDI_create(MusicType midiType, const Common::String &instrumentDataFilename);
-
+/** @} */
 } // End of namespace Audio
 
 #endif // AUDIO_MILES_MIDIDRIVER_H
