@@ -126,6 +126,11 @@ public:
 	 */
 	Timestamp getElapsedTime();
 
+	/**
+	 * Replaces the channel's stream with a version that loops indefinitely.
+	 */
+	void loop();
+
 	/**
 	 * Queries the channel's sound type.
 	 */
@@ -397,6 +402,16 @@ Timestamp MixerImpl::getElapsedTime(SoundHandle handle) {
 	return _channels[index]->getElapsedTime();
 }
 
+void MixerImpl::loopChannel(SoundHandle handle) {
+	Common::StackLock lock(_mutex);
+
+	const int index = handle._val % NUM_CHANNELS;
+	if (!_channels[index] || _channels[index]->getHandle()._val != handle._val)
+		return;
+
+	_channels[index]->loop();
+}
+
 void MixerImpl::pauseAll(bool paused) {
 	Common::StackLock lock(_mutex);
 	for (int i = 0; i != NUM_CHANNELS; i++) {
@@ -497,11 +512,11 @@ int MixerImpl::getVolumeForSoundType(SoundType type) const {
 #pragma mark -
 
 Channel::Channel(Mixer *mixer, Mixer::SoundType type, AudioStream *stream,
-                 DisposeAfterUse::Flag autofreeStream, bool reverseStereo, int id, bool permanent)
-    : _type(type), _mixer(mixer), _id(id), _permanent(permanent), _volume(Mixer::kMaxChannelVolume),
-      _balance(0), _pauseLevel(0), _samplesConsumed(0), _samplesDecoded(0), _mixerTimeStamp(0),
-      _pauseStartTime(0), _pauseTime(0), _converter(0), _volL(0), _volR(0),
-      _stream(stream, autofreeStream) {
+				 DisposeAfterUse::Flag autofreeStream, bool reverseStereo, int id, bool permanent)
+	: _type(type), _mixer(mixer), _id(id), _permanent(permanent), _volume(Mixer::kMaxChannelVolume),
+	  _balance(0), _pauseLevel(0), _samplesConsumed(0), _samplesDecoded(0), _mixerTimeStamp(0),
+	  _pauseStartTime(0), _pauseTime(0), _converter(0), _volL(0), _volR(0),
+	  _stream(stream, autofreeStream) {
 	assert(mixer);
 	assert(stream);
 
@@ -604,6 +619,18 @@ Timestamp Channel::getElapsedTime() {
 	return ts;
 }
 
+void Channel::loop() {
+	assert(_stream);
+
+	Audio::RewindableAudioStream *rewindableStream = dynamic_cast<RewindableAudioStream *>(_stream.get());
+	if (rewindableStream) {
+		DisposeAfterUse::Flag dispose = _stream.getDispose();
+		_stream.disownPtr();
+		Audio::LoopingAudioStream *loopingStream = new Audio::LoopingAudioStream(rewindableStream, 0, dispose, false);
+		_stream.reset(loopingStream, DisposeAfterUse::YES);
+	}
+}
+
 int Channel::mix(int16 *data, uint len) {
 	assert(_stream);
 
