@@ -29,6 +29,14 @@
 
 namespace Audio {
 
+/**
+ * @defgroup audio_mixer_intern Mixer implementation
+ * @ingroup audio
+ *
+ * @brief The (default) implementation of the ScummVM audio mixing subsystem.
+ * @{
+ */
+
 /**
  * The (default) implementation of the ScummVM audio mixing subsystem.
  *
@@ -51,7 +59,7 @@ namespace Audio {
 class MixerImpl : public Mixer {
 private:
 	enum {
-		NUM_CHANNELS = 16
+		NUM_CHANNELS = 32
 	};
 
 	Common::Mutex _mutex;
@@ -78,6 +86,8 @@ public:
 
 	virtual bool isReady() const { Common::StackLock lock(_mutex); return _mixerReady; }
 
+	virtual Common::Mutex &mutex() { return _mutex; }
+
 	virtual void playStream(
 		SoundType type,
 		SoundHandle *handle,
@@ -111,6 +121,8 @@ public:
 	virtual uint32 getSoundElapsedTime(SoundHandle handle);
 	virtual Timestamp getElapsedTime(SoundHandle handle);
 
+	virtual void loopChannel(SoundHandle handle);
+
 	virtual bool hasActiveChannelOfType(SoundType type);
 
 	virtual void setVolumeForSoundType(SoundType type, int volume);
@@ -141,7 +153,7 @@ public:
 	void setReady(bool ready);
 };
 
-
+/** @} */
 } // End of namespace Audio
 
 #endif
