@@ -71,7 +71,7 @@
 
 namespace Modules {
 
-class ModXmS3mStream : public Audio::AudioStream {
+class ModXmS3mStream : public Audio::RewindableAudioStream {
 private:
 	struct Channel {
 		Instrument *instrument;
@@ -100,6 +100,8 @@ private:
 	int8 **_playCount;
 	Channel *_channels;
 	int _dataLeft;
+	int _initialDataLength;
+	bool _finished;
 
 	// mix buffer to keep a partially consumed decoded tick.
 	int *_mixBuffer;
@@ -111,18 +113,19 @@ private:
 	static const int16 sinetable[];
 
 	int calculateDuration();
-	int calculateTickLength() { return (_sampleRate * 5) / (_tempo * 2); }
-	int calculateMixBufLength() { return (calculateTickLength() + 65) * 4; }
+	int calculateTickLength() const { return (_sampleRate * 5) / (_tempo * 2); }
+	int calculateMixBufLength() const { return (calculateTickLength() + 65) * 4; }
 
 	int initPlayCount(int8 **playCount);
 	void setSequencePos(int pos);
 	int tick();
 	void updateRow();
 	int seek(int samplePos);
+	bool rewind() override { setSequencePos(0); _dataLeft = _initialDataLength; return true; }
 
 	// Sample
 	void downsample(int *buf, int count);
-	void resample(Channel &channel, int *mixBuf, int offset, int count, int sampleRate);
+	void resample(const Channel &channel, int *mixBuf, int offset, int count, int sampleRate);
 	void updateSampleIdx(Channel &channel, int count, int sampleRate);
 
 	// Channel
@@ -147,8 +150,8 @@ private:
 
 	// Envelopes
 	void updateEnvelopes(Channel &channel);
-	int envelopeNextTick(Envelope &envelope, int tick, int keyOn);
-	int calculateAmpl(Envelope &envelope, int tick);
+	int envelopeNextTick(const Envelope &envelope, int tick, int keyOn);
+	int calculateAmpl(const Envelope &envelope, int tick);
 
 	// Read stream
 	int getAudio(int *mixBuf);
@@ -159,12 +162,12 @@ public:
 	bool loadSuccess() const { return _loadSuccess; }
 
 	// Implement virtual functions
-	virtual int readBuffer(int16 *buffer, const int numSamples);
-	virtual bool isStereo() const { return true; }
-	virtual int getRate() const { return _sampleRate; }
-	virtual bool endOfData() const { return _dataLeft <= 0; }
+	virtual int readBuffer(int16 *buffer, const int numSamples) override;
+	virtual bool isStereo() const override { return true; }
+	virtual int getRate() const override { return _sampleRate; }
+	virtual bool endOfData() const override { return _dataLeft <= 0; }
 
-	ModXmS3mStream(Common::SeekableReadStream *stream, int rate, int interpolation);
+	ModXmS3mStream(Common::SeekableReadStream *stream, int initialPos, int rate, int interpolation);
 	~ModXmS3mStream();
 };
 
@@ -176,26 +179,20 @@ const short ModXmS3mStream::sinetable[] = {
 		255, 253, 250, 244, 235, 224, 212, 197, 180, 161, 141, 120,  97,  74,  49,  24
 	};
 
-ModXmS3mStream::ModXmS3mStream(Common::SeekableReadStream *stream, int rate, int interpolation) {
-	_rampBuf = nullptr;
-	_playCount = nullptr;
-	_channels = nullptr;
-
+ModXmS3mStream::ModXmS3mStream(Common::SeekableReadStream *stream, int initialPos, int rate, int interpolation) :
+	_rampBuf(nullptr), _playCount(nullptr), _channels(nullptr),
+	_mixBuffer(nullptr), _sampleRate(rate), _interpolation(interpolation),
+	_seqPos(initialPos), _mixBufferSamples(0), _finished(false) {
 	if (!_module.load(*stream)) {
 		warning("It's not a valid Mod/S3m/Xm sound file");
 		_loadSuccess = false;
 		return;
 	}
 
-	// assign values
 	_loadSuccess = true;
-	_mixBufferSamples = 0;
-	_sampleRate = rate;
-	_interpolation = interpolation;
 	_rampBuf = new int[128];
 	_channels = new Channel[_module.numChannels];
-	_dataLeft = calculateDuration() * 4; // stereo and uint16
-	_mixBuffer = nullptr;
+	_initialDataLength = _dataLeft = calculateDuration() * 4; // stereo and uint16
 }
 
 ModXmS3mStream::~ModXmS3mStream() {
@@ -991,13 +988,18 @@ void ModXmS3mStream::updateRow() {
 		_nextRow = 0;
 	}
 	if (_breakPos >= 0) {
+		_finished = false;
 		if (_breakPos >= _module.sequenceLen) {
+			// Hit the end.
 			_breakPos = _nextRow = 0;
+			_finished = true;
 		}
 		while (_module.sequence[_breakPos] >= _module.numPatterns) {
 			_breakPos++;
 			if (_breakPos >= _module.sequenceLen) {
+				// Hit the end.
 				_breakPos = _nextRow = 0;
+				_finished = true;
 			}
 		}
 		_seqPos = _breakPos;
@@ -1006,7 +1008,7 @@ void ModXmS3mStream::updateRow() {
 		}
 		_breakPos = -1;
 	}
-	Pattern &pattern = _module.patterns[_module.sequence[_seqPos]];
+	const Pattern &pattern = _module.patterns[_module.sequence[_seqPos]];
 	_row = _nextRow;
 	if (_row >= pattern.numRows) {
 		_row = 0;
@@ -1109,7 +1111,7 @@ void ModXmS3mStream::updateRow() {
 	}
 }
 
-int ModXmS3mStream::envelopeNextTick(Envelope &envelope, int currentTick, int keyOn) {
+int ModXmS3mStream::envelopeNextTick(const Envelope &envelope, int currentTick, int keyOn) {
 	int nextTick = currentTick + 1;
 	if (envelope.looped && nextTick >= envelope.loopEndTick) {
 		nextTick = envelope.loopStartTick;
@@ -1120,7 +1122,7 @@ int ModXmS3mStream::envelopeNextTick(Envelope &envelope, int currentTick, int ke
 	return nextTick;
 }
 
-int ModXmS3mStream::calculateAmpl(Envelope &envelope, int currentTick) {
+int ModXmS3mStream::calculateAmpl(const Envelope &envelope, int currentTick) {
 	int idx, point, dt, da;
 	int ampl = envelope.pointsAmpl[envelope.numPoints - 1];
 	if (currentTick < envelope.pointsTick[envelope.numPoints - 1]) {
@@ -1141,6 +1143,7 @@ int ModXmS3mStream::calculateAmpl(Envelope &envelope, int currentTick) {
 int ModXmS3mStream::calculateDuration() {
 	int count = 0, duration = 0;
 	setSequencePos(0);
+	// Count the length of sequences until we hit a bit we've played before (or the end).
 	while (count < 1) {
 		duration += calculateTickLength();
 		count = tick();
@@ -1166,7 +1169,7 @@ int ModXmS3mStream::seek(int samplePos) {
 	return currentPos;
 }
 
-void ModXmS3mStream::resample(Channel &channel, int *mixBuf, int offset, int count, int sampleRate) {
+void ModXmS3mStream::resample(const Channel &channel, int *mixBuf, int offset, int count, int sampleRate) {
 	Sample *sample = channel.sample;
 	int lGain = 0, rGain = 0, samIdx = 0, samFra = 0, step = 0;
 	int loopLen = 0, loopEnd = 0, outIdx = 0, outEnd = 0, y = 0, m = 0, c = 0;
@@ -1285,7 +1288,7 @@ int ModXmS3mStream::getAudio(int *mixBuf) {
 
 int ModXmS3mStream::readBuffer(int16 *buffer, const int numSamples) {
 	int samplesRead = 0;
-	while (samplesRead < numSamples && _dataLeft >= 0) {
+	while (samplesRead < numSamples && _dataLeft > 0) {
 		int *mixBuf = new int[calculateMixBufLength()];
 		int samples = getAudio(mixBuf);
 		if (samplesRead + samples > numSamples) {
@@ -1305,9 +1308,21 @@ int ModXmS3mStream::readBuffer(int16 *buffer, const int numSamples) {
 			*buffer++ = ampl;
 		}
 		samplesRead += samples;
+
+		_dataLeft -= samples * 2;
+
 		delete []mixBuf; // free
 	}
-	_dataLeft -= samplesRead * 2;
+
+	if (_dataLeft <= 0 && !_finished) {
+		//
+		// The original data length calculation was used up but didn't hit
+		// the end, so this mod loops.
+		// From here can just reset data left to some sensible value, but
+		// it's actually infinite and we'll come back here.
+		//
+		_dataLeft = _initialDataLength;
+	}
 
 	return samplesRead;
 }
@@ -1347,8 +1362,8 @@ void ModXmS3mStream::setSequencePos(int pos) {
 
 namespace Audio {
 
-AudioStream *makeModXmS3mStream(Common::SeekableReadStream *stream, DisposeAfterUse::Flag disposeAfterUse, int rate, int interpolation) {
-	Modules::ModXmS3mStream *soundStream = new Modules::ModXmS3mStream(stream, rate, interpolation);
+RewindableAudioStream *makeModXmS3mStream(Common::SeekableReadStream *stream, DisposeAfterUse::Flag disposeAfterUse, int initialPos, int rate, int interpolation) {
+	Modules::ModXmS3mStream *soundStream = new Modules::ModXmS3mStream(stream, initialPos, rate, interpolation);
 
 	if (disposeAfterUse == DisposeAfterUse::YES)
 		delete stream;
@@ -1358,7 +1373,7 @@ AudioStream *makeModXmS3mStream(Common::SeekableReadStream *stream, DisposeAfter
 		return nullptr;
 	}
 
-	return (AudioStream *)soundStream;
+	return soundStream;
 }
 
 } // End of namespace Audio
