@@ -1,5 +1,5 @@
 /* Copyright (C) 2003, 2004, 2005, 2006, 2008, 2009 Dean Beeler, Jerome Fisher
- * Copyright (C) 2011-2020 Dean Beeler, Jerome Fisher, Sergey V. Mikayev
+ * Copyright (C) 2011-2021 Dean Beeler, Jerome Fisher, Sergey V. Mikayev
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -45,6 +45,8 @@ typedef enum {
 	MT32EMU_RC_OK = 0,
 	MT32EMU_RC_ADDED_CONTROL_ROM = 1,
 	MT32EMU_RC_ADDED_PCM_ROM = 2,
+	MT32EMU_RC_ADDED_PARTIAL_CONTROL_ROM = 3,
+	MT32EMU_RC_ADDED_PARTIAL_PCM_ROM = 4,
 
 	/* Definite error occurred. */
 	MT32EMU_RC_ROM_NOT_IDENTIFIED = -1,
@@ -53,6 +55,8 @@ typedef enum {
 	MT32EMU_RC_MISSING_ROMS = -4,
 	MT32EMU_RC_NOT_OPENED = -5,
 	MT32EMU_RC_QUEUE_FULL = -6,
+	MT32EMU_RC_ROMS_NOT_PAIRABLE = -7,
+	MT32EMU_RC_MACHINE_NOT_IDENTIFIED = -8,
 
 	/* Undefined error occurred. */
 	MT32EMU_RC_FAILED = -100
@@ -122,7 +126,8 @@ typedef enum {
 	MT32EMU_SERVICE_VERSION_1 = 1,
 	MT32EMU_SERVICE_VERSION_2 = 2,
 	MT32EMU_SERVICE_VERSION_3 = 3,
-	MT32EMU_SERVICE_VERSION_CURRENT = MT32EMU_SERVICE_VERSION_3
+	MT32EMU_SERVICE_VERSION_4 = 4,
+	MT32EMU_SERVICE_VERSION_CURRENT = MT32EMU_SERVICE_VERSION_4
 } mt32emu_service_version;
 
 /* === Report Handler Interface === */
@@ -312,6 +317,16 @@ typedef union mt32emu_service_i mt32emu_service_i;
 	void (*preallocateReverbMemory)(mt32emu_const_context context, const mt32emu_boolean enabled); \
 	void (*configureMIDIEventQueueSysexStorage)(mt32emu_const_context context, const mt32emu_bit32u storage_buffer_size);
 
+#define MT32EMU_SERVICE_I_V4 \
+	size_t (*getMachineIDs)(const char **machine_ids, size_t machine_ids_size); \
+	size_t (*getROMIDs)(const char **rom_ids, size_t rom_ids_size, const char *machine_id); \
+	mt32emu_return_code (*identifyROMData)(mt32emu_rom_info *rom_info, const mt32emu_bit8u *data, size_t data_size, const char *machine_id); \
+	mt32emu_return_code (*identifyROMFile)(mt32emu_rom_info *rom_info, const char *filename, const char *machine_id); \
+\
+	mt32emu_return_code (*mergeAndAddROMData)(mt32emu_context context, const mt32emu_bit8u *part1_data, size_t part1_data_size, const mt32emu_sha1_digest *part1_sha1_digest, const mt32emu_bit8u *part2_data, size_t part2_data_size, const mt32emu_sha1_digest *part2_sha1_digest); \
+	mt32emu_return_code (*mergeAndAddROMFiles)(mt32emu_context context, const char *part1_filename, const char *part2_filename); \
+	mt32emu_return_code (*addMachineROMFile)(mt32emu_context context, const char *machine_id, const char *filename);
+
 typedef struct {
 	MT32EMU_SERVICE_I_V0
 } mt32emu_service_i_v0;
@@ -334,6 +349,14 @@ typedef struct {
 	MT32EMU_SERVICE_I_V3
 } mt32emu_service_i_v3;
 
+typedef struct {
+	MT32EMU_SERVICE_I_V0
+	MT32EMU_SERVICE_I_V1
+	MT32EMU_SERVICE_I_V2
+	MT32EMU_SERVICE_I_V3
+	MT32EMU_SERVICE_I_V4
+} mt32emu_service_i_v4;
+
 /**
  * Extensible interface for all the library services.
  * Union intended to view an interface of any subsequent version as any parent interface not requiring a cast.
@@ -344,11 +367,13 @@ union mt32emu_service_i {
 	const mt32emu_service_i_v1 *v1;
 	const mt32emu_service_i_v2 *v2;
 	const mt32emu_service_i_v3 *v3;
+	const mt32emu_service_i_v4 *v4;
 };
 
 #undef MT32EMU_SERVICE_I_V0
 #undef MT32EMU_SERVICE_I_V1
 #undef MT32EMU_SERVICE_I_V2
 #undef MT32EMU_SERVICE_I_V3
+#undef MT32EMU_SERVICE_I_V4
 
 #endif /* #ifndef MT32EMU_C_TYPES_H */
