@@ -23,7 +23,9 @@
 #include "backends/audiocd/default/default-audiocd.h"
 #include "audio/audiostream.h"
 #include "common/config-manager.h"
+#include "common/file.h"
 #include "common/system.h"
+#include "common/util.h"
 
 DefaultAudioCDManager::DefaultAudioCDManager() {
 	_cd.playing = false;
@@ -54,6 +56,45 @@ void DefaultAudioCDManager::close() {
 	stop();
 }
 
+void DefaultAudioCDManager::fillPotentialTrackNames(Common::Array<Common::String> &trackNames, int track) const {
+	trackNames.reserve(4);
+	trackNames.push_back(Common::String::format("track%d", track));
+	trackNames.push_back(Common::String::format("track%02d", track));
+	trackNames.push_back(Common::String::format("track_%d", track));
+	trackNames.push_back(Common::String::format("track_%02d", track));
+}
+
+bool DefaultAudioCDManager::existExtractedCDAudioFiles() {
+	// keep this in sync with STREAM_FILEFORMATS
+	const char *extensions[] = {
+#ifdef USE_VORBIS
+		"ogg",
+#endif
+#ifdef USE_FLAC
+		"fla", "flac",
+#endif
+#ifdef USE_MAD
+		"mp3",
+#endif
+		"m4a",
+		"wav",
+		nullptr
+	};
+
+	Common::Array<Common::String> trackNames;
+	fillPotentialTrackNames(trackNames, 1);
+
+	for (Common::Array<Common::String>::iterator i = trackNames.begin(); i != trackNames.end(); ++i) {
+		for (const char **ext = extensions; *ext; ++ext) {
+			const Common::String &filename = Common::String::format("%s.%s", i->c_str(), *ext);
+			if (Common::File::exists(filename)) {
+				return true;
+			}
+		}
+	}
+	return false;
+}
+
 bool DefaultAudioCDManager::play(int track, int numLoops, int startFrame, int duration, bool onlyEmulate,
 		Audio::Mixer::SoundType soundType) {
 	stop();
@@ -67,13 +108,13 @@ bool DefaultAudioCDManager::play(int track, int numLoops, int startFrame, int du
 		// Try to load the track from a compressed data file, and if found, use
 		// that. If not found, attempt to start regular Audio CD playback of
 		// the requested track.
-		char trackName[2][16];
-		sprintf(trackName[0], "track%d", track);
-		sprintf(trackName[1], "track%02d", track);
+		Common::Array<Common::String> trackNames;
+		fillPotentialTrackNames(trackNames, track);
 		Audio::SeekableAudioStream *stream = 0;
 
-		for (int i = 0; !stream && i < 2; ++i)
-			stream = Audio::SeekableAudioStream::openStreamFile(trackName[i]);
+		for (Common::Array<Common::String>::iterator i = trackNames.begin(); !stream && i != trackNames.end(); ++i) {
+			stream = Audio::SeekableAudioStream::openStreamFile(*i);
+		}
 
 		if (stream != 0) {
 			Audio::Timestamp start = Audio::Timestamp(0, startFrame, 75);
