@@ -178,7 +178,9 @@ void GoogleDriveStorage::printInfo(StorageInfoResponse response) {
 	debug(9, "\nGoogleDriveStorage: user info:");
 	debug(9, "\tname: %s", response.value.name().c_str());
 	debug(9, "\temail: %s", response.value.email().c_str());
-	debug(9, "\tdisk usage: %lu/%lu", response.value.used(), response.value.available());
+	debug(9, "\tdisk usage: %llu/%llu",
+		  (unsigned long long)response.value.used(),
+		  (unsigned long long)response.value.available());
 }
 
 Networking::Request *GoogleDriveStorage::createDirectoryWithParentId(Common::String parentId, Common::String directoryName, BoolCallback callback, Networking::ErrorCallback errorCallback) {
