@@ -27,7 +27,7 @@
 #include "backends/networking/curl/connectionmanager.h"
 #include "common/debug.h"
 #include "common/file.h"
-#include <common/translation.h>
+#include "common/translation.h"
 #include "common/osd_message_queue.h"
 
 namespace Cloud {
@@ -343,13 +343,13 @@ void Storage::directoryDownloadedCallback(FileArrayResponse response) {
 	_downloadFolderRequest = nullptr;
 	_runningRequestsMutex.unlock();
 
-	Common::String message;
+	Common::U32String message;
 	if (response.value.size()) {
-		message = Common::String::format(_("Download complete.\nFailed to download %u files."), response.value.size());
+		message = Common::U32String::format(_("Download complete.\nFailed to download %u files."), response.value.size());
 	} else {
 		message = _("Download complete.");
 	}
-	Common::OSDMessageQueue::instance().addMessage(message.c_str());
+	Common::OSDMessageQueue::instance().addMessage(message);
 }
 
 void Storage::directoryDownloadedErrorCallback(Networking::ErrorResponse error) {
