@@ -30,7 +30,7 @@
 
 class GtkDialogManager : public Common::DialogManager {
 public:
-	virtual DialogResult showFileBrowser(const char *title, Common::FSNode &choice, bool isDirBrowser);
+	virtual DialogResult showFileBrowser(const Common::U32String &title, Common::FSNode &choice, bool isDirBrowser);
 };
 
 #endif
