@@ -40,6 +40,19 @@
 #include <Foundation/NSURL.h>
 #include <Foundation/NSAutoreleasePool.h>
 
+#if __MAC_OS_X_VERSION_MIN_REQUIRED < 101400
+
+    #ifndef NSControlStateValueOff
+      #define NSControlStateValueOff NSOffState
+    #endif
+
+    #ifndef NSControlStateValueOn
+      #define NSControlStateValueOn NSOnState
+    #endif
+
+#define NSButtonTypeSwitch NSSwitchButton
+#endif
+
 
 @interface BrowserDialogPresenter : NSObject {
 @public
@@ -73,25 +86,18 @@
 	NSButton *showHiddenFilesButton = 0;
 	if ([panel respondsToSelector:@selector(setShowsHiddenFiles:)]) {
 		showHiddenFilesButton = [[NSButton alloc] init];
-		[showHiddenFilesButton setButtonType:NSSwitchButton];
+		[showHiddenFilesButton setButtonType:NSButtonTypeSwitch];
 
-#ifdef USE_TRANSLATION
-		CFStringRef encStr = CFStringCreateWithCString(NULL, TransMan.getCurrentCharset().c_str(), kCFStringEncodingASCII);
-		CFStringEncoding stringEncoding = CFStringConvertIANACharSetNameToEncoding(encStr);
-		CFRelease(encStr);
-#else
-		CFStringEncoding stringEncoding = kCFStringEncodingASCII;
-#endif
-		CFStringRef hiddenFilesString = CFStringCreateWithCString(0, _("Show hidden files"), stringEncoding);
+		CFStringRef hiddenFilesString = CFStringCreateWithCString(0, _("Show hidden files").encode().c_str(), kCFStringEncodingUTF8);
 		[showHiddenFilesButton setTitle:(NSString*)hiddenFilesString];
 		CFRelease(hiddenFilesString);
 
 		[showHiddenFilesButton sizeToFit];
 		if (ConfMan.getBool("gui_browser_show_hidden", Common::ConfigManager::kApplicationDomain)) {
-			[showHiddenFilesButton setState:NSOnState];
+			[showHiddenFilesButton setState:NSControlStateValueOn];
 			[panel setShowsHiddenFiles: YES];
 		} else {
-			[showHiddenFilesButton setState:NSOffState];
+			[showHiddenFilesButton setState:NSControlStateValueOff];
 			[panel setShowsHiddenFiles: NO];
 		}
 		[panel setAccessoryView:showHiddenFilesButton];
@@ -117,7 +123,7 @@
 }
 
 - (IBAction) showHiddenFiles : (id) sender {
-	if ([sender state] == NSOnState) {
+	if ([sender state] == NSControlStateValueOn) {
 		[_panel setShowsHiddenFiles: YES];
 		ConfMan.setBool("gui_browser_show_hidden", true, Common::ConfigManager::kApplicationDomain);
 	} else {
@@ -128,22 +134,15 @@
 
 @end
 
-Common::DialogManager::DialogResult MacOSXDialogManager::showFileBrowser(const char *title, Common::FSNode &choice, bool isDirBrowser) {
-
+Common::DialogManager::DialogResult MacOSXDialogManager::showFileBrowser(const Common::U32String &title, Common::FSNode &choice, bool isDirBrowser) {
 	DialogResult result = kDialogCancel;
 
 	// Get current encoding
-#ifdef USE_TRANSLATION
-	CFStringRef encStr = CFStringCreateWithCString(NULL, TransMan.getCurrentCharset().c_str(), kCFStringEncodingASCII);
-	CFStringEncoding stringEncoding = CFStringConvertIANACharSetNameToEncoding(encStr);
-	CFRelease(encStr);
-#else
-	CFStringEncoding stringEncoding = kCFStringEncodingASCII;
-#endif
+	CFStringEncoding stringEncoding = kCFStringEncodingUTF8;
 
 	// Convert labels to NSString
-	CFStringRef titleRef = CFStringCreateWithCString(0, title, stringEncoding);
-	CFStringRef chooseRef = CFStringCreateWithCString(0, _("Choose"), stringEncoding);
+	CFStringRef titleRef = CFStringCreateWithCString(0, title.encode().c_str(), stringEncoding);
+	CFStringRef chooseRef = CFStringCreateWithCString(0, _("Choose").encode().c_str(), stringEncoding);
 
 	beginDialog();
 
