@@ -67,6 +67,7 @@ public:
 	virtual bool pollEvent(Common::Event &event) override;
 	virtual void pushEvent(const Common::Event &event) override;
 	virtual void purgeMouseEvents() override;
+	virtual void purgeKeyboardEvents() override;
 
 	virtual Common::Point getMousePos() const override { return _mousePos; }
 	virtual int getButtonState() const override { return _buttonState; }
@@ -74,9 +75,7 @@ public:
 	virtual int shouldQuit() const override { return _shouldQuit; }
 	virtual int shouldReturnToLauncher() const override { return _shouldReturnToLauncher; }
 	virtual void resetReturnToLauncher() override { _shouldReturnToLauncher = false; }
-#ifdef FORCE_RETURN_TO_LAUNCHER
 	virtual void resetQuit() override { _shouldQuit = false; }
-#endif
 
 	Common::Keymapper *getKeymapper() override { return _keymapper; }
 	Common::Keymap *getGlobalKeymap() override;
