@@ -32,9 +32,9 @@
  */
 class POSIXFilesystemFactory : public FilesystemFactory {
 protected:
-	virtual AbstractFSNode *makeRootFileNode() const;
-	virtual AbstractFSNode *makeCurrentDirectoryFileNode() const;
-	virtual AbstractFSNode *makeFileNodePath(const Common::String &path) const;
+	virtual AbstractFSNode *makeRootFileNode() const override;
+	virtual AbstractFSNode *makeCurrentDirectoryFileNode() const override;
+	virtual AbstractFSNode *makeFileNodePath(const Common::String &path) const override;
 };
 
 #endif /*POSIX_FILESYSTEM_FACTORY_H*/
