@@ -28,12 +28,21 @@
 /**
  * A file input / output stream using POSIX interfaces
  */
-class PosixIoStream : public StdioStream {
+class PosixIoStream final : public StdioStream {
 public:
+#if defined(ANDROID_PLAIN_PORT)
+	bool createdWithSAF;
+	Common::String hackyfilename;
+#endif
+
 	static PosixIoStream *makeFromPath(const Common::String &path, bool writeMode);
 	PosixIoStream(void *handle);
+#if defined(ANDROID_PLAIN_PORT)
+	PosixIoStream(void *handle, bool bCreatedWithSAF, Common::String sHackyFilename);
+	~PosixIoStream() override;
+#endif
 
-	int32 size() const override;
+	int64 size() const override;
 };
 
 #endif
