@@ -30,7 +30,7 @@
  *
  * Parts of this class are documented in the base interface class, AbstractFSNode.
  */
-class RISCOSFilesystemNode : public AbstractFSNode {
+class RISCOSFilesystemNode final : public AbstractFSNode {
 protected:
 	Common::String _displayName;
 	Common::String _nativePath;
@@ -54,21 +54,21 @@ public:
 	 */
 	RISCOSFilesystemNode(const Common::String &path);
 
-	virtual bool exists() const;
-	virtual Common::String getDisplayName() const { return _displayName; }
-	virtual Common::String getName() const { return _displayName; }
-	virtual Common::String getPath() const { return _path; }
-	virtual bool isDirectory() const { return _isDirectory; }
-	virtual bool isReadable() const;
-	virtual bool isWritable() const;
+	virtual bool exists() const override;
+	virtual Common::U32String getDisplayName() const override { return _displayName; }
+	virtual Common::String getName() const override { return _displayName; }
+	virtual Common::String getPath() const override { return _path; }
+	virtual bool isDirectory() const override { return _isDirectory; }
+	virtual bool isReadable() const override;
+	virtual bool isWritable() const override;
 
-	virtual AbstractFSNode *getChild(const Common::String &n) const;
-	virtual bool getChildren(AbstractFSList &list, ListMode mode, bool hidden) const;
-	virtual AbstractFSNode *getParent() const;
+	virtual AbstractFSNode *getChild(const Common::String &n) const override;
+	virtual bool getChildren(AbstractFSList &list, ListMode mode, bool hidden) const override;
+	virtual AbstractFSNode *getParent() const override;
 
-	virtual Common::SeekableReadStream *createReadStream();
-	virtual Common::WriteStream *createWriteStream();
-	virtual bool createDirectory();
+	virtual Common::SeekableReadStream *createReadStream() override;
+	virtual Common::SeekableWriteStream *createWriteStream() override;
+	virtual bool createDirectory() override;
 private:
 	/**
 	 * Tests and sets the _isValid and _isDirectory flags, using OS_File 20.
