@@ -27,7 +27,7 @@
 
 #include "backends/graphics/surfacesdl/surfacesdl-graphics.h"
 
-class MaemoSdlGraphicsManager : public SurfaceSdlGraphicsManager {
+class MaemoSdlGraphicsManager final : public SurfaceSdlGraphicsManager {
 public:
 	MaemoSdlGraphicsManager(SdlEventSource *sdlEventSource, SdlWindow *window);
 
