@@ -79,6 +79,14 @@ public:
 	virtual bool setStretchMode(int mode) override;
 	virtual int getStretchMode() const override;
 
+#ifdef USE_SCALERS
+	virtual uint getDefaultScaler() const override;
+	virtual uint getDefaultScaleFactor() const override;
+	virtual bool setScaler(uint mode, int factor) override;
+	virtual uint getScaler() const override;
+	virtual uint getScaleFactor() const override;
+#endif
+
 	virtual void beginGFXTransaction() override;
 	virtual OSystem::TransactionError endGFXTransaction() override;
 
@@ -157,13 +165,14 @@ protected:
 	/**
 	 * Create a surface with the specified pixel format.
 	 *
-	 * @param format    The pixel format the Surface object should accept as
-	 *                  input.
-	 * @param wantAlpha For CLUT8 surfaces this marks whether an alpha
-	 *                  channel should be used.
+	 * @param format     The pixel format the Surface object should accept as
+	 *                   input.
+	 * @param wantAlpha  For CLUT8 surfaces this marks whether an alpha
+	 *                   channel should be used.
+	 * @param wantScaler Whether or not a software scaler should be used.
 	 * @return A pointer to the surface or nullptr on failure.
 	 */
-	Surface *createSurface(const Graphics::PixelFormat &format, bool wantAlpha = false);
+	Surface *createSurface(const Graphics::PixelFormat &format, bool wantAlpha = false, bool wantScaler = false);
 
 	//
 	// Transaction support
@@ -173,7 +182,8 @@ protected:
 #ifdef USE_RGB_COLOR
 		    gameFormat(),
 #endif
-		    aspectRatioCorrection(false), graphicsMode(GFX_OPENGL), filtering(true) {
+		    aspectRatioCorrection(false), graphicsMode(GFX_OPENGL), filtering(true),
+		    scalerIndex(0), scaleFactor(1) {
 		}
 
 		bool valid;
@@ -186,6 +196,9 @@ protected:
 		int graphicsMode;
 		bool filtering;
 
+		uint scalerIndex;
+		int scaleFactor;
+
 		bool operator==(const VideoState &right) {
 			return gameWidth == right.gameWidth && gameHeight == right.gameHeight
 #ifdef USE_RGB_COLOR
@@ -310,6 +323,7 @@ protected:
 	bool getGLPixelFormat(const Graphics::PixelFormat &pixelFormat, GLenum &glIntFormat, GLenum &glFormat, GLenum &glType) const;
 
 	virtual bool gameNeedsAspectRatioCorrection() const override;
+	virtual int getGameRenderScale() const override;
 	virtual void recalculateDisplayAreas() override;
 	virtual void handleResizeImpl(const int width, const int height) override;
 
@@ -414,6 +428,13 @@ protected:
 	 */
 	byte _cursorPalette[3 * 256];
 
+#ifdef USE_SCALERS
+	/**
+	 * The list of scaler plugins
+	 */
+	const PluginList &_scalerPlugins;
+#endif
+
 #ifdef USE_OSD
 	//
 	// OSD
