@@ -31,7 +31,7 @@
 
 class SdlEventSource;
 
-#if !defined(_WIN32_WCE) && !defined(__SYMBIAN32__)
+#ifndef __SYMBIAN32__
 #define USE_OSD	1
 #endif
 
@@ -94,10 +94,11 @@ public:
 	 */
 	virtual bool notifyMousePosition(Common::Point &mouse);
 
-	virtual bool showMouse(const bool visible) override;
+	virtual bool showMouse(bool visible) override;
+	virtual bool lockMouse(bool lock) override;
 
 	virtual bool saveScreenshot(const Common::String &filename) const { return false; }
-	void saveScreenshot();
+	void saveScreenshot() override;
 
 	// Override from Common::EventObserver
 	virtual bool notifyEvent(const Common::Event &event) override;
@@ -134,7 +135,25 @@ public:
 
 	virtual void initSizeHint(const Graphics::ModeList &modes) override;
 
+	Common::Keymap *getKeymap();
+
 protected:
+	enum CustomEventAction {
+		kActionToggleFullscreen = 100,
+		kActionToggleMouseCapture,
+		kActionSaveScreenshot,
+		kActionToggleAspectRatioCorrection,
+		kActionToggleFilteredScaling,
+		kActionCycleStretchMode,
+		kActionIncreaseScaleFactor,
+		kActionDecreaseScaleFactor,
+		kActionNextScaleFilter,
+		kActionPreviousScaleFilter
+	};
+
+	/** Obtain the user configured fullscreen resolution, or default to the desktop resolution */
+	Common::Rect getPreferredFullscreenResolution();
+
 	virtual int getGraphicsModeScale(int mode) const = 0;
 
 	bool defaultGraphicsModeConfig() const;
@@ -147,7 +166,7 @@ protected:
 	void getWindowSizeFromSdl(int *width, int *height) const {
 #if SDL_VERSION_ATLEAST(2, 0, 0)
 		assert(_window);
-		SDL_GetWindowSize(_window->getSDLWindow(), width, height);
+		SDL_GL_GetDrawableSize(_window->getSDLWindow(), width, height);
 #else
 		assert(_hwScreen);
 
@@ -163,7 +182,7 @@ protected:
 
 	virtual void setSystemMousePosition(const int x, const int y) override;
 
-	virtual void handleResizeImpl(const int width, const int height, const int xdpi, const int ydpi) override;
+	virtual void handleResizeImpl(const int width, const int height) override;
 
 #if SDL_VERSION_ATLEAST(2, 0, 0)
 public:
