@@ -26,7 +26,7 @@
 
 namespace Common {
 
-Action::Action(const char *i, const String &des) :
+Action::Action(const char *i, const U32String &des) :
 		id(i),
 		description(des),
 		_shouldTriggerOnKbdRepeats(false) {
