@@ -33,7 +33,7 @@
 
 namespace Common {
 
-Keymap::Keymap(KeymapType type, const String &id, const String &description) :
+Keymap::Keymap(KeymapType type, const String &id, const U32String &description) :
 		_type(type),
 		_id(id),
 		_description(description),
@@ -44,6 +44,17 @@ Keymap::Keymap(KeymapType type, const String &id, const String &description) :
 
 }
 
+Keymap::Keymap(KeymapType type, const String &id, const String &description) :
+		_type(type),
+		_id(id),
+		_description(U32String(description)),
+		_enabled(true),
+		_configDomain(nullptr),
+		_hardwareInputSet(nullptr),
+		_backendDefaultBindings(nullptr) {
+
+}
+
 Keymap::~Keymap() {
 	for (ActionArray::iterator it = _actions.begin(); it != _actions.end(); ++it)
 		delete *it;
@@ -57,7 +68,7 @@ void Keymap::addAction(Action *action) {
 }
 
 void Keymap::registerMapping(Action *action, const HardwareInput &hwInput) {
-	ActionArray &actionArray = _hwActionMap.getVal(hwInput);
+	ActionArray &actionArray = _hwActionMap.getOrCreateVal(hwInput);
 
 	// Don't allow an input to map to the same action multiple times
 	ActionArray::const_iterator found = find(actionArray.begin(), actionArray.end(), action);
@@ -129,8 +140,8 @@ Keymap::KeymapMatch Keymap::getMappedActions(const Event &event, ActionArray &ac
 	case EVENT_KEYDOWN:
 	case EVENT_KEYUP: {
 		KeyState normalizedKeystate = KeyboardHardwareInputSet::normalizeKeyState(event.kbd);
-		HardwareInput hardwareInput = HardwareInput::createKeyboard("", normalizedKeystate, "");
-		actions.push_back(_hwActionMap[hardwareInput]);
+		HardwareInput hardwareInput = HardwareInput::createKeyboard("", normalizedKeystate, U32String());
+		actions.push_back(_hwActionMap.getValOrDefault(hardwareInput));
 		if (!actions.empty()) {
 			return kKeymapMatchExact;
 		}
@@ -150,75 +161,75 @@ Keymap::KeymapMatch Keymap::getMappedActions(const Event &event, ActionArray &ac
 
 			// Lastly check again for matches no non-sticky keyboard modifiers
 			normalizedKeystate.flags &= ~KBD_NON_STICKY;
-			hardwareInput = HardwareInput::createKeyboard("", normalizedKeystate, "");
-			actions.push_back(_hwActionMap[hardwareInput]);
+			hardwareInput = HardwareInput::createKeyboard("", normalizedKeystate, U32String());
+			actions.push_back(_hwActionMap.getValOrDefault(hardwareInput));
 			return actions.empty() ? kKeymapMatchNone : kKeymapMatchPartial;
 		}
 		break;
 	}
 	case EVENT_LBUTTONDOWN:
 	case EVENT_LBUTTONUP: {
-		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_BUTTON_LEFT, "");
-		actions.push_back(_hwActionMap[hardwareInput]);
+		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_BUTTON_LEFT, U32String());
+		actions.push_back(_hwActionMap.getValOrDefault(hardwareInput));
 		break;
 	}
 	case EVENT_RBUTTONDOWN:
 	case EVENT_RBUTTONUP: {
-		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_BUTTON_RIGHT, "");
-		actions.push_back(_hwActionMap[hardwareInput]);
+		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_BUTTON_RIGHT, U32String());
+		actions.push_back(_hwActionMap.getValOrDefault(hardwareInput));
 		break;
 	}
 	case EVENT_MBUTTONDOWN:
 	case EVENT_MBUTTONUP: {
-		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_BUTTON_MIDDLE, "");
-		actions.push_back(_hwActionMap[hardwareInput]);
+		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_BUTTON_MIDDLE, U32String());
+		actions.push_back(_hwActionMap.getValOrDefault(hardwareInput));
 		break;
 	}
 	case Common::EVENT_WHEELUP: {
-		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_WHEEL_UP, "");
-		actions.push_back(_hwActionMap[hardwareInput]);
+		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_WHEEL_UP, U32String());
+		actions.push_back(_hwActionMap.getValOrDefault(hardwareInput));
 		break;
 	}
 	case Common::EVENT_WHEELDOWN: {
-		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_WHEEL_DOWN, "");
-		actions.push_back(_hwActionMap[hardwareInput]);
+		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_WHEEL_DOWN, U32String());
+		actions.push_back(_hwActionMap.getValOrDefault(hardwareInput));
 		break;
 	}
 	case EVENT_X1BUTTONDOWN:
 	case EVENT_X1BUTTONUP: {
-		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_BUTTON_X1, "");
-		actions.push_back(_hwActionMap[hardwareInput]);
+		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_BUTTON_X1, U32String());
+		actions.push_back(_hwActionMap.getValOrDefault(hardwareInput));
 		break;
 	}
 	case EVENT_X2BUTTONDOWN:
 	case EVENT_X2BUTTONUP: {
-		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_BUTTON_X2, "");
-		actions.push_back(_hwActionMap[hardwareInput]);
+		HardwareInput hardwareInput = HardwareInput::createMouse("", MOUSE_BUTTON_X2, U32String());
+		actions.push_back(_hwActionMap.getValOrDefault(hardwareInput));
 		break;
 	}
 	case EVENT_JOYBUTTON_DOWN:
 	case EVENT_JOYBUTTON_UP: {
-		HardwareInput hardwareInput = HardwareInput::createJoystickButton("", event.joystick.button, "");
-		actions.push_back(_hwActionMap[hardwareInput]);
+		HardwareInput hardwareInput = HardwareInput::createJoystickButton("", event.joystick.button, U32String());
+		actions.push_back(_hwActionMap.getValOrDefault(hardwareInput));
 		break;
 	}
 	case EVENT_JOYAXIS_MOTION: {
 		if (event.joystick.position != 0) {
 			bool positiveHalf = event.joystick.position >= 0;
-			HardwareInput hardwareInput = HardwareInput::createJoystickHalfAxis("", event.joystick.axis, positiveHalf, "");
-			actions.push_back(_hwActionMap[hardwareInput]);
+			HardwareInput hardwareInput = HardwareInput::createJoystickHalfAxis("", event.joystick.axis, positiveHalf, U32String());
+			actions.push_back(_hwActionMap.getValOrDefault(hardwareInput));
 		} else {
 			// Axis position zero is part of both half axes, and triggers actions bound to both
-			HardwareInput hardwareInputPos = HardwareInput::createJoystickHalfAxis("", event.joystick.axis, true, "");
-			HardwareInput hardwareInputNeg = HardwareInput::createJoystickHalfAxis("", event.joystick.axis, false, "");
-			actions.push_back(_hwActionMap[hardwareInputPos]);
-			actions.push_back(_hwActionMap[hardwareInputNeg]);
+			HardwareInput hardwareInputPos = HardwareInput::createJoystickHalfAxis("", event.joystick.axis, true, U32String());
+			HardwareInput hardwareInputNeg = HardwareInput::createJoystickHalfAxis("", event.joystick.axis, false, U32String());
+			actions.push_back(_hwActionMap.getValOrDefault(hardwareInputPos));
+			actions.push_back(_hwActionMap.getValOrDefault(hardwareInputNeg));
 		}
 		break;
 	}
 	case EVENT_CUSTOM_BACKEND_HARDWARE: {
-		HardwareInput hardwareInput = HardwareInput::createCustom("", event.customType, "");
-		actions.push_back(_hwActionMap[hardwareInput]);
+		HardwareInput hardwareInput = HardwareInput::createCustom("", event.customType, U32String());
+		actions.push_back(_hwActionMap.getValOrDefault(hardwareInput));
 		break;
 	}
 	default:
@@ -348,10 +359,12 @@ bool Keymap::areMappingsIdentical(const Array<HardwareInput> &mappingsA, const S
 	// Assumes array values are not duplicated, but registerMapping and addDefaultInputMapping ensure that
 
 	uint foundCount = 0;
+	uint validDefaultMappings = 0;
 	for (uint i = 0; i < mappingsB.size(); i++) {
 		// We resolve the hardware input to make sure it is not a default for some hardware we don't have currently
 		HardwareInput mappingB = _hardwareInputSet->findHardwareInput(mappingsB[i]);
 		if (mappingB.type == kHardwareInputTypeInvalid) continue;
+		validDefaultMappings++;
 
 		for (uint j = 0; j < mappingsA.size(); j++) {
 			if (mappingsA[j].id == mappingB.id) {
@@ -361,7 +374,7 @@ bool Keymap::areMappingsIdentical(const Array<HardwareInput> &mappingsA, const S
 		}
 	}
 
-	return foundCount == mappingsA.size();
+	return foundCount == mappingsA.size() && foundCount == validDefaultMappings;
 }
 
 } // End of namespace Common
