@@ -25,7 +25,7 @@
 #include "backends/networking/sdl_net/handlerutils.h"
 #include "backends/networking/sdl_net/localwebserver.h"
 #include "common/translation.h"
-#include <common/callback.h>
+#include "common/callback.h"
 
 namespace Networking {
 
@@ -57,35 +57,35 @@ void CreateDirectoryHandler::handle(Client &client) {
 
 	// check that <path> is not an absolute root
 	if (path == "" || path == "/") {
-		handleError(client, HandlerUtils::toUtf8(_("Can't create directory here!")));
+		handleError(client, Common::convertFromU32String(_("Can't create directory here!")));
 		return;
 	}
 
 	// check that <path> contains no '../'
 	if (HandlerUtils::hasForbiddenCombinations(path)) {
-		handleError(client, HandlerUtils::toUtf8(_("Invalid path!")));
+		handleError(client, Common::convertFromU32String(_("Invalid path!")));
 		return;
 	}
 
 	// transform virtual path to actual file system one
 	Common::String prefixToRemove = "", prefixToAdd = "";
 	if (!transformPath(path, prefixToRemove, prefixToAdd) || path.empty()) {
-		handleError(client, HandlerUtils::toUtf8(_("Invalid path!")));
+		handleError(client, Common::convertFromU32String(_("Invalid path!")));
 		return;
 	}
 
 	// check that <path> exists, is directory and isn't forbidden
 	AbstractFSNode *node = g_system->getFilesystemFactory()->makeFileNodePath(path);
 	if (!HandlerUtils::permittedPath(node->getPath())) {
-		handleError(client, HandlerUtils::toUtf8(_("Invalid path!")));
+		handleError(client, Common::convertFromU32String(_("Invalid path!")));
 		return;
 	}
 	if (!node->exists()) {
-		handleError(client, HandlerUtils::toUtf8(_("Parent directory doesn't exists!")));
+		handleError(client, Common::convertFromU32String(_("Parent directory doesn't exists!")));
 		return;
 	}
 	if (!node->isDirectory()) {
-		handleError(client, HandlerUtils::toUtf8(_("Can't create a directory within a file!")));
+		handleError(client, Common::convertFromU32String(_("Can't create a directory within a file!")));
 		return;
 	}
 
@@ -95,20 +95,20 @@ void CreateDirectoryHandler::handle(Client &client) {
 	node = g_system->getFilesystemFactory()->makeFileNodePath(path + name);
 	if (node->exists()) {
 		if (!node->isDirectory()) {
-			handleError(client, HandlerUtils::toUtf8(_("There is a file with that name in the parent directory!")));
+			handleError(client, Common::convertFromU32String(_("There is a file with that name in the parent directory!")));
 			return;
 		}
 	} else {
 		// create the <directory_name> in <path>
 		if (!node->createDirectory()) {
-			handleError(client, HandlerUtils::toUtf8(_("Failed to create the directory!")));
+			handleError(client, Common::convertFromU32String(_("Failed to create the directory!")));
 			return;
 		}
 	}
 
 	// if json requested, respond with it
 	if (client.queryParameter("answer_json") == "true") {
-		setJsonResponseHandler(client, "success", HandlerUtils::toUtf8(_("Directory created successfully!")));
+		setJsonResponseHandler(client, "success", Common::convertFromU32String(_("Directory created successfully!")));
 		return;
 	}
 
@@ -117,9 +117,9 @@ void CreateDirectoryHandler::handle(Client &client) {
 		client,
 		Common::String::format(
 			"%s<br/><a href=\"files?path=%s\">%s</a>",
-			HandlerUtils::toUtf8(_("Directory created successfully!")).c_str(),
+			Common::convertFromU32String(_("Directory created successfully!")).c_str(),
 			client.queryParameter("path").c_str(),
-			HandlerUtils::toUtf8(_("Back to parent directory")).c_str()
+			Common::convertFromU32String(_("Back to parent directory")).c_str()
 		),
 		(client.queryParameter("ajax") == "true" ? "/filesAJAX?path=" : "/files?path=") +
 		LocalWebserver::urlEncodeQueryParameterValue(client.queryParameter("path"))
