@@ -32,8 +32,9 @@
 #include "gui/widgets/popup.h"
 
 #include "common/translation.h"
+#include "common/ustr.h"
 
-namespace _3DS {
+namespace N3DS {
 
 bool optionMenuOpened = false;
 
@@ -41,16 +42,16 @@ OptionsDialog::OptionsDialog() : GUI::Dialog(20, 20, 280, 200) {
 
 	optionMenuOpened = true;
 
-	new GUI::ButtonWidget(this, 120, 180, 72, 16, _("~C~lose"), 0, GUI::kCloseCmd);
-	new GUI::ButtonWidget(this, 200, 180, 72, 16, _("~S~ave"), 0, GUI::kOKCmd);
+	new GUI::ButtonWidget(this, 120, 180, 72, 16, _("~C~lose"), Common::U32String(), GUI::kCloseCmd);
+	new GUI::ButtonWidget(this, 200, 180, 72, 16, _("~S~ave"), Common::U32String(), GUI::kOKCmd);
 
-	_showCursorCheckbox = new GUI::CheckboxWidget(this, 5, 5, 130, 20, _("Show mouse cursor"), 0, 0, 'T');
+	_showCursorCheckbox = new GUI::CheckboxWidget(this, 5, 5, 130, 20, _("Show mouse cursor"), Common::U32String(), 0, 'T');
 	_showCursorCheckbox->setState(config.showCursor);
 
-	_snapToBorderCheckbox = new GUI::CheckboxWidget(this, 5, 22, 130, 20, _("Snap to edges"), 0, 0, 'T');
+	_snapToBorderCheckbox = new GUI::CheckboxWidget(this, 5, 22, 130, 20, _("Snap to edges"), Common::U32String(), 0, 'T');
 	_snapToBorderCheckbox->setState(config.snapToBorder);
 
-	_stretchToFitCheckbox = new GUI::CheckboxWidget(this, 140, 5, 130, 20, _("Stretch to fit"), 0, 0, 'T');
+	_stretchToFitCheckbox = new GUI::CheckboxWidget(this, 140, 5, 130, 20, _("Stretch to fit"), Common::U32String(), 0, 'T');
 	_stretchToFitCheckbox->setState(config.stretchToFit);
 
 	new GUI::StaticTextWidget(this, 0, 60, 110, 15, _("Use Screen:"), Graphics::kTextAlignRight);
@@ -106,4 +107,4 @@ void OptionsDialog::handleCommand(GUI::CommandSender *sender, uint32 cmd, uint32
 	}
 }
 
-} // namespace _3DS
+} // namespace N3DS
