@@ -72,9 +72,7 @@ void AndroidGraphicsManager::initSurface() {
 	// mode we setup.
 	notifyContextCreate(Graphics::PixelFormat(2, 5, 6, 5, 0, 11, 5, 0, 0), Graphics::PixelFormat(2, 5, 5, 5, 1, 11, 6, 1, 0));
 
-	float dpi[2];
-	JNI::getDPI(dpi);
-	handleResize(JNI::egl_surface_width, JNI::egl_surface_height, dpi[0], dpi[1]);
+	handleResize(JNI::egl_surface_width, JNI::egl_surface_height);
 }
 
 void AndroidGraphicsManager::deinitSurface() {
@@ -97,12 +95,23 @@ void AndroidGraphicsManager::updateScreen() {
 	OpenGLGraphicsManager::updateScreen();
 }
 
-void AndroidGraphicsManager::displayMessageOnOSD(const char *msg) {
-	ENTER("%s", msg);
+void AndroidGraphicsManager::displayMessageOnOSD(const Common::U32String &msg) {
+	ENTER("%s", msg.encode().c_str());
 
 	JNI::displayMessageOnOSD(msg);
 }
 
+float AndroidGraphicsManager::getHiDPIScreenFactor() const {
+	// TODO: Use JNI to get DisplayMetrics.density, which according to the documentation
+	// seems to be what we want.
+	// "On a medium-density screen, DisplayMetrics.density equals 1.0; on a high-density
+	//  screen it equals 1.5; on an extra-high-density screen, it equals 2.0; and on a
+	//  low-density screen, it equals 0.75. This figure is the factor by which you should
+	//  multiply the dp units in order to get the actual pixel count for the current screen."
+
+	return 2.f;
+}
+
 bool AndroidGraphicsManager::loadVideoMode(uint requestedWidth, uint requestedHeight, const Graphics::PixelFormat &format) {
 	ENTER("%d, %d, %s", requestedWidth, requestedHeight, format.toString().c_str());
 
