@@ -45,8 +45,6 @@
 #include "common/config-manager.h"
 #include "common/error.h"
 #include "common/textconsole.h"
-#include "common/translation.h"
-#include "common/encoding.h"
 #include "engines/engine.h"
 
 #include "backends/platform/android/android.h"
@@ -86,11 +84,15 @@ jmethodID JNI::_MID_isConnectionLimited = 0;
 jmethodID JNI::_MID_setWindowCaption = 0;
 jmethodID JNI::_MID_showVirtualKeyboard = 0;
 jmethodID JNI::_MID_showKeyboardControl = 0;
+jmethodID JNI::_MID_showSAFRevokePermsControl = 0;
 jmethodID JNI::_MID_getSysArchives = 0;
-jmethodID JNI::_MID_convertEncoding = 0;
 jmethodID JNI::_MID_getAllStorageLocations = 0;
 jmethodID JNI::_MID_initSurface = 0;
 jmethodID JNI::_MID_deinitSurface = 0;
+jmethodID JNI::_MID_createDirectoryWithSAF = 0;
+jmethodID JNI::_MID_createFileWithSAF = 0;
+jmethodID JNI::_MID_closeFileWithSAF = 0;
+jmethodID JNI::_MID_isDirectoryWritableWithSAF = 0;
 
 jmethodID JNI::_MID_EGL10_eglSwapBuffers = 0;
 
@@ -117,7 +119,9 @@ const JNINativeMethod JNI::_natives[] = {
 	{ "pushEvent", "(IIIIIII)V",
 		(void *)JNI::pushEvent },
 	{ "setPause", "(Z)V",
-		(void *)JNI::setPause }
+		(void *)JNI::setPause },
+	{ "getNativeVersionInfo", "()Ljava/lang/String;",
+		(void *)JNI::getNativeVersionInfo }
 };
 
 JNI::JNI() {
@@ -134,7 +138,11 @@ jint JNI::onLoad(JavaVM *vm) {
 	if (_vm->GetEnv((void **)&env, JNI_VERSION_1_2))
 		return JNI_ERR;
 
+#ifdef BACKEND_ANDROID3D
+	jclass cls = env->FindClass("org/residualvm/residualvm/ResidualVM");
+#else
 	jclass cls = env->FindClass("org/scummvm/scummvm/ScummVM");
+#endif
 	if (cls == 0)
 		return JNI_ERR;
 
@@ -222,15 +230,15 @@ void JNI::getDPI(float *values) {
 			env->ReleaseFloatArrayElements(array, res, 0);
 		}
 	}
-
+	LOGD("JNI::getDPI() xdpi: %f, ydpi: %f", values[0], values[1]);
 	env->DeleteLocalRef(array);
 }
 
-void JNI::displayMessageOnOSD(const Common::String &msg) {
+void JNI::displayMessageOnOSD(const Common::U32String &msg) {
 	// called from common/osd_message_queue, method: OSDMessageQueue::pollEvent()
 	JNIEnv *env = JNI::getEnv();
 
-	jstring java_msg = convertToJString(env, msg, getCurrentCharset());
+	jstring java_msg = convertToJString(env, msg);
 	if (java_msg == nullptr) {
 		// Show a placeholder indicative of the translation error instead of silent failing
 		java_msg = env->NewStringUTF("?");
@@ -283,7 +291,7 @@ bool JNI::hasTextInClipboard() {
 	return hasText;
 }
 
-Common::String JNI::getTextFromClipboard() {
+Common::U32String JNI::getTextFromClipboard() {
 	JNIEnv *env = JNI::getEnv();
 
 	jstring javaText = (jstring)env->CallObjectMethod(_jobj, _MID_getTextFromClipboard);
@@ -294,18 +302,18 @@ Common::String JNI::getTextFromClipboard() {
 		env->ExceptionDescribe();
 		env->ExceptionClear();
 
-		return Common::String();
+		return Common::U32String();
 	}
 
-	Common::String text = convertFromJString(env, javaText, getCurrentCharset());
+	Common::U32String text = convertFromJString(env, javaText);
 	env->DeleteLocalRef(javaText);
 
 	return text;
 }
 
-bool JNI::setTextInClipboard(const Common::String &text) {
+bool JNI::setTextInClipboard(const Common::U32String &text) {
 	JNIEnv *env = JNI::getEnv();
-	jstring javaText = convertToJString(env, text, getCurrentCharset());
+	jstring javaText = convertToJString(env, text);
 
 	bool success = env->CallBooleanMethod(_jobj, _MID_setTextInClipboard, javaText);
 
@@ -336,9 +344,9 @@ bool JNI::isConnectionLimited() {
 	return limited;
 }
 
-void JNI::setWindowCaption(const Common::String &caption) {
+void JNI::setWindowCaption(const Common::U32String &caption) {
 	JNIEnv *env = JNI::getEnv();
-	jstring java_caption = convertToJString(env, caption, "ISO-8859-1");
+	jstring java_caption = convertToJString(env, caption);
 
 	env->CallVoidMethod(_jobj, _MID_setWindowCaption, java_caption);
 
@@ -378,11 +386,30 @@ void JNI::showKeyboardControl(bool enable) {
 	}
 }
 
+void JNI::showSAFRevokePermsControl(bool enable) {
+#ifndef BACKEND_ANDROID3D
+	JNIEnv *env = JNI::getEnv();
+
+	env->CallVoidMethod(_jobj, _MID_showSAFRevokePermsControl, enable);
+
+	if (env->ExceptionCheck()) {
+		LOGE("Error trying to show the revoke SAF permissions button");
+
+		env->ExceptionDescribe();
+		env->ExceptionClear();
+	}
+#endif
+}
+
+// The following adds assets folder to search set.
+// However searching and retrieving from "assets" on Android this is slow
+// so we also make sure to add the "path" directory, with a higher priority
+// This is done via a call to ScummVMActivity's (java) getSysArchives
 void JNI::addSysArchivesToSearchSet(Common::SearchSet &s, int priority) {
 	JNIEnv *env = JNI::getEnv();
 
-	s.add("ASSET", _asset_archive, priority, false);
-
+	// get any additional specified paths (from ScummVMActivity code)
+	// Insert them with "priority" priority.
 	jobjectArray array =
 		(jobjectArray)env->CallObjectMethod(_jobj, _MID_getSysArchives);
 
@@ -407,36 +434,15 @@ void JNI::addSysArchivesToSearchSet(Common::SearchSet &s, int priority) {
 
 		env->DeleteLocalRef(path_obj);
 	}
-}
 
-char *JNI::convertEncoding(const char *to, const char *from, const char *string, size_t length) {
-	JNIEnv *env = JNI::getEnv();
-
-	jstring javaTo = env->NewStringUTF(to);
-	jstring javaFrom = env->NewStringUTF(from);
-	jbyteArray javaString = env->NewByteArray(length);
-	env->SetByteArrayRegion(javaString, 0, length, reinterpret_cast<const jbyte*>(string));
-
-	jbyteArray javaOut = (jbyteArray)env->CallObjectMethod(_jobj, _MID_convertEncoding, javaTo, javaFrom, javaString);
-
-	if (!javaOut || env->ExceptionCheck()) {
-		LOGE("Failed to convert text from %s to %s", from, to);
-
-		env->ExceptionDescribe();
-		env->ExceptionClear();
-
-		return nullptr;
-	}
-
-	int outLength = env->GetArrayLength(javaOut);
-	char *buf = (char *)malloc(outLength + 1);
-	if (!buf)
-		return nullptr;
-
-	env->GetByteArrayRegion(javaOut, 0, outLength, reinterpret_cast<jbyte *>(buf));
-	buf[outLength] = 0;
-
-	return buf;
+	// add the internal asset (android's structure) with a lower priority,
+	// since:
+	// 1. It is very slow in accessing large files (eg our growing fonts.dat)
+	// 2. we extract the asset contents anyway to the internal app path
+	// 3. we pass the internal app path in the process above (via _MID_getSysArchives)
+	// However, we keep android APK's "assets" as a fall back, in case something went wrong with the extraction process
+	//          and since we had the code anyway
+	s.add("ASSET", _asset_archive, priority - 1, false);
 }
 
 bool JNI::initSurface() {
@@ -567,9 +573,15 @@ void JNI::create(JNIEnv *env, jobject self, jobject asset_manager,
 	FIND_METHOD(, showKeyboardControl, "(Z)V");
 	FIND_METHOD(, getSysArchives, "()[Ljava/lang/String;");
 	FIND_METHOD(, getAllStorageLocations, "()[Ljava/lang/String;");
-	FIND_METHOD(, convertEncoding, "(Ljava/lang/String;Ljava/lang/String;[B)[B");
 	FIND_METHOD(, initSurface, "()Ljavax/microedition/khronos/egl/EGLSurface;");
 	FIND_METHOD(, deinitSurface, "()V");
+#ifndef BACKEND_ANDROID3D
+	FIND_METHOD(, showSAFRevokePermsControl, "(Z)V");
+	FIND_METHOD(, createDirectoryWithSAF, "(Ljava/lang/String;)Z");
+	FIND_METHOD(, createFileWithSAF, "(Ljava/lang/String;)Ljava/lang/String;");
+	FIND_METHOD(, closeFileWithSAF, "(Ljava/lang/String;)V");
+	FIND_METHOD(, isDirectoryWritableWithSAF, "(Ljava/lang/String;)Z");
+#endif
 
 	_jobj_egl = env->NewGlobalRef(egl);
 	_jobj_egl_display = env->NewGlobalRef(egl_display);
@@ -713,10 +725,12 @@ void JNI::setPause(JNIEnv *env, jobject self, jboolean value) {
 		else
 			JNI::_pauseToken.clear();
 
-		/*if (value &&
+#ifdef BACKEND_ANDROID3D
+		if (value &&
 				g_engine->hasFeature(Engine::kSupportsSavingDuringRuntime) &&
 				g_engine->canSaveGameStateCurrently())
-			g_engine->saveGameState(0, "Android parachute");*/
+			g_engine->saveGameState(0, "Android parachute");
+#endif
 	}
 
 	pause = value;
@@ -728,42 +742,31 @@ void JNI::setPause(JNIEnv *env, jobject self, jboolean value) {
 	}
 }
 
-Common::String JNI::getCurrentCharset() {
-#ifdef USE_TRANSLATION
-	if (TransMan.getCurrentCharset() != "ASCII") {
-		return TransMan.getCurrentCharset();
-	}
-#endif
-	return "ISO-8859-1";
+
+jstring JNI::getNativeVersionInfo(JNIEnv *env, jobject self) {
+	return convertToJString(env, Common::U32String(gScummVMVersion));
 }
 
-jstring JNI::convertToJString(JNIEnv *env, const Common::String &str, const Common::String &from) {
-	Common::Encoding converter("UTF-8", from.c_str());
-	char *utf8Str = converter.convert(str.c_str(), converter.stringLength(str.c_str(), from));
-	if (utf8Str == nullptr)
-		return nullptr;
-
-	jstring jstr = env->NewStringUTF(utf8Str);
-	free(utf8Str);
-
+jstring JNI::convertToJString(JNIEnv *env, const Common::U32String &str) {
+	uint len = 0;
+	uint16 *u16str = str.encodeUTF16Native(&len);
+	jstring jstr = env->NewString(u16str, len);
+	delete[] u16str;
 	return jstr;
 }
 
-Common::String JNI::convertFromJString(JNIEnv *env, const jstring &jstr, const Common::String &to) {
-	const char *utf8Str = env->GetStringUTFChars(jstr, 0);
-	if (!utf8Str)
-		return Common::String();
-
-	Common::Encoding converter(to.c_str(), "UTF-8");
-	char *asciiStr = converter.convert(utf8Str, env->GetStringUTFLength(jstr));
-	env->ReleaseStringUTFChars(jstr, utf8Str);
-
-	Common::String str(asciiStr);
-	free(asciiStr);
+Common::U32String JNI::convertFromJString(JNIEnv *env, const jstring &jstr) {
+	const uint16 *utf16Str = env->GetStringChars(jstr, 0);
+	uint jcount = env->GetStringLength(jstr);
+	if (!utf16Str)
+		return Common::U32String();
+	Common::U32String str = Common::U32String::decodeUTF16Native(utf16Str, jcount);
+	env->ReleaseStringChars(jstr, utf16Str);
 
 	return str;
 }
 
+// TODO should this be a U32String array?
 Common::Array<Common::String> JNI::getAllStorageLocations() {
 	Common::Array<Common::String> *res = new Common::Array<Common::String>();
 
@@ -797,5 +800,89 @@ Common::Array<Common::String> JNI::getAllStorageLocations() {
 	return *res;
 }
 
+bool JNI::createDirectoryWithSAF(const Common::String &dirPath) {
+#ifndef BACKEND_ANDROID3D
+	JNIEnv *env = JNI::getEnv();
+	jstring javaDirPath = env->NewStringUTF(dirPath.c_str());
+
+	bool created = env->CallBooleanMethod(_jobj, _MID_createDirectoryWithSAF, javaDirPath);
+
+	if (env->ExceptionCheck()) {
+		LOGE("JNI - Failed to create directory with SAF enhanced method");
+
+		env->ExceptionDescribe();
+		env->ExceptionClear();
+		created = false;
+	}
+
+	return created;
+#else
+	return false;
+#endif
+}
+
+Common::U32String JNI::createFileWithSAF(const Common::String &filePath) {
+#ifndef BACKEND_ANDROID3D
+	JNIEnv *env = JNI::getEnv();
+	jstring javaFilePath = env->NewStringUTF(filePath.c_str());
+
+	jstring hackyFilenameJSTR = (jstring)env->CallObjectMethod(_jobj, _MID_createFileWithSAF, javaFilePath);
+
+
+	if (env->ExceptionCheck()) {
+		LOGE("JNI - Failed to create file with SAF enhanced method");
+
+		env->ExceptionDescribe();
+		env->ExceptionClear();
+		hackyFilenameJSTR = env->NewStringUTF("");
+	}
+
+	Common::U32String hackyFilenameStr = convertFromJString(env, hackyFilenameJSTR);
+
+	env->DeleteLocalRef(hackyFilenameJSTR);
+
+	return hackyFilenameStr;
+#else
+	return Common::U32String();
+#endif
+}
+
+void JNI::closeFileWithSAF(const Common::String &hackyFilename) {
+#ifndef BACKEND_ANDROID3D
+	JNIEnv *env = JNI::getEnv();
+	jstring javaHackyFilename = env->NewStringUTF(hackyFilename.c_str());
+
+	env->CallVoidMethod(_jobj, _MID_closeFileWithSAF, javaHackyFilename);
+
+	if (env->ExceptionCheck()) {
+		LOGE("JNI - Failed to close file with SAF enhanced method");
+
+		env->ExceptionDescribe();
+		env->ExceptionClear();
+	}
+#endif
+}
+
+bool JNI::isDirectoryWritableWithSAF(const Common::String &dirPath) {
+#ifndef BACKEND_ANDROID3D
+	JNIEnv *env = JNI::getEnv();
+	jstring javaDirPath = env->NewStringUTF(dirPath.c_str());
+
+	bool isWritable = env->CallBooleanMethod(_jobj, _MID_isDirectoryWritableWithSAF, javaDirPath);
+
+	if (env->ExceptionCheck()) {
+		LOGE("JNI - Failed to check if directory is writable SAF enhanced method");
+
+		env->ExceptionDescribe();
+		env->ExceptionClear();
+		isWritable = false;
+	}
+
+	return isWritable;
+#else
+	return false;
+#endif
+}
 
 #endif
+
