@@ -31,6 +31,7 @@
 #include "common/fs.h"
 #include "common/archive.h"
 #include "common/array.h"
+#include "common/ustr.h"
 #include "engines/engine.h"
 
 class OSystem_Android;
@@ -57,18 +58,18 @@ public:
 
 	static void setReadyForEvents(bool ready);
 
-	static void setWindowCaption(const Common::String &caption);
+	static void setWindowCaption(const Common::U32String &caption);
 	static void getDPI(float *values);
-	static void displayMessageOnOSD(const Common::String &msg);
+	static void displayMessageOnOSD(const Common::U32String &msg);
 	static bool openUrl(const Common::String &url);
 	static bool hasTextInClipboard();
-	static Common::String getTextFromClipboard();
-	static bool setTextInClipboard(const Common::String &text);
+	static Common::U32String getTextFromClipboard();
+	static bool setTextInClipboard(const Common::U32String &text);
 	static bool isConnectionLimited();
 	static void showVirtualKeyboard(bool enable);
 	static void showKeyboardControl(bool enable);
+	static void showSAFRevokePermsControl(bool enable);
 	static void addSysArchivesToSearchSet(Common::SearchSet &s, int priority);
-	static char *convertEncoding(const char *to, const char *from, const char *string, size_t length);
 
 	static inline bool haveSurface();
 	static inline bool swapBuffers();
@@ -84,6 +85,11 @@ public:
 
 	static Common::Array<Common::String> getAllStorageLocations();
 
+	static bool createDirectoryWithSAF(const Common::String &dirPath);
+	static Common::U32String createFileWithSAF(const Common::String &filePath);
+	static void closeFileWithSAF(const Common::String &hackyFilename);
+	static bool isDirectoryWritableWithSAF(const Common::String &dirPath);
+
 private:
 	static JavaVM *_vm;
 	// back pointer to (java) peer instance
@@ -108,11 +114,15 @@ private:
 	static jmethodID _MID_setWindowCaption;
 	static jmethodID _MID_showVirtualKeyboard;
 	static jmethodID _MID_showKeyboardControl;
+	static jmethodID _MID_showSAFRevokePermsControl;
 	static jmethodID _MID_getSysArchives;
-	static jmethodID _MID_convertEncoding;
 	static jmethodID _MID_getAllStorageLocations;
 	static jmethodID _MID_initSurface;
 	static jmethodID _MID_deinitSurface;
+	static jmethodID _MID_createDirectoryWithSAF;
+	static jmethodID _MID_createFileWithSAF;
+	static jmethodID _MID_closeFileWithSAF;
+	static jmethodID _MID_isDirectoryWritableWithSAF;
 
 	static jmethodID _MID_EGL10_eglSwapBuffers;
 
@@ -141,10 +151,9 @@ private:
 							int arg2, int arg3, int arg4, int arg5, int arg6);
 	static void setPause(JNIEnv *env, jobject self, jboolean value);
 
-	static Common::String getCurrentCharset();
-
-	static jstring convertToJString(JNIEnv *env, const Common::String &str, const Common::String &from);
-	static Common::String convertFromJString(JNIEnv *env, const jstring &jstr, const Common::String &to);
+	static jstring getNativeVersionInfo(JNIEnv *env, jobject self);
+	static jstring convertToJString(JNIEnv *env, const Common::U32String &str);
+	static Common::U32String convertFromJString(JNIEnv *env, const jstring &jstr);
 
 	static PauseToken _pauseToken;
 };
