@@ -35,7 +35,7 @@ int main(int argc, char *argv[]) {
 	assert(g_system);
 
 	// Pre initialize the backend
-	((OSystem_POSIX *)g_system)->init();
+	g_system->init();
 
 	// Invoke the actual ScummVM main entry point:
 	int res = scummvm_main(argc, argv);
