@@ -321,7 +321,7 @@ bool OSystem_iOS7::handleEvent_mouseSecondDragged(Common::Event &event, int x, i
 		if (absX < kMaxDeviation && -vecY >= kNeededLength) {
 			// Swipe up
 			_mouseClickAndDragEnabled = !_mouseClickAndDragEnabled;
-			const char *dialogMsg;
+			Common::U32String dialogMsg;
 			if (_mouseClickAndDragEnabled) {
 				_touchpadModeEnabled = false;
 				dialogMsg = _("Mouse-click-and-drag mode enabled.");
@@ -335,7 +335,7 @@ bool OSystem_iOS7::handleEvent_mouseSecondDragged(Common::Event &event, int x, i
 		if (absY < kMaxDeviation && vecX >= kNeededLength) {
 			// Swipe right
 			_touchpadModeEnabled = !_touchpadModeEnabled;
-			const char *dialogMsg;
+			Common::U32String dialogMsg;
 			if (_touchpadModeEnabled)
 				dialogMsg = _("Touchpad mode enabled.");
 			else
@@ -363,6 +363,9 @@ void  OSystem_iOS7::handleEvent_orientationChanged(int orientation) {
 	case 1:
 		newOrientation = kScreenOrientationPortrait;
 		break;
+	case 2:
+		newOrientation = kScreenOrientationFlippedPortrait;
+		break;
 	case 3:
 		newOrientation = kScreenOrientationLandscape;
 		break;
@@ -449,7 +452,7 @@ bool OSystem_iOS7::handleEvent_swipe(Common::Event &event, int direction, int to
 		switch ((UIViewSwipeDirection)direction) {
 		case kUIViewSwipeUp: {
 			_mouseClickAndDragEnabled = !_mouseClickAndDragEnabled;
-			const char *dialogMsg;
+			Common::U32String dialogMsg;
 			if (_mouseClickAndDragEnabled) {
 				_touchpadModeEnabled = false;
 				dialogMsg = _("Mouse-click-and-drag mode enabled.");
@@ -471,7 +474,7 @@ bool OSystem_iOS7::handleEvent_swipe(Common::Event &event, int direction, int to
 		case kUIViewSwipeRight: {
 			// Swipe right
 			_touchpadModeEnabled = !_touchpadModeEnabled;
-			const char *dialogMsg;
+			Common::U32String dialogMsg;
 			if (_touchpadModeEnabled)
 				dialogMsg = _("Touchpad mode enabled.");
 			else
