@@ -25,8 +25,6 @@
 
 #include "backends/platform/ios7/ios7_video.h"
 
-#include "graphics/colormasks.h"
-#include "common/system.h"
 #include "backends/platform/ios7/ios7_app_delegate.h"
 
 static int g_needsScreenUpdate = 0;
@@ -194,9 +192,6 @@ uint getSizeNextPOT(uint size) {
 - (void)createOverlaySurface {
 	uint overlayWidth = (uint) MAX(_renderBufferWidth, _renderBufferHeight);
 	uint overlayHeight = (uint) MIN(_renderBufferWidth, _renderBufferHeight);
-	float hdpi_scaler = [UIScreen mainScreen].scale;
-	overlayWidth = (uint)(overlayWidth / hdpi_scaler);
-	overlayHeight = (uint)(overlayHeight / hdpi_scaler);
 
 	_videoContext.overlayWidth = overlayWidth;
 	_videoContext.overlayHeight = overlayHeight;
@@ -214,7 +209,7 @@ uint getSizeNextPOT(uint size) {
 	_overlayCoords[2].x = 0; _overlayCoords[2].y = 0; _overlayCoords[2].u = 0; _overlayCoords[2].v = v;
 	_overlayCoords[3].x = 0; _overlayCoords[3].y = 0; _overlayCoords[3].u = u; _overlayCoords[3].v = v;
 
-	_videoContext.overlayTexture.create((uint16) overlayTextureWidthPOT, (uint16) overlayTextureHeightPOT, Graphics::createPixelFormat<5551>());
+	_videoContext.overlayTexture.create((uint16) overlayTextureWidthPOT, (uint16) overlayTextureHeightPOT, Graphics::PixelFormat(2, 5, 5, 5, 1, 11, 6, 1, 0));
 }
 
 - (void)deleteFramebuffer {
@@ -423,23 +418,10 @@ uint getSizeNextPOT(uint size) {
 
 	_backgroundSaveStateTask = UIBackgroundTaskInvalid;
 
-#if defined(USE_SCALERS) || defined(USE_HQ_SCALERS)
-	InitScalers(565);
-#endif
-
 	[self setupGestureRecognizers];
 
 	[self setContentScaleFactor:[[UIScreen mainScreen] scale]];
 
-#ifdef ENABLE_IOS7_SCALERS
-	_scalerMemorySrc = NULL;
-	_scalerMemoryDst = NULL;
-	_scalerMemorySrcSize = 0;
-	_scalerMemoryDstSize = 0;
-	_scaler = NULL;
-	_scalerScale = 1;
-#endif
-
 	_keyboardView = nil;
 	_keyboardVisible = NO;
 	_screenTexture = 0;
@@ -471,11 +453,6 @@ uint getSizeNextPOT(uint size) {
 	_videoContext.overlayTexture.free();
 	_videoContext.mouseTexture.free();
 
-#ifdef ENABLE_IOS7_SCALERS
-	free(_scalerMemorySrc);
-	free(_scalerMemoryDst);
-#endif
-
 	[_eventLock release];
 	[super dealloc];
 }
@@ -498,79 +475,10 @@ uint getSizeNextPOT(uint size) {
 	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE); printOpenGLError();
 }
 
-#ifdef ENABLE_IOS7_SCALERS
-- (void)setScaler {
-	ScalerProc *scaler = NULL;
-	int scalerScale = 1;
-
-	switch (_videoContext.graphicsMode) {
-	case kGraphicsModeNone:
-		break;
-#ifdef USE_SCALERS
-	case kGraphicsMode2xSaI:
-		scaler = _2xSaI;
-		scalerScale = 2;
-		break;
-
-	case kGraphicsModeSuper2xSaI:
-		scaler = Super2xSaI;
-		scalerScale = 2;
-		break;
-
-	case kGraphicsModeSuperEagle:
-		scaler = SuperEagle;
-		scalerScale = 2;
-		break;
-
-	case kGraphicsModeAdvMame2x:
-		scaler = AdvMame2x;
-		scalerScale = 2;
-		break;
-
-	case kGraphicsModeAdvMame3x:
-		scaler = AdvMame3x;
-		scalerScale = 3;
-		break;
-
-#ifdef USE_HQ_SCALERS
-	case kGraphicsModeHQ2x:
-		scaler = HQ2x;
-		scalerScale = 2;
-		break;
-
-	case kGraphicsModeHQ3x:
-		scaler = HQ3x;
-		scalerScale = 3;
-		break;
-#endif
-
-	case kGraphicsModeTV2x:
-		scaler = TV2x;
-		scalerScale = 2;
-		break;
-
-	case kGraphicsModeDotMatrix:
-		scaler = DotMatrix;
-		scalerScale = 2;
-		break;
-#endif
-
-	default:
-		break;
-	}
-
-	_scaler = scaler;
-	_scalerScale = scalerScale;
-}
-#endif
-
 - (void)setGraphicsMode {
 	[self setFilterModeForTexture:_screenTexture];
 	[self setFilterModeForTexture:_overlayTexture];
 	[self setFilterModeForTexture:_mouseCursorTexture];
-#ifdef ENABLE_IOS7_SCALERS
-	[self setScaler];
-#endif
 }
 
 - (void)updateSurface {
@@ -664,40 +572,7 @@ uint getSizeNextPOT(uint size) {
 	// Unfortunately we have to update the whole texture every frame, since glTexSubImage2D is actually slower in all cases
 	// due to the iPhone internals having to convert the whole texture back from its internal format when used.
 	// In the future we could use several tiled textures instead.
-#ifdef ENABLE_IOS7_SCALERS
-	if (_scaler) {
-		size_t neededSrcMemorySize = (size_t) (_videoContext.screenTexture.pitch * (_videoContext.screenTexture.h + 4));
-		size_t neededDstMemorySize = (size_t) (_videoContext.screenTexture.pitch * (_videoContext.screenTexture.h + 4) * _scalerScale * _scalerScale);
-		if (neededSrcMemorySize != _scalerMemorySrcSize) {
-			_scalerMemorySrc = (uint8_t *) realloc(_scalerMemorySrc, neededSrcMemorySize);
-			_scalerMemorySrcSize = neededSrcMemorySize;
-		}
-		if (neededDstMemorySize != _scalerMemoryDstSize) {
-			_scalerMemoryDst = (uint8_t *) realloc(_scalerMemoryDst, neededDstMemorySize);
-			_scalerMemoryDstSize = neededDstMemorySize;
-		}
-
-		// Clear two lines before
-		memset(_scalerMemorySrc, 0, (size_t) (_videoContext.screenTexture.pitch * 2));
-		// Copy original buffer
-		memcpy(_scalerMemorySrc + _videoContext.screenTexture.pitch * 2, _videoContext.screenTexture.getPixels(), _videoContext.screenTexture.pitch * _videoContext.screenTexture.h);
-		// Clear two lines after
-		memset(_scalerMemorySrc + _videoContext.screenTexture.pitch * (2 + _videoContext.screenTexture.h), 0, (size_t) (_videoContext.screenTexture.pitch * 2));
-		// Apply scaler
-		_scaler(_scalerMemorySrc + _videoContext.screenTexture.pitch * 2,
-		        _videoContext.screenTexture.pitch,
-		        _scalerMemoryDst,
-		        (uint32) (_videoContext.screenTexture.pitch * _scalerScale),
-		        _videoContext.screenTexture.w,
-		        _videoContext.screenTexture.h);
-		glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB, _videoContext.screenTexture.w * _scalerScale, _videoContext.screenTexture.h * _scalerScale, 0, GL_RGB, GL_UNSIGNED_SHORT_5_6_5, _scalerMemoryDst); printOpenGLError();
-	}
-	else {
-#endif
-		glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB, _videoContext.screenTexture.w, _videoContext.screenTexture.h, 0, GL_RGB, GL_UNSIGNED_SHORT_5_6_5, _videoContext.screenTexture.getPixels()); printOpenGLError();
-#ifdef ENABLE_IOS7_SCALERS
-	}
-#endif
+	glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB, _videoContext.screenTexture.w, _videoContext.screenTexture.h, 0, GL_RGB, GL_UNSIGNED_SHORT_5_6_5, _videoContext.screenTexture.getPixels()); printOpenGLError();
 
 	glDrawArrays(GL_TRIANGLE_STRIP, 0, 4); printOpenGLError();
 }
@@ -730,7 +605,7 @@ uint getSizeNextPOT(uint size) {
 	_gameScreenCoords[1].u = _gameScreenCoords[3].u = _videoContext.screenWidth / (GLfloat)screenTexWidth;
 	_gameScreenCoords[2].v = _gameScreenCoords[3].v = _videoContext.screenHeight / (GLfloat)screenTexHeight;
 
-	_videoContext.screenTexture.create((uint16) screenTexWidth, (uint16) screenTexHeight, Graphics::createPixelFormat<565>());
+	_videoContext.screenTexture.create((uint16) screenTexWidth, (uint16) screenTexHeight, Graphics::PixelFormat(2, 5, 6, 5, 0, 11, 5, 0, 0));
 }
 
 - (void)initSurface {
@@ -806,7 +681,7 @@ uint getSizeNextPOT(uint size) {
 		GLfloat ratio = adjustedHeight / adjustedWidth;
 		int height = (int)(screenWidth * ratio);
 		//printf("Making rect (%u, %u)\n", screenWidth, height);
-        
+
 		_gameScreenRect = CGRectMake(0, 0, screenWidth, height);
 
 		overlayPortraitRatio = (_videoContext.overlayHeight * ratio) / _videoContext.overlayWidth;
@@ -823,7 +698,7 @@ uint getSizeNextPOT(uint size) {
 
 	[self setViewTransformation];
 	[self updateMouseCursorScaling];
-    [self adjustViewFrameForSafeArea];
+	[self adjustViewFrameForSafeArea];
 }
 
 #ifndef __has_builtin
@@ -838,23 +713,23 @@ uint getSizeNextPOT(uint size) {
 	// available when running on iOS 11+ if it has been compiled on iOS 11+
 #ifdef __IPHONE_11_0
 #if __has_builtin(__builtin_available)
-    if ( @available(iOS 11,*) ) {
+	if ( @available(iOS 11,*) ) {
 #else
-    if ( [[[UIApplication sharedApplication] keyWindow] respondsToSelector:@selector(safeAreaInsets)] ) {
+	if ( [[[UIApplication sharedApplication] keyWindow] respondsToSelector:@selector(safeAreaInsets)] ) {
 #endif
-        CGRect screenSize = [[UIScreen mainScreen] bounds];
-        UIEdgeInsets inset = [[[UIApplication sharedApplication] keyWindow] safeAreaInsets];
-        UIInterfaceOrientation orientation = [[UIApplication sharedApplication] statusBarOrientation];
-        CGRect newFrame = screenSize;
-        if ( orientation == UIInterfaceOrientationPortrait ) {
-            newFrame = CGRectMake(screenSize.origin.x, screenSize.origin.y + inset.top, screenSize.size.width, screenSize.size.height - inset.top);
-        } else if ( orientation == UIInterfaceOrientationLandscapeLeft ) {
-            newFrame = CGRectMake(screenSize.origin.x, screenSize.origin.y, screenSize.size.width - inset.right, screenSize.size.height);
-        } else if ( orientation == UIInterfaceOrientationLandscapeRight ) {
-            newFrame = CGRectMake(screenSize.origin.x + inset.left, screenSize.origin.y, screenSize.size.width - inset.left, screenSize.size.height);
-        }
-        self.frame = newFrame;
-    }
+		CGRect screenSize = [[UIScreen mainScreen] bounds];
+		UIEdgeInsets inset = [[[UIApplication sharedApplication] keyWindow] safeAreaInsets];
+		UIInterfaceOrientation orientation = [[UIApplication sharedApplication] statusBarOrientation];
+		CGRect newFrame = screenSize;
+		if ( orientation == UIInterfaceOrientationPortrait ) {
+			newFrame = CGRectMake(screenSize.origin.x, screenSize.origin.y + inset.top, screenSize.size.width, screenSize.size.height - inset.top);
+		} else if ( orientation == UIInterfaceOrientationLandscapeLeft ) {
+			newFrame = CGRectMake(screenSize.origin.x, screenSize.origin.y, screenSize.size.width - inset.right, screenSize.size.height);
+		} else if ( orientation == UIInterfaceOrientationLandscapeRight ) {
+			newFrame = CGRectMake(screenSize.origin.x + inset.left, screenSize.origin.y, screenSize.size.width - inset.left, screenSize.size.height);
+		}
+		self.frame = newFrame;
+	}
 #endif
 }
 
@@ -939,12 +814,12 @@ uint getSizeNextPOT(uint size) {
 - (void)deviceOrientationChanged:(UIDeviceOrientation)orientation {
 	[self addEvent:InternalEvent(kInputOrientationChanged, orientation, 0)];
 
-  BOOL isLandscape = (self.bounds.size.width > self.bounds.size.height);
-  if (isLandscape) {
-    [self hideKeyboard];
-  } else {
-    [self showKeyboard];
-  }
+	BOOL isLandscape = (self.bounds.size.width > self.bounds.size.height);
+	if (isLandscape) {
+		[self hideKeyboard];
+	} else {
+		[self showKeyboard];
+	}
 }
 
 - (void)showKeyboard {
