@@ -35,7 +35,7 @@ uint32 InPAKSave::read(void *buf, uint32 cnt) {
 	return pakfs_read(buf, 1, cnt, fd);
 }
 
-bool InPAKSave::seek(int32 offs, int whence) {
+bool InPAKSave::seek(int64 offs, int whence) {
 	pakfs_seek(fd, offs, whence);
 
 	return true;
@@ -59,7 +59,7 @@ Common::StringArray PAKSaveManager::listSavefiles(const Common::String &pattern)
 
 	while ((dp = pakfs_readdir(dirp)) != NULL) {
 		fname = new Common::String(dp->entryname);
-		if (fname->matchString(pattern, false, false))
+		if (fname->matchString(pattern, false, NULL))
 			list.push_back(dp->entryname);
 
 		delete fname;
