@@ -30,22 +30,15 @@
 
 class OSystem_PSP2 : public OSystem_SDL {
 public:
-	// Let the subclasses be able to change _baseConfigName in the constructor
-	OSystem_PSP2(Common::String baseConfigName = "scummvm.ini");
-	virtual ~OSystem_PSP2() {}
-
 	virtual void init() override;
 	virtual void initBackend() override;
 	virtual bool hasFeature(Feature f) override;
 	virtual void setFeatureState(Feature f, bool enable) override;
 	virtual bool getFeatureState(Feature f) override;
 	virtual void logMessage(LogMessageType::Type type, const char *message) override;
+	virtual Common::HardwareInputSet *getHardwareInputSet() override;
 
 protected:
-	// Base string for creating the default path and filename
-	// for the configuration file
-	Common::String _baseConfigName;
-
 	virtual Common::String getDefaultConfigFileName() override;
 	virtual Common::String getDefaultLogFileName() override;
 };
