@@ -32,11 +32,12 @@
 static const uint32 fullscreenMask = SDL_WINDOW_FULLSCREEN_DESKTOP | SDL_WINDOW_FULLSCREEN;
 #endif
 
-SdlWindow::SdlWindow()
+SdlWindow::SdlWindow() :
 #if SDL_VERSION_ATLEAST(2, 0, 0)
-	: _window(nullptr), _inputGrabState(false), _windowCaption("ScummVM"),
-	_lastFlags(0), _lastX(SDL_WINDOWPOS_UNDEFINED), _lastY(SDL_WINDOWPOS_UNDEFINED)
+	_window(nullptr), _windowCaption("ScummVM"),
+	_lastFlags(0), _lastX(SDL_WINDOWPOS_UNDEFINED), _lastY(SDL_WINDOWPOS_UNDEFINED),
 #endif
+	_inputGrabState(false), _inputLockState(false)
 	{
 
 #if SDL_VERSION_ATLEAST(2, 0, 0)
@@ -145,23 +146,41 @@ void SdlWindow::setWindowCaption(const Common::String &caption) {
 #endif
 }
 
-void SdlWindow::toggleMouseGrab() {
+void SdlWindow::grabMouse(bool grab) {
 #if SDL_VERSION_ATLEAST(2, 0, 0)
 	if (_window) {
-		_inputGrabState = SDL_GetWindowGrab(_window) == SDL_FALSE;
-		SDL_SetWindowGrab(_window, _inputGrabState ? SDL_TRUE : SDL_FALSE);
+		SDL_SetWindowGrab(_window, grab ? SDL_TRUE : SDL_FALSE);
 	}
+	_inputGrabState = grab;
 #else
-	if (SDL_WM_GrabInput(SDL_GRAB_QUERY) == SDL_GRAB_OFF) {
-		SDL_WM_GrabInput(SDL_GRAB_ON);
+	if (grab) {
 		_inputGrabState = true;
+		SDL_WM_GrabInput(SDL_GRAB_ON);
 	} else {
-		SDL_WM_GrabInput(SDL_GRAB_OFF);
 		_inputGrabState = false;
+		if (!_inputLockState)
+			SDL_WM_GrabInput(SDL_GRAB_OFF);
 	}
 #endif
 }
 
+bool SdlWindow::lockMouse(bool lock) {
+#if SDL_VERSION_ATLEAST(2, 0, 0)
+	SDL_SetRelativeMouseMode(lock ? SDL_TRUE : SDL_FALSE);
+	_inputLockState = lock;
+#else
+	if (lock) {
+		_inputLockState = true;
+		SDL_WM_GrabInput(SDL_GRAB_ON);
+	} else {
+		_inputLockState = false;
+		if (!_inputGrabState)
+			SDL_WM_GrabInput(SDL_GRAB_OFF);
+	}
+#endif
+	return true;
+}
+
 bool SdlWindow::hasMouseFocus() const {
 #if SDL_VERSION_ATLEAST(2, 0, 0)
 	if (_window) {
@@ -178,6 +197,9 @@ bool SdlWindow::warpMouseInWindow(int x, int y) {
 	if (hasMouseFocus()) {
 #if SDL_VERSION_ATLEAST(2, 0, 0)
 		if (_window) {
+			float dpiScale = getSdlDpiScalingFactor();
+			x = (int)(x / dpiScale + 0.5f);
+			y = (int)(y / dpiScale + 0.5f);
 			SDL_WarpMouseInWindow(_window, x, y);
 			return true;
 		}
@@ -213,9 +235,8 @@ bool SdlWindow::getSDLWMInformation(SDL_SysWMinfo *info) const {
 
 Common::Rect SdlWindow::getDesktopResolution() {
 #if SDL_VERSION_ATLEAST(2, 0, 0)
-	int displayIndex = _window ? SDL_GetWindowDisplayIndex(_window) : 0;
 	SDL_DisplayMode displayMode;
-	if (!SDL_GetDesktopDisplayMode(displayIndex, &displayMode)) {
+	if (!SDL_GetDesktopDisplayMode(getDisplayIndex(), &displayMode)) {
 		_desktopRes = Common::Rect(displayMode.w, displayMode.h);
 	}
 #endif
@@ -223,6 +244,48 @@ Common::Rect SdlWindow::getDesktopResolution() {
 	return _desktopRes;
 }
 
+void SdlWindow::getDisplayDpi(float *dpi, float *defaultDpi) const {
+	const float systemDpi =
+#ifdef __APPLE__
+	72.0f;
+#elif defined(_WIN32)
+	96.0f;
+#else
+	90.0f; // ScummVM default
+#endif
+	if (defaultDpi)
+		*defaultDpi = systemDpi;
+
+	if (dpi) {
+#if SDL_VERSION_ATLEAST(2, 0, 4)
+		if (SDL_GetDisplayDPI(getDisplayIndex(), NULL, dpi, NULL) != 0) {
+			*dpi = systemDpi;
+		}
+#else
+		*dpi = systemDpi;
+#endif
+	}
+}
+
+float SdlWindow::getDpiScalingFactor() const {
+	float dpi, defaultDpi;
+	getDisplayDpi(&dpi, &defaultDpi);
+	debug(4, "dpi: %g default: %g", dpi, defaultDpi);
+	float ratio = dpi / defaultDpi;
+	return ratio;
+}
+
+float SdlWindow::getSdlDpiScalingFactor() const {
+#if SDL_VERSION_ATLEAST(2, 0, 0)
+	int windowWidth, windowHeight;
+	SDL_GetWindowSize(getSDLWindow(), &windowWidth, &windowHeight);
+	int realWidth, realHeight;
+	SDL_GL_GetDrawableSize(getSDLWindow(), &realWidth, &realHeight);
+	return (float)realWidth / (float)windowWidth;
+#else
+	return 1.f;
+#endif
+}
 
 #if SDL_VERSION_ATLEAST(2, 0, 0)
 SDL_Surface *copySDLSurface(SDL_Surface *src) {
@@ -246,6 +309,16 @@ SDL_Surface *copySDLSurface(SDL_Surface *src) {
 	return res;
 }
 
+int SdlWindow::getDisplayIndex() const {
+	if (_window) {
+		int displayIndex = SDL_GetWindowDisplayIndex(_window);
+		if (displayIndex >= 0)
+			return displayIndex;
+	}
+	// Default to primary display
+	return 0;
+}
+
 bool SdlWindow::createOrUpdateWindow(int width, int height, uint32 flags) {
 	if (_inputGrabState) {
 		flags |= SDL_WINDOW_INPUT_GRABBED;
@@ -277,19 +350,26 @@ bool SdlWindow::createOrUpdateWindow(int width, int height, uint32 flags) {
 	// the documentation says it only works on X11 anyway, which means it is
 	// basically worthless. So we'll just try to keep things closeish to the
 	// maximum for now.
-	SDL_DisplayMode displayMode;
-	SDL_GetDesktopDisplayMode(0, &displayMode);
+	Common::Rect desktopRes = getDesktopResolution();
 	if (!fullscreenFlags) {
-		displayMode.w -= 20;
-		displayMode.h -= 30;
+		int top, left, bottom, right;
+#if SDL_VERSION_ATLEAST(2, 0, 5)
+		if (!_window || SDL_GetWindowBordersSize(_window, &top, &left, &bottom, &right) < 0)
+#endif
+		{
+			left = right = 10;
+			top = bottom = 15;
+		}
+		desktopRes.right -= (left + right);
+		desktopRes.bottom -= (top + bottom);
 	}
 
-	if (width > displayMode.w) {
-		width = displayMode.w;
+	if (width > desktopRes.right) {
+		width = desktopRes.right;
 	}
 
-	if (height > displayMode.h) {
-		height = displayMode.h;
+	if (height > desktopRes.bottom) {
+		height = desktopRes.bottom;
 	}
 
 	if (!_window || oldNonUpdateableFlags != newNonUpdateableFlags) {
