@@ -46,10 +46,15 @@ public:
 	void setWindowCaption(const Common::String &caption);
 
 	/**
-	 * Toggle mouse grab state. This decides whether the cursor can leave the
-	 * window or not.
+	 * Grab or ungrab the mouse cursor. This decides whether the cursor can leave
+	 * the window or not.
 	 */
-	void toggleMouseGrab();
+	void grabMouse(bool grab);
+
+	/**
+	 * Lock or unlock the mouse cursor within the window.
+	 */
+	bool lockMouse(bool lock);
 
 	/**
 	 * Check whether the application has mouse focus.
@@ -82,6 +87,23 @@ public:
 	 */
 	Common::Rect getDesktopResolution();
 
+	/*
+	 * Get the scaling between the SDL Window size and the SDL
+	 * drawable area size. On some system, when HiDPI support is
+	 * enabled, those two sizes are different.
+	 *
+	 * To convert from window coordinate to drawable area coordinate,
+	 * multiple the coordinate by this scaling factor. To convert
+	 * from drawable area coordinate to window coordinate, divide the
+	 * coordinate by this scaling factor.
+	 */
+	float getSdlDpiScalingFactor() const;
+
+	/**
+	 * Returns the scaling mode based on the display DPI
+	 */
+	virtual float getDpiScalingFactor() const;
+
 	bool mouseIsGrabbed() const {
 #if SDL_VERSION_ATLEAST(2, 0, 0)
 		if (_window) {
@@ -91,10 +113,20 @@ public:
 		return _inputGrabState;
 	}
 
-private:
-	bool _inputGrabState;
+	bool mouseIsLocked() const {
+#if SDL_VERSION_ATLEAST(2, 0, 0)
+		return SDL_GetRelativeMouseMode() == SDL_TRUE;
+#else
+		return _inputLockState;
+#endif
+	}
 
+private:
 	Common::Rect _desktopRes;
+	bool _inputGrabState, _inputLockState;
+
+protected:
+	void getDisplayDpi(float *dpi, float *defaultDpi) const;
 
 #if SDL_VERSION_ATLEAST(2, 0, 0)
 public:
@@ -103,6 +135,11 @@ public:
 	 */
 	SDL_Window *getSDLWindow() const { return _window; }
 
+	/**
+	 * @return The display containing the ScummVM window.
+	 */
+	int getDisplayIndex() const;
+
 	/**
 	 * Creates or updates the SDL window.
 	 *
