@@ -71,15 +71,21 @@ public:
 #if SDL_VERSION_ATLEAST(2, 0, 0)
 	// Clipboard
 	virtual bool hasTextInClipboard() override;
-	virtual Common::String getTextFromClipboard() override;
-	virtual bool setTextInClipboard(const Common::String &text) override;
+	virtual Common::U32String getTextFromClipboard() override;
+	virtual bool setTextInClipboard(const Common::U32String &text) override;
+
+	virtual void messageBox(LogMessageType::Type type, const char *message) override;
 #endif
 
-	virtual void setWindowCaption(const char *caption) override;
+#if SDL_VERSION_ATLEAST(2, 0, 14)
+	virtual bool openUrl(const Common::String &url) override;
+#endif
+
+	virtual void setWindowCaption(const Common::U32String &caption) override;
 	virtual void addSysArchivesToSearchSet(Common::SearchSet &s, int priority = 0) override;
 	virtual uint32 getMillis(bool skipRecord = false) override;
 	virtual void delayMillis(uint msecs) override;
-	virtual void getTimeAndDate(TimeDate &td) const override;
+	virtual void getTimeAndDate(TimeDate &td, bool skipRecord = false) const override;
 	virtual MixerManager *getMixerManager() override;
 	virtual Common::TimerManager *getTimerManager() override;
 	virtual Common::SaveFileManager *getSavefileManager() override;
@@ -87,6 +93,10 @@ public:
 	//Screenshots
 	virtual Common::String getScreenshotsPath();
 
+#if defined(USE_OPENGL_GAME) || defined(USE_OPENGL_SHADERS) || defined(USE_GLES2)
+	Common::Array<uint> getSupportedAntiAliasingLevels() const override;
+#endif
+
 protected:
 	bool _inited;
 	bool _initedSDL;
@@ -119,8 +129,19 @@ protected:
 	 */
 	SdlWindow *_window;
 
+	SdlGraphicsManager::State _gfxManagerState;
+
+#if defined(USE_OPENGL_GAME) || defined(USE_OPENGL_SHADERS) || defined(USE_GLES2)
+	// Graphics capabilities
+	void detectFramebufferSupport();
+	void detectAntiAliasingSupport();
+
+	bool _supportsFrameBuffer;
+	Common::Array<uint> _antiAliasLevels;
+#endif
+
 	/**
-	 * Initialze the SDL library.
+	 * Initialize the SDL library.
 	 */
 	virtual void initSDL();
 
@@ -144,17 +165,22 @@ protected:
 	int _defaultGLMode;
 
 	/**
-	 * Creates the merged graphics modes list
+	 * Create the merged graphics modes list.
 	 */
 	void setupGraphicsModes();
 
+	/**
+	 * Clear the merged graphics modes list.
+	 */
+	void clearGraphicsModes();
+
+	enum GraphicsManagerType { GraphicsManagerSDL, GraphicsManagerOpenGL };
+	virtual GraphicsManagerType getDefaultGraphicsManager() const { return GraphicsManagerSDL; }
 	virtual const OSystem::GraphicsMode *getSupportedGraphicsModes() const override;
 	virtual int getDefaultGraphicsMode() const override;
-	virtual bool setGraphicsMode(int mode) override;
+	virtual bool setGraphicsMode(int mode, uint flags) override;
 	virtual int getGraphicsMode() const override;
 #endif
-protected:
-	virtual char *convertEncoding(const char *to, const char *from, const char *string, size_t length) override;
 };
 
 #endif
