@@ -26,36 +26,38 @@
 #include "backends/platform/sdl/sdl.h"
 #include "backends/platform/sdl/win32/win32-window.h"
 
-class OSystem_Win32 : public OSystem_SDL {
+class OSystem_Win32 final : public OSystem_SDL {
 public:
-	virtual void init();
-	virtual void initBackend();
+	virtual void init() override;
+	virtual void initBackend() override;
 
-	virtual void addSysArchivesToSearchSet(Common::SearchSet &s, int priority = 0);
+#ifdef USE_OPENGL
+	virtual GraphicsManagerType getDefaultGraphicsManager() const override;
+#endif
 
-	virtual bool hasFeature(Feature f);
+	virtual void addSysArchivesToSearchSet(Common::SearchSet &s, int priority = 0) override;
 
-	virtual bool displayLogFile();
+	virtual bool hasFeature(Feature f) override;
 
-	virtual bool openUrl(const Common::String &url);
+	virtual bool displayLogFile() override;
 
-	virtual void logMessage(LogMessageType::Type type, const char *message);
+	virtual bool openUrl(const Common::String &url) override;
 
-	virtual Common::String getSystemLanguage() const;
+	virtual void logMessage(LogMessageType::Type type, const char *message) override;
 
-	virtual Common::String getScreenshotsPath();
+	virtual Common::String getSystemLanguage() const override;
+
+	virtual Common::String getScreenshotsPath() override;
 
 protected:
-	virtual Common::String getDefaultConfigFileName();
-	virtual Common::String getDefaultLogFileName();
+	virtual Common::String getDefaultConfigFileName() override;
+	virtual Common::String getDefaultLogFileName() override;
 
 	// Override createAudioCDManager() to get our Windows-specific
 	// version.
-	virtual AudioCDManager *createAudioCDManager();
-	
-	HWND getHwnd() { return ((SdlWindow_Win32*)_window)->getHwnd(); }
+	virtual AudioCDManager *createAudioCDManager() override;
 
-	virtual char *convertEncoding(const char *to, const char *from, const char *string, size_t length);
+	HWND getHwnd() { return ((SdlWindow_Win32*)_window)->getHwnd(); }
 };
 
 #endif
