@@ -75,7 +75,10 @@ CApaApplication* NewApplication() {
 #include <eikstart.h>
 // E32Main() contains the program's start up code, the entry point for an EXE.
 GLDEF_C TInt E32Main() {
-	return EikStart::RunApplication(NewApplication);
+	__UHEAP_MARK;
+	TInt i = EikStart::RunApplication(NewApplication);
+	__UHEAP_MARKEND;
+	return i;
 }
 #endif
 
