@@ -20,16 +20,31 @@
  *
  */
 
+#if (__GNUC__ && __cplusplus)
+#pragma GCC diagnostic ignored "-Wreturn-local-addr"
+#pragma GCC diagnostic ignored "-Wnarrowing"
+#pragma GCC diagnostic ignored "-Wc++14-compat"
+#endif
+
+#include <utf.h>
+#include <apgcli.h>
+#include <eikenv.h> // for CEikonEnv::Static()
 #include <sdlapp.h> // for CSDLApp::GetExecutablePathCStr() @ Symbian::GetExecutablePath()
 #include <bautils.h>
-#include <eikenv.h> // for CEikonEnv::Static()
+#include <e32base.h>
+#include <symbian_helper.h>
+
+#if (__GNUC__ && __cplusplus)
+// If a pop has no matching push, the command-line options are restored.
+#pragma GCC diagnostic pop
+#endif
+
 #define FORBIDDEN_SYMBOL_EXCEPTION_fclose
 #define FORBIDDEN_SYMBOL_EXCEPTION_fopen
 
 #include "backends/platform/symbian/src/SymbianOS.h"
 #include "common/config-manager.h"
 #include "common/scummsys.h"
-#include "common/translation.h"
 
 #include "gui/message.h"
 
@@ -37,10 +52,8 @@
 #include "backends/saves/default/default-saves.h"
 #include "backends/mixer/symbiansdl/symbiansdl-mixer.h"
 
-#ifdef GUI_ENABLE_KEYSDIALOG
-#include "backends/platform/symbian/src/SymbianActions.h"
-#include "backends/events/symbiansdl/symbiansdl-events.h"
-#endif
+#include "backends/keymapper/keymapper.h"
+#include "backends/keymapper/keymapper-defaults.h"
 
 #define DEFAULT_CONFIG_FILE "scummvm.ini"
 #define DEFAULT_SAVE_PATH "Savegames"
@@ -48,92 +61,99 @@
 ////////// extern "C" ///////////////////////////////////////////////////
 namespace Symbian {
 
-// make this easily available everywhere
+// Make this easily available everywhere.
 char *GetExecutablePath() {
 	return CSDLApp::GetExecutablePathCStr();
 }
 
-} // namespace Symbian {
+} // namespace Symbian.
 
 ////////// OSystem_SDL_Symbian //////////////////////////////////////////
 
-OSystem_SDL_Symbian::OSystem_SDL_Symbian()
-	:
-	_RFs(0) {
-
-}
+OSystem_SDL_Symbian::OSystem_SDL_Symbian() {}
 
 void OSystem_SDL_Symbian::init() {
-	_RFs = &CEikonEnv::Static()->FsSession();
 	// Use iconless window: it uses the EScummVM.aif file for the icon.
+	initSDL();
 	_window = new SdlIconlessWindow();
 	_fsFactory = new SymbianFilesystemFactory();
 	OSystem_SDL::init();
 }
 
 void OSystem_SDL_Symbian::initBackend() {
-	// Calculate the default savepath
+	// Calculate the default savepath.
 	Common::String savePath;
 	savePath = Symbian::GetExecutablePath();
 	savePath += DEFAULT_SAVE_PATH "\\";
 	_savefileManager = new DefaultSaveFileManager(savePath);
 
-	// If savepath has not already been set then set it
+	// If savepath has not already been set then set it.
 	if (!ConfMan.hasKey("savepath")) {
 		ConfMan.set("savepath", savePath);
 	}
 
-	// Ensure that the current set path (might have been altered by the user) exists
+#if _DEBUG
+#warning "set debuglevel = 20"
+	ConfMan.set("debuglevel", "20");
+	if (!ConfMan.hasKey("debuglevel"))
+		warning("debuglevel not set!\n");
+#endif
+	// Ensure that the current set path (might have been altered by the user) exists.
 	Common::String currentPath = ConfMan.get("savepath");
 	TFileName fname;
 	TPtrC8 ptr((const unsigned char*)currentPath.c_str(), currentPath.size());
 	fname.Copy(ptr);
-	BaflUtils::EnsurePathExistsL(dynamic_cast<OSystem_SDL_Symbian *>(g_system)->FsSession(), fname);
+	BaflUtils::EnsurePathExistsL(FsSession(), fname);
 
 	ConfMan.setBool("FM_high_quality", false);
-#if !defined(S60) || defined(S60V3) // S60 has low quality as default
+#if !defined(S60) || defined(S60V3) // S60 has low quality as default.
 	ConfMan.setBool("FM_medium_quality", true);
 #else
 	ConfMan.setBool("FM_medium_quality", false);
 #endif
 	// Symbian OS  should have joystick_num set to 0 in the ini file,
-	// but uiq devices might refuse opening the joystick
+	// but uiq devices might refuse opening the joystick.
 	ConfMan.setInt("joystick_num", 0);
 	ConfMan.setBool("fullscreen", true);
 	ConfMan.flushToDisk();
 
-#ifdef GUI_ENABLE_KEYSDIALOG
-	GUI::Actions::init();
-
-	// Creates the backend managers
-	if (_eventSource == 0)
-		_eventSource = new SymbianSdlEventSource();
-#endif
-
-	if (_mixerManager == 0) {
+	if (_mixerManager == nullptr) {
 		_mixerManager = new SymbianSdlMixerManager();
 
-		// Setup and start mixer
+		// Setup and start mixer.
 		_mixerManager->init();
 	}
 
-	// Call parent implementation of this method
+	// Call parent implementation of this method.
 	OSystem_SDL::initBackend();
-
-#ifdef GUI_ENABLE_KEYSDIALOG
-	// Initialize global key mapping for Smartphones
-	GUI::Actions* actions = GUI::Actions::Instance();
-
-	actions->initInstanceMain(this);
-	actions->loadMapping();
-#endif
 }
 
 void OSystem_SDL_Symbian::addSysArchivesToSearchSet(Common::SearchSet &s, int priority) {
+	RFs rfs = FsSession();
+	TChar driveLetter;
+	TFileName extraPath;
+
+#if !RELEASE_BUILD
+	_LIT(KDefaultBetaExtraPath,"!:\\DATA\\ScummVM\\BETA\\");
+	extraPath = KDefaultBetaExtraPath;
+#else
+	_LIT(KDefaultExtraPath,"!:\\DATA\\ScummVM\\");
+	extraPath = KDefaultExtraPath;
 	Common::FSNode pluginsNode(Symbian::GetExecutablePath());
 	if (pluginsNode.exists() && pluginsNode.isDirectory()) {
 			s.add("SYMBIAN_DATAFOLDER", new Common::FSDirectory(Symbian::GetExecutablePath()), priority);
 		}
+#endif
+
+	for (TInt i = EDriveA; i <= EDriveZ; i++) {
+		if (rfs.DriveToChar(i, driveLetter) != KErrNone)
+			continue;
+		extraPath[0] = driveLetter;
+		if(BaflUtils::FolderExists(rfs, extraPath)){
+			TBuf8<KMaxFileName> fileName8 = extraPath.Collapse();
+			s.add("SYMBIAN_DATAFOLDER" + driveLetter, new Common::FSDirectory((char *)fileName8.PtrZ()), priority);
+		}
+	}
 }
 
 void OSystem_SDL_Symbian::quitWithErrorMsg(const char * /*aMsg*/) {
@@ -143,32 +163,6 @@ void OSystem_SDL_Symbian::quitWithErrorMsg(const char * /*aMsg*/) {
 		g_system->quit();
 }
 
-#ifdef GUI_ENABLE_KEYSDIALOG
-void OSystem_SDL_Symbian::quit() {
-	delete GUI_Actions::Instance();
-
-	// Call parent implementation of this method
-	OSystem_SDL::quit();
-}
-
-void OSystem_SDL_Symbian::engineInit() {
-	// Check mappings for the engine just started
-	checkMappings();
-}
-
-void OSystem_SDL_Symbian::engineDone() {
-	// Need to reset engine to basic state after an engine has been running
-	GUI::Actions::Instance()->initInstanceMain(this);
-}
-
-void OSystem_SDL_Symbian::checkMappings() {
-	if (ConfMan.get("gameid").empty() || GUI::Actions::Instance()->initialized())
-		return;
-
-	GUI::Actions::Instance()->initInstanceGame();
-}
-#endif
-
 Common::String OSystem_SDL_Symbian::getDefaultConfigFileName() {
 	char configFile[MAXPATHLEN];
 	strcpy(configFile, Symbian::GetExecutablePath());
@@ -177,24 +171,77 @@ Common::String OSystem_SDL_Symbian::getDefaultConfigFileName() {
 }
 
 bool OSystem_SDL_Symbian::hasFeature(Feature f) {
-#ifdef GUI_ENABLE_KEYSDIALOG
-	if (f == kFeatureJoystickDeadzone)
-		return false;
-#endif
 	if (f == kFeatureFullscreenMode)
 		return false;
+	if (f == kFeatureOpenUrl) return true;
 
 	return OSystem_SDL::hasFeature(f);
 }
 
-
-RFs& OSystem_SDL_Symbian::FsSession() {
-	return *_RFs;
+Common::KeymapperDefaultBindings *OSystem_SDL_Symbian::getKeymapperDefaultBindings(){
+	Common::KeymapperDefaultBindings *keymapperDefaultBindings = new Common::KeymapperDefaultBindings();
+	keymapperDefaultBindings->setDefaultBinding(Common::kGlobalKeymapName, "MENU", "ASTERISK");
+	return keymapperDefaultBindings;
 }
 
-// Symbian bsearch implementation is flawed
+_LIT8(KHTMLMimeType, "text/html");
+_LIT(KOperaName,"OperaMobile.exe");
+const size_t kOpera10500_UID = 537056398;
+const char kFailMsg[] = "RApaLsSession failed: error = %d";
+
+bool OSystem_SDL_Symbian::openUrl(const Common::String &url) {
+	TAutoClose2<RApaLsSession> appArcSession;
+	TInt error = appArcSession->Connect();
+	if (error != KErrNone) {
+		warning(kFailMsg, error);
+		return false;
+	}
+	appArcSession->GetAllApps(); // inits RApaLsSession
+
+	TUid browserUID;
+	TDataType html = TDataType(KHTMLMimeType);
+	error = appArcSession->AppForDataType(html, browserUID);
+	if (browserUID == KNullUid) {
+		warning("Can't find any browser. Try to install Opera.");
+		return false;
+	}
+
+	TApaAppInfo info;
+	error = appArcSession->GetAppInfo(info, browserUID);
+
+	// Give more time to obtain app list
+	while (error == RApaLsSession::EAppListInvalid) {
+		error = appArcSession->GetAppInfo(info, browserUID);
+		User::After(TTimeIntervalMicroSeconds32(100000));  // 0.1 secs
+	}
+
+	// HACK: We should run Opera 10 itself, not launcher, because
+	// Opera's launcher doesn't recognize commandline args.
+	if (browserUID.iUid == kOpera10500_UID) {
+		TParse pth;
+		pth.Set(info.iFullName, NULL , NULL);
+		TPtrC name = pth.NameAndExt();
+		info.iFullName.SetLength(info.iFullName.Length() - name.Length());
+		info.iFullName.Append(KOperaName);
+	}
+
+	HBufC *addr = CnvUtfConverter::ConvertToUnicodeFromUtf8L(TPtrC8((TUint8 *)url.c_str(), url.size()));
+	CleanupStack::PushL(addr);
+
+	TAutoClose2<RProcess> proc;
+	error = proc->Create(info.iFullName, *addr);
+	if (error == KErrNone)
+		proc->Resume();
+	else
+		warning("Failure while browser starts = %d", error);
+
+	CleanupStack::PopAndDestroy(addr);
+	return false;
+}
+
+// Symbian bsearch implementation is flawed.
 void* scumm_bsearch(const void *key, const void *base, size_t nmemb, size_t size, int (*compar)(const void *, const void *)) {
-	// Perform binary search
+	// Perform binary search.
 	size_t lo = 0;
 	size_t hi = nmemb;
 	while (lo < hi) {
@@ -212,3 +259,9 @@ void* scumm_bsearch(const void *key, const void *base, size_t nmemb, size_t size
 	return NULL;
 }
 
+/** Provide access to file server session. Lifetime managed by UI framework. */
+RFs &FsSession() {
+	return CEikonEnv::Static()->FsSession();
+}
+
+extern "C" void __sync_synchronize(){}
