@@ -198,7 +198,7 @@ int OSystem_Wii::getDefaultGraphicsMode() const {
 	return gmStandard;
 }
 
-bool OSystem_Wii::setGraphicsMode(int mode) {
+bool OSystem_Wii::setGraphicsMode(int mode, uint flags) {
 	_configGraphicsMode = mode;
 	return true;
 }
@@ -244,13 +244,18 @@ void OSystem_Wii::initSize(uint width, uint height,
 #endif
 
 	uint newWidth, newHeight;
+
+#ifdef USE_RGB_COLOR
 	if (_pfGame.bytesPerPixel > 1) {
 		newWidth = ROUNDUP(width, 4);
 		newHeight = ROUNDUP(height, 4);
 	} else {
+#endif
 		newWidth = ROUNDUP(width, 8);
 		newHeight = ROUNDUP(height, 4);
+#ifdef USE_RGB_COLOR
 	}
+#endif
 
 	if (_gameWidth != newWidth || _gameHeight != newHeight) {
 		assert((newWidth <= 640) && (newHeight <= 480));
@@ -571,16 +576,15 @@ void OSystem_Wii::clearOverlay() {
 	_overlayDirty = true;
 }
 
-void OSystem_Wii::grabOverlay(void *buf, int pitch) {
-	int h = _overlayHeight;
-	uint16 *src = _overlayPixels;
-	byte *dst = (byte *)buf;
+void OSystem_Wii::grabOverlay(Graphics::Surface &surface) {
+	assert(surface.w >= _overlayWidth);
+	assert(surface.h >= _overlayHeight);
+	assert(surface.format.bytesPerPixel == sizeof(uint16));
 
-	do {
-		memcpy(dst, src, _overlayWidth * sizeof(uint16));
-		src += _overlayWidth;
-		dst += pitch;
-	} while (--h);
+	byte *src = (byte *)_overlayPixels;
+	byte *dst = (byte *)surface.getPixels();
+	Graphics::copyBlit(dst, src, surface.pitch, _overlayWidth * sizeof(uint16),
+		_overlayWidth, _overlayHeight, sizeof(uint16));
 }
 
 void OSystem_Wii::copyRectToOverlay(const void *buf, int pitch, int x,
@@ -651,7 +655,6 @@ void OSystem_Wii::setMouseCursor(const void *buf, uint w, uint h, int hotspotX,
 									const Graphics::PixelFormat *format) {
 	gfx_tex_format_t tex_format = GFX_TF_PALETTE_RGB5A3;
 	uint tw, th;
-	bool tmpBuf = false;
 	uint32 oldKeycolor = _mouseKeyColor;
 
 #ifdef USE_RGB_COLOR
@@ -666,13 +669,12 @@ void OSystem_Wii::setMouseCursor(const void *buf, uint w, uint h, int hotspotX,
 		tw = ROUNDUP(w, 4);
 		th = ROUNDUP(h, 4);
 
-		if (_pfCursor != _pfRGB3444)
-			tmpBuf = true;
 	} else {
 #endif
 		_mouseKeyColor = keycolor & 0xff;
 		tw = ROUNDUP(w, 8);
 		th = ROUNDUP(h, 4);
+
 #ifdef USE_RGB_COLOR
 	}
 #endif
@@ -684,64 +686,60 @@ void OSystem_Wii::setMouseCursor(const void *buf, uint w, uint h, int hotspotX,
 
 	gfx_tex_set_bilinear_filter(&_texMouse, _bilinearFilter);
 
-	if ((tw != w) || (th != h))
-		tmpBuf = true;
+	u8 bpp = _texMouse.bpp >> 3;
+	byte *tmp = (byte *) malloc(tw * th * bpp);
 
-	if (!tmpBuf) {
-		gfx_tex_convert(&_texMouse, (const byte *)buf);
-	} else {
-		u8 bpp = _texMouse.bpp >> 3;
-		byte *tmp = (byte *) malloc(tw * th * bpp);
+	if (!tmp) {
+		printf("could not alloc temp cursor buffer\n");
+		::abort();
+	}
 
-		if (!tmp) {
-			printf("could not alloc temp cursor buffer\n");
+	if (bpp > 1)
+		memset(tmp, 0, tw * th * bpp);
+	else
+		memset(tmp, _mouseKeyColor, tw * th);
+
+#ifdef USE_RGB_COLOR
+	if (bpp > 1) {
+
+		if (!Graphics::crossBlit(tmp, (const byte *)buf,
+									tw * _pfRGB3444.bytesPerPixel,
+									w * _pfCursor.bytesPerPixel,
+									tw, th, _pfRGB3444, _pfCursor)) {
+			printf("crossBlit failed (cursor)\n");
 			::abort();
 		}
 
-		if (bpp > 1)
-			memset(tmp, 0, tw * th * bpp);
-		else
-			memset(tmp, _mouseKeyColor, tw * th);
-
-#ifdef USE_RGB_COLOR
-		if (bpp > 1) {
-			if (!Graphics::crossBlit(tmp, (const byte *)buf,
-										tw * _pfRGB3444.bytesPerPixel,
-										w * _pfCursor.bytesPerPixel,
-										tw, th, _pfRGB3444, _pfCursor)) {
-				printf("crossBlit failed (cursor)\n");
-				::abort();
+		// nasty, shouldn't the frontend set the alpha channel?
+		const u16 *s = (const u16 *) buf;
+		u16 *d = (u16 *) tmp;
+		for (u16 y = 0; y < h; ++y) {
+			for (u16 x = 0; x < w; ++x) {
+				if (*s++ == _mouseKeyColor)
+					*d++ &= ~(7 << 12);
+				else
+					d++;
 			}
 
-			// nasty, shouldn't the frontend set the alpha channel?
-			const u16 *s = (const u16 *) buf;
-			u16 *d = (u16 *) tmp;
-			for (u16 y = 0; y < h; ++y) {
-				for (u16 x = 0; x < w; ++x) {
-					if (*s++ == _mouseKeyColor)
-						*d++ &= ~(7 << 12);
-					else
-						d++;
-				}
-
-				d += tw - w;
-			}
-		} else {
-#endif
-			byte *dst = tmp;
-			const byte *src = (const byte *)buf;
-			do {
-				memcpy(dst, src, w * bpp);
-				src += w * bpp;
-				dst += tw * bpp;
-			} while (--h);
-#ifdef USE_RGB_COLOR
+			d += tw - w;
 		}
+	} else {
+#endif
+		const byte *s = (const byte *)buf;
+		byte *d = (byte *) tmp;
+		for (u16 y = 0; y < h; ++y) {
+			for (u16 x = 0; x < w; ++x) {
+				*d++ = *s++;
+			}
+			d += tw - w;
+		}
+
+#ifdef USE_RGB_COLOR
+	}
 #endif
 
-		gfx_tex_convert(&_texMouse, tmp);
-		free(tmp);
-	}
+	gfx_tex_convert(&_texMouse, tmp);
+	free(tmp);
 
 	_mouseHotspotX = hotspotX;
 	_mouseHotspotY = hotspotY;
