@@ -19,38 +19,30 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
+ 
+// Disable symbol overrides so that we can use system headers.
+#define FORBIDDEN_SYMBOL_ALLOW_ALL
 
 #include "common/scummsys.h"
 
 #if defined(DYNAMIC_MODULES) && defined(_WIN32)
 
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+#include <tchar.h>
+
+#include "backends/platform/sdl/win32/win32_wrapper.h"
 #include "backends/plugins/win32/win32-provider.h"
 #include "backends/plugins/dynamic-plugin.h"
 #include "common/debug.h"
 #include "common/fs.h"
 
-#define WIN32_LEAN_AND_MEAN
-#include <windows.h>
-
-
-class Win32Plugin : public DynamicPlugin {
-private:
-	static const TCHAR* toUnicode(const char *x) {
-	#ifndef UNICODE
-		return (const TCHAR *)x;
-	#else
-		static TCHAR unicodeString[MAX_PATH];
-		MultiByteToWideChar(CP_ACP, 0, x, strlen(x) + 1, unicodeString, sizeof(unicodeString) / sizeof(TCHAR));
-		return unicodeString;
-	#endif
-	}
-
-
+class Win32Plugin final : public DynamicPlugin {
 protected:
 	void *_dlHandle;
 
-	virtual VoidFunc findSymbol(const char *symbol) {
-		FARPROC func = GetProcAddress((HMODULE)_dlHandle, toUnicode(symbol));
+	virtual VoidFunc findSymbol(const char *symbol) override {
+		FARPROC func = GetProcAddress((HMODULE)_dlHandle, symbol);
 		if (!func)
 			debug("Failed loading symbol '%s' from plugin '%s'", symbol, _filename.c_str());
 
@@ -61,9 +53,11 @@ public:
 	Win32Plugin(const Common::String &filename)
 		: DynamicPlugin(filename), _dlHandle(0) {}
 
-	bool loadPlugin() {
+	virtual bool loadPlugin() override {
 		assert(!_dlHandle);
-		_dlHandle = LoadLibrary(toUnicode(_filename.c_str()));
+		TCHAR *tFilename = Win32::stringToTchar(_filename);
+		_dlHandle = LoadLibrary(tFilename);
+		free(tFilename);
 
 		if (!_dlHandle) {
 			debug("Failed loading plugin '%s' (error code %d)", _filename.c_str(), (int32) GetLastError());
@@ -75,7 +69,7 @@ public:
 		return DynamicPlugin::loadPlugin();
 	}
 
-	void unloadPlugin() {
+	virtual void unloadPlugin() override {
 		DynamicPlugin::unloadPlugin();
 		if (_dlHandle) {
 			if (!FreeLibrary((HMODULE)_dlHandle))
