@@ -29,10 +29,11 @@
 
 #include "common/text-to-speech.h"
 #include "common/str.h"
+#include "common/ustr.h"
 #include "common/list.h"
 
 
-class WindowsTextToSpeechManager : public Common::TextToSpeechManager {
+class WindowsTextToSpeechManager final : public Common::TextToSpeechManager {
 public:
 	enum SpeechState {
 		READY,
@@ -51,7 +52,7 @@ public:
 	WindowsTextToSpeechManager();
 	virtual ~WindowsTextToSpeechManager() override;
 
-	virtual bool say(Common::String str, Action action, Common::String charset = "") override;
+	virtual bool say(const Common::U32String &str, Action action) override;
 
 	virtual bool stop() override;
 	virtual bool pause() override;
@@ -77,7 +78,7 @@ private:
 	void init();
 	virtual void updateVoices() override;
 	void createVoice(void *cpVoiceToken);
-	Common::String lcidToLocale(WCHAR *lcid);
+	Common::String lcidToLocale(LCID locale);
 	SpeechState _speechState;
 	Common::String _lastSaid;
 	HANDLE _thread;
