@@ -33,44 +33,28 @@
 #undef INCLUDED_FROM_BASE_PLUGINS_H
 
 
-/**
- * @page pagePlugins An overview of the ScummVM plugin system
- * This is a brief overview of how plugins (dynamically loadable code modules)
- * work in ScummVM. We will explain how to write plugins, how they work internally,
- * and sketch how porters can add support for them in their ports.
- *
- * \section secPluginImpl Implementing a plugin
- * TODO
- *
- * \section secPluginUse Using plugins
- * TODO
- *
- * \section secPluginInternals How plugins work internally
- * TODO
- *
- * \section secPluginBackend How to add support for dynamic plugins to a port
- * TODO
- */
-
-
-
 // Plugin versioning
 
 /** Global Plugin API version */
 #define PLUGIN_VERSION 1
 
 enum PluginType {
-	PLUGIN_TYPE_ENGINE = 0,
+	PLUGIN_TYPE_ENGINE_DETECTION = 0,
+	PLUGIN_TYPE_ENGINE,
 	PLUGIN_TYPE_MUSIC,
-	/* PLUGIN_TYPE_SCALER, */	// TODO: Add graphics scaler plugins
+	PLUGIN_TYPE_DETECTION,
+	PLUGIN_TYPE_SCALER,
 
 	PLUGIN_TYPE_MAX
 };
 
 // TODO: Make the engine API version depend on ScummVM's version
 // because of the backlinking (posibly from the checkout revision)
-#define PLUGIN_TYPE_ENGINE_VERSION 1
+#define PLUGIN_TYPE_ENGINE_DETECTION_VERSION 1
+#define PLUGIN_TYPE_ENGINE_VERSION 2
 #define PLUGIN_TYPE_MUSIC_VERSION 1
+#define PLUGIN_TYPE_DETECTION_VERSION 1
+#define PLUGIN_TYPE_SCALER_VERSION 1
 
 extern int pluginTypeVersions[PLUGIN_TYPE_MAX];
 
@@ -150,6 +134,18 @@ public:
 
 	/** Returns the name of the plugin. */
 	virtual const char *getName() const = 0;
+
+	/**
+	 * Returns the engine id of the plugin, if implemented.
+	 * This mostly has the use with MetaEngines, but if another
+	 * type of plugins request this, we return a nullptr.
+	 * This is used because MetaEngines are now available in the
+	 * executable, and querying this we can match a MetaEngine
+	 * with it's related engine.
+	 */
+	virtual const char *getEngineId() const {
+		return nullptr;
+	}
 };
 
 /**
@@ -180,6 +176,7 @@ public:
 	 **/
 	PluginType getType() const;
 	const char *getName() const;
+	const char *getEngineId() const;
 
 	template <class T>
 	T &get() const {
@@ -198,6 +195,15 @@ public:
 	virtual const char *getFileName() const { return 0; }
 };
 
+class StaticPlugin : public Plugin {
+public:
+	StaticPlugin(PluginObject *pluginobject, PluginType type);
+	~StaticPlugin();
+	virtual bool loadPlugin();
+	virtual void unloadPlugin();
+};
+
+
 /** List of Plugin instances. */
 typedef Common::Array<Plugin *> PluginList;
 
@@ -299,6 +305,8 @@ protected:
 
 	bool tryLoadPlugin(Plugin *plugin);
 	void addToPluginsInMemList(Plugin *plugin);
+	const Plugin *findEnginePlugin(const Common::String &engineId);
+	const Plugin *findLoadedPlugin(const Common::String &engineId);
 
 	static PluginManager *_instance;
 	PluginManager();
@@ -311,12 +319,38 @@ public:
 
 	void addPluginProvider(PluginProvider *pp);
 
+	/**
+	 * A method which takes in a plugin of type ENGINE,
+	 * and returns the appropriate & matching METAENGINE.
+	 * It uses the Engine plugin's getName method, which is an identifier,
+	 * and then tries to matches it with each plugin present in memory.
+	 *
+	 * @param plugin A plugin of type ENGINE.
+	 *
+	 * @return A plugin of type METAENGINE.
+	 */
+	const Plugin *getMetaEngineFromEngine(const Plugin *plugin);
+
+	/**
+	 * A method which takes in a plugin of type METAENGINE,
+	 * and returns the appropriate & matching ENGINE.
+	 * It uses the MetaEngine's getEngineID to reconstruct the name
+	 * of engine plugin, and then tries to matches it with each plugin in memory.
+	 *
+	 * @param A plugin of type METAENGINE.
+	 *
+	 * @return A plugin of type ENGINE.
+	 */
+	const Plugin *getEngineFromMetaEngine(const Plugin *plugin);
+
 	// Functions used by the uncached PluginManager
 	virtual void init()	{}
 	virtual void loadFirstPlugin() {}
 	virtual bool loadNextPlugin() { return false; }
 	virtual bool loadPluginFromEngineId(const Common::String &engineId) { return false; }
 	virtual void updateConfigWithFileName(const Common::String &engineId) {}
+	virtual void loadDetectionPlugin() {}
+	virtual void unloadDetectionPlugin() {}
 
 	// Functions used only by the cached PluginManager
 	virtual void loadAllPlugins();
@@ -336,20 +370,27 @@ class PluginManagerUncached : public PluginManager {
 protected:
 	friend class PluginManager;
 	PluginList _allEnginePlugins;
+	Plugin  *_detectionPlugin;
 	PluginList::iterator _currentPlugin;
 
-	PluginManagerUncached() {}
+	bool _isDetectionLoaded;
+
+	PluginManagerUncached() : _isDetectionLoaded(false), _detectionPlugin(nullptr) {}
 	bool loadPluginByFileName(const Common::String &filename);
 
 public:
-	virtual void init();
-	virtual void loadFirstPlugin();
-	virtual bool loadNextPlugin();
-	virtual bool loadPluginFromEngineId(const Common::String &engineId);
-	virtual void updateConfigWithFileName(const Common::String &engineId);
+	virtual void init() override;
+	virtual void loadFirstPlugin() override;
+	virtual bool loadNextPlugin() override;
+	virtual bool loadPluginFromEngineId(const Common::String &engineId) override;
+	virtual void updateConfigWithFileName(const Common::String &engineId) override;
+#ifndef DETECTION_STATIC
+	virtual void loadDetectionPlugin() override;
+	virtual void unloadDetectionPlugin() override;
+#endif
 
-	virtual void loadAllPlugins() {} 	// we don't allow these
-	virtual void loadAllPluginsOfType(PluginType type) {}
+	virtual void loadAllPlugins() override {} 	// we don't allow these
+	virtual void loadAllPluginsOfType(PluginType type) override {}
 };
 
 #endif
