@@ -28,14 +28,26 @@
 #include "common/textconsole.h" // For error()
 #include "common/memory.h"
 
+#ifdef USE_CXX11
+#include "common/initializer_list.h"
+#endif
+
 namespace Common {
 
+/**
+ * @defgroup common_array Arrays
+ * @ingroup common
+ *
+ * @brief  Functions for replacing std arrays.
+ * @{
+ */
+
 /**
  * This class implements a dynamically sized container, which
- * can be accessed similar to a regular C++ array. Accessing
+ * can be accessed similarly to a regular C++ array. Accessing
  * elements is performed in constant time (like with plain arrays).
- * In addition, one can append, insert and remove entries (this
- * is the 'dynamic' part). Doing that in general takes time
+ * In addition, you can append, insert, and remove entries (this
+ * is the 'dynamic' part). In general, doing that takes time
  * proportional to the number of elements in the array.
  *
  * The container class closest to this in the C++ standard library is
@@ -44,23 +56,23 @@ namespace Common {
 template<class T>
 class Array {
 public:
-	typedef T *iterator;
-	typedef const T *const_iterator;
+	typedef T *iterator; /*!< Array iterator. */
+	typedef const T *const_iterator; /*!< Const-qualified array iterator. */
 
-	typedef T value_type;
+	typedef T value_type; /*!< Value type of the array. */
 
-	typedef uint size_type;
+	typedef uint size_type; /*!< Size type of the array. */
 
 protected:
-	size_type _capacity;
-	size_type _size;
-	T *_storage;
+	size_type _capacity; /*!< Maximum number of elements the array can hold. */
+	size_type _size; /*!< How many elements the array holds. */
+	T *_storage;  /*!< Memory used for element storage. */
 
 public:
 	Array() : _capacity(0), _size(0), _storage(nullptr) {}
 
 	/**
-	 * Constructs an array with `count` default-inserted instances of T. No
+	 * Construct an array with @p count default-inserted instances of @p T. No
 	 * copies are made.
 	 */
 	explicit Array(size_type count) : _size(count) {
@@ -70,13 +82,16 @@ public:
 	}
 
 	/**
-	 * Constructs an array with `count` copies of elements with value `value`.
+	 * Construct an array with @p count copies of elements with value @p value.
 	 */
 	Array(size_type count, const T &value) : _size(count) {
 		allocCapacity(count);
 		uninitialized_fill_n(_storage, count, value);
 	}
 
+	/**
+	 * Construct an array as a copy of the given @p array.
+	 */
 	Array(const Array<T> &array) : _capacity(array._size), _size(array._size), _storage(nullptr) {
 		if (array._storage) {
 			allocCapacity(_size);
@@ -84,6 +99,33 @@ public:
 		}
 	}
 
+#ifdef USE_CXX11
+	/**
+	 * Construct an array as a copy of the given array using the C++11 move semantic.
+	 */
+	Array(Array<T> &&old) : _capacity(old._capacity), _size(old._size), _storage(old._storage) {
+		old._storage = nullptr;
+		old._capacity = 0;
+		old._size = 0;
+	}
+
+	/**
+	 * Construct an array using list initialization.
+	 * For example:
+	 * @code
+	 * Common::Array<int> myArray = {1, 7, 42};
+	 * @endcode
+	 * constructs an array with 3 elements whose values are 1, 7, and 42 respectively.
+	 * @note
+	 * This constructor is only available when C++11 support is enabled.
+	 */
+	Array(std::initializer_list<T> list) : _size(list.size()) {
+		allocCapacity(list.size());
+		if (_storage)
+			Common::uninitialized_copy(list.begin(), list.end(), _storage);
+	}
+#endif
+
 	/**
 	 * Construct an array by copying data from a regular array.
 	 */
@@ -100,7 +142,7 @@ public:
 		_capacity = _size = 0;
 	}
 
-	/** Appends element to the end of the array. */
+	/** Append an element to the end of the array. */
 	void push_back(const T &element) {
 		if (_size + 1 <= _capacity)
 			new ((void *)&_storage[_size++]) T(element);
@@ -108,6 +150,7 @@ public:
 			insert_aux(end(), &element, &element + 1);
 	}
 
+	/** Append an element to the end of the array. */
 	void push_back(const Array<T> &array) {
 		if (_size + array.size() <= _capacity) {
 			uninitialized_copy(array.begin(), array.end(), end());
@@ -116,7 +159,7 @@ public:
 			insert_aux(end(), array.begin(), array.end());
 	}
 
-	/** Removes the last element of the array. */
+	/** Remove the last element of the array. */
 	void pop_back() {
 		assert(_size > 0);
 		_size--;
@@ -124,58 +167,60 @@ public:
 		_storage[_size].~T();
 	}
 
-	/** Returns a pointer to the underlying memory serving as element storage. */
+	/** Return a pointer to the underlying memory serving as element storage. */
 	const T *data() const {
 		return _storage;
 	}
 
-	/** Returns a pointer to the underlying memory serving as element storage. */
+	/** Return a pointer to the underlying memory serving as element storage. */
 	T *data() {
 		return _storage;
 	}
 
-	/** Returns a reference to the first element of the array. */
+	/** Return a reference to the first element of the array. */
 	T &front() {
 		assert(_size > 0);
 		return _storage[0];
 	}
 
-	/** Returns a reference to the first element of the array. */
+	/** Return a reference to the first element of the array. */
 	const T &front() const {
 		assert(_size > 0);
 		return _storage[0];
 	}
 
-	/** Returns a reference to the last element of the array. */
+	/** Return a reference to the last element of the array. */
 	T &back() {
 		assert(_size > 0);
 		return _storage[_size-1];
 	}
 
-	/** Returns a reference to the last element of the array. */
+	/** Return a reference to the last element of the array. */
 	const T &back() const {
 		assert(_size > 0);
 		return _storage[_size-1];
 	}
 
-
+	/** Insert an element into the array at the given position. */
 	void insert_at(size_type idx, const T &element) {
 		assert(idx <= _size);
 		insert_aux(_storage + idx, &element, &element + 1);
 	}
 
+	/** Insert copies of all the elements from the given array into this array at the given position. */
 	void insert_at(size_type idx, const Array<T> &array) {
 		assert(idx <= _size);
 		insert_aux(_storage + idx, array.begin(), array.end());
 	}
 
 	/**
-	 * Inserts element before pos.
+	 * Insert an element before @p pos.
 	 */
 	void insert(iterator pos, const T &element) {
 		insert_aux(pos, &element, &element + 1);
 	}
 
+	/** Remove an element at the given position from the array and return the value of that element. */
 	T remove_at(size_type idx) {
 		assert(idx < _size);
 		T tmp = _storage[idx];
@@ -188,16 +233,19 @@ public:
 
 	// TODO: insert, remove, ...
 
+	/** Return a reference to the element at the given position in the array. */
 	T &operator[](size_type idx) {
 		assert(idx < _size);
 		return _storage[idx];
 	}
 
+	/** Return a const reference to the element at the given position in the array. */
 	const T &operator[](size_type idx) const {
 		assert(idx < _size);
 		return _storage[idx];
 	}
 
+	/** Assign the given @p array to this array. */
 	Array<T> &operator=(const Array<T> &array) {
 		if (this == &array)
 			return *this;
@@ -210,10 +258,31 @@ public:
 		return *this;
 	}
 
+#ifdef USE_CXX11
+	/** Assign the given array to this array using the C++11 move semantic. */
+	Array &operator=(Array<T> &&old) {
+		if (this == &old)
+			return *this;
+
+		freeStorage(_storage, _size);
+		_capacity = old._capacity;
+		_size = old._size;
+		_storage = old._storage;
+
+		old._storage = nullptr;
+		old._capacity = 0;
+		old._size = 0;
+
+		return *this;
+	}
+#endif
+
+	/** Return the size of the array. */
 	size_type size() const {
 		return _size;
 	}
 
+	/** Clear the array of all its elements. */
 	void clear() {
 		freeStorage(_storage, _size);
 		_storage = nullptr;
@@ -221,6 +290,7 @@ public:
 		_capacity = 0;
 	}
 
+	/** Erase the element at @p pos position and return an iterator pointing to the next element in the array. */
 	iterator erase(iterator pos) {
 		copy(pos + 1, _storage + _size, pos);
 		_size--;
@@ -229,10 +299,12 @@ public:
 		return pos;
 	}
 
+	/** Check whether the array is empty. */
 	bool empty() const {
 		return (_size == 0);
 	}
 
+	/** Check whether two arrays are identical. */
 	bool operator==(const Array<T> &other) const {
 		if (this == &other)
 			return true;
@@ -245,26 +317,34 @@ public:
 		return true;
 	}
 
+	/** Check if two arrays are different. */
 	bool operator!=(const Array<T> &other) const {
 		return !(*this == other);
 	}
 
+	/** Return an iterator pointing to the first element in the array. */
 	iterator       begin() {
 		return _storage;
 	}
 
+	/** Return an iterator pointing past the last element in the array. */
 	iterator       end() {
 		return _storage + _size;
 	}
 
+	/** Return a const iterator pointing to the first element in the array. */
 	const_iterator begin() const {
 		return _storage;
 	}
 
+	/** Return a const iterator pointing past the last element in the array. */
 	const_iterator end() const {
 		return _storage + _size;
 	}
 
+	/** Reserve enough memory in the array so that it can store at least the given number of elements.
+	 *  The current content of the array is not modified.
+	 */
 	void reserve(size_type newCapacity) {
 		if (newCapacity <= _capacity)
 			return;
@@ -279,13 +359,19 @@ public:
 		}
 	}
 
+	/** Change the size of the array. */
 	void resize(size_type newSize) {
 		reserve(newSize);
+		for (size_type i = newSize; i < _size; ++i)
+			_storage[i].~T();
 		for (size_type i = _size; i < newSize; ++i)
 			new ((void *)&_storage[i]) T();
 		_size = newSize;
 	}
 
+	/** Assign to this array the elements between the given iterators from another array,
+	 *  from @p first included to @p last excluded.
+	 */
 	void assign(const_iterator first, const_iterator last) {
 		resize(distance(first, last)); // FIXME: ineffective?
 		T *dst = _storage;
@@ -294,15 +380,17 @@ public:
 	}
 
 protected:
+	/** Round up capacity to the next power of 2.
+	  * A minimal capacity of 8 is used.
+	  */
 	static size_type roundUpCapacity(size_type capacity) {
-		// Round up capacity to the next power of 2;
-		// we use a minimal capacity of 8.
 		size_type capa = 8;
 		while (capa < capacity)
 			capa <<= 1;
 		return capa;
 	}
 
+	/** Allocate a specific capacity for the array. */
 	void allocCapacity(size_type capacity) {
 		_capacity = capacity;
 		if (capacity) {
@@ -314,6 +402,7 @@ protected:
 		}
 	}
 
+	/** Free the storage used by the array. */
 	void freeStorage(T *storage, const size_type elements) {
 		for (size_type i = 0; i < elements; ++i)
 			storage[i].~T();
@@ -325,7 +414,7 @@ protected:
 	 * Unlike std::vector::insert, this method does not accept
 	 * arbitrary iterators, mainly because our iterator system is
 	 * seriously limited and does not distinguish between input iterators,
-	 * output iterators, forward iterators or random access iterators.
+	 * output iterators, forward iterators, or random access iterators.
 	 *
 	 * So, we simply restrict to Array iterators. Extending this to arbitrary
 	 * random access iterators would be trivial.
@@ -352,7 +441,7 @@ protected:
 				uninitialized_copy(oldStorage, oldStorage + idx, _storage);
 				// Copy the data we insert
 				uninitialized_copy(first, last, _storage + idx);
-				// Afterwards copy the old data from the position where we
+				// Afterwards, copy the old data from the position where we
 				// insert.
 				uninitialized_copy(oldStorage + idx, oldStorage + _size, _storage + idx + n);
 
@@ -390,20 +479,21 @@ protected:
 };
 
 /**
- * Double linked list with sorted nodes.
+ * Array with sorted nodes.
  */
-template<class T>
+template<class T, typename CompareArgType = const void *>
 class SortedArray : public Array<T> {
 public:
+	typedef int (*Comparator)(CompareArgType, CompareArgType);
 	typedef T *iterator;
 	typedef uint size_type;
 
-	SortedArray(int (*comparator)(const void *, const void *)) {
+	SortedArray(Comparator comparator) {
 		_comparator = comparator;
 	}
 
 	/**
-	 * Inserts element at the sorted position.
+	 * Insert an element at the sorted position.
 	 */
 	void insert(const T &element) {
 		if (!this->_size) {
@@ -435,7 +525,7 @@ private:
 	// Based on code Copyright (C) 2008-2009 Ksplice, Inc.
 	// Author: Tim Abbott <tabbott@ksplice.com>
 	// Licensed under GPLv2+
-	T *bsearchMin(void *key) {
+	T *bsearchMin(CompareArgType key) {
 		uint start_ = 0, end_ = this->_size;
 		int result;
 
@@ -445,18 +535,18 @@ private:
 			result = this->_comparator(key, this->_storage[mid]);
 			if (result < 0)
 				end_ = mid;
-			else if (result > 0)
-				start_ = mid + 1;
 			else
-				return &this->_storage[mid];
+				start_ = mid + 1;
 		}
 
 		return &this->_storage[start_];
 	}
 
-	int (*_comparator)(const void *, const void *);
+	Comparator _comparator;
 };
 
+/** @} */
+
 } // End of namespace Common
 
 #endif
