@@ -29,30 +29,41 @@
 #include "common/hashmap.h"
 #include "common/ptr.h"
 #include "common/str.h"
+#include "common/ustr.h"
 
 class AbstractFSNode;
 
 namespace Common {
 
+/**
+ * @defgroup common_fs File system
+ * @ingroup common
+ *
+ * @brief API for operations on the file system.
+ *
+ * @{
+ */
+
 class FSNode;
 class SeekableReadStream;
 class WriteStream;
+class SeekableWriteStream;
 
 /**
- * List of multiple file system nodes. E.g. the contents of a given directory.
- * This is subclass instead of just a typedef so that we can use forward
- * declarations of it in other places.
+ * List of multiple file system nodes. For example, the contents of a given directory.
+ * This is a subclass instead of just a typedef so that forward declarations
+ * of it can be used in other places.
  */
 class FSList : public Array<FSNode> {};
 
 /**
  * FSNode, short for "File System Node", provides an abstraction for file
- * paths, allowing for portable file system browsing. This means for example,
+ * paths, allowing for portable file system browsing. This means, for example,
  * that multiple or single roots have to be supported (compare Unix with a
  * single root, Windows with multiple roots C:, D:, ...).
  *
  * To this end, we abstract away from paths; implementations can be based on
- * paths (and it's left to them whether / or \ or : is the path separator :-);
+ * paths (and it is left to them whether '/', '\', or ':' is the path separator)
  * but it is also possible to use inodes or vrefs (MacOS 9) or anything else.
  */
 class FSNode : public ArchiveMember {
@@ -60,7 +71,7 @@ private:
 	friend class ::AbstractFSNode;
 	SharedPtr<AbstractFSNode>	_realNode;
 	/**
-	 * Construct a FSNode from a backend's AbstractFSNode implementation.
+	 * Construct an FSNode from a backend's AbstractFSNode implementation.
 	 *
 	 * @param realNode Pointer to a heap allocated instance. FSNode will take
 	 *                 ownership of the pointer.
@@ -78,7 +89,7 @@ public:
 	};
 
 	/**
-	 * Create a new pathless FSNode. Since there's no path associated
+	 * Create a new pathless FSNode. Since there is no path associated
 	 * with this node, path-related operations (i.e. exists(), isDirectory(),
 	 * getPath()) will always return false or raise an assertion.
 	 */
@@ -88,12 +99,12 @@ public:
 	 * Create a new FSNode referring to the specified path. This is
 	 * the counterpart to the path() method.
 	 *
-	 * If path is empty or equals ".", then a node representing the "current
+	 * If the path is empty or equals ".", then a node representing the "current
 	 * directory" will be created. If that is not possible (since e.g. the
-	 * operating system doesn't support the concept), some other directory is
+	 * operating system does not support the concept), some other directory is
 	 * used (usually the root directory).
 	 */
-	explicit FSNode(const String &path);
+	explicit FSNode(const Path &path);
 
 	virtual ~FSNode() {}
 
@@ -104,9 +115,9 @@ public:
 	bool operator<(const FSNode& node) const;
 
 	/**
-	 * Indicates whether the object referred by this node exists in the filesystem or not.
+	 * Indicate whether the object referred by this node exists in the file system or not.
 	 *
-	 * @return bool true if the node exists, false otherwise.
+	 * @return True if the node exists, false otherwise.
 	 */
 	bool exists() const;
 
@@ -122,10 +133,10 @@ public:
 	 *       this should affect what exists/isDirectory/isReadable/isWritable return
 	 *       for existing nodes. However, this is not the case for many existing
 	 *       FSNode implementations. Either fix those, or document that FSNodes
-	 *       can become 'stale'...
+	 *       can become 'stale'.
 	 *
-	 * @param name	the name of a child of this directory
-	 * @return the node referring to the child with the given name
+	 * @param name	Name of a child of this directory.
+	 * @return The node referring to the child with the given name.
 	 */
 	FSNode getChild(const String &name) const;
 
@@ -133,40 +144,40 @@ public:
 	 * Return a list of all child nodes of this directory node. If called on a node
 	 * that does not represent a directory, false is returned.
 	 *
-	 * @return true if successful, false otherwise (e.g. when the directory does not exist).
+	 * @return True if successful, false otherwise (e.g. when the directory does not exist).
 	 */
 	bool getChildren(FSList &fslist, ListMode mode = kListDirectoriesOnly, bool hidden = true) const;
 
 	/**
-	 * Return a human readable string for this node, usable for display (e.g.
+	 * Return a human-readable string for this node, usable for display (e.g.
 	 * in the GUI code). Do *not* rely on it being usable for anything else,
-	 * like constructing paths!
+	 * like constructing paths.
 	 *
-	 * @return the display name
+	 * @return The display name.
 	 */
-	virtual String getDisplayName() const;
+	virtual U32String getDisplayName() const;
 
 	/**
 	 * Return a string representation of the name of the file. This can be
 	 * used e.g. by detection code that relies on matching the name of a given
-	 * file. But it is *not* suitable for use with fopen / File::open, nor
+	 * file. However, it is *not* suitable for use with fopen / File::open, nor
 	 * should it be archived.
 	 *
-	 * @return the file name
+	 * @return The file name.
 	 */
 	virtual String getName() const;
 
 	/**
-	 * Return a string representation of the file which is suitable for
+	 * Return a string representation of the file that is suitable for
 	 * archiving (i.e. writing to the config file). This will usually be a
 	 * 'path' (hence the name of the method), but can be anything that meets
-	 * the above criterions. What a 'path' is differs greatly from system to
-	 * system anyway.
+	 * the above criteria. What a 'path' is differs greatly from system to
+	 * system.
 	 *
 	 * @note Do not assume that this string contains (back)slashes or any
 	 *       other kind of 'path separators'.
 	 *
-	 * @return the 'path' represented by this filesystem node
+	 * @return The 'path' represented by this file system node.
 	 */
 	String getPath() const;
 
@@ -177,7 +188,7 @@ public:
 	FSNode getParent() const;
 
 	/**
-	 * Indicates whether the node refers to a directory or not.
+	 * Indicate whether the node refers to a directory or not.
 	 *
 	 * @todo Currently we assume that a node that is not a directory
 	 * automatically is a file (ignoring things like symlinks or pipes).
@@ -188,7 +199,7 @@ public:
 	bool isDirectory() const;
 
 	/**
-	 * Indicates whether the object referred by this node can be read from or not.
+	 * Indicate whether the object referred by this node can be read from or not.
 	 *
 	 * If the node refers to a directory, readability implies being able to read
 	 * and list the directory entries.
@@ -196,63 +207,63 @@ public:
 	 * If the node refers to a file, readability implies being able to read the
 	 * contents of the file.
 	 *
-	 * @return true if the object can be read, false otherwise.
+	 * @return True if the object can be read, false otherwise.
 	 */
 	bool isReadable() const;
 
 	/**
-	 * Indicates whether the object referred by this node can be written to or not.
+	 * Indicate whether the object referred by this node can be written to or not.
 	 *
 	 * If the node refers to a directory, writability implies being able to modify
-	 * the directory entry (i.e. rename the directory, remove it or write files inside of it).
+	 * the directory entry (i.e. rename the directory, remove it, or write files inside of it).
 	 *
 	 * If the node refers to a file, writability implies being able to write data
 	 * to the file.
 	 *
-	 * @return true if the object can be written to, false otherwise.
+	 * @return True if the object can be written to, false otherwise.
 	 */
 	bool isWritable() const;
 
 	/**
-	 * Creates a SeekableReadStream instance corresponding to the file
+	 * Create a SeekableReadStream instance corresponding to the file
 	 * referred by this node. This assumes that the node actually refers
 	 * to a readable file. If this is not the case, 0 is returned.
 	 *
-	 * @return pointer to the stream object, 0 in case of a failure
+	 * @return Pointer to the stream object, 0 in case of a failure.
 	 */
 	virtual SeekableReadStream *createReadStream() const;
 
 	/**
-	 * Creates a WriteStream instance corresponding to the file
+	 * Create a WriteStream instance corresponding to the file
 	 * referred by this node. This assumes that the node actually refers
 	 * to a readable file. If this is not the case, 0 is returned.
 	 *
-	 * @return pointer to the stream object, 0 in case of a failure
+	 * @return Pointer to the stream object, 0 in case of a failure.
 	 */
-	WriteStream *createWriteStream() const;
+	SeekableWriteStream *createWriteStream() const;
 
 	/**
-	 * Creates a directory referred by this node. This assumes that this
-	 * node refers to non-existing directory. If this is not the case,
+	 * Create a directory referred by this node. This assumes that this
+	 * node refers to a non-existing directory. If this is not the case,
 	 * false is returned.
 	 *
-	 * @return true if the directory was created, false otherwise.
+	 * @return True if the directory was created, false otherwise.
 	 */
 	bool createDirectory() const;
 };
 
 /**
- * FSDirectory models a directory tree from the filesystem and allows users
+ * FSDirectory models a directory tree from the file system and allows users
  * to access it through the Archive interface. Searching is case-insensitive,
- * since the intended goal is supporting retrieval of game data.
+ * since the intended goal is to support retrieval of game data.
  *
  * FSDirectory can represent a single directory, or a tree with specified depth,
  * depending on the value passed to the 'depth' parameter in the constructors.
- * In the default mode, filenames are cached with their relative path,
+ * In the default mode, file names are cached with their relative path,
  * with elements separated by slashes, e.g.:
- *
+ * @code
  * c:\my\data\file.ext
- *
+ * @endcode
  * would be cached as 'data/file.ext' if FSDirectory was created on 'c:/my' with
  * depth > 1. If depth was 1, then the 'data' subdirectory would have been
  * ignored, instead.
@@ -260,24 +271,27 @@ public:
  * underlying file system.
  *
  * Relative paths can be specified when calling matching functions like createReadStreamForMember(),
- * hasFile(), listMatchingMembers() and listMembers(). Please see the function
- * specific comments for more information.
+ * hasFile(), listMatchingMembers(), and listMembers(). See the function-specific
+ * documentation for more information.
  *
  * If the 'flat' argument to the constructor is true, files in subdirectories
- * are cached without the relative path, so in the example above
- * c:\my\data\file.ext would be cached as file.ext.
+ * are cached without the relative path, so in the following example:
+ * @code
+ * c:\my\data\file.ext
+ * @endcode
+ * would be cached as 'file.ext'.
  *
  * When the 'ignoreClashes' argument to the constructor is true, name clashes are
- * expected by the engine. It means that files which clash should be identical and
- * getSubDirectory shouldn't be used on clashing directories. This flag is useful
- * in flat mode when there are directories with same name at different places in the
- * tree whose name isn't relevant for the engine code.
+ * expected by the engine. It means that files that clash should be identical and
+ * getSubDirectory should not be used on clashing directories. This flag is useful
+ * in flat mode when there are directories with the same name at different places in the
+ * tree whose name is not relevant for the engine code.
  *
- * Client code can customize cache by using the constructors with the 'prefix'
+ * Client code can customize the cache by using constructors with the 'prefix'
  * parameter. In this case, the prefix is prepended to each entry in the cache,
  * and effectively treated as a 'virtual' parent subdirectory. FSDirectory adds
- * a trailing slash to prefix if needed. Following on with the previous example
- * and using 'your' as prefix, the cache entry would have been 'your/data/file.ext'.
+ * a trailing slash to the prefix if needed. Following on with the previous example
+ * and using 'your' as a prefix, the cache entry would have been 'your/data/file.ext'.
  * This is done both in non-flat and flat mode.
  *
  */
@@ -286,6 +300,7 @@ class FSDirectory : public Archive {
 	int _depth;
 	bool _flat;
 	bool _ignoreClashes;
+	bool _includeDirectories;
 
 	String	_prefix; // string that is prepended to each cache item key
 	void setPrefix(const String &prefix);
@@ -300,7 +315,7 @@ class FSDirectory : public Archive {
 	FSNode *lookupCache(NodeCache &cache, const String &name) const;
 
 	// cache management
-	void cacheDirectoryRecursive(FSNode node, int depth, const String& prefix) const;
+	void cacheDirectoryRecursive(FSNode node, int depth, const Path& prefix) const;
 
 	// fill cache if not already cached
 	void ensureCached() const;
@@ -308,69 +323,80 @@ class FSDirectory : public Archive {
 public:
 	/**
 	 * Create a FSDirectory representing a tree with the specified depth. Will result in an
-	 * unbound FSDirectory if name is not found on the filesystem or if the node is not a
+	 * unbound FSDirectory if name is not found in the file system or if the node is not a
 	 * valid directory.
 	 */
-	FSDirectory(const String &name, int depth = 1, bool flat = false,
-	            bool ignoreClashes = false);
+	FSDirectory(const Path &name, int depth = 1, bool flat = false,
+	            bool ignoreClashes = false, bool includeDirectories = false);
+	/**
+	 * @overload
+	 */
 	FSDirectory(const FSNode &node, int depth = 1, bool flat = false,
-	            bool ignoreClashes = false);
+	            bool ignoreClashes = false, bool includeDirectories = false);
 
 	/**
 	 * Create a FSDirectory representing a tree with the specified depth. The parameter
-	 * prefix is prepended to the keys in the cache. See class comment.
+	 * prefix is prepended to the keys in the cache. See @ref FSDirectory.
 	 */
-	FSDirectory(const String &prefix, const String &name, int depth = 1,
-	            bool flat = false, bool ignoreClashes = false);
-	FSDirectory(const String &prefix, const FSNode &node, int depth = 1,
-	            bool flat = false, bool ignoreClashes = false);
+	FSDirectory(const Path &prefix, const Path &name, int depth = 1,
+	            bool flat = false, bool ignoreClashes = false, bool includeDirectories = false);
+	/**
+	 * @overload
+	 */
+	FSDirectory(const Path &prefix, const FSNode &node, int depth = 1,
+	            bool flat = false, bool ignoreClashes = false, bool includeDirectories = false);
 
 	virtual ~FSDirectory();
 
 	/**
-	 * This return the underlying FSNode of the FSDirectory.
+	 * Return the underlying FSNode of the FSDirectory.
 	 */
 	FSNode getFSNode() const;
 
 	/**
-	 * Create a new FSDirectory pointing to a sub directory of the instance. See class comment
-	 * for an explanation of the prefix parameter.
-	 * @return a new FSDirectory instance
+	 * Create a new FSDirectory pointing to a subdirectory of the instance.
+	 * @return A new FSDirectory instance.
 	 */
-	FSDirectory *getSubDirectory(const String &name, int depth = 1, bool flat = false,
+	FSDirectory *getSubDirectory(const Path &name, int depth = 1, bool flat = false,
 	                             bool ignoreClashes = false);
-	FSDirectory *getSubDirectory(const String &prefix, const String &name, int depth = 1,
+	/**
+	 * Create a new FSDirectory pointing to a subdirectory of the instance. See FSDirectory
+	 * for an explanation of the prefix parameter.
+	 * @return A new FSDirectory instance.
+	 */
+	FSDirectory *getSubDirectory(const Path &prefix, const Path &name, int depth = 1,
 	                             bool flat = false, bool ignoreClashes = false);
 
 	/**
-	 * Checks for existence in the cache. A full match of relative path and filename is needed
-	 * for success.
+	 * Check for the existence of a file in the cache. A full match of relative path and file name
+	 * is needed for success.
 	 */
-	virtual bool hasFile(const String &name) const;
+	virtual bool hasFile(const Path &path) const;
 
 	/**
-	 * Returns a list of matching file names. Pattern can use GLOB wildcards.
+	 * Return a list of matching file names. Pattern can use GLOB wildcards.
 	 */
-	virtual int listMatchingMembers(ArchiveMemberList &list, const String &pattern) const;
+	virtual int listMatchingMembers(ArchiveMemberList &list, const Path &pattern) const;
 
 	/**
-	 * Returns a list of all the files in the cache.
+	 * Return a list of all the files in the cache.
 	 */
 	virtual int listMembers(ArchiveMemberList &list) const;
 
 	/**
-	 * Get a ArchiveMember representation of the specified file. A full match of relative
-	 * path and filename is needed for success.
+	 * Get an ArchiveMember representation of the specified file. A full match of relative
+	 * path and file name is needed for success.
 	 */
-	virtual const ArchiveMemberPtr getMember(const String &name) const;
+	virtual const ArchiveMemberPtr getMember(const Path &path) const;
 
 	/**
-	 * Open the specified file. A full match of relative path and filename is needed
+	 * Open the specified file. A full match of relative path and file name is needed
 	 * for success.
 	 */
-	virtual SeekableReadStream *createReadStreamForMember(const String &name) const;
+	virtual SeekableReadStream *createReadStreamForMember(const Path &path) const;
 };
 
+/** @} */
 
 } // End of namespace Common
 
