@@ -26,25 +26,24 @@
 #ifndef COMMON_HASHMAP_H
 #define COMMON_HASHMAP_H
 
-/**
- * @def DEBUG_HASH_COLLISIONS
- * Enable the following #define if you want to check how many collisions the
- * code produces (many collisions indicate either a bad hash function, or a
- * hash table that is too small).
- */
+// Enable the following #define if you want to check how many collisions the
+// code produces (many collisions indicate either a bad hash function, or a
+// hash table that is too small).
+
 //#define DEBUG_HASH_COLLISIONS
 
 /**
- * @def USE_HASHMAP_MEMORY_POOL
  * Enable the following define to let HashMaps use a memory pool for the
- nodes they contain. * This increases memory usage, but also can improve
- speed quite a bit.
+ * nodes they contain. This increases memory usage, but can also improve
+ * speed quite a bit.
  */
 #define USE_HASHMAP_MEMORY_POOL
 
 
 #include "common/func.h"
 
+#include "common/str.h"
+
 #ifdef DEBUG_HASH_COLLISIONS
 #include "common/debug.h"
 #endif
@@ -53,10 +52,17 @@
 #include "common/memorypool.h"
 #endif
 
-
-
 namespace Common {
 
+/**
+ * @defgroup common_hashmap Hash table (HashMap)
+ * @ingroup common
+ *
+ * @brief API for operations on a hash table.
+ *
+ * @{
+ */
+
 // The sgi IRIX MIPSpro Compiler has difficulties with nested templates.
 // This and the other __sgi conditionals below work around these problems.
 // The Intel C++ Compiler suffers from the same problems.
@@ -67,15 +73,15 @@ template<class T> class IteratorImpl;
 
 /**
  * HashMap<Key,Val> maps objects of type Key to objects of type Val.
- * For each used Key type, we need an "size_type hashit(Key,size_type)" function
- * that computes a hash for the given Key object and returns it as an
- * an integer from 0 to hashsize-1, and also an "equality functor".
- * that returns true if if its two arguments are to be considered
- * equal. Also, we assume that "=" works on Val objects for assignment.
+ * For each used Key type, a "size_type hashit(Key,size_type)" function
+ * is required that computes a hash for the given Key object and returns it as
+ * an integer from 0 to hashsize-1. An "equality functor" is also required
+ * that returns true if its two arguments are to be considered
+ * equal. Also, it is assumed that "=" works on Val objects for assignment.
  *
- * If aa is an HashMap<Key,Val>, then space is allocated each time aa[key] is
+ * If aa is a HashMap<Key,Val>, then space is allocated each time aa[key] is
  * referenced, for a new key. If the object is const, then an assertion is
- * triggered instead. Hence if you are not sure whether a key is contained in
+ * triggered instead. Hence, if you are not sure whether a key is contained in
  * the map, use contains() first to check for its presence.
  */
 template<class Key, class Val, class HashFunc = Hash<Key>, class EqualFunc = EqualTo<Key> >
@@ -240,9 +246,12 @@ public:
 	Val &operator[](const Key &key);
 	const Val &operator[](const Key &key) const;
 
+	Val &getOrCreateVal(const Key &key);
 	Val &getVal(const Key &key);
 	const Val &getVal(const Key &key) const;
-	const Val &getVal(const Key &key, const Val &defaultVal) const;
+	const Val &getValOrDefault(const Key &key) const;
+	const Val &getValOrDefault(const Key &key, const Val &defaultVal) const;
+	bool tryGetVal(const Key &key, Val &out) const;
 	void setVal(const Key &key, const Val &val);
 
 	void clear(bool shrinkArray = 0);
@@ -291,12 +300,44 @@ public:
 	}
 
 	// TODO: insert() method?
-
+	/** Return true if hashmap is empty. */
 	bool empty() const {
 		return (_size == 0);
 	}
 };
 
+template <class Key>
+void NORETURN_PRE unknownKeyError(Key k) NORETURN_POST {
+	error("Unknown key");
+}
+
+template<>
+void NORETURN_PRE unknownKeyError(::Common::String key) NORETURN_POST;
+template<>
+void NORETURN_PRE unknownKeyError(signed char key) NORETURN_POST;
+template<>
+void NORETURN_PRE unknownKeyError(unsigned char key) NORETURN_POST;
+template<>
+void NORETURN_PRE unknownKeyError(short signed key) NORETURN_POST;
+template<>
+void NORETURN_PRE unknownKeyError(short unsigned key) NORETURN_POST;
+template<>
+void NORETURN_PRE unknownKeyError(long signed key) NORETURN_POST;
+template<>
+void NORETURN_PRE unknownKeyError(long unsigned key) NORETURN_POST;
+template<>
+void NORETURN_PRE unknownKeyError(signed int key) NORETURN_POST;
+template<>
+void NORETURN_PRE unknownKeyError(unsigned int key) NORETURN_POST;
+template<>
+void NORETURN_PRE unknownKeyError(long long signed key) NORETURN_POST;
+template<>
+void NORETURN_PRE unknownKeyError(long long unsigned key) NORETURN_POST;
+template<>
+void NORETURN_PRE unknownKeyError(void *key) NORETURN_POST;
+template<>
+void NORETURN_PRE unknownKeyError(const char *key) NORETURN_POST;
+
 //-------------------------------------------------------
 // HashMap functions
 
@@ -322,8 +363,8 @@ HashMap<Key, Val, HashFunc, EqualFunc>::HashMap() : _defaultVal() {
 
 /**
  * Copy constructor, creates a full copy of the given hashmap.
- * We must provide a custom copy constructor as we use pointers
- * to heap buffers for the internal storage.
+ * A custom copy constructor must be provided as pointers
+ * to heap buffers are used for the internal storage.
  */
 template<class Key, class Val, class HashFunc, class EqualFunc>
 HashMap<Key, Val, HashFunc, EqualFunc>::HashMap(const HM_t &map) :
@@ -355,7 +396,7 @@ HashMap<Key, Val, HashFunc, EqualFunc>::~HashMap() {
  * Internal method for assigning the content of another HashMap
  * to this one.
  *
- * @note We do *not* deallocate the previous storage here -- the caller is
+ * @note The previous storage here is *not* deallocated here -- the caller is
  *       responsible for doing that!
  */
 template<class Key, class Val, class HashFunc, class EqualFunc>
@@ -383,6 +424,9 @@ void HashMap<Key, Val, HashFunc, EqualFunc>::assign(const HM_t &map) {
 	assert(_deleted == map._deleted);
 }
 
+/**
+ * Clear all values in the hashmap.
+ */
 
 template<class Key, class Val, class HashFunc, class EqualFunc>
 void HashMap<Key, Val, HashFunc, EqualFunc>::clear(bool shrinkArray) {
@@ -545,6 +589,9 @@ typename HashMap<Key, Val, HashFunc, EqualFunc>::size_type HashMap<Key, Val, Has
 	return ctr;
 }
 
+/**
+ * Check whether the hashmap contains the given key.
+ */
 
 template<class Key, class Val, class HashFunc, class EqualFunc>
 bool HashMap<Key, Val, HashFunc, EqualFunc>::contains(const Key &key) const {
@@ -552,30 +599,83 @@ bool HashMap<Key, Val, HashFunc, EqualFunc>::contains(const Key &key) const {
 	return (_storage[ctr] != nullptr);
 }
 
+/**
+ * Get a value from the hashmap.
+ */
+
 template<class Key, class Val, class HashFunc, class EqualFunc>
 Val &HashMap<Key, Val, HashFunc, EqualFunc>::operator[](const Key &key) {
-	return getVal(key);
+	return getOrCreateVal(key);
 }
 
+/**
+ * @overload
+ */
+
 template<class Key, class Val, class HashFunc, class EqualFunc>
 const Val &HashMap<Key, Val, HashFunc, EqualFunc>::operator[](const Key &key) const {
 	return getVal(key);
 }
 
+/**
+ * Get a value from the hashmap.
+ */
+
 template<class Key, class Val, class HashFunc, class EqualFunc>
-Val &HashMap<Key, Val, HashFunc, EqualFunc>::getVal(const Key &key) {
+Val &HashMap<Key, Val, HashFunc, EqualFunc>::getOrCreateVal(const Key &key) {
 	size_type ctr = lookupAndCreateIfMissing(key);
 	assert(_storage[ctr] != nullptr);
 	return _storage[ctr]->_value;
 }
 
+/**
+ * @overload
+ */
+
 template<class Key, class Val, class HashFunc, class EqualFunc>
-const Val &HashMap<Key, Val, HashFunc, EqualFunc>::getVal(const Key &key) const {
-	return getVal(key, _defaultVal);
+Val &HashMap<Key, Val, HashFunc, EqualFunc>::getVal(const Key &key) {
+	size_type ctr = lookup(key);
+	if (_storage[ctr] != nullptr)
+		return _storage[ctr]->_value;
+	else
+		// In the past getVal() and operator[] used to return the default value for this case.
+		// Clarifying the intent by using getValOrDefault() when we query a key that may not be
+		// present is a good idea, but we have a lot of legacy code that may need to be updated.
+		// So for now only returns an error in non-release builds. Once we are confident all the
+		// code has been updated to use the correct function we can remove the RELEASE_BUILD
+		// special case.
+#ifdef RELEASE_BUILD
+		return _defaultVal;
+#else
+		unknownKeyError(key);
+#endif
 }
 
 template<class Key, class Val, class HashFunc, class EqualFunc>
-const Val &HashMap<Key, Val, HashFunc, EqualFunc>::getVal(const Key &key, const Val &defaultVal) const {
+const Val &HashMap<Key, Val, HashFunc, EqualFunc>::getVal(const Key &key) const {
+	size_type ctr = lookup(key);
+	if (_storage[ctr] != nullptr)
+		return _storage[ctr]->_value;
+	else
+		// See comment in non-const getVal() above.
+#ifdef RELEASE_BUILD
+		return _defaultVal;
+#else
+		unknownKeyError(key);
+#endif
+}
+
+template<class Key, class Val, class HashFunc, class EqualFunc>
+const Val &HashMap<Key, Val, HashFunc, EqualFunc>::getValOrDefault(const Key &key) const {
+	return getValOrDefault(key, _defaultVal);
+}
+
+/**
+ * Get a value from the hashmap. If the key is not present, then return @p defaultVal.
+ */
+
+template<class Key, class Val, class HashFunc, class EqualFunc>
+const Val &HashMap<Key, Val, HashFunc, EqualFunc>::getValOrDefault(const Key &key, const Val &defaultVal) const {
 	size_type ctr = lookup(key);
 	if (_storage[ctr] != nullptr)
 		return _storage[ctr]->_value;
@@ -583,6 +683,21 @@ const Val &HashMap<Key, Val, HashFunc, EqualFunc>::getVal(const Key &key, const
 		return defaultVal;
 }
 
+/**
+ * Assign an element specified by @p key to a value @p val.
+ */
+
+template<class Key, class Val, class HashFunc, class EqualFunc>
+bool HashMap<Key, Val, HashFunc, EqualFunc>::tryGetVal(const Key &key, Val &out) const {
+	size_type ctr = lookup(key);
+	if (_storage[ctr] != nullptr) {
+		out = _storage[ctr]->_value;
+		return true;
+	} else {
+		return false;
+	}
+}
+
 template<class Key, class Val, class HashFunc, class EqualFunc>
 void HashMap<Key, Val, HashFunc, EqualFunc>::setVal(const Key &key, const Val &val) {
 	size_type ctr = lookupAndCreateIfMissing(key);
@@ -590,6 +705,10 @@ void HashMap<Key, Val, HashFunc, EqualFunc>::setVal(const Key &key, const Val &v
 	_storage[ctr]->_value = val;
 }
 
+/**
+ * Erase an element referred to by an iterator.
+ */
+
 template<class Key, class Val, class HashFunc, class EqualFunc>
 void HashMap<Key, Val, HashFunc, EqualFunc>::erase(iterator entry) {
 	// Check whether we have a valid iterator
@@ -607,6 +726,10 @@ void HashMap<Key, Val, HashFunc, EqualFunc>::erase(iterator entry) {
 	_deleted++;
 }
 
+/**
+ * Erase an element specified by a key.
+ */
+
 template<class Key, class Val, class HashFunc, class EqualFunc>
 void HashMap<Key, Val, HashFunc, EqualFunc>::erase(const Key &key) {
 
@@ -624,6 +747,8 @@ void HashMap<Key, Val, HashFunc, EqualFunc>::erase(const Key &key) {
 
 #undef HASHMAP_DUMMY_NODE
 
+/** @} */
+
 } // End of namespace Common
 
 #endif
