@@ -8,12 +8,12 @@
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
@@ -27,16 +27,30 @@
 
 namespace Common {
 
+/**
+ * @defgroup common_installshield InstallShield
+ * @ingroup common
+ *
+ * @brief API for managing the InstallShield.
+ *
+ *
+ * @{
+ */
+
 class Archive;
 class SeekableReadStream;
 
 /**
  * This factory method creates an Archive instance corresponding to the content
- * of the InstallShield compressed stream.
+ * of the single- or multi-file InstallShield cabinet with the given base name
  *
  * May return 0 in case of a failure.
+ * 
+ * @param baseName The base filename, e.g. the "data" in "data1.cab"
  */
-Archive *makeInstallShieldArchive(SeekableReadStream *stream, DisposeAfterUse::Flag disposeAfterUse = DisposeAfterUse::YES);
+Archive *makeInstallShieldArchive(const Common::String &baseName);
+
+/** @} */
 
 } // End of namespace Common
 
