@@ -22,12 +22,7 @@
 
 /**
  * @file
- * Macintosh resource fork manager used in engines:
- * - groovie
- * - mohawk
- * - pegasus
- * - sci
- * - scumm
+
  */
 
 #include "common/array.h"
@@ -40,6 +35,21 @@
 
 namespace Common {
 
+/**
+ * @defgroup common_macresman Macintosh resource fork manager
+ * @ingroup common
+ *
+ * @brief API for Macintosh resource fork manager.
+ *
+ * @details Used in engines:
+ *          - groovie
+ *          - mohawk
+ *          - pegasus
+ *          - sci
+ *          - scumm
+ * @{
+ */
+
 typedef Array<uint16> MacResIDArray;
 typedef Array<uint32> MacResTagArray;
 
@@ -65,24 +75,24 @@ public:
 	 * @note This will check for the raw resource fork, MacBinary, and AppleDouble formats.
 	 * @return True on success
 	 */
-	bool open(const String &fileName);
+	bool open(const Path &fileName);
 
 	/**
-	 * Open a Mac data/resource fork pair.
+	 * Open a Mac data/resource fork pair from within the given archive.
 	 *
 	 * @param path The path that holds the forks
 	 * @param fileName The base file name of the file
 	 * @note This will check for the raw resource fork, MacBinary, and AppleDouble formats.
 	 * @return True on success
 	 */
-	bool open(const FSNode &path, const String &fileName);
+	bool open(const Path &fileName, Archive &archive);
 
 	/**
 	 * See if a Mac data/resource fork pair exists.
 	 * @param fileName The base file name of the file
 	 * @return True if either a data fork or resource fork with this name exists
 	 */
-	static bool exists(const String &fileName);
+	static bool exists(const Path &fileName);
 
 	/**
 	 * List all filenames matching pattern for opening with open().
@@ -168,9 +178,9 @@ public:
 	 * Get the base file name of the data/resource fork pair
 	 * @return The base file name of the data/resource fork pair
 	 */
-	String getBaseFileName() const { return _baseFileName; }
+	Path getBaseFileName() const { return _baseFileName; }
 
-	void setBaseFileName(Common::String str) { _baseFileName = str; }
+	void setBaseFileName(Common::Path str) { _baseFileName = str; }
 
 	/**
 	 * Return list of resource IDs with specified type ID
@@ -212,15 +222,15 @@ public:
 
 private:
 	SeekableReadStream *_stream;
-	String _baseFileName;
+	Path _baseFileName;
 
 	bool load(SeekableReadStream &stream);
 
 	bool loadFromRawFork(SeekableReadStream &stream);
 	bool loadFromAppleDouble(SeekableReadStream &stream);
 
-	static String constructAppleDoubleName(String name);
-	static String disassembleAppleDoubleName(String name, bool *isAppleDouble);
+	static Path constructAppleDoubleName(Path name);
+	static Path disassembleAppleDoubleName(Path name, bool *isAppleDouble);
 
 	/**
 	 * Do a sanity check whether the given stream is a raw resource fork.
@@ -282,6 +292,8 @@ private:
 	ResPtr  *_resLists;
 };
 
+/** @} */
+
 } // End of namespace Common
 
 #endif
