@@ -29,6 +29,14 @@
 
 namespace Common {
 
+/**
+ * @defgroup common_memory_pool Memory stream
+ * @ingroup common_memory
+ *
+ * @brief API for managing the memory stream.
+ * @{
+ */
+
 /**
  * Simple memory based 'stream', which implements the ReadStream interface for
  * a plain memory block.
@@ -67,10 +75,10 @@ public:
 	bool eos() const { return _eos; }
 	void clearErr() { _eos = false; }
 
-	int32 pos() const { return _pos; }
-	int32 size() const { return _size; }
+	int64 pos() const { return _pos; }
+	int64 size() const { return _size; }
 
-	bool seek(int32 offs, int whence = SEEK_SET);
+	bool seek(int64 offs, int whence = SEEK_SET);
 };
 
 
@@ -83,12 +91,12 @@ public:
 	MemoryReadStreamEndian(const byte *buf, uint32 len, bool bigEndian, DisposeAfterUse::Flag disposeMemory = DisposeAfterUse::NO)
 		: MemoryReadStream(buf, len, disposeMemory), SeekableReadStreamEndian(bigEndian), ReadStreamEndian(bigEndian) {}
 
-	int32 pos() const { return MemoryReadStream::pos(); }
-	int32 size() const { return MemoryReadStream::size(); }
+	int64 pos() const override { return MemoryReadStream::pos(); }
+	int64 size() const override { return MemoryReadStream::size(); }
 
-	bool seek(int32 offs, int whence = SEEK_SET) { return MemoryReadStream::seek(offs, whence); }
+	bool seek(int64 offs, int whence = SEEK_SET) override { return MemoryReadStream::seek(offs, whence); }
 
-	bool skip(uint32 offset) { return MemoryReadStream::seek(offset, SEEK_CUR); }
+	bool skip(uint32 offset) override { return MemoryReadStream::seek(offset, SEEK_CUR); }
 };
 
 /**
@@ -118,13 +126,13 @@ public:
 		return dataSize;
 	}
 
-	virtual int32 pos() const override { return _pos; }
-	virtual int32 size() const override { return _bufSize; }
+	virtual int64 pos() const override { return _pos; }
+	virtual int64 size() const override { return _bufSize; }
 
 	virtual bool err() const override { return _err; }
 	virtual void clearErr() override { _err = false; }
 
-	virtual bool seek(int32 offset, int whence = SEEK_SET) override { return false; }
+	virtual bool seek(int64 offset, int whence = SEEK_SET) override { return false; }
 };
 
 /**
@@ -136,7 +144,7 @@ private:
 public:
 	SeekableMemoryWriteStream(byte *buf, uint32 len) : MemoryWriteStream(buf, len), _ptrOrig(buf) {}
 
-	virtual bool seek(int32 offset, int whence = SEEK_SET) override {
+	virtual bool seek(int64 offset, int whence = SEEK_SET) override {
 		switch (whence) {
 		case SEEK_END:
 			// SEEK_END works just like SEEK_SET, only 'reversed',
@@ -178,13 +186,13 @@ protected:
 	uint32 _pos;
 	DisposeAfterUse::Flag _disposeMemory;
 
-	void ensureCapacity(uint32 new_len) {
-		if (new_len <= _capacity)
+	void ensureCapacity(uint32 capacity) {
+		if (capacity <= _capacity)
 			return;
 
 		byte *old_data = _data;
 
-		_capacity = MAX(new_len + 32, _capacity * 2);
+		_capacity = capacity;
 		_data = (byte *)malloc(_capacity);
 		_ptr = _data + _pos;
 
@@ -193,8 +201,16 @@ protected:
 			memcpy(_data, old_data, _size);
 			free(old_data);
 		}
+	}
 
-		_size = new_len;
+	/** Round up capacity to the next power of 2.
+	  * A minimal capacity of 8 is used.
+	  */
+	static size_t roundUpCapacity(size_t capacity) {
+		size_t capa = 8;
+		while (capa < capacity)
+			capa <<= 1;
+		return capa;
 	}
 public:
 	explicit MemoryWriteStreamDynamic(DisposeAfterUse::Flag disposeMemory) : _capacity(0), _size(0), _ptr(nullptr), _data(nullptr), _pos(0), _disposeMemory(disposeMemory) {}
@@ -205,7 +221,9 @@ public:
 	}
 
 	uint32 write(const void *dataPtr, uint32 dataSize) override {
-		ensureCapacity(_pos + dataSize);
+		if ((_pos + dataSize) >= _capacity)
+			ensureCapacity(roundUpCapacity(_pos + dataSize));
+
 		memcpy(_ptr, dataPtr, dataSize);
 		_ptr += dataSize;
 		_pos += dataSize;
@@ -214,12 +232,12 @@ public:
 		return dataSize;
 	}
 
-	virtual int32 pos() const override { return _pos; }
-	virtual int32 size() const override { return _size; }
+	virtual int64 pos() const override { return _pos; }
+	virtual int64 size() const override { return _size; }
 
 	byte *getData() { return _data; }
 
-	virtual bool seek(int32 offs, int whence = SEEK_SET) override {
+	virtual bool seek(int64 offs, int whence = SEEK_SET) override {
 		// Pre-Condition
 		assert(_pos <= _size);
 		switch (whence) {
@@ -325,15 +343,116 @@ public:
 		return dataSize;
 	}
 
-	virtual int32 pos() const override { return _pos - _length; }
-	virtual int32 size() const override { return _size; }
-	virtual bool seek(int32, int) override { return false; }
+	virtual int64 pos() const override { return _pos - _length; }
+	virtual int64 size() const override { return _size; }
+	virtual bool seek(int64, int) override { return false; }
 	virtual bool eos() const override { return _eos; }
 	virtual void clearErr() override { _eos = false; }
 
 	byte *getData() { return _data; }
 };
 
+/**
+ * A seekable read and writeable memory stream that operates on an already existing memory buffer
+ */
+class MemorySeekableReadWriteStream : public SeekableReadStream, public SeekableWriteStream {
+private:
+	const uint32 _bufSize;
+	byte *_ptrOrig;
+	byte *_ptr;
+	uint32 _pos;
+	bool _err;
+	bool _eos;
+	DisposeAfterUse::Flag _disposeMemory;
+
+public:
+	MemorySeekableReadWriteStream(byte *buf, uint32 len, DisposeAfterUse::Flag disposeMemory = DisposeAfterUse::NO) :
+			_ptrOrig(buf), _ptr(buf), _bufSize(len), _pos(0), _err(false), _eos(false), _disposeMemory(disposeMemory) {}
+
+	~MemorySeekableReadWriteStream() {
+		if (_disposeMemory) {
+			free(_ptrOrig);
+		}
+	}
+
+	uint32 write(const void *dataPtr, uint32 dataSize) override {
+		// Write at most as many bytes as are still available...
+		if (dataSize > _bufSize - _pos) {
+			dataSize = _bufSize - _pos;
+			// We couldn't write all the data => set error indicator
+			_err = true;
+		}
+		memcpy(_ptr, dataPtr, dataSize);
+		_ptr += dataSize;
+		_pos += dataSize;
+		return dataSize;
+	}
+
+	int64 pos() const override { return _pos; }
+	int64 size() const override { return _bufSize; }
+
+	bool eos() const override { return _eos; }
+
+	bool err() const override { return _err; }
+	void clearErr() override { _err = false; }
+
+	inline void rewind(int32 bytes) {
+		seek(pos() - bytes);
+	}
+
+	byte peekByte() {
+		if (_bufSize - _pos <= 0) {
+			_eos = true;
+			return 0;
+		}
+		return *_ptr;
+	}
+
+	uint32 read(void *dataPtr, uint32 dataSize) override {
+		// Read at most as many bytes as are still available...
+		if (dataSize > _bufSize - _pos) {
+			dataSize = _bufSize - _pos;
+			_eos = true;
+		}
+		memcpy(dataPtr, _ptr, dataSize);
+
+		_ptr += dataSize;
+		_pos += dataSize;
+
+		return dataSize;
+	}
+
+	bool seek(int64 offset, int whence = SEEK_SET) override {
+		switch (whence) {
+		case SEEK_END:
+			// SEEK_END works just like SEEK_SET, only 'reversed',
+			// i.e. from the end.
+			offset = size() + offset;
+			// Fall through
+		case SEEK_SET:
+			// Fall through
+		default:
+			_ptr = _ptrOrig + offset;
+			_pos = offset;
+			break;
+		case SEEK_CUR:
+			_ptr += offset;
+			_pos += offset;
+			break;
+		}
+		// Post-Condition
+		if ((int32)_pos > size()) {
+			_pos = size();
+			_ptr = _ptrOrig + _pos;
+		}
+
+		_eos = false;
+		return true;
+	}
+};
+
+/** @} */
+
 } // End of namespace Common
 
 #endif
