@@ -26,11 +26,20 @@
 #include "common/events.h"
 #include "common/singleton.h"
 #include "common/str.h"
+#include "common/ustr.h"
 #include "common/queue.h"
 #include "common/mutex.h"
 
 namespace Common {
 
+/**
+ * @defgroup common_osd_message_queue OSD message queue
+ * @ingroup common
+ *
+ * @brief API for managing the queue of On Screen Display (OSD) messages.
+ * @{
+ */
+
 /**
  * Queue OSD messages from any thread to be displayed by the graphic thread.
  */
@@ -48,7 +57,7 @@ public:
 	/**
 	 * Add a message to the OSD message queue.
 	 */
-	void addMessage(const char *msg);
+	void addMessage(const Common::U32String &msg);
 
 	/**
 	 * Common::EventSource interface
@@ -63,10 +72,12 @@ public:
 
 private:
 	Mutex _mutex;
-	Queue<String> _messages;
+	Queue<U32String> _messages;
 	uint32 _lastUpdate;
 };
 
+/** @} */
+
 } // End of namespace Common
 
 #endif
