@@ -27,6 +27,14 @@
 
 namespace Common {
 
+/**
+ * @defgroup common_platform Game platforms
+ * @ingroup common
+ *
+ * @brief API for managing game platforms.
+ * @{
+ */
+
 class String;
 
 /**
@@ -56,11 +64,18 @@ enum Platform {
 	kPlatformPC98,
 	kPlatformWii,
 	kPlatformPSX,
+	kPlatformPS2,
+	kPlatformXbox,
 	kPlatformCDi,
 	kPlatformIOS,
 	kPlatformOS2,
 	kPlatformBeOS,
 	kPlatformPocketPC,
+	kPlatformMegaDrive,
+	kPlatformSaturn,
+	kPlatformPippin,
+	kPlatformMacintoshII,
+	kPlatformShockwave,
 
 	kPlatformUnknown = -1
 };
@@ -81,6 +96,8 @@ extern const char *getPlatformCode(Platform id);
 extern const char *getPlatformAbbrev(Platform id);
 extern const char *getPlatformDescription(Platform id);
 
+/** @} */
+
 } // End of namespace Common
 
 #endif
