@@ -34,7 +34,10 @@
 
 namespace Common {
 
-PlaybackFile::PlaybackFile() : _tmpRecordFile(_tmpBuffer, kRecordBuffSize), _tmpPlaybackFile(_tmpBuffer, kRecordBuffSize) {
+PlaybackFile::PlaybackFile()
+	: _tmpBuffer(kRecordBuffSize)
+	, _tmpRecordFile(_tmpBuffer.data(), kRecordBuffSize)
+	, _tmpPlaybackFile(_tmpBuffer.data(), kRecordBuffSize) {
 	_readStream = NULL;
 	_writeStream = NULL;
 	_screenshotsFile = NULL;
@@ -44,7 +47,7 @@ PlaybackFile::PlaybackFile() : _tmpRecordFile(_tmpBuffer, kRecordBuffSize), _tmp
 	_headerDumped = false;
 	_recordCount = 0;
 	_eventsSize = 0;
-	memset(_tmpBuffer, 1, kRecordBuffSize);
+	memset(_tmpBuffer.data(), 1, kRecordBuffSize);
 
 	_playbackParseState = kFileStateCheckFormat;
 }
@@ -109,7 +112,6 @@ void PlaybackFile::close() {
 }
 
 bool PlaybackFile::parseHeader() {
-	PlaybackFileHeader result;
 	ChunkHeader nextChunk;
 	_playbackParseState = kFileStateCheckFormat;
 	if (!readChunkHeader(nextChunk)) {
@@ -257,7 +259,7 @@ bool PlaybackFile::processChunk(ChunkHeader &nextChunk) {
 		}
 		break;
 	default:
-			return false;
+		return false;
 	}
 	return true;
 }
@@ -317,9 +319,19 @@ bool PlaybackFile::readSaveRecord() {
 	return true;
 }
 
-
+bool PlaybackFile::hasNextEvent() const {
+	if (_readStream->err()) {
+		return false;
+	}
+	return !_readStream->eos();
+}
 
 RecorderEvent PlaybackFile::getNextEvent() {
+	if (!hasNextEvent()) {
+		debug(3, "end of recorder file reached.");
+		g_system->quit();
+	}
+
 	assert(_mode == kRead);
 	if (isEventsBufferEmpty()) {
 		PlaybackFile::ChunkHeader header;
@@ -361,12 +373,23 @@ void PlaybackFile::readEvent(RecorderEvent& event) {
 	case kRecorderEventTypeTimer:
 		event.time = _tmpPlaybackFile.readUint32LE();
 		break;
+	case kRecorderEventTypeTimeDate:
+		event.timeDate.tm_sec = _tmpPlaybackFile.readSint32LE();
+		event.timeDate.tm_min = _tmpPlaybackFile.readSint32LE();
+		event.timeDate.tm_hour = _tmpPlaybackFile.readSint32LE();
+		event.timeDate.tm_mday = _tmpPlaybackFile.readSint32LE();
+		event.timeDate.tm_mon = _tmpPlaybackFile.readSint32LE();
+		event.timeDate.tm_year = _tmpPlaybackFile.readSint32LE();
+		event.timeDate.tm_wday = _tmpPlaybackFile.readSint32LE();
+		break;
 	default:
 		// fallthrough intended
 	case kRecorderEventTypeNormal:
 		event.type = (EventType)_tmpPlaybackFile.readUint32LE();
 		switch (event.type) {
 		case EVENT_KEYDOWN:
+			event.kbdRepeat = _tmpPlaybackFile.readByte();
+			// fallthrough
 		case EVENT_KEYUP:
 			event.time = _tmpPlaybackFile.readUint32LE();
 			event.kbd.keycode = (KeyCode)_tmpPlaybackFile.readSint32LE();
@@ -390,17 +413,32 @@ void PlaybackFile::readEvent(RecorderEvent& event) {
 			event.mouse.x = _tmpPlaybackFile.readSint16LE();
 			event.mouse.y = _tmpPlaybackFile.readSint16LE();
 			break;
+		case EVENT_CUSTOM_BACKEND_ACTION_START:
+		case EVENT_CUSTOM_BACKEND_ACTION_END:
+		case EVENT_CUSTOM_ENGINE_ACTION_START:
+		case EVENT_CUSTOM_ENGINE_ACTION_END:
+			event.time = _tmpPlaybackFile.readUint32LE();
+			event.customType = _tmpPlaybackFile.readUint32LE();
+			break;
+		case EVENT_JOYAXIS_MOTION:
+		case EVENT_JOYBUTTON_UP:
+		case EVENT_JOYBUTTON_DOWN:
+			event.time = _tmpPlaybackFile.readUint32LE();
+			event.joystick.axis = _tmpPlaybackFile.readByte();
+			event.joystick.button = _tmpPlaybackFile.readByte();
+			event.joystick.position = _tmpPlaybackFile.readSint16LE();
+			break;
 		default:
 			event.time = _tmpPlaybackFile.readUint32LE();
 			break;
 		}
 		break;
 	}
-	event.kbdRepeat = true;
+	debug(3, "read event of type: %i (time: %u, systemmillis: %u)", event.type, event.time, g_system->getMillis(true));
 }
 
 void PlaybackFile::readEventsToBuffer(uint32 size) {
-	_readStream->read(_tmpBuffer, size);
+	_readStream->read(_tmpBuffer.data(), size);
 	_tmpPlaybackFile.seek(0);
 	_eventsSize = size;
 }
@@ -423,7 +461,7 @@ void PlaybackFile::dumpRecordsToFile() {
 	}
 	_writeStream->writeUint32LE(kEventTag);
 	_writeStream->writeUint32LE(_tmpRecordFile.pos());
-	_writeStream->write(_tmpBuffer, _tmpRecordFile.pos());
+	_writeStream->write(_tmpBuffer.data(), _tmpRecordFile.pos());
 	_tmpRecordFile.seek(0);
 	_recordCount = 0;
 }
@@ -520,12 +558,23 @@ void PlaybackFile::writeEvent(const RecorderEvent &event) {
 	case kRecorderEventTypeTimer:
 		_tmpRecordFile.writeUint32LE(event.time);
 		break;
+	case kRecorderEventTypeTimeDate:
+		_tmpRecordFile.writeSint32LE(event.timeDate.tm_sec);
+		_tmpRecordFile.writeSint32LE(event.timeDate.tm_min);
+		_tmpRecordFile.writeSint32LE(event.timeDate.tm_hour);
+		_tmpRecordFile.writeSint32LE(event.timeDate.tm_mday);
+		_tmpRecordFile.writeSint32LE(event.timeDate.tm_mon);
+		_tmpRecordFile.writeSint32LE(event.timeDate.tm_year);
+		_tmpRecordFile.writeSint32LE(event.timeDate.tm_wday);
+		break;
 	default:
 		// fallthrough intended
 	case kRecorderEventTypeNormal:
 		_tmpRecordFile.writeUint32LE((uint32)event.type);
 		switch(event.type) {
 		case EVENT_KEYDOWN:
+			_tmpRecordFile.writeByte(event.kbdRepeat);
+			// fallthrough
 		case EVENT_KEYUP:
 			_tmpRecordFile.writeUint32LE(event.time);
 			_tmpRecordFile.writeSint32LE(event.kbd.keycode);
@@ -549,6 +598,21 @@ void PlaybackFile::writeEvent(const RecorderEvent &event) {
 			_tmpRecordFile.writeSint16LE(event.mouse.x);
 			_tmpRecordFile.writeSint16LE(event.mouse.y);
 			break;
+		case EVENT_CUSTOM_BACKEND_ACTION_START:
+		case EVENT_CUSTOM_BACKEND_ACTION_END:
+		case EVENT_CUSTOM_ENGINE_ACTION_START:
+		case EVENT_CUSTOM_ENGINE_ACTION_END:
+			_tmpRecordFile.writeUint32LE(event.time);
+			_tmpRecordFile.writeUint32LE(event.customType);
+			break;
+		case EVENT_JOYAXIS_MOTION:
+		case EVENT_JOYBUTTON_UP:
+		case EVENT_JOYBUTTON_DOWN:
+			_tmpRecordFile.writeUint32LE(event.time);
+			_tmpRecordFile.writeByte(event.joystick.axis);
+			_tmpRecordFile.writeByte(event.joystick.button);
+			_tmpRecordFile.writeSint16LE(event.joystick.position);
+			break;
 		default:
 			_tmpRecordFile.writeUint32LE(event.time);
 			break;
@@ -558,6 +622,7 @@ void PlaybackFile::writeEvent(const RecorderEvent &event) {
 	if (_recordCount == kMaxBufferedRecords) {
 		dumpRecordsToFile();
 	}
+	debug(3, "write event of type: %i (time: %u, systemmillis: %u)", event.type, event.time, g_system->getMillis(true));
 }
 
 void PlaybackFile::writeGameSettings() {
@@ -594,18 +659,16 @@ int PlaybackFile::getScreensCount() {
 }
 
 bool PlaybackFile::skipToNextScreenshot() {
-	while (true) {
+	while (!_readStream->eos() && !_readStream->err()) {
 		FileTag id = (FileTag)_readStream->readUint32LE();
-		if (_readStream->eos()) {
+		if (_readStream->eos() || _readStream->err()) {
 			break;
 		}
 		if (id == kScreenShotTag) {
 			return true;
 		}
-		else {
-			uint32 size = _readStream->readUint32LE();
-			_readStream->skip(size);
-		}
+		uint32 size = _readStream->readUint32LE();
+		_readStream->skip(size);
 	}
 	return false;
 }
@@ -646,8 +709,8 @@ void PlaybackFile::updateHeader() {
 	dumpHeaderToFile();
 	uint32 readedSize = 0;
 	do {
-		readedSize = _readStream->read(_tmpBuffer, kRecordBuffSize);
-		_writeStream->write(_tmpBuffer, readedSize);
+		readedSize = _readStream->read(_tmpBuffer.data(), kRecordBuffSize);
+		_writeStream->write(_tmpBuffer.data(), readedSize);
 	} while (readedSize != 0);
 	delete _writeStream;
 	_writeStream = NULL;
