@@ -25,14 +25,26 @@
 
 #include "common/array.h"
 #include "common/str.h"
+#include "common/ustr.h"
 
 namespace Common {
 
+/**
+ * @defgroup common_str_array String array
+ * @ingroup common_str
+ *
+ * @brief String array implementation.
+ *
+ * @{
+ */
+
 /**
  * An array of of strings.
  */
-typedef Array<String> StringArray;
+typedef Array<String>		StringArray;
+typedef Array<U32String>	U32StringArray;
 
+/** @} */
 
 } // End of namespace Common
 
