@@ -33,6 +33,15 @@
 
 namespace Common {
 
+/**
+ * @defgroup common_taskbar Taskbar Manager
+ * @ingroup common
+ *
+ * @brief The TaskbarManager module allows for interaction with the ScummVM application icon.
+ *
+ * @{
+ */
+
 /**
  * The TaskbarManager allows interaction with the ScummVM application icon:
  *  - in the taskbar on Windows 7 and later
@@ -158,6 +167,7 @@ protected:
 		Common::String targetIcon = target + extension;
 		Common::String qualifiedIcon = ConfMan.get("engineid") + "-" + ConfMan.get("gameid") + extension;
 		Common::String gameIcon = ConfMan.get("gameid") + extension;
+		Common::String engineIcon = ConfMan.get("engineid") + extension;
 
 #define TRY_ICON_PATH(path) { \
 Common::FSNode node((path)); \
@@ -168,18 +178,22 @@ return (path); \
 			TRY_ICON_PATH(iconsPath + "/" + targetIcon);
 			TRY_ICON_PATH(iconsPath + "/" + qualifiedIcon);
 			TRY_ICON_PATH(iconsPath + "/" + gameIcon);
+			TRY_ICON_PATH(iconsPath + "/" + engineIcon);
 			TRY_ICON_PATH(iconsPath + "/icons/" + targetIcon);
 			TRY_ICON_PATH(iconsPath + "/icons/" + qualifiedIcon);
 			TRY_ICON_PATH(iconsPath + "/icons/" + gameIcon);
+			TRY_ICON_PATH(iconsPath + "/icons/" + engineIcon);
 		}
 
 		if (!extraPath.empty()) {
 			TRY_ICON_PATH(extraPath + "/" + targetIcon);
 			TRY_ICON_PATH(extraPath + "/" + qualifiedIcon);
 			TRY_ICON_PATH(extraPath + "/" + gameIcon);
+			TRY_ICON_PATH(extraPath + "/" + engineIcon);
 			TRY_ICON_PATH(extraPath + "/icons/" + targetIcon);
 			TRY_ICON_PATH(extraPath + "/icons/" + qualifiedIcon);
 			TRY_ICON_PATH(extraPath + "/icons/" + gameIcon);
+			TRY_ICON_PATH(extraPath + "/icons/" + engineIcon);
 		}
 #undef TRY_ICON_PATH
 
@@ -187,6 +201,8 @@ return (path); \
 	}
 };
 
+/** @} */
+
 } // End of namespace Common
 
 #endif
