@@ -23,8 +23,6 @@
 
 #include "common/text-to-speech.h"
 #include "common/system.h"
-#if defined(USE_TTS)
-
 namespace Common {
 
 TTSVoice::TTSVoice()
@@ -88,15 +86,6 @@ TextToSpeechManager::TextToSpeechManager() {
 	_ttsState->_next = nullptr;
 }
 
-TextToSpeechManager::~TextToSpeechManager() {
-	TTSState *tmp = _ttsState;
-	while (tmp != nullptr) {
-		tmp = _ttsState->_next;
-		delete _ttsState;
-		_ttsState = tmp;
-	}
-}
-
 void TextToSpeechManager::pushState() {
 	stop();
 	TTSState *newState = new TTSState;
@@ -130,6 +119,15 @@ bool TextToSpeechManager::popState() {
 	return false;
 }
 
+void TextToSpeechManager::clearState() {
+	TTSState *tmp = _ttsState;
+	while (tmp != nullptr) {
+		tmp = _ttsState->_next;
+		delete _ttsState;
+		_ttsState = tmp;
+	}
+}
+
 TTSVoice TextToSpeechManager::getVoice() {
 	if (!_ttsState->_availableVoices.empty())
 		return _ttsState->_availableVoices[_ttsState->_activeVoice];
@@ -146,8 +144,6 @@ Array<int> TextToSpeechManager::getVoiceIndicesByGender(TTSVoice::Gender gender)
 }
 
 void TextToSpeechManager::setLanguage(Common::String language) {
-	if (language == "C")
-		language = "en";
 	// The speech manager uses the ISO 639-1 for language codes (2 letter code)
 	// if we get a longer language string, just take the first 2 letters from that
 	// if it won't be a valid language code, the Manager just won't find any voice
@@ -159,4 +155,3 @@ void TextToSpeechManager::setLanguage(Common::String language) {
 }
 
 }
-#endif
