@@ -25,7 +25,7 @@
 #include <windows.h>
 #endif
 
-#define TRANSLATIONS_DAT_VER 3
+#define TRANSLATIONS_DAT_VER 4
 
 #include "common/translation.h"
 #include "common/config-manager.h"
@@ -39,21 +39,21 @@
 
 namespace Common {
 
-DECLARE_SINGLETON(TranslationManager);
+DECLARE_SINGLETON(MainTranslationManager);
 
 bool operator<(const TLanguage &l, const TLanguage &r) {
-	return strcmp(l.name, r.name) < 0;
+	return l.name < r.name;
 }
 
-TranslationManager::TranslationManager() : _currentLang(-1), _charmap(nullptr) {
-	loadTranslationsInfoDat();
+TranslationManager::TranslationManager(const Common::String &fileName) : _currentLang(-1) {
+	loadTranslationsInfoDat(fileName);
 
 	// Set the default language
 	setLanguage("");
 }
 
 TranslationManager::~TranslationManager() {
-	delete[] _charmap;
+
 }
 
 int32 TranslationManager::findMatchingLanguage(const String &lang) {
@@ -108,14 +108,14 @@ void TranslationManager::setLanguage(const String &lang) {
 	}
 }
 
-const char *TranslationManager::getTranslation(const char *message) const {
+U32String TranslationManager::getTranslation(const char *message) const {
 	return getTranslation(message, nullptr);
 }
 
-const char *TranslationManager::getTranslation(const char *message, const char *context) const {
+U32String TranslationManager::getTranslation(const char *message, const char *context) const {
 	// If no language is set or message is empty, return msgid as is
 	if (_currentTranslationMessages.empty() || *message == '\0')
-		return message;
+		return U32String(message);
 
 	// Binary-search for the msgid
 	int leftIndex = 0;
@@ -144,24 +144,24 @@ const char *TranslationManager::getTranslation(const char *message, const char *
 			}
 			// Find the context we want
 			if (context == nullptr || *context == '\0' || leftIndex == rightIndex)
-				return _currentTranslationMessages[leftIndex].msgstr.c_str();
+				return _currentTranslationMessages[leftIndex].msgstr;
 			// We could use again binary search, but there should be only a small number of contexts.
 			while (rightIndex > leftIndex) {
 				compareResult = strcmp(context, _currentTranslationMessages[rightIndex].msgctxt.c_str());
 				if (compareResult == 0)
-					return _currentTranslationMessages[rightIndex].msgstr.c_str();
+					return _currentTranslationMessages[rightIndex].msgstr;
 				else if (compareResult > 0)
 					break;
 				--rightIndex;
 			}
-			return _currentTranslationMessages[leftIndex].msgstr.c_str();
+			return _currentTranslationMessages[leftIndex].msgstr;
 		} else if (compareResult < 0)
 			rightIndex = midIndex - 1;
 		else
 			leftIndex = midIndex + 1;
 	}
 
-	return message;
+	return U32String(message);
 }
 
 String TranslationManager::getCurrentCharset() const {
@@ -172,15 +172,15 @@ String TranslationManager::getCurrentCharset() const {
 
 String TranslationManager::getCurrentLanguage() const {
 	if (_currentLang == -1)
-		return "C";
+		return "en";
 	return _langs[_currentLang];
 }
 
-String TranslationManager::getTranslation(const String &message) const {
+U32String TranslationManager::getTranslation(const String &message) const {
 	return getTranslation(message.c_str());
 }
 
-String TranslationManager::getTranslation(const String &message, const String &context) const {
+U32String TranslationManager::getTranslation(const String &message, const String &context) const {
 	return getTranslation(message.c_str(), context.c_str());
 }
 
@@ -188,7 +188,7 @@ const TLangArray TranslationManager::getSupportedLanguageNames() const {
 	TLangArray languages;
 
 	for (unsigned int i = 0; i < _langNames.size(); i++) {
-		TLanguage lng(_langNames[i].c_str(), i + 1);
+		TLanguage lng(_langNames[i], i + 1);
 		languages.push_back(lng);
 	}
 
@@ -211,7 +211,7 @@ String TranslationManager::getLangById(int id) const {
 	case kTranslationAutodetectId:
 		return "";
 	case kTranslationBuiltinId:
-		return "C";
+		return "en";
 	default:
 		if (id >= 0 && id - 1 < (int)_langs.size())
 			return _langs[id - 1];
@@ -230,7 +230,7 @@ bool TranslationManager::openTranslationsFile(File &inFile) {
 
 	// Then try to open it using the SearchMan.
 	ArchiveMemberList fileList;
-	SearchMan.listMatchingMembers(fileList, "translations.dat");
+	SearchMan.listMatchingMembers(fileList, _translationsFileName);
 	for (ArchiveMemberList::iterator it = fileList.begin(); it != fileList.end(); ++it) {
 		ArchiveMember       const &m      = **it;
 		SeekableReadStream *const  stream = m.createReadStream();
@@ -251,7 +251,7 @@ bool TranslationManager::openTranslationsFile(const FSNode &node, File &inFile,
 	// Check if we can find the file in this directory
 	// Since File::open(FSNode) makes all the needed tests, it is not really
 	// necessary to make them here. But it avoid printing warnings.
-	FSNode fileNode = node.getChild("translations.dat");
+	FSNode fileNode = node.getChild(_translationsFileName);
 	if (fileNode.exists() && fileNode.isReadable() && !fileNode.isDirectory()) {
 		if (inFile.open(fileNode)) {
 			if (checkHeader(inFile))
@@ -278,10 +278,11 @@ bool TranslationManager::openTranslationsFile(const FSNode &node, File &inFile,
 	return false;
 }
 
-void TranslationManager::loadTranslationsInfoDat() {
+void TranslationManager::loadTranslationsInfoDat(const Common::String &name) {
 	File in;
+	_translationsFileName = name;
 	if (!openTranslationsFile(in)) {
-		warning("You are missing a valid 'translations.dat' file. GUI translation will not be available");
+		warning("You are missing a valid '%s' file. GUI translation will not be available", name.c_str());
 		return;
 	}
 
@@ -291,14 +292,11 @@ void TranslationManager::loadTranslationsInfoDat() {
 	// Get number of translations
 	int nbTranslations = in.readUint16BE();
 
-	// Get number of codepages
-	int nbCodepages = in.readUint16BE();
-
-	// Determine where the codepages start
-	_charmapStart = 0;
-	for (int i = 0; i < nbTranslations + 3; ++i)
-		_charmapStart += in.readUint16BE();
-	_charmapStart += in.pos();
+	// Skip translation description & size for the original language (english) block
+	// Also skip size of each translation block. Each block is written in Uint32BE.
+	for (int i = 0; i < nbTranslations + 2; i++) {
+		in.readUint32BE();
+	}
 
 	// Read list of languages
 	_langs.resize(nbTranslations);
@@ -309,15 +307,7 @@ void TranslationManager::loadTranslationsInfoDat() {
 		_langs[i] = String(buf, len - 1);
 		len = in.readUint16BE();
 		in.read(buf, len);
-		_langNames[i] = String(buf, len - 1);
-	}
-
-	// Read list of codepages
-	_charmaps.resize(nbCodepages);
-	for (int i = 0; i < nbCodepages; ++i) {
-		len = in.readUint16BE();
-		in.read(buf, len);
-		_charmaps[i] = String(buf, len - 1);
+		_langNames[i] = String(buf, len - 1).decode();
 	}
 
 	// Read messages
@@ -359,19 +349,16 @@ void TranslationManager::loadLanguageDat(int index) {
 		return;
 	}
 
-	// Get the number of codepages
-	int nbCodepages = in.readUint16BE();
-	if (nbCodepages != (int)_charmaps.size()) {
-		warning("The 'translations.dat' file has changed since starting ScummVM. GUI translation will not be available");
-		return;
-	}
-
 	// Get size of blocks to skip.
 	int skipSize = 0;
-	for (int i = 0; i < index + 3; ++i)
-		skipSize += in.readUint16BE();
+
+	// Skip translation description & size for the original language (english) block
+	// Also skip size of each translation block. All block sizes are written in Uint32BE.
+	for (int i = 0; i < index + 2; ++i)
+		skipSize += in.readUint32BE();
+
 	// We also need to skip the remaining block sizes
-	skipSize += 2 * (nbTranslations - index);
+	skipSize += 4 * (nbTranslations - index);	// 4 because block sizes are written in Uint32BE in the .dat file.
 
 	// Seek to start of block we want to read
 	in.seek(skipSize, SEEK_CUR);
@@ -380,10 +367,7 @@ void TranslationManager::loadLanguageDat(int index) {
 	int nbMessages = in.readUint16BE();
 	_currentTranslationMessages.resize(nbMessages);
 
-	// Read charset
-	len = in.readUint16BE();
-	in.read(buf, len);
-	_currentCharset = String(buf, len - 1);
+	_currentCharset = "UTF-32";
 
 	// Read messages
 	for (int i = 0; i < nbMessages; ++i) {
@@ -395,36 +379,13 @@ void TranslationManager::loadLanguageDat(int index) {
 			msg += String(buf, len > 256 ? 256 : len - 1);
 			len -= 256;
 		}
-		_currentTranslationMessages[i].msgstr = msg;
+		_currentTranslationMessages[i].msgstr = msg.decode();
 		len = in.readUint16BE();
 		if (len > 0) {
 			in.read(buf, len);
 			_currentTranslationMessages[i].msgctxt = String(buf, len - 1);
 		}
 	}
-
-	// Find the charset
-	int charmapNum = -1;
-	for (uint i = 0; i < _charmaps.size(); ++i) {
-		if (_charmaps[i].equalsIgnoreCase(_currentCharset)) {
-			charmapNum = i;
-			break;
-		}
-	}
-
-	// Setup the new charset mapping
-	if (charmapNum == -1) {
-		delete[] _charmap;
-		_charmap = nullptr;
-	} else {
-		if (!_charmap)
-			_charmap = new uint32[256];
-
-		in.seek(_charmapStart + charmapNum * 256 * 4, SEEK_SET);
-		for (int i = 0; i < 256; ++i)
-			_charmap[i] = in.readUint32BE();
-	}
-
 }
 
 bool TranslationManager::checkHeader(File &in) {
@@ -451,19 +412,6 @@ bool TranslationManager::checkHeader(File &in) {
 	return true;
 }
 
-String TranslationManager::convertBiDiString(const String &input) {
-	if (getCurrentLanguage() != "he")		//TODO: modify when we'll support other RTL languages, such as Arabic and Farsi
-		return input;
-
-	if (getCurrentCharset() != "iso-8859-8") {
-		warning("convertBiDiString: Unexpected charset is used with %s language: %s", getCurrentLanguage().c_str(), getCurrentCharset().c_str());
-		return input;
-	};
-
-	return Common::convertBiDiString(input, HE_ISR);
-}
-
-
 } // End of namespace Common
 
 #endif // USE_TRANSLATION
