@@ -131,29 +131,39 @@ bool WinResources::loadFromCompressedEXE(const String &fileName) {
 	assert(unpackedData);
 	byte *dataPos = unpackedData;
 
+	uint32 remaining = unpackedLength;
+
 	// Apply simple LZSS decompression
 	for (;;) {
 		byte controlByte = file.readByte();
 
-		if (file.eos())
+		if (remaining == 0 || file.eos())
 			break;
 
 		for (byte i = 0; i < 8; i++) {
 			if (controlByte & (1 << i)) {
 				*dataPos++ = window[pos++] = file.readByte();
 				pos &= 0xFFF;
+				if (--remaining == 0)
+					break;
 			} else {
 				int matchPos = file.readByte();
 				int matchLen = file.readByte();
 				matchPos |= (matchLen & 0xF0) << 4;
 				matchLen = (matchLen & 0xF) + 3;
+				if ((uint32)matchLen > remaining)
+					matchLen = remaining;
+				remaining -= matchLen;
+
 				while (matchLen--) {
 					*dataPos++ = window[pos++] = window[matchPos++];
 					pos &= 0xFFF;
 					matchPos &= 0xFFF;
 				}
-			}
 
+				if (remaining == 0)
+					break;
+			}
 		}
 	}
 
@@ -184,59 +194,81 @@ WinResources *WinResources::createFromEXE(const String &fileName) {
 	return nullptr;
 }
 
-WinResources::VersionHash *WinResources::parseVersionInfo(SeekableReadStream *res) {
-	VersionHash *versionMap = new VersionHash;
+WinResources *WinResources::createFromEXE(SeekableReadStream *stream) {
+	WinResources *exe;
 
-	while (res->pos() < res->size() && !res->eos()) {
-		while (res->pos() % 4 && !res->eos()) // Pad to 4
-			res->readByte();
-
-		/* uint16 len = */ res->readUint16LE();
-		uint16 valLen = res->readUint16LE();
-		uint16 type = res->readUint16LE();
-		uint16 c;
-
-		Common::U32String info;
-		while ((c = res->readUint16LE()) != 0 && !res->eos())
-			info += c;
-
-		while (res->pos() % 4 && !res->eos()) // Pad to 4
-			res->readByte();
-
-		if (res->eos())
-			break;
-
-		if (type != 0) {	// text
-			Common::U32String value;
-			for (int j = 0; j < valLen; j++)
-				value += res->readUint16LE();
-
-			versionMap->setVal(info.encode(), value);
-		} else {
-			if (info == "VS_VERSION_INFO") {
-				uint16 pos2 = res->pos() + valLen;
-
-				res->readUint32LE();
-				res->readUint32LE();
-				uint16 fileB = res->readUint16LE();
-				uint16 fileA = res->readUint16LE();
-				uint16 fileD = res->readUint16LE();
-				uint16 fileC = res->readUint16LE();
-				uint16 prodB = res->readUint16LE();
-				uint16 prodA = res->readUint16LE();
-				uint16 prodD = res->readUint16LE();
-				uint16 prodC = res->readUint16LE();
-
-				versionMap->setVal("File:", Common::String::format("%d.%d.%d.%d", fileA, fileB, fileC, fileD));
-				versionMap->setVal("Prod:", Common::String::format("%d.%d.%d.%d", prodA, prodB, prodC, prodD));
-
-				while (res->pos() != pos2 && !res->eos())
-					res->readByte();
-			}
-		}
+	// First try loading via the NE code
+	stream->seek(0);
+	exe = new Common::NEResources();
+	if (exe->loadFromEXE(stream, DisposeAfterUse::NO)) {
+		return exe;
 	}
+	delete exe;
 
-	return versionMap;
+	// Then try loading via the PE code
+	stream->seek(0);
+	exe = new Common::PEResources();
+	if (exe->loadFromEXE(stream, DisposeAfterUse::NO)) {
+		return exe;
+	}
+	delete exe;
+
+	return nullptr;
+}
+
+WinResources::VersionInfo *WinResources::getVersionResource(const WinResourceID &id) {
+		VersionInfo *info = nullptr;
+
+		SeekableReadStream *res = getResource(kWinVersion, id);
+		if (res) {
+			info = parseVersionInfo(res);
+			delete res;
+		}
+
+		return info;
+}
+
+WinResources::VersionInfo::VersionInfo() {
+	fileVersion[0] = fileVersion[1] = fileVersion[2] = fileVersion[3] = 0;
+	productVersion[0] = productVersion[1] = productVersion[2] = productVersion[3] = 0;
+	fileFlagsMask = 0;
+	fileFlags = 0;
+	fileOS = 0;
+	fileType = 0;
+	fileSubtype = 0;
+	fileDate[0] = fileDate[1] = 0;
+}
+
+
+bool WinResources::VersionInfo::readVSVersionInfo(SeekableReadStream *res) {
+	// Signature check
+	if (res->readUint32LE() != 0xFEEF04BD)
+		return false;
+
+	res->readUint32LE(); // struct version
+
+	// The versions are stored a bit weird
+	fileVersion[1] = res->readUint16LE();
+	fileVersion[0] = res->readUint16LE();
+	fileVersion[3] = res->readUint16LE();
+	fileVersion[2] = res->readUint16LE();
+	productVersion[1] = res->readUint16LE();
+	productVersion[0] = res->readUint16LE();
+	productVersion[3] = res->readUint16LE();
+	productVersion[2] = res->readUint16LE();
+
+	fileFlagsMask = res->readUint32LE();
+	fileFlags = res->readUint32LE();
+	fileOS = res->readUint32LE();
+	fileType = res->readUint32LE();
+	fileSubtype = res->readUint32LE();
+	fileDate[0] = res->readUint32LE();
+	fileDate[1] = res->readUint32LE();
+
+	hash.setVal("File:", Common::U32String::format("%d.%d.%d.%d", fileVersion[0], fileVersion[1], fileVersion[2], fileVersion[3]));
+	hash.setVal("Prod:", Common::U32String::format("%d.%d.%d.%d", productVersion[0], productVersion[1], productVersion[2], productVersion[3]));
+
+	return true;
 }
 
 } // End of namespace Common
