@@ -97,7 +97,7 @@ except ImportError:
 	print "[Error] struct python library is required to be installed!"
 else:
 	structLibFound = True
-	
+
 
 
 if 	(not osLibFound) \
@@ -125,7 +125,7 @@ from struct import *
 from subtlsVersTextResource import *
 
 COMPANY_EMAIL = "classic.adventures.in.greek@gmail.com"
-APP_VERSION = "1.50"
+APP_VERSION = "1.70"
 APP_NAME = "packBladeRunnerMIXFromPCTLKXLS"
 APP_WRAPPER_NAME = "mixResourceCreator.py"
 APP_NAME_SPACED = "Blade Runner MIX Resource Creator"
@@ -146,7 +146,7 @@ SUPPORTED_INGAME_DIALOGUE_SHEETS = ['INGQUO_']
 # Video cut-scenes' dialogue sheets - these need the appendix of (x) for the language code, and a suffix of '.VQA'.
 # These two first videos seem to be in _E (english) language across translations
 SUPPORTED_VIDEO_DIALOGUE_SHEETS_ENGLISH = ['WSTLGO_', 'BRLOGO_']
-SUPPORTED_VIDEO_DIALOGUE_SHEETS_LOCALIZED = ['INTRO_', 'MW_A_', 'MW_B01_', 'MW_B02_', 'MW_B03_', 'MW_B04_', 'MW_B05_', 'INTRGT_', 'MW_D_', 'MW_C01_', 'MW_C02_', 'MW_C03_', 'END04A_', 'END04B_', 'END04C_', 'END06_', 'END01A_', 'END01B_', 'END01C_', 'END01D_', 'END01E_', 'END01F_', 'END03_']
+SUPPORTED_VIDEO_DIALOGUE_SHEETS_LOCALIZED = ['INTRO_', 'MW_A_', 'MW_B01_', 'MW_B02_', 'MW_B03_', 'MW_B04_', 'MW_B05_', 'INTRGT_', 'MW_D_', 'MW_C01_', 'MW_C02_', 'MW_C03_', 'END04A_', 'END04B_', 'END04C_', 'END06_', 'END01A_', 'END01B_', 'END01C_', 'END01D_', 'END01E_', 'END01F_', 'END03_', 'TB_FLY_']
 #
 # Each Text Resource (TRx) sheet gets a specific font to handle their translation to Text Resource
 # TAHOMA means both TAHOMA Fonts (18 and 24)(their translation should be identical (although in the original they have minor differences but they don't affect anything)
@@ -170,7 +170,7 @@ SUPPORTED_TRANSLATION_SHEETS = [('OPTIONS.TR', 'KIA6PT'),
 								('CLUETYPE.TR', 'KIA6PT'),
 								('ENDCRED.TR', 'TAHOMA'),
 								('POGO.TR', 'KIA6PT'),
-								(SUPPORTED_DIALOGUE_VERSION_SHEET[:-1], 'KIA6PT')]
+								(SUPPORTED_DIALOGUE_VERSION_SHEET[:-1], SUBTITLES_FONT_NAME_CATEGORY)]
 # The FON files that are identically named to the originals are supposed to override them (needs ScummVM compatible functionality for that)
 # We don't deal with 10PT.FON since it's not used.
 # Also we don't deal with the SYSTEM (external OS font) that ERRORMSG.TRx uses!
@@ -668,7 +668,7 @@ def translateQuoteToAsciiProper(cellObj, pSheetName):
 
 		if(len(gListOfFontNamesToOutOfOrderGlyphs) > 0):
 			for (tmpFontName, tmpOOOList) in gListOfFontNamesToOutOfOrderGlyphs:
-				if tmpFontName ==  pertinentFontType:
+				if tmpFontName == pertinentFontType:
 					pertinentListOfOutOfOrderGlyphs = tmpOOOList
 					break
 
@@ -793,7 +793,7 @@ def inputXLS(pathtoInputExcelFilename):
 		if gTraceModeEnabled:
 			print '[Debug] Sheet: %s was not found. Creating a temporary sheet for version info...' % (SUPPORTED_DIALOGUE_VERSION_SHEET)
 		sbtlVersTRInstance = sbtlVersTextResource(gTraceModeEnabled)
-		bookCopy = copy(xl_workbook) 
+		bookCopy = copy(xl_workbook)
 		xl_sheet = bookCopy.add_sheet(SUPPORTED_DIALOGUE_VERSION_SHEET)
 		n = 0
 		col1_name = 'Subtitles Version Info'
