@@ -23,12 +23,6 @@
  // Disable symbol overrides so that we can use system headers.
 #define FORBIDDEN_SYMBOL_ALLOW_ALL
 
-// HACK to allow building with the SDL backend on MinGW
-// see bug #1800764 "TOOLS: MinGW tools building broken"
-#ifdef main
-#undef main
-#endif // main
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -150,7 +144,7 @@ private:
 	const byte *_ptr;
 public:
 	MemoryReadStream(const byte *ptr) : _ptr(ptr) {}
-	
+
 	byte readByte() {
 		return *_ptr++;
 	}
