@@ -177,6 +177,9 @@ enum kExtractID {
 	k3ItemAnimData,
 	k3ItemMagicTable,
 	k3ItemStringMap,
+	k3FontData,
+	k3VqaSubtitlesIntro,
+	k3VqaSubtitlesBoat,
 
 	kRpgCommonMoreStrings,
 	kRpgCommonDscShapeIndex,
@@ -346,6 +349,7 @@ enum kExtractID {
 	kEoBBaseEncodeMonsterDefs21,
 
 	kEoBBaseNpcPresets,
+	kEoBBaseNpcPresetsNames,
 
 	kEoBBaseWllFlagPreset,
 	kEoBBaseDscShapeCoords,
@@ -451,6 +455,8 @@ enum kExtractID {
 	kEoBBaseTextInputCharacterLines,
 	kEoBBaseTextInputSelectStrings,
 
+	kEoBBaseSaveNamePatterns,
+
 	kEoB1DefaultPartyStats,
 	kEoB1DefaultPartyNames,
 	kEoB1MainMenuStrings,
@@ -1047,7 +1053,6 @@ enum kExtractID {
 	kEoB2FontDmpSearchTbl,
 	kEoB2Ascii2SjisTables,
 	kEoB2Ascii2SjisTables2,
-	kEoB2SaveNamePatterns,
 	kEoB2PcmSoundEffectsIngame,
 	kEoB2PcmSoundEffectsIntro,
 	kEoB2PcmSoundEffectsFinale,
