@@ -1679,7 +1679,7 @@ static const uint16 kEoB1EncodeMonsterDefsDOS[168] = {
 static const Uint16Provider kEoB1EncodeMonsterDefsDOSProvider = { ARRAYSIZE(kEoB1EncodeMonsterDefsDOS), kEoB1EncodeMonsterDefsDOS };
 
 static const EoBCharacter kEoB1NpcPresetsDOS[9] = {
-	{ 0x00, 0x01, "Anya",
+	{ 0x00, 0x01,
 	  18, 18, 59, 59,  5,  5, 11, 11, 14, 14, 16, 16,  9,  9,
 	    45,   45, 10, 0, 1, 0, 2, -1, 100, { 4, 0, 0 },
 	  { 0x00001F40, 0x00000000, 0x00000000 }, 0x00000000,
@@ -1687,7 +1687,7 @@ static const EoBCharacter kEoB1NpcPresetsDOS[9] = {
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000 } },
-	{ 0x00, 0x01, "Beohram",
+	{ 0x00, 0x01,
 	  17, 17,  0,  0,  9,  9, 15, 15, 13, 13, 18, 18, 17, 17,
 	    55,   55, 10, 0, 0, 0, 0, -2, 100, { 7, 0, 0 },
 	  { 0x000130B0, 0x00000000, 0x00000000 }, 0x00000000,
@@ -1695,7 +1695,7 @@ static const EoBCharacter kEoB1NpcPresetsDOS[9] = {
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000 } },
-	{ 0x00, 0x01, "Kirath",
+	{ 0x00, 0x01,
 	  11, 11,  0,  0, 17, 17, 13, 13, 18, 18,  8,  8, 12, 12,
 	    20,   20, 10, 0, 4, 3, 4, -3, 100, { 7, 0, 0 },
 	  { 0x00011170, 0x00000000, 0x00000000 }, 0x00B3126B,
@@ -1703,7 +1703,7 @@ static const EoBCharacter kEoB1NpcPresetsDOS[9] = {
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000 } },
-	{ 0x00, 0x01, "Ileria",
+	{ 0x00, 0x01,
 	  10, 10,  0,  0, 12, 12,  9,  9, 15, 15, 17, 17, 17, 17,
 	    52,   52, 10, 0, 4, 4, 0, -4, 100, { 6, 0, 0 },
 	  { 0x00004E20, 0x00000000, 0x00000000 }, 0xFFFFFFFF,
@@ -1711,7 +1711,7 @@ static const EoBCharacter kEoB1NpcPresetsDOS[9] = {
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000 } },
-	{ 0x00, 0x01, "Tyrra",
+	{ 0x00, 0x01,
 	  16, 16,  0,  0, 14, 14, 16, 16, 18, 18, 17, 17,  7,  7,
 	    45,   45, 10, 0, 1, 1, 2, -5, 100, { 6, 0, 0 },
 	  { 0x0000CF08, 0x00000000, 0x00000000 }, 0x00000000,
@@ -1719,7 +1719,7 @@ static const EoBCharacter kEoB1NpcPresetsDOS[9] = {
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000 } },
-	{ 0x00, 0x01, "Tod Uphill",
+	{ 0x00, 0x01,
 	  17, 17,  0,  0, 11, 11, 14, 14, 19, 19, 18, 18, 16, 16,
 	    32,   32, 10, 0, 10, 5, 5, -6, 100, { 5, 0, 0 },
 	  { 0x00002D3F, 0x00000000, 0x00000000 }, 0x00000000,
@@ -1727,7 +1727,7 @@ static const EoBCharacter kEoB1NpcPresetsDOS[9] = {
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000 } },
-	{ 0x00, 0x01, "Taghor",
+	{ 0x00, 0x01,
 	  17, 17,  0,  0, 11, 11, 15, 15, 15, 15, 19, 19,  9,  9,
 	     3,   45,  3, 0, 6, 0, 1, -7, 25, { 5, 0, 0 },
 	  { 0x00003F6A, 0x00000000, 0x00000000 }, 0x00000000,
@@ -1735,7 +1735,7 @@ static const EoBCharacter kEoB1NpcPresetsDOS[9] = {
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0029, 0x0000, 0x002B, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000 } },
-	{ 0x00, 0x01, "Dohrum",
+	{ 0x00, 0x01,
 	  18, 18, 29, 29, 13, 13, 11, 11, 16, 16, 17, 17, 14, 14,
 	    28,   28, 10, 0, 6, 0, 0, -8, 100, { 3, 0, 0 },
 	  { 0x000013A0, 0x00000000, 0x00000000 }, 0x00000000,
@@ -1743,7 +1743,7 @@ static const EoBCharacter kEoB1NpcPresetsDOS[9] = {
 	    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0029, 0x0000, 0x002B, 0x0000, 0x0000, 0x0000, 0x0000,
 	    0x0000, 0x0000, 0x0000 } },
-	{ 0x00, 0x01, "Keirgar",
+	{ 0x00, 0x01,
 	  18, 18, 92, 92, 15, 15, 15, 15, 12, 12, 19, 19, 17, 17,
 	     3,   45,  3, 0, 6, 0, 1, -9, 25, { 5, 0, 0 },
 	  { 0x00001F40, 0x00000000, 0x00000000 }, 0x00000000,
