@@ -33,21 +33,21 @@ public:
 
 protected:
 	void createProjectFile(const std::string &name, const std::string &uuid, const BuildSetup &setup, const std::string &moduleDir,
-	                       const StringList &includeList, const StringList &excludeList);
+	                       const StringList &includeList, const StringList &excludeList) override;
 
 	void outputProjectSettings(std::ofstream &project, const std::string &name, const BuildSetup &setup, bool isRelease, MSVC_Architecture arch, const std::string &configuration);
 
 	void writeFileListToProject(const FileNode &dir, std::ofstream &projectFile, const int indentation,
-	                            const StringList &duplicate, const std::string &objPrefix, const std::string &filePrefix);
+	                            const std::string &objPrefix, const std::string &filePrefix) override;
 
-	void writeReferences(const BuildSetup &setup, std::ofstream &output);
+	void writeReferences(const BuildSetup &setup, std::ofstream &output) override;
 
 	void outputGlobalPropFile(const BuildSetup &setup, std::ofstream &properties, MSVC_Architecture arch, const StringList &defines, const std::string &prefix, bool runBuildEvents) override;
 
 	void createBuildProp(const BuildSetup &setup, bool isRelease, MSVC_Architecture arch, const std::string &configuration) override;
 
-	const char *getProjectExtension();
-	const char *getPropertiesExtension();
+	const char *getProjectExtension() override;
+	const char *getPropertiesExtension() override;
 
 private:
 	struct FileEntry {
@@ -69,11 +69,13 @@ private:
 	FileEntries _asmFiles;
 	FileEntries _resourceFiles;
 
-	void computeFileList(const FileNode &dir, const StringList &duplicate, const std::string &objPrefix, const std::string &filePrefix);
+	void computeFileList(const FileNode &dir, const std::string &objPrefix, const std::string &filePrefix);
 	void createFiltersFile(const BuildSetup &setup, const std::string &name);
 
 	void outputFilter(std::ostream &filters, const FileEntries &files, const std::string &action);
 	void outputFiles(std::ostream &projectFile, const FileEntries &files, const std::string &action);
+
+	void outputNasmCommand(std::ostream &projectFile, const std::string &config, const std::string &prefix);
 };
 
 } // namespace CreateProjectTool
