@@ -23,12 +23,6 @@
  // Disable symbol overrides so that we can use system headers.
 #define FORBIDDEN_SYMBOL_ALLOW_ALL
 
-// HACK to allow building with the SDL backend on MinGW
-// see bug #1800764 "TOOLS: MinGW tools building broken"
-#ifdef main
-#undef main
-#endif // main
-
 #include "file.h"
 #include "tag_maps.h"
 
@@ -650,7 +644,7 @@ static const TagMapping LIFTBOT_MAP_DE[119] = {
 	{ 0x46d47, 0x07536 }, { 0x46d4a, 0x3360c }, { 0x46d4e, 0x337fc },
 	{ 0x46d50, 0x337fd }, { 0x46d56, 0x33800 }, { 0x46d58, 0x33694 },
 	{ 0x46dc2, 0x337f3 }, { 0x46dc6, 0x337fb }, { 0x46dc7, 0x337f9 },
-	{ 0x46dca, 0x33802 }, { 0x46dd3, 0x33775 } 
+	{ 0x46dca, 0x33802 }, { 0x46dd3, 0x33775 }
 };
 
 #define MAITRED_COUNT_DE 105
