@@ -40,7 +40,7 @@ my @subs_files = qw(
 	dists/iphone/Info.plist
 	dists/ios7/Info.plist
 	dists/irix/scummvm.spec
-	dists/wii/meta.xml 
+	dists/wii/meta.xml
 	dists/openpandora/PXML.xml
 	dists/openpandora/README-OPENPANDORA
 	dists/openpandora/README-PND.txt
@@ -48,7 +48,7 @@ my @subs_files = qw(
 	dists/gph/README-GPH
 	dists/gph/scummvm.ini
 	dists/riscos/!Boot,feb
-	dists/amiga/RM2AG.rexx
+	dists/amigaos/md2ag.rexx
 	backends/platform/psp/README.PSP
 	);
 
