@@ -20,19 +20,17 @@
  *
  */
 
-#include "common/system.h"
-#include "common/savefile.h"
 #include "common/translation.h"
 #include "common/file.h"
 #include "common/md5.h"
 #include "common/debug.h"
 
-#include "graphics/thumbnail.h"
-
 #include "engines/advancedDetector.h"
 
 #include "adl/detection.h"
 #include "adl/disk.h"
+#include "adl/disk_image_helpers.h"
+#include "adl/adl.h"
 
 namespace Adl {
 
@@ -44,6 +42,11 @@ namespace Adl {
 #define GAMEOPTION_NTSC              GUIO_GAMEOPTIONS4
 #define GAMEOPTION_MONO_TEXT         GUIO_GAMEOPTIONS5
 
+static const DebugChannelDef debugFlagList[] = {
+	{Adl::kDebugChannelScript, "Script", "Trace script execution"},
+	DEBUG_CHANNEL_END
+};
+
 static const ADExtraGuiOptionsMap optionsList[] = {
 	{
 		GAMEOPTION_NTSC,
@@ -112,16 +115,10 @@ static const PlainGameDescriptor adlGames[] = {
 	{ 0, 0 }
 };
 
-struct AdlGameDescription {
-	ADGameDescription desc;
-	GameType gameType;
-	GameVersion version;
-};
-
 static const AdlGameDescription gameFileDescriptions[] = {
-	{ // Hi-Res Adventure #1: Mystery House - Apple II - Contains Simi Valley address
+	{ // Hi-Res Adventure #1: Mystery House - Apple II - Simi Valley
 		{
-			"hires1", 0,
+			"hires1", "On-Line Systems [A]",
 			{
 				{ "ADVENTURE", 0, "22d9e63a11d69fa033ba1738715ad09a", 29952 },
 				{ "AUTO LOAD OBJ", 0, "a2ab7be25842e1fa9f1343b0894a8b6f", 4095 },
@@ -135,9 +132,57 @@ static const AdlGameDescription gameFileDescriptions[] = {
 		GAME_TYPE_HIRES1,
 		GAME_VER_HR1_SIMI
 	},
-	{ // Hi-Res Adventure #1: Mystery House - Apple II - Contains Coarsegold address
+	{ // Hi-Res Adventure #1: Mystery House - Apple II - Coarsegold - Without MIXEDON
 		{
-			"hires1", 0,
+			"hires1", "On-Line Systems [B]",
+			{
+				{ "ADVENTURE", 0, "22d9e63a11d69fa033ba1738715ad09a", 29952 },
+				{ "AUTO LOAD OBJ", 0, "669b5f313ffdfb373ab8dce5961688d3", 12288 },
+				AD_LISTEND
+			},
+			Common::EN_ANY,
+			Common::kPlatformApple2,
+			ADGF_NO_FLAGS,
+			MH_OPTIONS
+		},
+		GAME_TYPE_HIRES1,
+		GAME_VER_HR1_COARSE
+	},
+	{ // Hi-Res Adventure #1: Mystery House - Apple II - French - Without MIXEDON
+		{
+			"hires1", "Malibu Microcomputing [A]",
+			{
+				{ "ADVENTURE", 0, "6e2245979871b44a9fec46b4b2ba590a", 29952 },
+				{ "AUTO LOAD OBJ", 0, "3d417e923e70abe9a82e51155974027d", 12288 },
+				AD_LISTEND
+			},
+			Common::FR_FRA,
+			Common::kPlatformApple2,
+			ADGF_NO_FLAGS,
+			MH_OPTIONS
+		},
+		GAME_TYPE_HIRES1,
+		GAME_VER_HR1_VF1
+	},
+	{ // Hi-Res Adventure #1: Mystery House - Apple II - French - Modified parser
+		{
+			"hires1", "Malibu Microcomputing [B]",
+			{
+				{ "ADVENTURE", 0, "f9a1add3609b4bc24b5dc4a9db1fec67", 29952 },
+				{ "AUTO LOAD OBJ", 0, "2a348058363da4c78a069ee5a2d81a31", 12287 },
+				AD_LISTEND
+			},
+			Common::FR_FRA,
+			Common::kPlatformApple2,
+			ADGF_NO_FLAGS,
+			MH_OPTIONS
+		},
+		GAME_TYPE_HIRES1,
+		GAME_VER_HR1_VF2
+	},
+	{ // Hi-Res Adventure #1: Mystery House - Apple II - Coarsegold - With MIXEDON
+		{
+			"hires1", "On-Line Systems [C]",
 			{
 				{ "ADVENTURE", 0, "22d9e63a11d69fa033ba1738715ad09a", 29952 },
 				{ "AUTO LOAD OBJ", 0, "f6a6ac60c04c6ba6dff68b92cc279ba2", 12291 },
@@ -151,13 +196,12 @@ static const AdlGameDescription gameFileDescriptions[] = {
 		GAME_TYPE_HIRES1,
 		GAME_VER_HR1_COARSE
 	},
-	{ // Hi-Res Adventure #1: Mystery House - Apple II - Roberta Williams Anthology
+	{ // Hi-Res Adventure #1: Mystery House - Apple II - Public Domain
 		{
-			"hires1", 0,
+			"hires1", "Public Domain",
 			{
 				{ "ADVENTURE", 0, "22d9e63a11d69fa033ba1738715ad09a", 29952 },
 				{ "AUTO LOAD OBJ", 0, "23bfccfe9fcff9b22cf6c41bde9078ac", 12291 },
-				{ "MYSTERY.HELLO", 0, "2289b7fea300b506e902a4c597968369", 836 },
 				AD_LISTEND
 			},
 			Common::EN_ANY,
@@ -172,13 +216,46 @@ static const AdlGameDescription gameFileDescriptions[] = {
 };
 
 static const AdlGameDescription gameDiskDescriptions[] = {
-	{ // Hi-Res Adventure #1: Mystery House - Apple II - Contains Coarsegold address
+	{ // Hi-Res Adventure #1: Mystery House - Apple II - Simi Valley - DOS 3.2 only
 		{
-			"hires1", "",
-			{
-				{ "mysthous", 0, "8df0b3b3e609a2e40237e2419c1cb767", 116480 },
-				AD_LISTEND
-			},
+			"hires1", "On-Line Systems [A]",
+			AD_ENTRY1s("mysthous", "629b9d034cbf8d8e3a612398f53a8dfc", 116480),
+			Common::EN_ANY,
+			Common::kPlatformApple2,
+			ADGF_NO_FLAGS,
+			MH_OPTIONS
+		},
+		GAME_TYPE_HIRES1,
+		GAME_VER_HR1_SIMI
+	},
+	{ // Hi-Res Adventure #1: Mystery House - Apple II - Coarsegold - Without MIXEDON
+		{
+			"hires1", "On-Line Systems [B]",
+			AD_ENTRY1s("mysthous", "b22561b5327c7dcdb659e2d649749310", 116480),
+			Common::EN_ANY,
+			Common::kPlatformApple2,
+			ADGF_NO_FLAGS,
+			MH_OPTIONS
+		},
+		GAME_TYPE_HIRES1,
+		GAME_VER_HR1_COARSE
+	},
+	{ // Hi-Res Adventure #1: Mystery House - Apple II - French - Modified parser
+		{
+			"hires1", "Malibu Microcomputing [B]",
+			AD_ENTRY1s("mysthous", "7bd1918ffc28e551e5b3baf610982bd3", 116480),
+			Common::FR_FRA,
+			Common::kPlatformApple2,
+			ADGF_NO_FLAGS,
+			MH_OPTIONS
+		},
+		GAME_TYPE_HIRES1,
+		GAME_VER_HR1_VF2
+	},
+	{ // Hi-Res Adventure #1: Mystery House - Apple II - Coarsegold - With MIXEDON
+		{
+			"hires1", "On-Line Systems [C]",
+			AD_ENTRY1s("mysthous", "8df0b3b3e609a2e40237e2419c1cb767", 116480),
 			Common::EN_ANY,
 			Common::kPlatformApple2,
 			ADGF_NO_FLAGS,
@@ -189,11 +266,8 @@ static const AdlGameDescription gameDiskDescriptions[] = {
 	},
 	{ // Hi-Res Adventure #1: Mystery House - Apple II - Roberta Williams Anthology
 		{
-			"hires1", "",
-			{
-				{ "mysthous", 0, "54d20eb1ef0084ac3c2d16c31c5b7eb7", 143360 },
-				AD_LISTEND
-			},
+			"hires1", "Public Domain",
+			AD_ENTRY1s("mysthous", "54d20eb1ef0084ac3c2d16c31c5b7eb7", 143360),
 			Common::EN_ANY,
 			Common::kPlatformApple2,
 			ADGF_NO_FLAGS,
@@ -202,13 +276,58 @@ static const AdlGameDescription gameDiskDescriptions[] = {
 		GAME_TYPE_HIRES1,
 		GAME_VER_HR1_PD
 	},
+	{ // Hi-Res Adventure #1: Mystery House - Apple II - Public Domain
+		{
+			"hires1", "Public Domain",
+			AD_ENTRY1s("mysthous", "bc0f34d153a530b9bb4e554b0a42f8d7", 143360),
+			Common::EN_ANY,
+			Common::kPlatformApple2,
+			ADGF_NO_FLAGS,
+			MH_OPTIONS
+		},
+		GAME_TYPE_HIRES1,
+		GAME_VER_HR1_PD
+	},
+	{ // Hi-Res Adventure #2: Wizard and the Princess - Apple II - DOS 3.2 only
+		{
+			"hires2", "On-Line Systems [A]",
+			AD_ENTRY1s("wizard", "5201c87db24ba7e3fa447471f4f2ec99", 116480),
+			Common::EN_ANY,
+			Common::kPlatformApple2,
+			ADGF_NO_FLAGS,
+			DEFAULT_OPTIONS
+		},
+		GAME_TYPE_HIRES2,
+		GAME_VER_NONE
+	},
+	{ // Hi-Res Adventure #2: Wizard and the Princess - Apple II
+		{
+			"hires2", "On-Line Systems [B]",
+			AD_ENTRY1s("wizard", "1de984859212ff11cf61b29cb9b55f8c", 116480),
+			Common::EN_ANY,
+			Common::kPlatformApple2,
+			ADGF_NO_FLAGS,
+			DEFAULT_OPTIONS
+		},
+		GAME_TYPE_HIRES2,
+		GAME_VER_NONE
+	},
+	{ // Hi-Res Adventure #2: Wizard and the Princess - Apple II - Green Valley Publishing
+		{
+			"hires2", "Green Valley [A]",
+			AD_ENTRY1s("wizard", "73cd373e9a2946c3181b72fdf7a32c77", 143360),
+			Common::EN_ANY,
+			Common::kPlatformApple2,
+			ADGF_NO_FLAGS,
+			DEFAULT_OPTIONS
+		},
+		GAME_TYPE_HIRES2,
+		GAME_VER_NONE
+	},
 	{ // Hi-Res Adventure #2: Wizard and the Princess - Apple II - Roberta Williams Anthology
 		{
-			"hires2", "",
-			{
-				{ "wizard", 0, "72b114bf8f94fafe5672daac2a70c765", 143360 },
-				AD_LISTEND
-			},
+			"hires2", "Green Valley [B]",
+			AD_ENTRY1s("wizard", "72b114bf8f94fafe5672daac2a70c765", 143360),
 			Common::EN_ANY,
 			Common::kPlatformApple2,
 			ADGF_NO_FLAGS,
@@ -220,10 +339,7 @@ static const AdlGameDescription gameDiskDescriptions[] = {
 	{ // Hi-Res Adventure #0: Mission Asteroid - Apple II - Roberta Williams Anthology
 		{
 			"hires0", "",
-			{
-				{ "mission", 0, "6bc53f51a3c8ee65c020af55fb8bd875", 116480 },
-				AD_LISTEND
-			},
+			AD_ENTRY1s("mission", "6bc53f51a3c8ee65c020af55fb8bd875", 116480),
 			Common::EN_ANY,
 			Common::kPlatformApple2,
 			ADGF_NO_FLAGS,
@@ -235,10 +351,7 @@ static const AdlGameDescription gameDiskDescriptions[] = {
 	{ // Hi-Res Adventure #3: Cranston Manor - Apple II
 		{
 			"hires3", "",
-			{
-				{ "cranston", 0, "e4d35440791a36e55299c7be1ccd2b04", 116480 },
-				AD_LISTEND
-			},
+			AD_ENTRY1s("cranston", "e4d35440791a36e55299c7be1ccd2b04", 116480),
 			Common::EN_ANY,
 			Common::kPlatformApple2,
 			ADGF_NO_FLAGS,
@@ -309,7 +422,7 @@ static const AdlGameDescription gameDiskDescriptions[] = {
 	},
 	{ // Hi-Res Adventure #6: The Dark Crystal - Apple II - Roberta Williams Anthology / SierraVenture
 		{
-			"hires6", "SierraVenture [version A]",
+			"hires6", "SierraVenture [A]",
 			{
 				{ "dark1a", 0, "9a5968a8f378c84454d88f4cd4e143a9", 143360 },
 				{ "dark1b", 3, "1271ff9c3e1bdb4942301dd37dd0ef87", 143360 },
@@ -327,7 +440,7 @@ static const AdlGameDescription gameDiskDescriptions[] = {
 	},
 	{ // Hi-Res Adventure #6: The Dark Crystal - Apple II - SierraVenture
 		{
-			"hires6", "SierraVenture [version B]",
+			"hires6", "SierraVenture [B]",
 			{
 				{ "dark1a", 0, "d0b8e808b02564b6ce58b5ea5cc61ead", 143360 },
 				{ "dark1b", 3, "1271ff9c3e1bdb4942301dd37dd0ef87", 143360 },
@@ -346,23 +459,9 @@ static const AdlGameDescription gameDiskDescriptions[] = {
 	{ AD_TABLE_END_MARKER, GAME_TYPE_NONE, GAME_VER_NONE }
 };
 
-struct DiskImageExt {
-	Common::Platform platform;
-	const char *extension;
-};
-
-const DiskImageExt diskImageExts[] = {
-	{ Common::kPlatformApple2, ".woz" },
-	{ Common::kPlatformApple2, ".nib" },
-	{ Common::kPlatformApple2, ".dsk" },
-	{ Common::kPlatformApple2, ".d13" },
-	{ Common::kPlatformAtari8Bit, ".xfd" },
-	{ Common::kPlatformDOS, ".img" }
-};
-
-class AdlMetaEngine : public AdvancedMetaEngine {
+class AdlMetaEngineDetection : public AdvancedMetaEngineDetection {
 public:
-	AdlMetaEngine() : AdvancedMetaEngine(gameFileDescriptions, sizeof(AdlGameDescription), adlGames, optionsList) { }
+	AdlMetaEngineDetection() : AdvancedMetaEngineDetection(gameFileDescriptions, sizeof(AdlGameDescription), adlGames, optionsList) { }
 
 	const char *getName() const override {
 		return "ADL";
@@ -376,172 +475,16 @@ public:
 		return "Copyright (C) Sierra On-Line";
 	}
 
-	bool hasFeature(MetaEngineFeature f) const override;
-	SaveStateDescriptor querySaveMetaInfos(const char *target, int slot) const override;
-	int getMaximumSaveSlot() const override { return 'O' - 'A'; }
-	SaveStateList listSaves(const char *target) const override;
-	void removeSaveState(const char *target, int slot) const override;
+	const DebugChannelDef *getDebugChannels() const override {
+		return debugFlagList;
+	}
+
 	ADDetectedGames detectGame(const Common::FSNode &parent, const FileMap &allFiles, Common::Language language, Common::Platform platform, const Common::String &extra) const override;
 
 	bool addFileProps(const FileMap &allFiles, Common::String fname, FilePropertiesMap &filePropsMap) const;
-
-	bool createInstance(OSystem *syst, Engine **engine, const ADGameDescription *gd) const override;
 };
 
-bool AdlMetaEngine::hasFeature(MetaEngineFeature f) const {
-	switch(f) {
-	case kSupportsListSaves:
-	case kSupportsLoadingDuringStartup:
-	case kSupportsDeleteSave:
-	case kSavesSupportMetaInfo:
-	case kSavesSupportThumbnail:
-	case kSavesSupportCreationDate:
-	case kSavesSupportPlayTime:
-	case kSimpleSavesNames:
-		return true;
-	default:
-		return false;
-	}
-}
-
-SaveStateDescriptor AdlMetaEngine::querySaveMetaInfos(const char *target, int slot) const {
-	Common::String fileName = Common::String::format("%s.s%02d", target, slot);
-	Common::InSaveFile *inFile = g_system->getSavefileManager()->openForLoading(fileName);
-
-	if (!inFile)
-		return SaveStateDescriptor();
-
-	if (inFile->readUint32BE() != MKTAG('A', 'D', 'L', ':')) {
-		delete inFile;
-		return SaveStateDescriptor();
-	}
-
-	byte saveVersion = inFile->readByte();
-	if (saveVersion != SAVEGAME_VERSION) {
-		delete inFile;
-		return SaveStateDescriptor();
-	}
-
-	char name[SAVEGAME_NAME_LEN] = { };
-	inFile->read(name, sizeof(name) - 1);
-	inFile->readByte();
-
-	if (inFile->eos() || inFile->err()) {
-		delete inFile;
-		return SaveStateDescriptor();
-	}
-
-	SaveStateDescriptor sd(slot, name);
-
-	int year = inFile->readUint16BE();
-	int month = inFile->readByte();
-	int day = inFile->readByte();
-	sd.setSaveDate(year + 1900, month + 1, day);
-
-	int hour = inFile->readByte();
-	int minutes = inFile->readByte();
-	sd.setSaveTime(hour, minutes);
-
-	uint32 playTime = inFile->readUint32BE();
-	sd.setPlayTime(playTime);
-
-	if (inFile->eos() || inFile->err()) {
-		delete inFile;
-		return SaveStateDescriptor();
-	}
-
-	Graphics::Surface *thumbnail;
-	if (!Graphics::loadThumbnail(*inFile, thumbnail)) {
-		delete inFile;
-		return SaveStateDescriptor();
-	}
-	sd.setThumbnail(thumbnail);
-
-	delete inFile;
-	return sd;
-}
-
-SaveStateList AdlMetaEngine::listSaves(const char *target) const {
-	Common::SaveFileManager *saveFileMan = g_system->getSavefileManager();
-	Common::StringArray files = saveFileMan->listSavefiles(Common::String(target) + ".s##");
-
-	SaveStateList saveList;
-
-	for (uint i = 0; i < files.size(); ++i) {
-		const Common::String &fileName = files[i];
-		Common::InSaveFile *inFile = saveFileMan->openForLoading(fileName);
-		if (!inFile) {
-			warning("Cannot open save file '%s'", fileName.c_str());
-			continue;
-		}
-
-		if (inFile->readUint32BE() != MKTAG('A', 'D', 'L', ':')) {
-			warning("No header found in '%s'", fileName.c_str());
-			delete inFile;
-			continue;
-		}
-
-		byte saveVersion = inFile->readByte();
-		if (saveVersion != SAVEGAME_VERSION) {
-			warning("Unsupported save game version %i found in '%s'", saveVersion, fileName.c_str());
-			delete inFile;
-			continue;
-		}
-
-		char name[SAVEGAME_NAME_LEN] = { };
-		inFile->read(name, sizeof(name) - 1);
-		delete inFile;
-
-		int slotNum = atoi(fileName.c_str() + fileName.size() - 2);
-		SaveStateDescriptor sd(slotNum, name);
-		saveList.push_back(sd);
-	}
-
-	// Sort saves based on slot number.
-	Common::sort(saveList.begin(), saveList.end(), SaveStateDescriptorSlotComparator());
-	return saveList;
-}
-
-void AdlMetaEngine::removeSaveState(const char *target, int slot) const {
-	Common::String fileName = Common::String::format("%s.s%02d", target, slot);
-	g_system->getSavefileManager()->removeSavefile(fileName);
-}
-
-Common::String getDiskImageName(const AdlGameDescription &adlDesc, byte volume) {
-	const ADGameDescription &desc = adlDesc.desc;
-	for (uint i = 0; desc.filesDescriptions[i].fileName; ++i) {
-		const ADGameFileDescription &fDesc = desc.filesDescriptions[i];
-
-		if (fDesc.fileType == volume) {
-			for (uint e = 0; e < ARRAYSIZE(diskImageExts); ++e) {
-				if (diskImageExts[e].platform == desc.platform) {
-					Common::String testFileName(fDesc.fileName);
-					testFileName += diskImageExts[e].extension;
-					if (Common::File::exists(testFileName))
-						return testFileName;
-				}
-			}
-
-			error("Failed to find disk image '%s'", fDesc.fileName);
-		}
-	}
-
-	error("Disk volume %d not found", volume);
-}
-
-GameType getGameType(const AdlGameDescription &adlDesc) {
-	return adlDesc.gameType;
-}
-
-GameVersion getGameVersion(const AdlGameDescription &adlDesc) {
-	return adlDesc.version;
-}
-
-Common::Platform getPlatform(const AdlGameDescription &adlDesc) {
-	return adlDesc.desc.platform;
-}
-
-bool AdlMetaEngine::addFileProps(const FileMap &allFiles, Common::String fname, FilePropertiesMap &filePropsMap) const {
+bool AdlMetaEngineDetection::addFileProps(const FileMap &allFiles, Common::String fname, FilePropertiesMap &filePropsMap) const {
 	if (filePropsMap.contains(fname))
 		return true;
 
@@ -552,7 +495,7 @@ bool AdlMetaEngine::addFileProps(const FileMap &allFiles, Common::String fname,
 	fileProps.size = computeMD5(allFiles[fname], fileProps.md5, 16384);
 
 	if (fileProps.size != -1) {
-		debug(3, "> '%s': '%s'", fname.c_str(), fileProps.md5.c_str());
+		debugC(3, kDebugGlobalDetection, "> '%s': '%s'", fname.c_str(), fileProps.md5.c_str());
 		filePropsMap[fname] = fileProps;
 	}
 
@@ -560,14 +503,14 @@ bool AdlMetaEngine::addFileProps(const FileMap &allFiles, Common::String fname,
 }
 
 // Based on AdvancedMetaEngine::detectGame
-ADDetectedGames AdlMetaEngine::detectGame(const Common::FSNode &parent, const FileMap &allFiles, Common::Language language, Common::Platform platform, const Common::String &extra) const {
+ADDetectedGames AdlMetaEngineDetection::detectGame(const Common::FSNode &parent, const FileMap &allFiles, Common::Language language, Common::Platform platform, const Common::String &extra) const {
 	// We run the file-based detector first, if it finds a match we do not search for disk images
-	ADDetectedGames matched = AdvancedMetaEngine::detectGame(parent, allFiles, language, platform, extra);
+	ADDetectedGames matched = AdvancedMetaEngineDetection::detectGame(parent, allFiles, language, platform, extra);
 
 	if (!matched.empty())
 		return matched;
 
-	debug(3, "Starting disk image detection in dir '%s'", parent.getPath().c_str());
+	debugC(3, kDebugGlobalDetection, "Starting disk image detection in dir '%s'", parent.getPath().c_str());
 
 	FilePropertiesMap filesProps;
 
@@ -621,30 +564,30 @@ ADDetectedGames AdlMetaEngine::detectGame(const Common::FSNode &parent, const Fi
 				continue;
 
 			if (fDesc.md5 && fDesc.md5 != filesProps[fileName].md5) {
-				debug(3, "MD5 Mismatch. Skipping (%s) (%s)", fDesc.md5, filesProps[fileName].md5.c_str());
+				debugC(3, kDebugGlobalDetection, "MD5 Mismatch. Skipping (%s) (%s)", fDesc.md5, filesProps[fileName].md5.c_str());
 				game.hasUnknownFiles = true;
 				continue;
 			}
 
 			if (fDesc.fileSize != -1 && fDesc.fileSize != filesProps[fileName].size) {
-				debug(3, "Size Mismatch. Skipping");
+				debugC(3, kDebugGlobalDetection, "Size Mismatch. Skipping");
 				game.hasUnknownFiles = true;
 				continue;
 			}
 
-			debug(3, "Matched file: %s", fileName.c_str());
+			debugC(3, kDebugGlobalDetection, "Matched file: %s", fileName.c_str());
 		}
 
 		// This assumes that the detection table groups together games that have the same gameId and platform
 		if (allFilesPresent) {
 			if (!game.hasUnknownFiles) {
-				debug(2, "Found game: %s (%s/%s) (%d)", game.desc->gameId, getPlatformDescription(game.desc->platform), getLanguageDescription(game.desc->language), g);
+				debugC(2, kDebugGlobalDetection, "Found game: %s (%s/%s) (%d)", game.desc->gameId, getPlatformDescription(game.desc->platform), getLanguageDescription(game.desc->language), g);
 				// If we just added an unknown variant for this game and platform, remove it
 				if (!matched.empty() && strcmp(matched.back().desc->gameId, game.desc->gameId) == 0 && matched.back().desc->platform == game.desc->platform)
 					matched.pop_back();
 				matched.push_back(game);
 			} else {
-				debug(5, "Skipping game: %s (%s/%s) (%d)", game.desc->gameId, getPlatformDescription(game.desc->platform), getLanguageDescription(game.desc->language), g);
+				debugC(5, kDebugGlobalDetection, "Skipping game: %s (%s/%s) (%d)", game.desc->gameId, getPlatformDescription(game.desc->platform), getLanguageDescription(game.desc->language), g);
 				// If we already added a known or unknown variant for this game and platform, don't add another
 				if (matched.empty() || strcmp(matched.back().desc->gameId, game.desc->gameId) != 0 || matched.back().desc->platform != game.desc->platform)
 					matched.push_back(game);
@@ -655,53 +598,6 @@ ADDetectedGames AdlMetaEngine::detectGame(const Common::FSNode &parent, const Fi
 	return matched;
 }
 
-Engine *HiRes1Engine_create(OSystem *syst, const AdlGameDescription *gd);
-Engine *HiRes2Engine_create(OSystem *syst, const AdlGameDescription *gd);
-Engine *HiRes0Engine_create(OSystem *syst, const AdlGameDescription *gd);
-Engine *HiRes3Engine_create(OSystem *syst, const AdlGameDescription *gd);
-Engine *HiRes4Engine_create(OSystem *syst, const AdlGameDescription *gd);
-Engine *HiRes5Engine_create(OSystem *syst, const AdlGameDescription *gd);
-Engine *HiRes6Engine_create(OSystem *syst, const AdlGameDescription *gd);
-
-bool AdlMetaEngine::createInstance(OSystem *syst, Engine **engine, const ADGameDescription *gd) const {
-	if (!gd)
-		return false;
-
-	const AdlGameDescription *adlGd = (const AdlGameDescription *)gd;
-
-	switch (adlGd->gameType) {
-	case GAME_TYPE_HIRES1:
-		*engine = HiRes1Engine_create(syst, adlGd);
-		break;
-	case GAME_TYPE_HIRES2:
-		*engine = HiRes2Engine_create(syst, adlGd);
-		break;
-	case GAME_TYPE_HIRES0:
-		*engine = HiRes0Engine_create(syst, adlGd);
-		break;
-	case GAME_TYPE_HIRES3:
-		*engine = HiRes3Engine_create(syst, adlGd);
-		break;
-	case GAME_TYPE_HIRES4:
-		*engine = HiRes4Engine_create(syst, adlGd);
-		break;
-	case GAME_TYPE_HIRES5:
-		*engine = HiRes5Engine_create(syst, adlGd);
-		break;
-	case GAME_TYPE_HIRES6:
-		*engine = HiRes6Engine_create(syst, adlGd);
-		break;
-	default:
-		error("Unknown GameType");
-	}
-
-	return true;
-}
-
 } // End of namespace Adl
 
-#if PLUGIN_ENABLED_DYNAMIC(ADL)
-	REGISTER_PLUGIN_DYNAMIC(ADL, PLUGIN_TYPE_ENGINE, Adl::AdlMetaEngine);
-#else
-	REGISTER_PLUGIN_STATIC(ADL, PLUGIN_TYPE_ENGINE, Adl::AdlMetaEngine);
-#endif
+REGISTER_PLUGIN_STATIC(ADL_DETECTION, PLUGIN_TYPE_ENGINE_DETECTION, Adl::AdlMetaEngineDetection);
