@@ -141,6 +141,21 @@ void AgiEngine::processScummVMEvents() {
 				}
 			}
 
+			if (_game._vm->getLanguage() == Common::HE_ISR && key >= 0x05d0 && key <= 0x05ea) {
+				// convert to WIN-1255
+				key = key - 0x05d0 + 0xe0;
+			}
+
+			if (_game._vm->getLanguage() == Common::RU_RUS) {
+				// Convert UTF16 to CP866
+				if (key >= 0x400 && key <= 0x4ff) {
+					if (key >= 0x440)
+						key = key - 0x410 + 0xb0;
+					else
+						key = key - 0x410 + 0x80;
+				}
+			}
+
 			if ((key) && (key <= 0xFF)) {
 				// No special key, directly accept it
 				// Is ISO-8859-1, we need lower 128 characters only, which is plain ASCII, so no mapping required
@@ -502,7 +517,7 @@ bool AgiEngine::handleController(uint16 key) {
 				if (key == AGI_MOUSE_BUTTON_LEFT) {
 					if (getGameID() == GID_PQ1 && getVar(VM_VAR_CURRENT_ROOM) == 116) {
 						// WORKAROUND: Special handling for mouse clicks in the newspaper
-						// screen of PQ1. Fixes bug #3018770.
+						// screen of PQ1. Fixes bug #4908.
 						newDirection = 3;   // fake a right arrow key (next page)
 
 					} else {
