@@ -44,6 +44,8 @@ PictureMgr::PictureMgr(AgiBase *agi, GfxMgr *gfx) {
 	_minCommand = 0xf0;
 	_flags = 0;
 	_currentStep = 0;
+
+	_width = _height = 0;
 }
 
 void PictureMgr::putVirtPixel(int x, int y) {
@@ -210,7 +212,6 @@ void PictureMgr::plotPattern(int x, int y) {
 
 	int pen_x = x;
 	int pen_y = y;
-	uint16 texture_num = 0;
 	uint16 pen_size = (_patCode & 0x07);
 
 	circle_ptr = &circle_data[circle_list[pen_size]];
@@ -245,7 +246,7 @@ void PictureMgr::plotPattern(int x, int y) {
 
 	pen_final_y = pen_y;    // used in plotrelated
 
-	t = (uint8)(texture_num | 0x01);        // even
+	t = (uint8)(_patNum | 0x01);     // even
 
 	// new purpose for temp16
 
@@ -268,7 +269,7 @@ void PictureMgr::plotPattern(int x, int y) {
 	} else {
 		circleCond = ((_patCode & 0x10) != 0);
 		counterStep = 4;
-		ditherCond = 0x01;
+		ditherCond = 0x02;
 	}
 
 	for (; pen_y < pen_final_y; pen_y++) {
@@ -306,9 +307,10 @@ void PictureMgr::plotBrush() {
 
 	for (;;) {
 		if (_patCode & 0x20) {
-			if ((_patNum = getNextByte()) >= _minCommand)
+			byte b = getNextByte();
+			if (b >= _minCommand)
 				break;
-			_patNum = (_patNum >> 1) & 0x7f;
+			_patNum = b;
 		}
 
 		if ((x1 = getNextByte()) >= _minCommand)
@@ -1001,7 +1003,7 @@ void PictureMgr::clear() {
 void PictureMgr::showPic() {
 	debugC(8, kDebugLevelMain, "Show picture!");
 
-	_gfx->render_Block(0, 167, SCRIPT_WIDTH, SCRIPT_HEIGHT);
+	_gfx->render_Block(0, 0, SCRIPT_WIDTH, SCRIPT_HEIGHT);
 }
 
 /**
@@ -1014,8 +1016,7 @@ void PictureMgr::showPic(int16 x, int16 y, int16 pic_width, int16 pic_height) {
 
 	debugC(8, kDebugLevelMain, "Show picture!");
 
-	// render block requires lower left coordinate!
-	_gfx->render_Block(x, pic_height + y - 1, pic_width, pic_height);
+	_gfx->render_Block(x, y, pic_width, pic_height);
 }
 
 void PictureMgr::showPicWithTransition() {
@@ -1038,13 +1039,13 @@ void PictureMgr::showPicWithTransition() {
 		case Common::kRenderAmiga:
 		case Common::kRenderApple2GS:
 			// Platform Amiga/Apple II GS -> render and do Amiga transition
-			_gfx->render_Block(0, 167, SCRIPT_WIDTH, SCRIPT_HEIGHT, false);
+			_gfx->render_Block(0, 0, SCRIPT_WIDTH, SCRIPT_HEIGHT, false);
 			_gfx->transition_Amiga();
 			return;
 			break;
 		case Common::kRenderAtariST:
 			// Platform Atari ST used a different transition, looks "high-res" (full 320x168)
-			_gfx->render_Block(0, 167, SCRIPT_WIDTH, SCRIPT_HEIGHT, false);
+			_gfx->render_Block(0, 0, SCRIPT_WIDTH, SCRIPT_HEIGHT, false);
 			_gfx->transition_AtariSt();
 			return;
 		default:
@@ -1054,7 +1055,7 @@ void PictureMgr::showPicWithTransition() {
 		}
 	}
 
-	_gfx->render_Block(0, 167, SCRIPT_WIDTH, SCRIPT_HEIGHT);
+	_gfx->render_Block(0, 0, SCRIPT_WIDTH, SCRIPT_HEIGHT);
 }
 
 // preagi needed functions (for plotPattern)
