@@ -102,6 +102,26 @@ SystemUI::SystemUI(AgiEngine *vm, GfxMgr *gfx, TextMgr *text) {
 		_textRestoreGameError = "\x8E\xE8\xA8\xA1\xAA\xA0 \xA2 \xA7\xA0\xAF\xA8\xE1\xA0\xAD\xAD\xAE\xA9 \xA8\xA3\xE0\xA5.\nENTER - \xA2\xEB\xE5\xAE\xA4.";
 		_textRestoreGameVerify = "\x83\xAE\xE2\xAE\xA2 \xAA \xE1\xE7\xA8\xE2\xEB\xA2\xA0\xAD\xA8\xEE \xA8\xA3\xE0\xEB\x2C\n\xAE\xAF\xA8\xE1\xA0\xAD\xAD\xAE\xA9 \xAA\xA0\xAA.\n\n%s\n\n\xA8\xA7 \xE4\xA0\xA9\xAB\xA0:\n%s\n\n\x84\xAB\xEF \xAF\xE0\xAE\xA4\xAE\xAB\xA6\xA5\xAD\xA8\xEF \xAD\xA0\xA6\xAC\xA8\xE2\xA5 ENTER.\nESC - \xAE\xE2\xAC\xA5\xAD\xA0.";
 		break;
+	case Common::HE_ISR:
+		_textStatusScore = "\xf0\xe9\xf7\xe5\xe3: %v3 \xee\xfa\xe5\xea %v7";
+		_textStatusSoundOn = "\xf6\xec\xe9\xec: \xf4\xe5\xf2\xec";
+		_textStatusSoundOff = "\xf6\xec\xe9\xec: \xeb\xe1\xe5\xe9";
+		_textEnterCommand = "\xe4\xeb\xf0\xe9\xf1\xe5 \xf7\xec\xe8\n\n";
+		_textPause = "      \xe4\xee\xf9\xe7\xf7 \xee\xe5\xf9\xe4\xe4.\n\xec\xe7\xf6\xe5 \xf2\xec ENTER \xeb\xe3\xe9 \xec\xe4\xee\xf9\xe9\xea.";
+		_textRestart = "\xec\xe7\xf6\xe5 \xf2\xec ENTER \xeb\xe3\xe9 \xec\xe4\xfa\xe7\xe9\xec \xee\xe7\xe3\xf9\n\xe0\xfa \xe4\xee\xf9\xe7\xf7.\n\n\xec\xe7\xf6\xe5 \xf2\xec ESC \xeb\xe3\xe9 \xec\xe4\xee\xf9\xe9\xea\n\xe0\xfa \xe4\xee\xf9\xe7\xf7 \xe4\xf0\xe5\xeb\xe7\xe9.";
+		_textQuit = "\xec\xe7\xf6\xe5 \xf2\xec ENTER \xec\xe9\xf6\xe9\xe0\xe4.\n\xec\xe7\xf6\xe5 \xf2\xec ESC \xeb\xe3\xe9 \xec\xe4\xee\xf9\xe9\xea \xec\xf9\xe7\xf7.";
+		_textInventoryYouAreCarrying = "\xe0\xfa\xe4 \xf0\xe5\xf9\xe0:";
+		_textInventoryNothing = "\xec\xe0 \xeb\xec\xe5\xed";
+		_textInventorySelectItems = "\xec\xe7\xf6\xe5 \xf2\xec ENTER \xeb\xe3\xe9 \xec\xe1\xe7\xe5\xf8, ESC \xeb\xe3\xe9 \xec\xe1\xe8\xec";
+		_textInventoryReturnToGame = "\xec\xe7\xf6\xe5 \xf2\xec \xee\xf7\xf9 \xeb\xec\xf9\xe4\xe5 \xeb\xe3\xe9 \xec\xe7\xe6\xe5\xf8 \xec\xee\xf9\xe7\xf7";
+		_textSaveGameSelectSlot = "\xe4\xf9\xfa\xee\xf9\xe5 \xe1\xee\xf7\xf9\xe9 \xe4\xe7\xe9\xf6\xe9\xed \xf2\xec \xee\xf0\xfa \xec\xe1\xe7\xe5\xf8 \xee\xf9\xe1\xf6\xfa \xf9\xe1\xe4 \xfa\xf8\xf6\xe5 \xec\xf9\xee\xe5\xf8 \xe0\xfa \xe4\xee\xf9\xe7\xf7. \xec\xe7\xf6\xe5 \xf2\xec ENTER \xec\xf9\xee\xe9\xf8\xfa \xee\xf9\xe7\xf7 \xe1\xee\xf9\xe1\xf6\xfa, ESC \xec\xe1\xe9\xe8\xe5\xec.";
+		_textSaveGameEnterDescription = "\xe0\xe9\xea \xfa\xf8\xf6\xe5 \xec\xfa\xe0\xf8 \xe0\xfa \xe4\xee\xf9\xe7\xf7 \xe4\xf9\xee\xe5\xf8 \xe4\xe6\xe4?\n\n";
+		_textSaveGameVerify = "\xe1\xe7\xf8\xfa \xec\xf9\xee\xe5\xf8 \xe0\xfa \xe4\xee\xf9\xe7\xf7\n\xf2\xed \xe4\xfa\xe9\xe0\xe5\xf8:\n\n%s\n\n\xe1\xf7\xe5\xe1\xf5:\n%s\n\n\xec\xe7\xf6\xe5 \xf2\xec ENTER \xec\xe4\xee\xf9\xea.\n\xec\xe7\xf6\xe5 \xf2\xec ESC \xec\xe1\xe9\xe8\xe5\xec.";
+		_textRestoreGameNoSlots = "\xe0\xe9\xef \xee\xf9\xe7\xf7\xe9\xed\n\xec\xf9\xe7\xe6\xf8\n\n \xe1\xf1\xf4\xf8\xe9\xe9\xfa \xe4\xee\xf9\xe7\xf7\xe9\xed \xe4\xf9\xee\xe5\xf8\xe9\xed \xf9\xec ScummVM\n\n\xec\xe7\xf6\xe5 \xf2\xec ENTER \xeb\xe3\xe9 \xec\xe4\xee\xf9\xe9\xea.";
+		_textRestoreGameSelectSlot = "\xe4\xf9\xfa\xee\xf9\xe5 \xe1\xee\xf7\xf9\xe9 \xe4\xe7\xe9\xf6\xe9\xed \xf2\xec \xee\xf0\xfa \xec\xe1\xe7\xe5\xf8 \xe0\xfa \xe4\xee\xf9\xe7\xf7 \xf9\xfa\xf8\xf6\xe5 \xec\xf9\xe7\xe6\xf8. \xec\xe7\xf6\xe5 \xf2\xec ENTER \xec\xf9\xe7\xe6\xe5\xf8 \xe4\xee\xf9\xe7\xf7, ESC \xec\xe1\xe9\xe8\xe5\xec.";
+		_textRestoreGameError = "\xf9\xe2\xe9\xe0\xe4 \xe1\xf0\xe9\xf1\xe9\xe5\xef \xec\xf9\xe7\xe6\xe5\xf8 \xee\xf9\xe7\xf7.\n\xec\xe7\xf6\xe5 \xf2\xec ENTER \xec\xe9\xf6\xe9\xe0\xe4.";
+		_textRestoreGameVerify = "\xe1\xe7\xf8\xfa \xec\xf9\xe7\xe6\xf8 \xe0\xfa \xe4\xee\xf9\xe7\xf7\n\xf2\xed \xe4\xfa\xe9\xe0\xe5\xf8:\n\n%s\n\n\xee\xe4\xf7\xe5\xe1\xf5:\n%s\n\n\xec\xe7\xf6\xe5 \xf2\xec ENTER \xec\xe4\xee\xf9\xea.\n\xec\xe7\xf6\xe5 \xf2\xec ESC \xec\xe1\xe9\xe8\xe5\xec.";
+		break;
 	default:
 		break;
 	}
@@ -723,8 +743,13 @@ void SystemUI::drawSavedGameSlots() {
 	_text->charAttrib_Set(0, 15);
 
 	for (slotNr = 0; slotNr < slotsToDrawCount; slotNr++) {
-		_text->displayTextInsideWindow("-", 5 + slotNr, 1);
-		_text->displayTextInsideWindow(_savedGameArray[_savedGameUpmostSlotNr + slotNr].displayText, 5 + slotNr, 3);
+		if (!_vm->isLanguageRTL()) {
+			_text->displayTextInsideWindow("-", 5 + slotNr, 1);
+			_text->displayTextInsideWindow(_savedGameArray[_savedGameUpmostSlotNr + slotNr].displayText, 5 + slotNr, 3);
+		} else {
+			_text->displayTextInsideWindow(_savedGameArray[_savedGameUpmostSlotNr + slotNr].displayText, 5 + slotNr, 0);
+			_text->displayTextInsideWindow("-", 5 + slotNr, 32);
+		}
 	}
 	_text->charAttrib_Pop();
 }
@@ -734,10 +759,19 @@ void SystemUI::drawSavedGameSlotSelector(bool active) {
 
 	_text->charAttrib_Push();
 	_text->charAttrib_Set(0, 15);
-	if (active) {
-		_text->displayTextInsideWindow("\x1a", windowRow, 0);
+	int16 column;
+	const char *arrow;
+	if (!_vm->isLanguageRTL()) {
+		column = 0;
+		arrow = "\x1a";
 	} else {
-		_text->displayTextInsideWindow(" ", windowRow, 0);
+		column = 33;
+		arrow = "\x1b";
+	}
+	if (active) {
+		_text->displayTextInsideWindow(arrow, windowRow, column);
+	} else {
+		_text->displayTextInsideWindow(" ", windowRow, column);
 	}
 	_text->charAttrib_Pop();
 }
