@@ -25,6 +25,7 @@
 #include "common/fs.h"
 #include "common/debug.h"
 #include "common/textconsole.h"
+#include "common/ini-file.h"
 
 #include "agi/wagparser.h"
 
@@ -54,7 +55,6 @@ void WagProperty::deepCopy(const WagProperty &other) {
 	_propNum  = other._propNum;
 	_propSize = other._propSize;
 
-	deleteData(); // Delete old data (If any) and set _propData to NULL
 	if (other._propData != NULL) {
 		_propData = new char[other._propSize + 1UL]; // Allocate space for property's data plus trailing zero
 		memcpy(_propData, other._propData, other._propSize + 1UL); // Copy the whole thing
@@ -63,8 +63,8 @@ void WagProperty::deepCopy(const WagProperty &other) {
 
 bool WagProperty::read(Common::SeekableReadStream &stream) {
 	// First read the property's header
-	_propCode = (enum WagPropertyCode) stream.readByte();
-	_propType = (enum WagPropertyType) stream.readByte();
+	_propCode = (enum WagPropertyCode)stream.readByte();
+	_propType = (enum WagPropertyType)stream.readByte();
 	_propNum  = stream.readByte();
 	_propSize = stream.readUint16LE();
 
@@ -74,7 +74,6 @@ bool WagProperty::read(Common::SeekableReadStream &stream) {
 	}
 
 	// Then read the property's data
-	deleteData(); // Delete old data (If any)
 	_propData = new char[_propSize + 1UL]; // Allocate space for property's data plus trailing zero
 	uint32 readBytes = stream.read(_propData, _propSize); // Read the data in
 	_propData[_propSize] = 0; // Set the trailing zero for easy C-style string access
@@ -98,7 +97,8 @@ void WagProperty::setDefaults() {
 }
 
 void WagProperty::deleteData() {
-	delete[] _propData;
+	if (_propData)
+		delete[] _propData;
 	_propData = NULL;
 }
 
@@ -171,6 +171,16 @@ bool WagFileParser::checkWagVersion(Common::SeekableReadStream &stream) {
 	}
 }
 
+void WagFileParser::addPropFromIni(Common::INIFile *iniWagFile, Common::String section, Common::String key, Agi::WagProperty::WagPropertyCode code) {
+	WagProperty property;
+	property.setPropCode(code);
+	Common::String value;
+	if (iniWagFile->getKey(key, section, value)) {
+		property.setPropDataSize(value);
+		_propList.push_back(property);
+	}
+}
+
 bool WagFileParser::parse(const Common::FSNode &node) {
 	WagProperty property; // Temporary property used for reading
 	Common::SeekableReadStream *stream = NULL; // The file stream
@@ -199,8 +209,21 @@ bool WagFileParser::parse(const Common::FSNode &node) {
 
 			if (!_parsedOk) // Error parsing stream
 				warning("Error parsing WAG file (%s). WAG file ignored", node.getPath().c_str());
-		} else // Invalid WinAGI version string or it couldn't be read
-			warning("Invalid WAG file (%s) version or error reading it. WAG file ignored", node.getPath().c_str());
+		} else {
+			// Invalid WinAGI version string or it couldn't be read
+			// Let's try to read WAG file as newer INI format
+			Common::INIFile *iniWagFile = new Common::INIFile();
+			_parsedOk = iniWagFile->loadFromStream(*stream);
+			if (_parsedOk) {
+				addPropFromIni(iniWagFile, "General", "Interpreter", WagProperty::PC_INTVERSION);
+				addPropFromIni(iniWagFile, "General", "GameID", WagProperty::PC_GAMEID);
+				addPropFromIni(iniWagFile, "General", "Description", WagProperty::PC_GAMEDESC);
+				addPropFromIni(iniWagFile, "General", "GameVersion", WagProperty::PC_GAMEVERSION);
+				addPropFromIni(iniWagFile, "General", "LastEdit", WagProperty::PC_GAMELAST);
+			} else
+				warning("Invalid WAG file (%s) version or error reading it. WAG file ignored", node.getPath().c_str());
+		}
+
 	} else // Couldn't open file
 		warning("Couldn't open WAG file (%s). WAG file ignored", node.getPath().c_str());
 
@@ -218,4 +241,14 @@ bool WagFileParser::endOfProperties(const Common::SeekableReadStream &stream) co
 	return stream.pos() >= (stream.size() - WINAGI_VERSION_LENGTH);
 }
 
+
+void WagProperty::setPropCode(WagPropertyCode propCode) {
+	_propCode = propCode;
+}
+
+void WagProperty::setPropDataSize(Common::String str) {
+	_propData = scumm_strdup(str.c_str());
+	_propSize = str.size();
+}
+
 } // End of namespace Agi
