@@ -37,6 +37,7 @@
 #include "backends/audiocd/audiocd.h"
 
 #include "graphics/surface.h"
+#include "graphics/sjis.h"
 
 #include "audio/mididrv.h"
 
@@ -140,16 +141,28 @@ AGOSEngine_Elvira2::AGOSEngine_Elvira2(OSystem *system, const AGOSGameDescriptio
 }
 
 AGOSEngine_Elvira1::AGOSEngine_Elvira1(OSystem *system, const AGOSGameDescription *gd)
-	: AGOSEngine(system, gd) {
+	: AGOSEngine(system, gd), _sjisCurChar(0), _sjisFont(0) {
+}
+
+AGOSEngine_Elvira1::~AGOSEngine_Elvira1() {
+	delete _sjisFont;
+}
+
+Common::Error AGOSEngine_Elvira1::init() {
+	Common::Error ret = AGOSEngine::init();
+	if (ret.getCode() == Common::kNoError && getPlatform() == Common::kPlatformPC98) {
+		_sjisFont = Graphics::FontSJIS::createFont(Common::kPlatformPC98);
+		if (_sjisFont)
+			_sjisFont->toggleFatPrint(true);
+		else
+			error("AGOSEngine_Elvira1::init(): Failed to load SJIS font.");
+	}
+	return ret;
 }
 
 AGOSEngine::AGOSEngine(OSystem *system, const AGOSGameDescription *gd)
 	: Engine(system), _rnd("agos"), _gameDescription(gd) {
 
-	DebugMan.addDebugChannel(kDebugOpcode, "opcode", "Opcode debug level");
-	DebugMan.addDebugChannel(kDebugVGAOpcode, "vga_opcode", "VGA Opcode debug level");
-	DebugMan.addDebugChannel(kDebugSubroutine, "subroutine", "Subroutine debug level");
-	DebugMan.addDebugChannel(kDebugVGAScript, "vga_script", "VGA Script debug level");
 	//Image dumping command disabled as it doesn't work well
 #if 0
 	DebugMan.addDebugChannel(kDebugImageDump, "image_dump", "Enable dumping of images to files");
@@ -497,6 +510,8 @@ AGOSEngine::AGOSEngine(OSystem *system, const AGOSGameDescription *gd)
 	memset(_lettersToPrintBuf, 0, sizeof(_lettersToPrintBuf));
 
 	_planarBuf = 0;
+	_pak98Buf = 0;
+	_paletteModNext = 16;
 
 	_midiEnabled = false;
 
@@ -540,11 +555,12 @@ AGOSEngine::AGOSEngine(OSystem *system, const AGOSGameDescription *gd)
 	_moveXMax = 0;
 	_moveYMax = 0;
 
+	_forceAscii = false;
+
 	_vc10BasePtrOld = 0;
 	memcpy (_hebrewCharWidths,
 		"\x5\x5\x4\x6\x5\x3\x4\x5\x6\x3\x5\x5\x4\x6\x5\x3\x4\x6\x5\x6\x6\x6\x5\x5\x5\x6\x5\x6\x6\x6\x6\x6", 32);
 
-
 	const Common::FSNode gameDataDir(ConfMan.get("path"));
 
 	// Add default file directories for Acorn version of
@@ -575,18 +591,24 @@ Common::Error AGOSEngine::init() {
 		_screenHeight = 200;
 	}
 
-	initGraphics(_screenWidth, _screenHeight);
+	_internalWidth = _screenWidth;
+	_internalHeight = _screenHeight;
+
+	if (getPlatform() == Common::kPlatformPC98) {
+		_internalWidth <<= 1;
+		_internalHeight <<= 1;
+	}
+
+	initGraphics(_internalWidth, _internalHeight);
 
 	_midi = new MidiPlayer();
 
 	if ((getGameType() == GType_SIMON2 && getPlatform() == Common::kPlatformWindows) ||
 		(getGameType() == GType_SIMON1 && getPlatform() == Common::kPlatformWindows) ||
 		((getFeatures() & GF_TALKIE) && getPlatform() == Common::kPlatformAcorn) ||
-		(getPlatform() == Common::kPlatformDOS)) {
+		(getPlatform() == Common::kPlatformDOS || getPlatform() == Common::kPlatformPC98)) {
 
-		bool isDemo = (getFeatures() & GF_DEMO) ? true : false;
-
-		int ret = _midi->open(getGameType(), isDemo);
+		int ret = _midi->open(getGameType(), getPlatform(), (getFeatures() & GF_DEMO));
 		if (ret)
 			warning("MIDI Player init failed: \"%s\"", MidiDriver::getErrorName(ret));
 
@@ -602,11 +624,11 @@ Common::Error AGOSEngine::init() {
 	_backGroundBuf = new Graphics::Surface();
 	_backGroundBuf->create(_screenWidth, _screenHeight, Graphics::PixelFormat::createFormatCLUT8());
 
-	if (getGameType() == GType_FF || getGameType() == GType_PP) {
+	if (getGameType() == GType_FF || getGameType() == GType_PP || (getGameType() == GType_ELVIRA1 && getPlatform() == Common::kPlatformPC98)) {
 		_backBuf = new Graphics::Surface();
 		_backBuf->create(_screenWidth, _screenHeight, Graphics::PixelFormat::createFormatCLUT8());
 		_scaleBuf = new Graphics::Surface();
-		_scaleBuf->create(_screenWidth, _screenHeight, Graphics::PixelFormat::createFormatCLUT8());
+		_scaleBuf->create(_internalWidth, _internalHeight, Graphics::PixelFormat::createFormatCLUT8());
 	}
 
 	if (getGameType() == GType_SIMON2) {
@@ -945,6 +967,7 @@ AGOSEngine::~AGOSEngine() {
 		_backBuf->free();
 	delete _backBuf;
 	free(_planarBuf);
+	delete[] _pak98Buf;
 	if (_scaleBuf)
 		_scaleBuf->free();
 	delete _scaleBuf;
