@@ -95,7 +95,7 @@ const uint16 frequencyLookUpTableMusicDrv[12] = {
 // I have currently not implemented dynamic channel allocation.
 
 MidiDriver_Accolade_AdLib::MidiDriver_Accolade_AdLib()
-		: _masterVolume(15), _opl(0),
+		: _masterVolume(143), _opl(0),
 		  _adlibTimerProc(0), _adlibTimerParam(0), _isOpen(false) {
 	memset(_channelMapping, 0, sizeof(_channelMapping));
 	memset(_instrumentMapping, 0, sizeof(_instrumentMapping));
@@ -166,15 +166,13 @@ void MidiDriver_Accolade_AdLib::close() {
 }
 
 void MidiDriver_Accolade_AdLib::setVolume(byte volume) {
-	// Set the master volume in range from -128 to 127
-	_masterVolume = CLIP<int>(-128 + volume, -128, 127);
+	_masterVolume = volume;
 	for (int i = 0; i < AGOS_ADLIB_VOICES_COUNT; i++) {
-		// Adjust channel volume with the master volume and re-set registers
-		byte adjustedVelocity = _channels[i].velocity * ((float) (128 + _masterVolume) / 128);
-		noteOnSetVolume(i, 1, adjustedVelocity);
+		// Re-set registers
+		noteOnSetVolume(i, 1, _channels[i].velocity);
 		if (i <= AGOS_ADLIB_VOICES_PERCUSSION_START) {
 			// Set second operator for FM voices + first percussion
-			noteOnSetVolume(i, 2, adjustedVelocity);
+			noteOnSetVolume(i, 2, _channels[i].velocity);
 		}
 	}
 }
@@ -286,19 +284,11 @@ void MidiDriver_Accolade_AdLib::setTimerCallback(void *timerParam, Common::Timer
 
 void MidiDriver_Accolade_AdLib::noteOn(byte FMvoiceChannel, byte note, byte velocity) {
 	byte adjustedNote     = note;
-	byte adjustedVelocity = velocity;
 	byte regValueA0h      = 0;
 	byte regValueB0h      = 0;
 
 	// adjust velocity
-	int16 channelVolumeAdjust = _channels[FMvoiceChannel].volumeAdjust;
-	channelVolumeAdjust += adjustedVelocity;
-	channelVolumeAdjust = CLIP<int16>(channelVolumeAdjust, 0, 0x7F);
-
-	// adjust velocity with the master volume
-	byte volumeAdjust = adjustedVelocity * ((float) (128 + _masterVolume) / 128);
-
-	adjustedVelocity = volumeAdjust;
+	byte adjustedVelocity = velocity + _channels[FMvoiceChannel].volumeAdjust;
 
 	if (!_musicDrvMode) {
 		// INSTR.DAT
@@ -435,11 +425,14 @@ void MidiDriver_Accolade_AdLib::noteOn(byte FMvoiceChannel, byte note, byte velo
 
 // 100% the same for INSTR.DAT and MUSIC.DRV variants
 // except for a bug, that was introduced for MUSIC.DRV
-void MidiDriver_Accolade_AdLib::noteOnSetVolume(byte FMvoiceChannel, byte operatorNr, byte adjustedVelocity) {
+void MidiDriver_Accolade_AdLib::noteOnSetVolume(byte FMvoiceChannel, byte operatorNr, byte velocity) {
 	byte operatorReg = 0;
 	byte regValue40h = 0;
 	const InstrumentEntry *curInstrument = NULL;
 
+	// Adjust velocity with the master volume
+	uint16 adjustedVelocity = CLIP<uint16>((velocity * _masterVolume) / 255, 0, 0x3F);
+
 	regValue40h = (63 - adjustedVelocity) & 0x3F;
 
 	if ((operatorNr == 1) && (FMvoiceChannel <= AGOS_ADLIB_VOICES_PERCUSSION_START)) {
