@@ -640,7 +640,7 @@ void AGOSEngine_Simon1::drawImage(VC10_state *state) {
 	if (!drawImage_clip(state))
 		return;
 
-	Graphics::Surface *screen = _system->lockScreen();
+	Graphics::Surface *screen = getBackendSurface();
 
 	if (getFeatures() & GF_32COLOR)
 		state->palette = 0xC0;
@@ -738,7 +738,7 @@ void AGOSEngine_Simon1::drawImage(VC10_state *state) {
 		drawVertImage(state);
 	}
 
-	 _system->unlockScreen();
+	updateBackendSurface();
 }
 
 void AGOSEngine::drawBackGroundImage(VC10_state *state) {
@@ -857,9 +857,9 @@ void AGOSEngine::drawImage(VC10_state *state) {
 	if (!drawImage_clip(state))
 		return;
 
-	Graphics::Surface *screen = _system->lockScreen();
+	Graphics::Surface *screen = getBackendSurface();
 
-	uint16 xoffs = 0, yoffs = 0;
+	uint16 xoffs = 0, yoffs = 0, xmax = 0, ymax = 0;
 	if (getGameType() == GType_WW) {
 		if (_windowNum == 4 || (_windowNum >= 10 && _windowNum <= 27)) {
 			state->surf_addr = (byte *)_window4BackScn->getPixels();
@@ -868,8 +868,8 @@ void AGOSEngine::drawImage(VC10_state *state) {
 			xoffs = ((vlut[0] - _videoWindows[16]) * 2 + state->x) * 8;
 			yoffs = (vlut[1] - _videoWindows[17] + state->y);
 
-			uint xmax = (xoffs + state->draw_width * 2);
-			uint ymax = (yoffs + state->draw_height);
+			xmax = (xoffs + state->draw_width * 2);
+			ymax = (yoffs + state->draw_height);
 			setMoveRect(xoffs, yoffs, xmax, ymax);
 
 			_window4Flag = 1;
@@ -879,6 +879,8 @@ void AGOSEngine::drawImage(VC10_state *state) {
 
 			xoffs = (vlut[0] * 2 + state->x) * 8;
 			yoffs = vlut[1] + state->y;
+			xmax = (xoffs + state->draw_width * 2);
+			ymax = (yoffs + state->draw_height);
 		}
 	} else if (getGameType() == GType_ELVIRA2) {
 		if (_windowNum == 4 || _windowNum >= 10) {
@@ -888,8 +890,8 @@ void AGOSEngine::drawImage(VC10_state *state) {
 			xoffs = ((vlut[0] - _videoWindows[16]) * 2 + state->x) * 8;
 			yoffs = (vlut[1] - _videoWindows[17] + state->y);
 
-			uint xmax = (xoffs + state->draw_width * 2);
-			uint ymax = (yoffs + state->draw_height);
+			xmax = (xoffs + state->draw_width * 2);
+			ymax = (yoffs + state->draw_height);
 			setMoveRect(xoffs, yoffs, xmax, ymax);
 
 			_window4Flag = 1;
@@ -899,6 +901,8 @@ void AGOSEngine::drawImage(VC10_state *state) {
 
 			xoffs = (vlut[0] * 2 + state->x) * 8;
 			yoffs = vlut[1] + state->y;
+			xmax = (xoffs + state->draw_width * 2);
+			ymax = (yoffs + state->draw_height);
 		}
 	} else if (getGameType() == GType_ELVIRA1) {
 		if (_windowNum == 6) {
@@ -907,12 +911,16 @@ void AGOSEngine::drawImage(VC10_state *state) {
 
 			xoffs = state->x * 8;
 			yoffs = state->y;
+			xmax = xoffs + vlut[2] * 16;
+			ymax = yoffs + vlut[3];
 		} else if (_windowNum == 2 || _windowNum == 3) {
 			state->surf_addr = (byte *)screen->getPixels();
 			state->surf_pitch = screen->pitch;
 
 			xoffs = (vlut[0] * 2 + state->x) * 8;
 			yoffs = vlut[1] + state->y;
+			xmax = xoffs + state->draw_width * 2;
+			ymax = yoffs + state->draw_height;
 		} else {
 			state->surf_addr = (byte *)_window4BackScn->getPixels();
 			state->surf_pitch = _videoWindows[18] * 16;
@@ -920,8 +928,8 @@ void AGOSEngine::drawImage(VC10_state *state) {
 			xoffs = ((vlut[0] - _videoWindows[16]) * 2 + state->x) * 8;
 			yoffs = (vlut[1] - _videoWindows[17] + state->y);
 
-			uint xmax = (xoffs + state->draw_width * 2);
-			uint ymax = (yoffs + state->draw_height);
+			xmax = (xoffs + state->draw_width * 2);
+			ymax = (yoffs + state->draw_height);
 			setMoveRect(xoffs, yoffs, xmax, ymax);
 
 			_window4Flag = 1;
@@ -932,12 +940,15 @@ void AGOSEngine::drawImage(VC10_state *state) {
 
 		xoffs = (vlut[0] * 2 + state->x) * 8;
 		yoffs = vlut[1] + state->y;
+		xmax = (xoffs + state->draw_width * 2);
+		ymax = (yoffs + state->draw_height);
 	}
 
 	state->surf_addr += xoffs + yoffs * state->surf_pitch;
 
 	if (getGameType() == GType_ELVIRA1 && (state->flags & kDFNonTrans) && yoffs > 133)
-		state->paletteMod = 16;
+		state->paletteMod = _paletteModNext;
+	_paletteModNext = 16;
 
 	if (getGameType() == GType_ELVIRA2 || getGameType() == GType_WW)
 		state->palette = state->surf_addr[0] & 0xF0;
@@ -951,7 +962,8 @@ void AGOSEngine::drawImage(VC10_state *state) {
 		drawVertImage(state);
 	}
 
-	 _system->unlockScreen();
+	Common::Rect dirtyRect(xoffs, yoffs, xmax, ymax);
+	updateBackendSurface(&dirtyRect);
 }
 
 void AGOSEngine::horizontalScroll(VC10_state *state) {
@@ -1023,6 +1035,61 @@ void AGOSEngine::verticalScroll(VC10_state *state) {
 	}
 }
 
+Graphics::Surface *AGOSEngine::getBackendSurface() const {
+	return (getGameId() == GID_ELVIRA1 && getPlatform() == Common::kPlatformPC98) ? _backBuf : _system->lockScreen();
+}
+
+void AGOSEngine::updateBackendSurface(Common::Rect *area) const {
+	if (getGameId() == GID_ELVIRA1 && getPlatform() == Common::kPlatformPC98) {
+		int x = 0;
+		int y = 0;
+		int w = _screenWidth;
+		int h = _screenHeight;
+
+		if (area) {
+			x = area->left;
+			y = area->top;
+			w = area->width();
+			h = area->height();
+		}
+
+		Graphics::Surface *screen = _system->lockScreen();
+
+		int src0Pitch = _backBuf->pitch;
+		int src1Pitch = _scaleBuf->pitch;
+		int dst1Pitch = screen->pitch;
+		const byte *src00 = (byte*)_backBuf->getBasePtr(x, y);
+		const byte *src10 = (byte*)_scaleBuf->getBasePtr(x << 1, y << 1);
+		const byte *src11 = src10 + src1Pitch;
+		byte *dst10 = (byte*)screen->getBasePtr(x << 1, y << 1);
+		byte *dst11 = dst10 + dst1Pitch;
+		src0Pitch -= w;
+		src1Pitch += (src1Pitch - (w << 1));
+		dst1Pitch += (dst1Pitch - (w << 1));
+
+		while (h--) {
+			for (int i = 0; i < w; ++i) {
+				uint8 v0 = *src00++;
+				uint8 v1 = *src10++;
+				*dst10++ = v1 ? v1 : v0;
+				v1 = *src10++;
+				*dst10++ = v1 ? v1 : v0;
+				v1 = *src11++;
+				*dst11++ = v1 ? v1 : v0;
+				v1 = *src11++;
+				*dst11++ = v1 ? v1 : v0;
+			}
+			src00 += src0Pitch;
+			src10 += src1Pitch;
+			src11 += src1Pitch;
+			dst10 += dst1Pitch;
+			dst11 += dst1Pitch;
+		}
+	}
+
+	_system->unlockScreen();
+}
+
 void AGOSEngine::paletteFadeOut(byte *palPtr, uint num, uint size) {
 	byte *p = palPtr;
 
@@ -1372,7 +1439,7 @@ void AGOSEngine::setWindowImage(uint16 mode, uint16 vgaSpriteId, bool specialCas
 		uint width = _videoWindows[updateWindow * 4 + 2] * 16;
 		uint height = _videoWindows[updateWindow * 4 + 3];
 
-		Graphics::Surface *screen = _system->lockScreen();
+		Graphics::Surface *screen = getBackendSurface();
 		byte *dst = (byte *)_backGroundBuf->getBasePtr(xoffs, yoffs);
 		byte *src = 0;
 		uint srcWidth = 0;
@@ -1389,7 +1456,7 @@ void AGOSEngine::setWindowImage(uint16 mode, uint16 vgaSpriteId, bool specialCas
 				src = (byte *)screen->getBasePtr(xoffs, yoffs);
 				srcWidth = screen->pitch;
 			} else {
-				_system->unlockScreen();
+				updateBackendSurface();
 				_videoLockOut &= ~0x20;
 				return;
 			}
@@ -1404,7 +1471,7 @@ void AGOSEngine::setWindowImage(uint16 mode, uint16 vgaSpriteId, bool specialCas
 				src = (byte *)screen->getBasePtr(xoffs, yoffs);
 				srcWidth = screen->pitch;
 			} else {
-				_system->unlockScreen();
+				updateBackendSurface();
 				_videoLockOut &= ~0x20;
 				return;
 			}
@@ -1416,7 +1483,7 @@ void AGOSEngine::setWindowImage(uint16 mode, uint16 vgaSpriteId, bool specialCas
 				src = (byte *)screen->getBasePtr(xoffs, yoffs);
 				srcWidth = screen->pitch;
 			} else {
-				_system->unlockScreen();
+				updateBackendSurface();
 				_videoLockOut &= ~0x20;
 				return;
 			}
@@ -1428,7 +1495,7 @@ void AGOSEngine::setWindowImage(uint16 mode, uint16 vgaSpriteId, bool specialCas
 				src = (byte *)screen->getBasePtr(xoffs, yoffs);
 				srcWidth = screen->pitch;
 			} else {
-				_system->unlockScreen();
+				updateBackendSurface();
 				_videoLockOut &= ~0x20;
 				return;
 			}
@@ -1472,9 +1539,15 @@ void AGOSEngine::setWindowImage(uint16 mode, uint16 vgaSpriteId, bool specialCas
 					dst[w] += 0x10;
 				dst += screen->pitch;
 			}
+
+			if (getPlatform() == Common::kPlatformPC98) {
+				Common::Rect dirtyRect(0, 133, _screenWidth, _screenHeight);
+				updateBackendSurface(&dirtyRect);
+			}
 		}
 
-		_system->unlockScreen();
+		Common::Rect dirtyRect(xoffs, yoffs, xoffs + width, yoffs + _boxStarHeight);
+		updateBackendSurface(&dirtyRect);
 	}
 
 	_videoLockOut &= ~0x20;
@@ -1485,7 +1558,7 @@ void AGOSEngine::drawEdging() {
 	byte *dst;
 	uint8 color = (getPlatform() == Common::kPlatformDOS) ? 7 : 15;
 
-	Graphics::Surface *screen = _system->lockScreen();
+	Graphics::Surface *screen = getBackendSurface();
 
 	dst = (byte *)screen->getBasePtr(0, 136);
 	uint8 len = 52;
@@ -1499,7 +1572,7 @@ void AGOSEngine::drawEdging() {
 	dst = (byte *)screen->getBasePtr(0, 187);
 	memset(dst, color, _screenWidth);
 
-	_system->unlockScreen();
+	updateBackendSurface();
 }
 
 } // End of namespace AGOS
