@@ -268,9 +268,11 @@ int AGOSEngine::vcReadVarOrWord() {
 	}
 }
 
-uint AGOSEngine::vcReadNextWord() {
+uint AGOSEngine::vcReadNextWord(bool forceLERead) {
 	uint a;
 	a = readUint16Wrapper(_vcPtr);
+	if (forceLERead)
+		a = FROM_BE_16(a);
 	_vcPtr += 2;
 	return a;
 }
@@ -635,13 +637,13 @@ void AGOSEngine::drawImage_init(int16 image, uint16 palette, int16 x, int16 y, u
 	state.flags = flags;
 
 	src = _curVgaFile2 + state.image * 8;
-	state.srcPtr = _curVgaFile2 + readUint32Wrapper(src);
+	state.srcPtr = _curVgaFile2 + (getPlatform() == Common::kPlatformPC98 ? READ_LE_UINT32(src) : readUint32Wrapper(src));
 	if (getGameType() == GType_FF || getGameType() == GType_PP) {
 		width = READ_LE_UINT16(src + 6);
 		height = READ_LE_UINT16(src + 4) & 0x7FFF;
 		flags = src[5];
 	} else {
-		width = READ_BE_UINT16(src + 6) / 16;
+		width = (getPlatform() == Common::kPlatformPC98 ? READ_LE_UINT16(src + 6) : READ_BE_UINT16(src + 6)) / 16;
 		height = src[5];
 		flags = src[4];
 	}
@@ -662,10 +664,9 @@ void AGOSEngine::drawImage_init(int16 image, uint16 palette, int16 x, int16 y, u
 
 	if (getFeatures() & GF_PLANAR) {
 		if (getGameType() == GType_PN) {
-			state.srcPtr = convertImage(&state, ((state.flags & (kDFCompressed | kDFCompressedFlip)) != 0));
-		}
-		else
-			state.srcPtr = convertImage(&state, ((flags & 0x80) != 0));
+			state.srcPtr = convertAmigaImage(&state, ((state.flags & (kDFCompressed | kDFCompressedFlip)) != 0));
+		} else
+			state.srcPtr = convertAmigaImage(&state, ((flags & 0x80) != 0));
 
 		// converted planar clip is already uncompressed
 		if (state.flags & kDFCompressedFlip) {
@@ -690,6 +691,9 @@ void AGOSEngine::drawImage_init(int16 image, uint16 palette, int16 x, int16 y, u
 		}
 	}
 
+	if (getPlatform() == Common::kPlatformPC98)
+		convertPC98Image(state);
+
 	uint maxWidth = (getGameType() == GType_FF || getGameType() == GType_PP) ? 640 : 20;
 	if ((getGameType() == GType_SIMON2 || getGameType() == GType_FF) && width > maxWidth) {
 		horizontalScroll(&state);
@@ -1178,7 +1182,7 @@ void AGOSEngine::vc31_setWindow() {
 
 void AGOSEngine::vc32_saveScreen() {
 	if (getGameType() == GType_PN) {
-		Graphics::Surface *screen = _system->lockScreen();
+		Graphics::Surface *screen = getBackendSurface();
 		byte *dst = getBackGround();
 		byte *src = (byte *)screen->getPixels();
 		for (int i = 0; i < _screenHeight; i++) {
@@ -1186,7 +1190,7 @@ void AGOSEngine::vc32_saveScreen() {
 			dst += _backGroundBuf->pitch;
 			src += screen->pitch;
 		}
-		_system->unlockScreen();
+		updateBackendSurface();
 	} else {
 		uint16 xoffs = _videoWindows[4 * 4 + 0] * 16;
 		uint16 yoffs = _videoWindows[4 * 4 + 1];
@@ -1247,13 +1251,14 @@ void AGOSEngine::clearVideoWindow(uint16 num, uint16 color) {
 	}
 
 	if (getGameType() == GType_ELVIRA1 && num == 3) {
-		Graphics::Surface *screen = _system->lockScreen();
+		Graphics::Surface *screen = getBackendSurface();
 		byte *dst = (byte *)screen->getPixels();
 		for (int i = 0; i < _screenHeight; i++) {
 			memset(dst, color, _screenWidth);
 			dst += screen->pitch;
 		}
-		 _system->unlockScreen();
+		clearHiResTextLayer();
+		updateBackendSurface();
 	} else {
 		const uint16 *vlut = &_videoWindows[num * 4];
 		uint16 xoffs = (vlut[0] - _videoWindows[16]) * 16;
