@@ -24,6 +24,7 @@
 #define BBVS_BBVS_H
 
 #include "audio/mixer.h"
+
 #include "common/array.h"
 #include "common/events.h"
 #include "common/file.h"
@@ -32,8 +33,11 @@
 #include "common/str.h"
 #include "common/substream.h"
 #include "common/system.h"
+
 #include "engines/engine.h"
 
+#include "bbvs/detection.h"
+
 struct ADGameDescription;
 
 namespace Bbvs {
@@ -59,10 +63,6 @@ class SoundMan;
 
 #define BBVS_SAVEGAME_VERSION 0
 
-enum {
-	GF_GUILANGSWITCH =    (1 << 0) // If GUI language switch is required for menus
-};
-
 enum {
 	kVerbLook      = 0,
 	kVerbUse       = 1,
@@ -172,7 +172,27 @@ struct SceneObject {
 	int xIncr, yIncr;
 	int turnValue, turnCount, turnTicks;
 	Common::Point walkDestPt;
-	SceneObject() : sceneObjectDef(0), anim(0) {
+
+	SceneObject() {
+		clear();
+	}
+
+	void clear() {
+		x = 0;
+		y = 0;
+		sceneObjectDef = nullptr;
+		anim = nullptr;
+		animIndex = 0;
+		frameIndex = 0;
+		frameTicks = 0;
+		walkCount = 0;
+		xIncr = 0;
+		yIncr = 0;
+		turnValue = 0;
+		turnCount = 0;
+		turnTicks = 0;
+		walkDestPt.x = 0;
+		walkDestPt.y = 0;
 	}
 };
 
