@@ -39,16 +39,49 @@ AmbientSounds::AmbientSounds(BladeRunnerEngine *vm) {
 	_nonLoopingSounds = new NonLoopingSound[kNonLoopingSounds];
 	_loopingSounds = new LoopingSound[kLoopingSounds];
 
+	// The actual volume of ambient sounds is determined by the mixer (see BladeRunnerEngine::syncSoundSettings())
+	// In our BladeRunner engine ambient sounds do not have a distinct sound type of their own,
+	// so they are treated as kAmbientSoundType (default type, see: ambient_sounds.h).
+	//
+	// _ambientVolume here sets a percentage to be appied on the specified track volume
+	// before sending it to the audio player
+	// (setting _ambientVolume to 100 renders it indifferent)
 	_ambientVolume = BLADERUNNER_ORIGINAL_SETTINGS ? 65 : 100;
 
 	for (int i = 0; i != kNonLoopingSounds; ++i) {
 		NonLoopingSound &track = _nonLoopingSounds[i];
 		track.isActive = false;
+#if !BLADERUNNER_ORIGINAL_BUGS
+		track.name.clear();
+		track.hash = 0;
+		track.audioPlayerTrack = -1;
+		track.delayMin = 0u;
+		track.delayMax = 0u;
+		track.nextPlayTimeStart = 0u;
+		track.nextPlayTimeDiff = 0u;
+		track.volumeMin = 0;
+		track.volumeMax = 0;
+		track.volume = 0;
+		track.panStartMin = 0;
+		track.panStartMax = 0;
+		track.panEndMin = 0;
+		track.panEndMax = 0;
+		track.priority = 0;
+		track.soundType = -1;
+#endif // !BLADERUNNER_ORIGINAL_BUGS
 	}
 
 	for (int i = 0; i != kLoopingSounds; ++i) {
 		LoopingSound &track = _loopingSounds[i];
 		track.isActive = false;
+#if !BLADERUNNER_ORIGINAL_BUGS
+		track.name.clear();
+		track.hash = 0;
+		track.audioPlayerTrack = -1;
+		track.volume = 0;
+		track.pan = 0;
+		track.soundType = -1;
+#endif // !BLADERUNNER_ORIGINAL_BUGS
 	}
 }
 
@@ -73,9 +106,13 @@ static inline void sort(uint32 *a, uint32 *b) {
 	}
 }
 
+//
+// addSound() will add a track to the non-looping tracks array list
+// it will use the kAmbientSoundType for Mixer's Sound Type.
+// see AmbientSounds::tick()
 void AmbientSounds::addSound(
 	int sfxId,
-	uint32 timeMin, uint32 timeMax,
+	uint32 delayMinSeconds, uint32 delayMaxSeconds,
 	int volumeMin, int volumeMax,
 	int panStartMin, int panStartMax,
 	int panEndMin, int panEndMax,
@@ -83,7 +120,7 @@ void AmbientSounds::addSound(
 
 #if BLADERUNNER_ORIGINAL_BUGS
 #else
-	sort(&timeMin, &timeMax);
+	sort(&delayMinSeconds, &delayMaxSeconds);
 #endif // BLADERUNNER_ORIGINAL_BUGS
 	sort(&volumeMin, &volumeMax);
 	sort(&panStartMin, &panStartMax);
@@ -91,7 +128,7 @@ void AmbientSounds::addSound(
 
 	addSoundByName(
 				_vm->_gameInfo->getSfxTrack(sfxId),
-				timeMin, timeMax,
+				delayMinSeconds, delayMaxSeconds,
 				volumeMin, volumeMax,
 				panStartMin, panStartMax,
 				panEndMin, panEndMax,
@@ -113,10 +150,14 @@ void AmbientSounds::removeAllNonLoopingSounds(bool stopPlaying) {
 	}
 }
 
-void AmbientSounds::addSpeech(int actorId, int sentenceId, uint32 timeMin, uint32 timeMax, int volumeMin, int volumeMax, int panStartMin, int panStartMax, int panEndMin, int panEndMax, int priority, int unk) {
+//
+// addSpeech() will add a track to the non-looping tracks array list
+// it will use the kAmbientSoundType for Mixer's Sound Type
+// see AmbientSounds::tick()
+void AmbientSounds::addSpeech(int actorId, int sentenceId, uint32 delayMinSeconds, uint32 delayMaxSeconds, int volumeMin, int volumeMax, int panStartMin, int panStartMax, int panEndMin, int panEndMax, int priority, int unk) {
 #if BLADERUNNER_ORIGINAL_BUGS
 #else
-	sort(&timeMin, &timeMax);
+	sort(&delayMinSeconds, &delayMaxSeconds);
 #endif // BLADERUNNER_ORIGINAL_BUGS
 	sort(&volumeMin, &volumeMax);
 	sort(&panStartMin, &panStartMax);
@@ -124,23 +165,40 @@ void AmbientSounds::addSpeech(int actorId, int sentenceId, uint32 timeMin, uint3
 
 	Common::String name = Common::String::format( "%02d-%04d%s.AUD", actorId, sentenceId, _vm->_languageCode.c_str());
 	addSoundByName(name,
-					timeMin, timeMax,
+					delayMinSeconds, delayMaxSeconds,
 					volumeMin, volumeMax,
 					panStartMin, panStartMax,
 					panEndMin, panEndMax,
 					priority, unk);
 }
 
-void AmbientSounds::playSound(int sfxId, int volume, int panStart, int panEnd, int priority) {
-	_vm->_audioPlayer->playAud(_vm->_gameInfo->getSfxTrack(sfxId), volume * _ambientVolume / 100, panStart, panEnd, priority, kAudioPlayerOverrideVolume);
+// Explicitly plays a sound effect (sfx) track (specified by id)
+// It does not add it as a track to the non-looping tracks array list
+// It uses the parameter "type" as the mixer's sound type - which determines the volume setting in effect.
+// By default sound type is kAmbientSoundType (see ambient_sounds.h).
+void AmbientSounds::playSound(int sfxId, int volume, int panStart, int panEnd, int priority, Audio::Mixer::SoundType type) {
+	_vm->_audioPlayer->playAud(_vm->_gameInfo->getSfxTrack(sfxId), volume * _ambientVolume / 100, panStart, panEnd, priority, kAudioPlayerOverrideVolume, type);
 }
 
+// Explicitly plays a speech cue
+// It does not add it as a track to the non-looping tracks array list
+// It uses mixer's sound type kSpeechSoundType - which determines the volume setting in effect (Speech)
 void AmbientSounds::playSpeech(int actorId, int sentenceId, int volume, int panStart, int panEnd, int priority) {
 	Common::String name = Common::String::format( "%02d-%04d%s.AUD", actorId, sentenceId, _vm->_languageCode.c_str());
 	_vm->_audioPlayer->playAud(name, volume * _ambientVolume / 100, panStart, panEnd, priority, kAudioPlayerOverrideVolume, Audio::Mixer::kSpeechSoundType);
 }
 
-void AmbientSounds::addLoopingSound(int sfxId, int volume, int pan, uint32 delay) {
+// Looping Sound will use paramerter "type" as the mixer's SoundType when playing this track.
+// By default sound type is kAmbientSoundType (see ambient_sounds.h).
+// This determines the volume setting that will be in effect for the audio.
+//
+// NOTE If restoring from a saved game, a looping track will always use the default SoundType (kAmbientSoundType)
+// because sound type is not stored.
+// TODO We could save the sound type re-using the space for field "track.audioPlayerTrack"
+// which is skipped for *both* looping and non-looping tracks in save() and load() code
+// However, the issue is negligible; the default SoundType for looping tracks is overridden
+// only in one special case so far (restored content Outtake "FLYTRU_E.VQA", see: outtake.cpp)
+void AmbientSounds::addLoopingSound(int sfxId, int volume, int pan, uint32 delaySeconds, Audio::Mixer::SoundType type) {
 	const Common::String &name = _vm->_gameInfo->getSfxTrack(sfxId);
 	int32 hash = MIXArchive::getHash(name);
 
@@ -159,55 +217,57 @@ void AmbientSounds::addLoopingSound(int sfxId, int volume, int pan, uint32 delay
 	track.hash = hash;
 	track.pan = pan;
 	track.volume = volume;
+	track.soundType = (int32) type;
 
 	int actualVolumeStart = volume * _ambientVolume / 100;
 	int actualVolumeEnd = actualVolumeStart;
 
-	if (delay > 0u) {
+	if (delaySeconds > 0u) {
 		actualVolumeStart = 0;
 	}
 
-	track.audioPlayerTrack = _vm->_audioPlayer->playAud(name, actualVolumeStart, pan, pan, 99, kAudioPlayerLoop | kAudioPlayerOverrideVolume);
+	track.audioPlayerTrack = _vm->_audioPlayer->playAud(name, actualVolumeStart, pan, pan, 99, kAudioPlayerLoop | kAudioPlayerOverrideVolume, type);
 
 	if (track.audioPlayerTrack == -1) {
-		removeLoopingSoundByIndex(i, 0);
+		removeLoopingSoundByIndex(i, 0u);
 	} else {
-		if (delay) {
-			_vm->_audioPlayer->adjustVolume(track.audioPlayerTrack, actualVolumeEnd, delay, false);
+		if (delaySeconds) {
+			_vm->_audioPlayer->adjustVolume(track.audioPlayerTrack, actualVolumeEnd, delaySeconds, false);
 		}
 	}
 }
 
-void AmbientSounds::adjustLoopingSound(int sfxId, int volume, int pan, uint32 delay) {
+void AmbientSounds::adjustLoopingSound(int sfxId, int volume, int pan, uint32 delaySeconds) {
 	int32 hash = MIXArchive::getHash(_vm->_gameInfo->getSfxTrack(sfxId));
 	int index = findLoopingTrackByHash(hash);
 
 	if (index >= 0 && _loopingSounds[index].audioPlayerTrack != -1 && _vm->_audioPlayer->isActive(_loopingSounds[index].audioPlayerTrack)) {
 		if (volume != -1) {
 			_loopingSounds[index].volume = volume;
-			_vm->_audioPlayer->adjustVolume(_loopingSounds[index].audioPlayerTrack, _ambientVolume * volume / 100, delay, false);
+			_vm->_audioPlayer->adjustVolume(_loopingSounds[index].audioPlayerTrack, _ambientVolume * volume / 100, delaySeconds, false);
 		}
 		if (pan != -101) {
 			_loopingSounds[index].pan = pan;
-			_vm->_audioPlayer->adjustPan(_loopingSounds[index].audioPlayerTrack, pan, delay);
+			_vm->_audioPlayer->adjustPan(_loopingSounds[index].audioPlayerTrack, pan, delaySeconds);
 		}
 	}
 }
 
-void AmbientSounds::removeLoopingSound(int sfxId, uint32 delay) {
+void AmbientSounds::removeLoopingSound(int sfxId, uint32 delaySeconds) {
 	int32 hash = MIXArchive::getHash(_vm->_gameInfo->getSfxTrack(sfxId));
 	int index = findLoopingTrackByHash(hash);
 	if (index >= 0) {
-		removeLoopingSoundByIndex(index, delay);
+		removeLoopingSoundByIndex(index, delaySeconds);
 	}
 }
 
-void AmbientSounds::removeAllLoopingSounds(uint32 delay) {
+void AmbientSounds::removeAllLoopingSounds(uint32 delaySeconds) {
 	for (int i = 0; i < kLoopingSounds; ++i) {
-		removeLoopingSoundByIndex(i, delay);
+		removeLoopingSoundByIndex(i, delaySeconds);
 	}
 }
 
+// tick() only handles the non-looping added ambient sounds
 void AmbientSounds::tick() {
 	uint32 now = _vm->_time->current();
 
@@ -229,15 +289,20 @@ void AmbientSounds::tick() {
 
 		track.volume = _vm->_rnd.getRandomNumberRng(track.volumeMin, track.volumeMax);
 
+		Audio::Mixer::SoundType mixerAmbientSoundType = kAmbientSoundType;
+		if (track.soundType >= 0) {
+			mixerAmbientSoundType = (Audio::Mixer::SoundType) track.soundType;
+		}
 		track.audioPlayerTrack = _vm->_audioPlayer->playAud(track.name,
-															track.volume * _ambientVolume / 100,
-															panStart,
-															panEnd,
-															track.priority,
-															kAudioPlayerOverrideVolume);
+		                                                    track.volume * _ambientVolume / 100,
+		                                                    panStart,
+		                                                    panEnd,
+		                                                    track.priority,
+		                                                    kAudioPlayerOverrideVolume,
+		                                                    mixerAmbientSoundType);
 
 		track.nextPlayTimeStart = now;
-		track.nextPlayTimeDiff  = _vm->_rnd.getRandomNumberRng(track.timeMin, track.timeMax);
+		track.nextPlayTimeDiff  = _vm->_rnd.getRandomNumberRng(track.delayMin, track.delayMax);
 	}
 }
 
@@ -249,9 +314,13 @@ void AmbientSounds::setVolume(int volume) {
 				if (_vm->_audioPlayer->isActive(_loopingSounds[i].audioPlayerTrack)) {
 					_vm->_audioPlayer->adjustVolume(_loopingSounds[i].audioPlayerTrack, newVolume, 1u, false);
 				} else {
-					_loopingSounds[i].audioPlayerTrack = _vm->_audioPlayer->playAud(_loopingSounds[i].name, 1, _loopingSounds[i].pan, _loopingSounds[i].pan, 99, kAudioPlayerLoop | kAudioPlayerOverrideVolume);
+					Audio::Mixer::SoundType mixerAmbientSoundType = kAmbientSoundType;
+					if (_loopingSounds[i].soundType >= 0) {
+						mixerAmbientSoundType = (Audio::Mixer::SoundType) _loopingSounds[i].soundType;
+					}
+					_loopingSounds[i].audioPlayerTrack = _vm->_audioPlayer->playAud(_loopingSounds[i].name, 1, _loopingSounds[i].pan, _loopingSounds[i].pan, 99, kAudioPlayerLoop | kAudioPlayerOverrideVolume, mixerAmbientSoundType);
 					if (_loopingSounds[i].audioPlayerTrack == -1) {
-						removeLoopingSound(i, 0);
+						removeLoopingSound(i, 0u);
 					} else {
 						_vm->_audioPlayer->adjustVolume(_loopingSounds[i].audioPlayerTrack, newVolume, 1u, false);
 					}
@@ -316,7 +385,7 @@ int AmbientSounds::findLoopingTrackByHash(int32 hash) const {
 
 void AmbientSounds::addSoundByName(
 	const Common::String &name,
-	uint32 timeMin, uint32 timeMax,
+	uint32 delayMinSeconds, uint32 delayMaxSeconds,
 	int volumeMin, int volumeMax,
 	int panStartMin, int panStartMax,
 	int panEndMin, int panEndMax,
@@ -333,7 +402,7 @@ void AmbientSounds::addSoundByName(
 
 #if BLADERUNNER_ORIGINAL_BUGS
 #else
-	sort(&timeMin, &timeMax);
+	sort(&delayMinSeconds, &delayMaxSeconds);
 	sort(&volumeMin, &volumeMax);
 	sort(&panStartMin, &panStartMax);
 	sort(&panEndMin, &panEndMax);
@@ -342,10 +411,10 @@ void AmbientSounds::addSoundByName(
 	track.isActive = true;
 	track.name = name;
 	track.hash = MIXArchive::getHash(name);
-	track.timeMin = 1000u * timeMin;
-	track.timeMax = 1000u * timeMax;
+	track.delayMin = 1000u * delayMinSeconds; // store as milliseconds
+	track.delayMax = 1000u * delayMaxSeconds; // store as milliseconds
 	track.nextPlayTimeStart = now;
-	track.nextPlayTimeDiff  = _vm->_rnd.getRandomNumberRng(track.timeMin, track.timeMax);
+	track.nextPlayTimeDiff  = _vm->_rnd.getRandomNumberRng(track.delayMin, track.delayMax);
 	track.volumeMin = volumeMin;
 	track.volumeMax = volumeMax;
 	track.volume = 0;
@@ -354,6 +423,7 @@ void AmbientSounds::addSoundByName(
 	track.panEndMin = panEndMin;
 	track.panEndMax = panEndMax;
 	track.priority = priority;
+	track.soundType = -1;
 }
 
 void AmbientSounds::removeNonLoopingSoundByIndex(int index, bool stopPlaying) {
@@ -366,13 +436,30 @@ void AmbientSounds::removeNonLoopingSoundByIndex(int index, bool stopPlaying) {
 	track.isActive = false;
 	track.audioPlayerTrack = -1;
 	//	track.field_45 = 0;
+	track.soundType = -1;
+#if !BLADERUNNER_ORIGINAL_BUGS
+	track.name.clear();
+	track.hash = 0;
+	track.delayMin = 0u;
+	track.delayMax = 0u;
+	track.nextPlayTimeStart = 0u;
+	track.nextPlayTimeDiff = 0u;
+	track.volumeMin = 0;
+	track.volumeMax = 0;
+	track.volume = 0;
+	track.panStartMin = 0;
+	track.panStartMax = 0;
+	track.panEndMin = 0;
+	track.panEndMax = 0;
+	track.priority = 0;
+#endif // !BLADERUNNER_ORIGINAL_BUGS
 }
 
-void AmbientSounds::removeLoopingSoundByIndex(int index, uint32 delay) {
+void AmbientSounds::removeLoopingSoundByIndex(int index, uint32 delaySeconds) {
 	LoopingSound &track = _loopingSounds[index];
 	if (track.isActive && track.audioPlayerTrack != -1 && _vm->_audioPlayer->isActive(track.audioPlayerTrack)) {
-		if (delay > 0u) {
-			_vm->_audioPlayer->adjustVolume(track.audioPlayerTrack, 0, delay, false);
+		if (delaySeconds > 0u) {
+			_vm->_audioPlayer->adjustVolume(track.audioPlayerTrack, 0, delaySeconds, false);
 		} else {
 			_vm->_audioPlayer->stop(track.audioPlayerTrack, false);
 		}
@@ -383,6 +470,7 @@ void AmbientSounds::removeLoopingSoundByIndex(int index, uint32 delay) {
 	track.audioPlayerTrack = -1;
 	track.volume = 0;
 	track.pan = 0;
+	track.soundType = -1;
 }
 
 void AmbientSounds::save(SaveFileWriteStream &f) {
@@ -395,8 +483,8 @@ void AmbientSounds::save(SaveFileWriteStream &f) {
 		f.writeStringSz(track.name, 13);
 		f.writeSint32LE(track.hash);
 		f.writeInt(-1); // track.audioPlayerTrack is not used after load
-		f.writeInt(track.timeMin);
-		f.writeInt(track.timeMax);
+		f.writeInt(track.delayMin);
+		f.writeInt(track.delayMax);
 		f.writeInt(0); // track.nextPlayTime is not used after load
 		f.writeInt(track.volumeMin);
 		f.writeInt(track.volumeMax);
@@ -422,7 +510,7 @@ void AmbientSounds::save(SaveFileWriteStream &f) {
 }
 
 void AmbientSounds::load(SaveFileReadStream &f) {
-	removeAllLoopingSounds(0);
+	removeAllLoopingSounds(0u);
 	removeAllNonLoopingSounds(true);
 
 	f.skip(4); // _isDisabled - not used
@@ -436,15 +524,13 @@ void AmbientSounds::load(SaveFileReadStream &f) {
 		track.hash = f.readSint32LE();
 		f.skip(4); // track.audioPlayerTrack is not used after load
 		track.audioPlayerTrack = -1;
-		track.timeMin = (uint32)f.readInt();
-		track.timeMax = (uint32)f.readInt();
+		track.delayMin = (uint32)f.readInt();
+		track.delayMax = (uint32)f.readInt();
 		f.skip(4); // track.nextPlayTime is not used after load
 		track.nextPlayTimeStart = now;
 #if BLADERUNNER_ORIGINAL_BUGS
-#else
-		sort(&(track.timeMin), &(track.timeMax));
+		track.nextPlayTimeDiff  = _vm->_rnd.getRandomNumberRng(track.delayMin, track.delayMax);
 #endif // BLADERUNNER_ORIGINAL_BUGS
-		track.nextPlayTimeDiff  = _vm->_rnd.getRandomNumberRng(track.timeMin, track.timeMax);
 		track.volumeMin = f.readInt();
 		track.volumeMax = f.readInt();
 		track.volume = f.readInt();
@@ -452,14 +538,34 @@ void AmbientSounds::load(SaveFileReadStream &f) {
 		track.panStartMax = f.readInt();
 		track.panEndMin = f.readInt();
 		track.panEndMax = f.readInt();
-#if BLADERUNNER_ORIGINAL_BUGS
-#else
-		sort(&(track.volumeMin), &(track.volumeMax));
-		sort(&(track.panStartMin), &(track.panStartMax));
-		sort(&(track.panEndMin), &(track.panEndMax));
-#endif // BLADERUNNER_ORIGINAL_BUGS
 		track.priority = f.readInt();
 		f.skip(4); // field_45
+		track.soundType = -1;
+#if !BLADERUNNER_ORIGINAL_BUGS
+		// Since unused ambient sound track fields are unitialized
+		// don't keep garbage field values for non-active tracks
+		// This was basically an issue when calling _vm->_rnd.getRandomNumberRng()
+		// with uninitialized fields, but it's a good practice to sanitize the fields here anyway
+		if (!track.isActive) {
+			track.delayMin = 0u;
+			track.delayMax = 0u;
+			track.nextPlayTimeDiff  = 0u;
+			track.volumeMin = 0;
+			track.volumeMax = 0;
+			track.volume = 0;
+			track.panStartMin = 0;
+			track.panStartMax = 0;
+			track.panEndMin = 0;
+			track.panEndMax = 0;
+			track.priority = 0;
+		} else {
+			sort(&(track.delayMin), &(track.delayMax));
+			track.nextPlayTimeDiff  = _vm->_rnd.getRandomNumberRng(track.delayMin, track.delayMax);
+			sort(&(track.volumeMin), &(track.volumeMax));
+			sort(&(track.panStartMin), &(track.panStartMax));
+			sort(&(track.panEndMin), &(track.panEndMax));
+		}
+#endif // !BLADERUNNER_ORIGINAL_BUGS
 	}
 
 	for (int i = 0; i != kLoopingSounds; ++i) {
@@ -471,14 +577,27 @@ void AmbientSounds::load(SaveFileReadStream &f) {
 		track.audioPlayerTrack = -1;
 		track.volume = f.readInt();
 		track.pan = f.readInt();
+		track.soundType = -1;
+#if !BLADERUNNER_ORIGINAL_BUGS
+		// Since unused ambient sound track fields are unitialized
+		// don't keep garbage field values for non-active tracks
+		if (!track.isActive) {
+			track.volume = 0;
+			track.pan = 0;
+		}
+#endif // !BLADERUNNER_ORIGINAL_BUGS
 	}
 
 	for (int i = 0; i != kLoopingSounds; ++i) {
 		LoopingSound &track = _loopingSounds[i];
 		if (track.isActive) {
-			track.audioPlayerTrack = _vm->_audioPlayer->playAud(track.name, 1, track.pan, track.pan, 99, kAudioPlayerLoop | kAudioPlayerOverrideVolume);
+			Audio::Mixer::SoundType mixerAmbientSoundType = kAmbientSoundType;
+			if (track.soundType >= 0) {
+				mixerAmbientSoundType = (Audio::Mixer::SoundType) track.soundType;
+			}
+			track.audioPlayerTrack = _vm->_audioPlayer->playAud(track.name, 1, track.pan, track.pan, 99, kAudioPlayerLoop | kAudioPlayerOverrideVolume, mixerAmbientSoundType);
 			if (track.audioPlayerTrack == -1) {
-				removeLoopingSoundByIndex(i, 0);
+				removeLoopingSoundByIndex(i, 0u);
 			} else {
 				_vm->_audioPlayer->adjustVolume(track.audioPlayerTrack, _ambientVolume * track.volume / 100, 2u, false);
 			}
