@@ -24,6 +24,7 @@
 #define BLADERUNNER_AMBIENT_SOUNDS_H
 
 #include "audio/audiostream.h"
+#include "audio/mixer.h"
 
 #include "common/str.h"
 
@@ -34,18 +35,19 @@ class SaveFileReadStream;
 class SaveFileWriteStream;
 
 class AmbientSounds {
-	static const int kNonLoopingSounds = 25;
-	static const int kLoopingSounds = 3;
+	static const int kNonLoopingSounds                     = 25;
+	static const int kLoopingSounds                        = 3;
+	static const Audio::Mixer::SoundType kAmbientSoundType = Audio::Mixer::kPlainSoundType;
 
 	struct NonLoopingSound {
 		bool           isActive;
 		Common::String name;
 		int32          hash;
 		int            audioPlayerTrack;
-		uint32         timeMin;
-		uint32         timeMax;
-		uint32         nextPlayTimeStart;
-		uint32         nextPlayTimeDiff;
+		uint32         delayMin;          // milliseconds
+		uint32         delayMax;          // milliseconds
+		uint32         nextPlayTimeStart; // milliseconds
+		uint32         nextPlayTimeDiff;  // milliseconds
 		int            volumeMin;
 		int            volumeMax;
 		int            volume;
@@ -54,6 +56,7 @@ class AmbientSounds {
 		int            panEndMin;
 		int            panEndMax;
 		int            priority;
+		int32          soundType; // new - not stored in saved games
 	};
 
 	struct LoopingSound {
@@ -63,6 +66,7 @@ class AmbientSounds {
 		int            audioPlayerTrack;
 		int            volume;
 		int            pan;
+		int32          soundType; // new - not stored in saved games
 	};
 
 	BladeRunnerEngine *_vm;
@@ -77,7 +81,7 @@ public:
 
 	void addSound(
 		int sfxId,
-		uint32 timeMin, uint32 timeMax,
+		uint32 delayMinSeconds, uint32 delayMaxSeconds,
 		int volumeMin, int volumeMax,
 		int panStartMin, int panStartMax,
 		int panEndMin, int panEndMax,
@@ -88,20 +92,20 @@ public:
 
 	void addSpeech(
 		int actorId, int sentenceId,
-		uint32 timeMin, uint32 timeMax,
+		uint32 delayMinSeconds, uint32 delayMaxSeconds,
 		int volumeMin, int volumeMax,
 		int panStartMin, int panStartMax,
 		int panEndMin, int panEndMax,
 		int priority, int unk);
-	void playSound(int sfxId, int volume, int panStart, int panEnd, int priority);
+	void playSound(int sfxId, int volume, int panStart, int panEnd, int priority, Audio::Mixer::SoundType type = kAmbientSoundType);
 	void playSpeech(int actorId, int sentenceId, int volume, int panStart, int panEnd, int priority);
 
-	void addLoopingSound(int sfxId, int volume, int pan, uint32 delay);
-	void adjustLoopingSound(int sfxId, int volume, int pan, uint32 delay);
+	void addLoopingSound(int sfxId, int volume, int pan, uint32 delaySeconds, Audio::Mixer::SoundType type = kAmbientSoundType);
+	void adjustLoopingSound(int sfxId, int volume, int pan, uint32 delaySeconds);
 	// it seems there is little confusion in original code about delay parameter,
 	// sometimes it is used as boolean in same way as stopPlaying from non looping
-	void removeLoopingSound(int sfxId, uint32 delay);
-	void removeAllLoopingSounds(uint32 delay);
+	void removeLoopingSound(int sfxId, uint32 delaySeconds);
+	void removeAllLoopingSounds(uint32 delaySeconds);
 
 	void tick();
 
@@ -121,14 +125,14 @@ private:
 
 	void addSoundByName(
 		const Common::String &name,
-		uint32 timeMin, uint32 timeMax,
+		uint32 delayMinSeconds, uint32 delayMaxSeconds,
 		int volumeMin, int volumeMax,
 		int panStartMin, int panStartMax,
 		int panEndMin, int panEndMax,
 		int priority, int unk);
 
 	void removeNonLoopingSoundByIndex(int index, bool stopPlaying);
-	void removeLoopingSoundByIndex(int index, uint32 delay);
+	void removeLoopingSoundByIndex(int index, uint32 delaySeconds);
 };
 
 } // End of namespace BladeRunner
