@@ -92,12 +92,13 @@ public:
 
 	bool cmdAnimation(int argc, const char **argv);
 	bool cmdHealth(int argc, const char **argv);
-	bool cmdChapter(int argc, const char **argv);
+//	bool cmdChapter(int argc, const char **argv);
 	bool cmdDraw(int argc, const char **argv);
 	bool cmdFlag(int argc, const char **argv);
 	bool cmdGoal(int argc, const char **argv);
 	bool cmdLoop(int argc, const char **argv);
 	bool cmdPosition(int argc, const char **argv);
+	bool cmdMusic(int argc, const char** argv);
 	bool cmdSay(int argc, const char **argv);
 	bool cmdScene(int argc, const char **argv);
 	bool cmdVariable(int argc, const char **argv);
