@@ -33,6 +33,11 @@
 
 #include "engines/advancedDetector.h"
 
+static const DebugChannelDef debugFlagList[] = {
+	{BladeRunner::kDebugScript, "Script", "Debug the scripts"},
+	DEBUG_CHANNEL_END
+};
+
 namespace BladeRunner {
 
 static const PlainGameDescriptor bladeRunnerGames[] = {
@@ -92,76 +97,37 @@ static const ADExtraGuiOptionsMap optionsList[] = {
 
 } // End of namespace BladeRunner
 
-class BladeRunnerMetaEngine : public AdvancedMetaEngine {
+class BladeRunnerMetaEngineDetection : public AdvancedMetaEngineDetection {
 public:
-	BladeRunnerMetaEngine();
+	BladeRunnerMetaEngineDetection();
 
 	const char *getEngineId() const override;
 	const char *getName() const override;
 	const char *getOriginalCopyright() const override;
-	bool createInstance(OSystem *syst, Engine **engine, const ADGameDescription *desc) const override;
-	bool hasFeature(MetaEngineFeature f) const override;
-	SaveStateList listSaves(const char *target) const override;
-	int getMaximumSaveSlot() const override;
-	void removeSaveState(const char *target, int slot) const override;
-	SaveStateDescriptor querySaveMetaInfos(const char *target, int slot) const override;
+	const DebugChannelDef *getDebugChannels() const override;
 };
 
-BladeRunnerMetaEngine::BladeRunnerMetaEngine()
-	: AdvancedMetaEngine(
+BladeRunnerMetaEngineDetection::BladeRunnerMetaEngineDetection()
+	: AdvancedMetaEngineDetection(
 		BladeRunner::gameDescriptions,
 		sizeof(BladeRunner::gameDescriptions[0]),
 		BladeRunner::bladeRunnerGames,
 		BladeRunner::optionsList) {}
 
-const char *BladeRunnerMetaEngine::getEngineId() const {
+const char *BladeRunnerMetaEngineDetection::getEngineId() const {
 	return "bladerunner";
 }
 
-const char *BladeRunnerMetaEngine::getName() const {
+const char *BladeRunnerMetaEngineDetection::getName() const {
 	return "Blade Runner";
 }
 
-const char *BladeRunnerMetaEngine::getOriginalCopyright() const {
+const char *BladeRunnerMetaEngineDetection::getOriginalCopyright() const {
 	return "Blade Runner (C) 1997 Westwood Studios";
 }
 
-bool BladeRunnerMetaEngine::createInstance(OSystem *syst, Engine **engine, const ADGameDescription *desc) const {
-	*engine = new BladeRunner::BladeRunnerEngine(syst, desc);
-
-	return true;
+const DebugChannelDef *BladeRunnerMetaEngineDetection::getDebugChannels() const {
+	return debugFlagList;
 }
 
-bool BladeRunnerMetaEngine::hasFeature(MetaEngineFeature f) const {
-	return
-		f == kSupportsListSaves ||
-		f == kSupportsLoadingDuringStartup ||
-		f == kSupportsDeleteSave ||
-		f == kSavesSupportMetaInfo ||
-		f == kSavesSupportThumbnail ||
-		f == kSavesSupportCreationDate ||
-		f == kSavesSupportPlayTime ||
-		f == kSimpleSavesNames;
-}
-
-SaveStateList BladeRunnerMetaEngine::listSaves(const char *target) const {
-	return BladeRunner::SaveFileManager::list(target);
-}
-
-int BladeRunnerMetaEngine::getMaximumSaveSlot() const {
-	return 999;
-}
-
-void BladeRunnerMetaEngine::removeSaveState(const char *target, int slot) const {
-	BladeRunner::SaveFileManager::remove(target, slot);
-}
-
-SaveStateDescriptor BladeRunnerMetaEngine::querySaveMetaInfos(const char *target, int slot) const {
-	return BladeRunner::SaveFileManager::queryMetaInfos(target, slot);
-}
-
-#if PLUGIN_ENABLED_DYNAMIC(BLADERUNNER)
-	REGISTER_PLUGIN_DYNAMIC(BLADERUNNER, PLUGIN_TYPE_ENGINE, BladeRunnerMetaEngine);
-#else
-	REGISTER_PLUGIN_STATIC(BLADERUNNER, PLUGIN_TYPE_ENGINE, BladeRunnerMetaEngine);
-#endif
+REGISTER_PLUGIN_STATIC(BLADERUNNER_DETECTION, PLUGIN_TYPE_ENGINE_DETECTION, BladeRunnerMetaEngineDetection);
