@@ -145,6 +145,7 @@ bool AIScriptBryant::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			AI_Movement_Track_Append(kActorBryant, 139, 0);
 			AI_Movement_Track_Repeat(kActorBryant);
 			break;
+
 		case 1:
 			AI_Movement_Track_Append(kActorBryant, 139, 0);
 			AI_Movement_Track_Append(kActorBryant, 138, 0);
@@ -154,54 +155,63 @@ bool AIScriptBryant::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			AI_Movement_Track_Append(kActorBryant, 134, 0);
 			AI_Movement_Track_Repeat(kActorBryant);
 			break;
+
 		case 2:
 			AI_Movement_Track_Append(kActorBryant, 196, 0);
 			AI_Movement_Track_Append(kActorBryant, 197, 0);
 			AI_Movement_Track_Append(kActorBryant, 198, 0);
 			AI_Movement_Track_Repeat(kActorBryant);
 			break;
+
 		case 3:
 			AI_Movement_Track_Append(kActorBryant, 198, 0);
 			AI_Movement_Track_Append(kActorBryant, 197, 0);
 			AI_Movement_Track_Append(kActorBryant, 196, 0);
 			AI_Movement_Track_Repeat(kActorBryant);
 			break;
+
 		case 4:
 			AI_Movement_Track_Append(kActorBryant, 326, 0);
 			AI_Movement_Track_Append(kActorBryant, 332, 0);
 			AI_Movement_Track_Append(kActorBryant, 327, 0);
 			AI_Movement_Track_Repeat(kActorBryant);
 			break;
+
 		case 5:
 			AI_Movement_Track_Append(kActorBryant, 327, 0);
 			AI_Movement_Track_Append(kActorBryant, 332, 0);
 			AI_Movement_Track_Append(kActorBryant, 326, 0);
 			AI_Movement_Track_Repeat(kActorBryant);
 			break;
+
 		case 6:
 			AI_Movement_Track_Append(kActorBryant, 329, 0);
 			AI_Movement_Track_Append(kActorBryant, 328, 0);
 			AI_Movement_Track_Append(kActorBryant, 330, 0);
 			AI_Movement_Track_Repeat(kActorBryant);
 			break;
+
 		case 7:
 			AI_Movement_Track_Append(kActorBryant, 330, 0);
 			AI_Movement_Track_Append(kActorBryant, 328, 0);
 			AI_Movement_Track_Append(kActorBryant, 329, 0);
 			AI_Movement_Track_Repeat(kActorBryant);
 			break;
+
 		case 8:
 			AI_Movement_Track_Append(kActorBryant, 331, 0);
 			AI_Movement_Track_Append(kActorBryant, 333, 0);
 			AI_Movement_Track_Append(kActorBryant, 335, 0);
 			AI_Movement_Track_Repeat(kActorBryant);
 			break;
+
 		case 9:
 			AI_Movement_Track_Append(kActorBryant, 335, 0);
 			AI_Movement_Track_Append(kActorBryant, 333, 0);
 			AI_Movement_Track_Append(kActorBryant, 331, 0);
 			AI_Movement_Track_Repeat(kActorBryant);
 			break;
+
 		default:
 			break;
 		}
@@ -221,33 +231,37 @@ bool AIScriptBryant::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 bool AIScriptBryant::UpdateAnimation(int *animation, int *frame) {
 	switch (_animationState) {
 	case 0:
-		*animation = 806;
+		*animation = kModelAnimationBearToyOscillatingIdle;
 		++_animationFrame;
 
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(806)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationBearToyOscillatingIdle)) {
 			_animationFrame = 0;
 		}
 		break;
+
 	case 1:
-		*animation = 805;
+		*animation = kModelAnimationBearToyWalking;
 		++_animationFrame;
 
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(805)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationBearToyWalking)) {
 			_animationFrame = 0;
 		}
 		break;
+
 	case 2:
-		*animation = 808;
+		*animation = kModelAnimationBearToyShotDead;
 		++_animationFrame;
 
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(808) - 1) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationBearToyShotDead) - 1) {
 			_animationState = 3;
 		}
 		break;
+
 	case 3:
-		*animation = 808;
-		_animationFrame = Slice_Animation_Query_Number_Of_Frames(808) - 1;
+		*animation = kModelAnimationBearToyShotDead;
+		_animationFrame = Slice_Animation_Query_Number_Of_Frames(kModelAnimationBearToyShotDead) - 1;
 		break;
+
 	default:
 		break;
 	}
@@ -262,15 +276,18 @@ bool AIScriptBryant::ChangeAnimationMode(int mode) {
 		_animationState = 0;
 		_animationFrame = 0;
 		break;
+
 	case kAnimationModeWalk:
 		_animationState = 1;
 		_animationFrame = 0;
 		break;
+
 	case kAnimationModeDie:
 		_animationState = 2;
 		_animationFrame = 0;
 		Actor_Set_Goal_Number(kActorBryant, 0);
 		break;
+
 	default:
 		break;
 	}
