@@ -25,7 +25,7 @@
 namespace BladeRunner {
 
 AIScriptDektora::AIScriptDektora(BladeRunnerEngine *vm) : AIScriptBase(vm) {
-	_flag = false;
+	_resumeIdleAfterFramesetCompletesFlag = false;
 	_x = _y = _z = 0.0f;
 }
 
@@ -35,7 +35,7 @@ void AIScriptDektora::Initialize() {
 	_animationStateNext = 0;
 	_animationNext = 0;
 
-	_flag = false;
+	_resumeIdleAfterFramesetCompletesFlag = false;
 	_x = _y = _z = 0.0f;
 
 	Actor_Set_Goal_Number(kActorDektora, kGoalDektoraDefault);
@@ -118,8 +118,8 @@ bool AIScriptDektora::Update() {
 	}
 
 	if (chapter == 4) {
-		if (Actor_Query_Goal_Number(kActorDektora) < 300) {
-			Actor_Set_Goal_Number(kActorDektora, 300);
+		if (Actor_Query_Goal_Number(kActorDektora) < kGoalDektoraStartAct4StashedAway) {
+			Actor_Set_Goal_Number(kActorDektora, kGoalDektoraStartAct4StashedAway);
 		}
 		return true;
 	}
@@ -278,13 +278,15 @@ bool AIScriptDektora::ShotAtAndHit() {
 		Actor_Set_Health(kActorDektora, 100, 100);
 		if (_vm->_cutContent) {
 		// add hit sounds with small probability
-		switch (Random_Query(1, 10)) {
+			switch (Random_Query(1, 10)) {
 			case 1:
 				Sound_Play_Speech_Line(kActorDektora, 9000, 65, 0, 99);
 				break;
+
 			case 2:
 				Sound_Play_Speech_Line(kActorDektora, 9005, 65, 0, 99);
 				break;
+
 			default:
 				break;
 			}
@@ -344,7 +346,7 @@ void AIScriptDektora::Retired(int byActorId) {
 			Player_Set_Combat_Mode(false);
 			Loop_Actor_Walk_To_XYZ(kActorMcCoy, -12.0f, -41.58f, 72.0f, 0, true, false, false);
 			Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-			Ambient_Sounds_Remove_All_Looping_Sounds(1);
+			Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 			Game_Flag_Set(kFlagKP07toKP06);
 			Game_Flag_Reset(kFlagMcCoyIsHelpingReplicants);
 			Set_Enter(kSetKP05_KP06, kSceneKP06);
@@ -573,6 +575,11 @@ bool AIScriptDektora::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 
 	case kGoalDektoraNR11RanAway:
 		Game_Flag_Set(kFlagDektoraRanAway);
+#if !BLADERUNNER_ORIGINAL_BUGS
+		// This will teleport Dektora out of the NR11 scene
+		// and remove the awry target hotspot at the region where she left
+		Actor_Set_Goal_Number(kActorDektora, kGoalDektoraStartAct4StashedAway);
+#endif // !BLADERUNNER_ORIGINAL_BUGS
 		break;
 
 	case 299:
@@ -581,10 +588,10 @@ bool AIScriptDektora::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 		Actor_Set_Goal_Number(kActorDektora, kGoalDektoraGone);
 		break;
 
-	case 300:
+	case kGoalDektoraStartAct4StashedAway:
 		AI_Movement_Track_Flush(kActorDektora);
 		Actor_Put_In_Set(kActorDektora, kSetFreeSlotA);
-		Actor_Set_At_Waypoint(kActorDektora, 33, 0);
+		Actor_Set_At_Waypoint(kActorDektora, 33, 0); // in kSetFreeSlotA
 		break;
 
 	default:
@@ -606,15 +613,14 @@ bool AIScriptDektora::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 1:
-		*animation = 19;
+		// Dummy placeholder, kModelAnimationMcCoyIdle (19) is a McCoy animation
+		*animation = kModelAnimationMcCoyIdle;
 		_animationFrame = 0;
 		break;
 
 	case 2:
 		*animation = kModelAnimationDektoraStandingNodShort;
-		if (_animationFrame == 0
-		 && _flag
-		) {
+		if (_animationFrame == 0 && _resumeIdleAfterFramesetCompletesFlag) {
 			*animation = kModelAnimationDektoraStandingIdle;
 			_animationState = 0;
 		} else {
@@ -898,7 +904,7 @@ bool AIScriptDektora::UpdateAnimation(int *animation, int *frame) {
 
 	case 27:
 		*animation = kModelAnimationDektoraSittingSubtleTalking;
-		if (!_animationFrame && _flag) {
+		if (_animationFrame == 0 && _resumeIdleAfterFramesetCompletesFlag) {
 			*animation = kModelAnimationDektoraSittingIdle;
 			_animationState = 25;
 		} else {
@@ -1150,43 +1156,69 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 		}
 		switch (_animationState) {
 		case 2:
+			// fall through
 		case 3:
+			// fall through
 		case 4:
+			// fall through
 		case 5:
+			// fall through
 		case 6:
+			// fall through
 		case 7:
+			// fall through
 		case 8:
+			// fall through
 		case 27:
+			// fall through
 		case 28:
-			_flag = true;
+			_resumeIdleAfterFramesetCompletesFlag = true;
 			break;
+
 		case 9:
+			// fall through
 		case 10:
+			// fall through
 		case 12:
+			// fall through
 		case 13:
+			// fall through
 		case 14:
+			// fall through
 		case 15:
+			// fall through
 		case 16:
+			// fall through
 		case 17:
 			_animationState = 11;
 			_animationFrame = 0;
 			break;
+
 		case 11:
+			// fall through
 		case 18:
+			// fall through
 		case 19:
+			// fall through
 		case 20:
+			// fall through
 		case 26:
+			// fall through
 		case 29:
+			// fall through
 		case 30:
 			break;
+
 		case 25:
 			_animationState = 25;
 			_animationFrame = 0;
 			break;
+
 		case 31:
 			_animationState = 31;
 			_animationFrame = 0;
 			break;
+
 		default:
 			_animationState = 0;
 			_animationFrame = 0;
@@ -1215,27 +1247,35 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 		) {
 			_animationState = 2;
 			_animationFrame = 0;
-			_flag = false;
+			_resumeIdleAfterFramesetCompletesFlag = false;
 		}
 		break;
 
 	case kAnimationModeCombatIdle:
 		switch (_animationState) {
 		case 9:
+			// fall through
 		case 10:
+			// fall through
 		case 16:
+			// fall through
 		case 17:
 			break;
+
 		case 25:
+			// fall through
 		case 27:
+			// fall through
 		case 28:
 			_animationState = 29;
 			_animationFrame = 0;
 			break;
+
 		case 31:
 			_animationState = 30;
 			_animationFrame = Slice_Animation_Query_Number_Of_Frames(kModelAnimationDektoraSittingPullingGunOut) - 1;
 			break;
+
 		default:
 			_animationState = 10;
 			_animationFrame = 0;
@@ -1275,7 +1315,7 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 		) {
 			_animationState = 3;
 			_animationFrame = 0;
-			_flag = false;
+			_resumeIdleAfterFramesetCompletesFlag = false;
 		}
 		break;
 
@@ -1285,7 +1325,7 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 		) {
 			_animationState = 4;
 			_animationFrame = 0;
-			_flag = false;
+			_resumeIdleAfterFramesetCompletesFlag = false;
 		}
 		break;
 
@@ -1295,7 +1335,7 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 		) {
 			_animationState = 5;
 			_animationFrame = 0;
-			_flag = 0;
+			_resumeIdleAfterFramesetCompletesFlag = false;
 		}
 		break;
 
@@ -1305,7 +1345,7 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 		) {
 			_animationState = 6;
 			_animationFrame = 0;
-			_flag = false;
+			_resumeIdleAfterFramesetCompletesFlag = false;
 		}
 		break;
 
@@ -1315,7 +1355,7 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 		) {
 			_animationState = 7;
 			_animationFrame = 0;
-			_flag = false;
+			_resumeIdleAfterFramesetCompletesFlag = false;
 		}
 		break;
 
@@ -1325,7 +1365,7 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 		) {
 			_animationState = 8;
 			_animationFrame = 0;
-			_flag = false;
+			_resumeIdleAfterFramesetCompletesFlag = false;
 		}
 		break;
 
@@ -1337,11 +1377,17 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 		}
 		switch (_animationState) {
 		case 9:
+			// fall through
 		case 10:
+			// fall through
 		case 11:
+			// fall through
 		case 12:
+			// fall through
 		case 13:
+			// fall through
 		case 16:
+			// fall through
 		case 17:
 			if (Random_Query(0, 1) == 1) {
 				_animationState = 14;
@@ -1349,7 +1395,9 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 				_animationState = 15;
 			}
 			break;
+
 		case 14:
+			// fall through
 		case 15:
 			if (Random_Query(0, 1) == 1) {
 				_animationState = 18;
@@ -1357,6 +1405,7 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 				_animationState = 19;
 			}
 			break;
+
 		default:
 			break;
 		}
@@ -1374,7 +1423,7 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 		) {
 			_animationState = 27;
 			_animationFrame = 0;
-			_flag = false;
+			_resumeIdleAfterFramesetCompletesFlag = false;
 		}
 		break;
 
@@ -1384,7 +1433,7 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 		) {
 			_animationState = 28;
 			_animationFrame = 0;
-			_flag = false;
+			_resumeIdleAfterFramesetCompletesFlag = false;
 		}
 		break;
 
@@ -1400,7 +1449,7 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 
 	case kAnimationModeDie:
 		if (_vm->_cutContent && Global_Variable_Query(kVariableChapter) == 5) {
-			// only play the rattle sound in the Act 5 death (moon bud), but not in chapter 3 death
+			// only play the rattle sound in the Act 5 death (moon bus), but not in chapter 3 death
 			// The rattle also plays in ShotAtAndHit() in Act 3 (if Dektora is shot at the back in NR11,
 			// and she is Human) but that case is currently never triggered.
 			Sound_Play_Speech_Line(kActorDektora, 9020, 60, 0, 99); // add Dektora's death rattle here
@@ -1412,14 +1461,20 @@ bool AIScriptDektora::ChangeAnimationMode(int mode) {
 	case 53:
 		switch (_animationState) {
 		case 26:
+			// fall through
 		case 29:
+			// fall through
 		case 30:
+			// fall through
 		case 31:
 			break;
+
 		case 27:
+			// fall through
 		case 28:
-			_flag = true;
+			_resumeIdleAfterFramesetCompletesFlag = true;
 			break;
+
 		default:
 			_animationState = 25;
 			_animationFrame = 0;
