@@ -24,7 +24,7 @@
 namespace BladeRunner {
 
 AIScriptGordo::AIScriptGordo(BladeRunnerEngine *vm) : AIScriptBase(vm) {
-	var_45B078 = 0;
+	_resumeIdleAfterFramesetCompletesFlag = false;
 	_counter = 0;
 	_counterTarget = 0;
 	_frameMin = 0;
@@ -37,7 +37,7 @@ void AIScriptGordo::Initialize() {
 	_animationState = 0;
 	_animationFrame = 0;
 	_animationStateNext = 0;
-	var_45B078 = 0;
+	_resumeIdleAfterFramesetCompletesFlag = false;
 	_counter = 0;
 	_counterTarget = 0;
 	_frameMin = 0;
@@ -130,11 +130,30 @@ void AIScriptGordo::CompletedMovementTrack() {
 			Actor_Force_Stop_Walking(kActorMcCoy);
 			Player_Loses_Control();
 			Player_Set_Combat_Mode(true);
-			Actor_Change_Animation_Mode(kActorMcCoy, kAnimationModeCombatAim); // TODO: check this, it was set directly by calling actor script
+			// we need to set McCoy to Combat Aim via callChangeAnimationMode() (which is forced)
+			// Changing the animation to "combat aim" via Actor_Change_Animation_Mode() won't work here
+			// (probably because we just switched to combat mode and animation was just set to combat idle)
+			// Also note that changing the animation via Actor_Says does not work when in combat mode (at all)!
+			// callChangeAnimationMode() does not actually set the _animationMode member for the actor's AI
+			// it just changes the animation, so to return back to idle (while player has not control)
+			// we will call the callChangeAnimationMode() again.
+			// Note the calling the Actor_Change_Animation_Mode(kActorMcCoy, kAnimationModeCombatAim) won't work
+			//		and McCoy will still use the Combat Idle animation in that case
+			// see also: kGoalEarlyQNR04McCoyPulledGun for Early Q AI script
+			Actor_Change_Animation_Mode(kActorMcCoy, kAnimationModeCombatIdle);
+			_vm->_aiScripts->callChangeAnimationMode(kActorMcCoy, kAnimationModeCombatAim);
 			Actor_Face_Actor(kActorMcCoy, kActorGordo, true);
 			Actor_Face_Actor(kActorGordo, kActorMcCoy, true);
+			if (_vm->_cutContent) {
+				Actor_Says(kActorMcCoy, 460, kAnimationModeCombatAim);
+			}
 			Actor_Says(kActorGordo, 50, 13);
-			Actor_Says(kActorMcCoy, 465, kAnimationModeCombatAim);
+			if (_vm->_cutContent) {
+				_vm->_aiScripts->callChangeAnimationMode(kActorMcCoy, kAnimationModeCombatIdle);
+				Actor_Says(kActorMcCoy, 465, kAnimationModeCombatIdle);
+			} else {
+				Actor_Says(kActorMcCoy, 465, kAnimationModeCombatAim);
+			}
 			Actor_Says(kActorGordo, 60, 14);
 			Player_Set_Combat_Mode(false);
 			Player_Gains_Control();
@@ -199,7 +218,7 @@ void AIScriptGordo::CompletedMovementTrack() {
 	}
 
 	if (Actor_Query_Goal_Number(kActorGordo) == kGoalGordoNR01RunAway) {
-		Music_Stop(2);
+		Music_Stop(2u);
 		Actor_Set_Goal_Number(kActorGordo, kGoalGordoNR01RanAway);
 	}
 	// return false;
@@ -304,7 +323,7 @@ void AIScriptGordo::Retired(int byActorId) {
 #endif // BLADERUNNER_ORIGINAL_BUGS
 			Loop_Actor_Walk_To_XYZ(kActorMcCoy, -12.0f, -41.58f, 72.0f, 0, true, false, false);
 			Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-			Ambient_Sounds_Remove_All_Looping_Sounds(1);
+			Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 			Game_Flag_Set(kFlagKP07toKP06);
 			Game_Flag_Reset(kFlagMcCoyIsHelpingReplicants);
 			Set_Enter(kSetKP05_KP06, kSceneKP06);
@@ -392,15 +411,19 @@ bool AIScriptGordo::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 		}
 		switch (rnd) {
 		case 1:
+			// fall through
 		case 2:
 			Actor_Set_Goal_Number(kActorGordo, kGoalGordoGoToDNARow);
 			break;
+
 		case 3:
 			Actor_Set_Goal_Number(kActorGordo, kGoalGordoGoToChinaTown);
 			break;
+
 		case 4:
 			Actor_Set_Goal_Number(kActorGordo, kGoalGordoGoToFreeSlotHAGJ);
 			break;
+
 		case 5:
 			Actor_Set_Goal_Number(kActorGordo, kGoalGordoGoToFreeSlotAH);
 			break;
@@ -504,14 +527,17 @@ bool AIScriptGordo::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			Global_Variable_Increment(kVariableGordosJoke, 1);
 			Actor_Set_Goal_Number(kActorGordo, kGoalGordoNR02TellJoke1);
 			break;
+
 		case 1:
 			Global_Variable_Increment(kVariableGordosJoke, 1);
 			Actor_Set_Goal_Number(kActorGordo, kGoalGordoNR02TellJoke2);
 			break;
+
 		case 2:
 			Global_Variable_Increment(kVariableGordosJoke, 1);
 			Actor_Set_Goal_Number(kActorGordo, kGoalGordoNR02TellJoke3);
 			break;
+
 		case 3:
 			Global_Variable_Increment(kVariableGordosJoke, 1);
 			Actor_Set_Goal_Number(kActorGordo, kGoalGordoNR02TalkAboutMcCoy);
@@ -546,7 +572,7 @@ bool AIScriptGordo::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 		Actor_Face_Actor(kActorGordo, kActorMcCoy, true);
 		Actor_Says(kActorGordo, 720, 16);
 		Actor_Says(kActorGordo, 730, 18);
-		Music_Stop(1);
+		Music_Stop(1u);
 		Actor_Face_Actor(kActorMcCoy, kActorGordo, true);
 		Actor_Says(kActorGordo, 740, 17);
 		Sound_Play(kSfxRIMSHOT1, 50, 0, 0, 50);
@@ -600,7 +626,7 @@ bool AIScriptGordo::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 		AI_Movement_Track_Flush(kActorGordo);
 		AI_Movement_Track_Append_Run(kActorGordo, 366, 0);
 		AI_Movement_Track_Repeat(kActorGordo);
-		Music_Play(kMusicBatl226M, 50, 0, 2, -1, 0, 0);
+		Music_Play(kMusicBatl226M, 50, 0, 2, -1, kMusicLoopPlayOnce, 0);
 		break;
 
 	case kGoalGordoNR02RunAway2:
@@ -693,7 +719,7 @@ bool AIScriptGordo::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 		break;
 
 	case kGoalGordoNR01Die:
-		Music_Stop(2);
+		Music_Stop(2u);
 		AI_Countdown_Timer_Reset(kActorGordo, kActorTimerAIScriptCustomTask0);
 		ADQ_Flush();
 		AI_Movement_Track_Flush(kActorGordo);
@@ -720,7 +746,7 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 	case 0:
 		switch (_state) {
 		case 0:
-			*animation = 116;
+			*animation = kModelAnimationGordoIdle;
 			if (_counter < _counterTarget) {
 				_animationFrame += _frameDelta;
 				if (_animationFrame > _frameMax) {
@@ -763,20 +789,22 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 				}
 			}
 			break;
+
 		case 1:
-			*animation = 117;
+			*animation = kModelAnimationGordoBrushOffShoulder;
 			++_animationFrame;
-			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(117)) {
-				*animation = 116;
+			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoBrushOffShoulder)) {
+				*animation = kModelAnimationGordoIdle;
 				_animationFrame = 0;
 				_state = 0;
 			}
 			break;
+
 		case 2:
-			*animation = 118;
+			*animation = kModelAnimationGordoChecksHand;
 			++_animationFrame;
-			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(118)) {
-				*animation = 116;
+			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoChecksHand)) {
+				*animation = kModelAnimationGordoIdle;
 				_animationFrame = 0;
 				_state = 0;
 			}
@@ -787,8 +815,8 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 	case 1:
 		switch (_state) {
 		case 0:
-			*animation = 116;
-			if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(116) / 2) {
+			*animation = kModelAnimationGordoIdle;
+			if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoIdle) / 2) {
 				_animationFrame += 2;
 			} else {
 				_animationFrame -= 2;
@@ -799,19 +827,21 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 				_animationState = _animationStateNext;
 			}
 			break;
+
 		case 1:
-			*animation = 117;
+			*animation = kModelAnimationGordoBrushOffShoulder;
 			_animationFrame += 2;
-			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(117)) {
+			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoBrushOffShoulder)) {
 				*animation = _animationNext;
 				_animationFrame = 0;
 				_animationState = _animationStateNext;
 			}
 			break;
+
 		case 2:
-			*animation = 118;
+			*animation = kModelAnimationGordoChecksHand;
 			_animationFrame += 2;
-			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(118)) {
+			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoChecksHand)) {
 				*animation = _animationNext;
 				_animationFrame = 0;
 				_animationState = _animationStateNext;
@@ -821,7 +851,7 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 2:
-		*animation = 114;
+		*animation = kModelAnimationGordoSitting;
 		if (Random_Query(0, 1)) {
 			++_animationFrame;
 		}
@@ -831,10 +861,10 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 3:
-		*animation = 115;
+		*animation = kModelAnimationGordoWavesGetsUpAndPays;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(115)) {
-			*animation = 116;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWavesGetsUpAndPays)) {
+			*animation = kModelAnimationGordoIdle;
 			_animationState = 0;
 			_animationFrame = 0;
 			Actor_Change_Animation_Mode(kActorGordo, kAnimationModeIdle);
@@ -843,9 +873,9 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 4:
-		*animation = 120;
-		if (_animationFrame == 0 && var_45B078) {
-			*animation = 116;
+		*animation = kModelAnimationGordoIdleTalk;
+		if (_animationFrame == 0 && _resumeIdleAfterFramesetCompletesFlag) {
+			*animation = kModelAnimationGordoIdle;
 			_animationState = 0;
 		} else {
 			++_animationFrame;
@@ -856,117 +886,118 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 5:
-		*animation = 121;
+		*animation = kModelAnimationGordoSuggestingTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(121)) {
-			*animation = 120;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoSuggestingTalk)) {
+			*animation = kModelAnimationGordoIdleTalk;
 			_animationFrame = 0;
 			_animationState = 4;
 		}
 		break;
 
 	case 6:
-		*animation = 122;
+		*animation = kModelAnimationGordoSuggestAndPointTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(122)) {
-			*animation = 120;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoSuggestAndPointTalk)) {
+			*animation = kModelAnimationGordoIdleTalk;
 			_animationFrame = 0;
 			_animationState = 4;
 		}
 		break;
 
 	case 7:
-		*animation = 123;
+		*animation = kModelAnimationGordoSuggestAndDismissTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(123)) {
-			*animation = 120;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoSuggestAndDismissTalk)) {
+			*animation = kModelAnimationGordoIdleTalk;
 			_animationFrame = 0;
 			_animationState = 4;
 		}
 		break;
 
 	case 8:
-		*animation = 124;
+		*animation = kModelAnimationGordoDismissiveTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(124)) {
-			*animation = 120;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoDismissiveTalk)) {
+			*animation = kModelAnimationGordoIdleTalk;
 			_animationFrame = 0;
 			_animationState = 4;
 		}
 		break;
 
 	case 9:
-		*animation = 125;
+		*animation = kModelAnimationGordoUpsetTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(125)) {
-			*animation = 120;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoUpsetTalk)) {
+			*animation = kModelAnimationGordoIdleTalk;
 			_animationFrame = 0;
 			_animationState = 4;
 		}
 		break;
 
 	case 10:
-		*animation = 126;
+		*animation = kModelAnimationGordoExplainAndPointTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(126)) {
-			*animation = 120;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoExplainAndPointTalk)) {
+			*animation = kModelAnimationGordoIdleTalk;
 			_animationFrame = 0;
 			_animationState = 4;
 		}
 		break;
 
 	case 11:
-		*animation = 127;
+		*animation = kModelAnimationGordoAdjustBowtieTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(127)) {
-			*animation = 120;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoAdjustBowtieTalk)) {
+			*animation = kModelAnimationGordoIdleTalk;
 			_animationFrame = 0;
 			_animationState = 4;
 		}
 		break;
 
 	case 12:
-		*animation = 127;
+		// TODO this case is identical with case 11 (is this correct?)
+		*animation = kModelAnimationGordoAdjustBowtieTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(127)) {
-			*animation = 120;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoAdjustBowtieTalk)) {
+			*animation = kModelAnimationGordoIdleTalk;
 			_animationFrame = 0;
 			_animationState = 4;
 		}
 		break;
 
 	case 13:
-		*animation = 114;
+		*animation = kModelAnimationGordoSitting;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(114)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoSitting)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 14:
-		*animation = 103;
+		*animation = kModelAnimationGordoWithGunUnholsterGun;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(103)) {
-			*animation = 93;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunUnholsterGun)) {
+			*animation = kModelAnimationGordoWithGunIdle;
 			_animationFrame = 0;
 			_animationState = 16;
 		}
 		break;
 
 	case 15:
-		*animation = 104;
+		*animation = kModelAnimationGordoWithGunHolsterGun;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(104)) {
-			*animation = 116;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunHolsterGun)) {
+			*animation = kModelAnimationGordoIdle;
 			_animationFrame = 0;
 			_animationState = 0;
 		}
 		break;
 
 	case 16:
-		*animation = 93;
+		*animation = kModelAnimationGordoWithGunIdle;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(93)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunIdle)) {
 			_animationFrame = 0;
 		}
 		break;
@@ -975,7 +1006,7 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 18:
-		*animation = 105;
+		*animation = kModelAnimationGordoWithGunShooting;
 		++_animationFrame;
 		if (_animationFrame == 1) {
 			Sound_Play_Speech_Line(kActorGordo, Random_Query(0, 1) ? 9010 : 9015, 75, 0, 99);
@@ -984,7 +1015,7 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 			Actor_Combat_AI_Hit_Attempt(kActorGordo);
 		}
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
-			*animation = 93;
+			*animation = kModelAnimationGordoWithGunIdle;
 			_animationFrame = 0;
 			_animationState = 16;
 			Actor_Change_Animation_Mode(kActorGordo, kAnimationModeCombatIdle);
@@ -992,10 +1023,10 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 19:
-		*animation = 111;
+		*animation = kModelAnimationGordoGotHitRight;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(111)) {
-			*animation = 116;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoGotHitRight)) {
+			*animation = kModelAnimationGordoIdle;
 			_animationFrame = 0;
 			_animationState = 0;
 			Actor_Change_Animation_Mode(kActorGordo, kAnimationModeIdle);
@@ -1003,10 +1034,10 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 20:
-		*animation = 112;
+		*animation = kModelAnimationGordoGotHitLeft;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(112)) {
-			*animation = 116;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoGotHitLeft)) {
+			*animation = kModelAnimationGordoIdle;
 			_animationFrame = 0;
 			_animationState = 0;
 			Actor_Change_Animation_Mode(kActorGordo, kAnimationModeIdle);
@@ -1014,10 +1045,10 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 21:
-		*animation = 96;
+		*animation = kModelAnimationGordoWithGunGotHitRight;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(96)) {
-			*animation = 93;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunGotHitRight)) {
+			*animation = kModelAnimationGordoWithGunIdle;
 			_animationFrame = 0;
 			_animationState = 16;
 			Actor_Change_Animation_Mode(kActorGordo, kAnimationModeCombatIdle);
@@ -1025,10 +1056,10 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 22:
-		*animation = 97;
+		*animation = kModelAnimationGordoWithGunGotHitLeft;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(97)) {
-			*animation = 93;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunGotHitLeft)) {
+			*animation = kModelAnimationGordoWithGunIdle;
 			_animationFrame = 0;
 			_animationState = 16;
 			Actor_Change_Animation_Mode(kActorGordo, kAnimationModeCombatIdle);
@@ -1036,88 +1067,88 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 23:
-		*animation = 113;
-		if (_animationFrame < Slice_Animation_Query_Number_Of_Frames(113) - 1) {
+		*animation = kModelAnimationGordoShotDead;
+		if (_animationFrame < Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoShotDead) - 1) {
 			++_animationFrame;
 		}
 		break;
 
 	case 24:
-		*animation = 100;
-		if (_animationFrame < Slice_Animation_Query_Number_Of_Frames(100) - 1) {
+		*animation = kModelAnimationGordoWithGunShotDead;
+		if (_animationFrame < Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunShotDead) - 1) {
 			++_animationFrame;
 		}
 		break;
 
 	case 25:
-		*animation = 107;
+		*animation = kModelAnimationGordoWalking;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(107)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWalking)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 26:
-		*animation = 108;
+		*animation = kModelAnimationGordoRunning;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(108)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoRunning)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 27:
-		*animation = 98;
+		*animation = kModelAnimationGordoWithGunWalking;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(98)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunWalking)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 28:
-		*animation = 99;
+		*animation = kModelAnimationGordoWithGunRunning;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(99)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunRunning)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 29:
-		*animation = 109;
+		*animation = kModelAnimationGordoClimbStairsUp;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(109)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoClimbStairsUp)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 30:
-		*animation = 110;
+		*animation = kModelAnimationGordoClimbStairsDown;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(110)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoClimbStairsDown)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 31:
-		*animation = 101;
+		*animation = kModelAnimationGordoWithGunClimbStairsUp;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(101)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunClimbStairsUp)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 32:
-		*animation = 102;
+		*animation = kModelAnimationGordoWithGunClimbStairsDown;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(102)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunClimbStairsDown)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 33:
-		*animation = 106;
+		*animation = kModelAnimationGordoWithGunJumpingDown;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(106)) {
-			*animation = 93;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunJumpingDown)) {
+			*animation = kModelAnimationGordoWithGunIdle;
 			_animationState = 16;
 			_animationFrame = 0;
 			Actor_Change_Animation_Mode(kActorGordo, kAnimationModeCombatIdle);
@@ -1129,9 +1160,9 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 34:
-		*animation = 119;
+		*animation = kModelAnimationGordoLeavesSomethingOnCounter;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(119)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoLeavesSomethingOnCounter)) {
 			if (Game_Flag_Query(kFlagNR02GordoLeaveLighter)) {
 				Game_Flag_Reset(kFlagNR02GordoLeaveLighter);
 				if (Game_Flag_Query(kFlagGordoIsReplicant)) {
@@ -1141,7 +1172,7 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 				}
 				Actor_Set_Goal_Number(kActorGordo, kGoalGordoNR02GoToPodium);
 			}
-			*animation = 116;
+			*animation = kModelAnimationGordoIdle;
 			_animationState = 0;
 			_animationFrame = 0;
 			Actor_Change_Animation_Mode(kActorGordo, kAnimationModeIdle);
@@ -1149,43 +1180,45 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 35:
-		*animation = 128;
+		*animation = kModelAnimationGordoWithGunWithHostageATalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(128)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunWithHostageATalk)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 36:
-		if (_animationFrame == 0 && var_45B078) {
+		if (_animationFrame == 0 && _resumeIdleAfterFramesetCompletesFlag) {
+			// TODO use of _resumeIdleAfterFramesetCompletesFlag here, means change to another animation after this one completed)
 			Actor_Change_Animation_Mode(kActorGordo, 80);
-			*animation = 128;
+			*animation = kModelAnimationGordoWithGunWithHostageATalk;
 			_animationState = 35;
 		} else {
-			*animation = 129;
+			*animation = kModelAnimationGordoWithGunWithHostageBTalk;
 			++_animationFrame;
-			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(129)) {
+			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunWithHostageBTalk)) {
 				_animationFrame = 0;
 			}
 		}
 		break;
 
 	case 37:
-		if (_animationFrame == 0 && var_45B078) {
+		if (_animationFrame == 0 && _resumeIdleAfterFramesetCompletesFlag) {
+			// TODO use of _resumeIdleAfterFramesetCompletesFlag here, means change to another animation after this one completed)
 			Actor_Change_Animation_Mode(kActorGordo, 80);
-			*animation = 128;
+			*animation = kModelAnimationGordoWithGunWithHostageATalk;
 			_animationState = 35;
 		} else {
-			*animation = 130;
+			*animation = kModelAnimationGordoWithGunWithHostageCTalk;
 			++_animationFrame;
-			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(130)) {
+			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGordoWithGunWithHostageCTalk)) {
 				_animationFrame = 0;
 			}
 		}
 		break;
 
 	case 38:
-		*animation = 131;
+		*animation = kModelAnimationGordoWithGunWithHostageLetsGo;
 		++_animationFrame;
 		if (_animationFrame == 7) {
 			if (Actor_Query_Goal_Number(kActorGordo) == kGoalGordoNR01HostageDie) {
@@ -1196,19 +1229,19 @@ bool AIScriptGordo::UpdateAnimation(int *animation, int *frame) {
 		}
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			Actor_Change_Animation_Mode(kActorGordo, kAnimationModeCombatIdle);
-			*animation = 93;
+			*animation = kModelAnimationGordoWithGunIdle;
 			_animationFrame = 0;
 			Actor_Set_Goal_Number(kActorGordo, kGoalGordoNR01RunAway);
 		}
 		break;
 
 	case 39:
-		*animation = 132;
+		*animation = kModelAnimationGordoWithGunWithHostageGetsShot;
 		++_animationFrame;
 		if (_animationFrame == 6) {
 			Actor_Set_Goal_Number(kActorTaffyPatron, 250);
 			Actor_Change_Animation_Mode(kActorGordo, kAnimationModeCombatDie);
-			*animation = 100;
+			*animation = kModelAnimationGordoWithGunShotDead;
 			_animationFrame = 0;
 			_animationState = 24;
 		}
@@ -1224,23 +1257,37 @@ bool AIScriptGordo::ChangeAnimationMode(int mode) {
 		switch (_animationState) {
 		case 0:
 			break;
+
 		case 2:
+			// fall through
 		case 13:
 			Actor_Change_Animation_Mode(kActorGordo, kAnimationModeSit);
 			break;
+
 		case 4:
+			// fall through
 		case 5:
+			// fall through
 		case 6:
+			// fall through
 		case 7:
+			// fall through
 		case 8:
+			// fall through
 		case 9:
+			// fall through
 		case 10:
+			// fall through
 		case 11:
+			// fall through
 		case 12:
+			// fall through
 		case 36:
+			// fall through
 		case 37:
-			var_45B078 = 1;
+			_resumeIdleAfterFramesetCompletesFlag = true;
 			break;
+
 		default:
 			_animationState = 0;
 			_animationFrame = 0;
@@ -1261,34 +1308,45 @@ bool AIScriptGordo::ChangeAnimationMode(int mode) {
 		break;
 
 	case kAnimationModeTalk:
-		if (_animationState) {
+		if (_animationState > 0) {
 			_animationState = 4;
 			_animationFrame = 0;
 		} else {
 			_animationState = 1;
 			_animationStateNext = 4;
-			_animationNext = 120;
+			_animationNext = kModelAnimationGordoIdleTalk;
 		}
-		var_45B078 = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case kAnimationModeCombatIdle:
 		switch (_animationState) {
 		case 14:
+			// fall through
 		case 16:
+			// fall through
 		case 17:
+			// fall through
 		case 18:
+			// fall through
 		case 21:
+			// fall through
 		case 22:
 			break;
+
 		case 15:
+			// fall through
 		case 27:
+			// fall through
 		case 28:
+			// fall through
 		case 31:
+			// fall through
 		case 32:
 			_animationState = 16;
 			_animationFrame = 0;
 			break;
+
 		default:
 			_animationState = 14;
 			_animationFrame = 0;
@@ -1312,106 +1370,109 @@ bool AIScriptGordo::ChangeAnimationMode(int mode) {
 		break;
 
 	case 12:
-		if (_animationState) {
+		if (_animationState > 0) {
 			_animationState = 5;
 			_animationFrame = 0;
 		} else {
 			_animationState = 1;
 			_animationStateNext = 5;
-			_animationNext = 121;
+			_animationNext = kModelAnimationGordoSuggestingTalk;
 		}
-		var_45B078 = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 13:
-		if (_animationState) {
+		if (_animationState > 0) {
 			_animationState = 6;
 			_animationFrame = 0;
 		} else {
 			_animationState = 1;
 			_animationStateNext = 6;
-			_animationNext = 122;
+			_animationNext = kModelAnimationGordoSuggestAndPointTalk;
 		}
-		var_45B078 = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 14:
-		if (_animationState) {
+		if (_animationState > 0) {
 			_animationState = 7;
 			_animationFrame = 0;
 		} else {
 			_animationState = 1;
 			_animationStateNext = 7;
-			_animationNext = 123;
+			_animationNext = kModelAnimationGordoSuggestAndDismissTalk;
 		}
-		var_45B078 = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 15:
-		if (_animationState) {
+		if (_animationState > 0) {
 			_animationState = 8;
 			_animationFrame = 0;
 		} else {
 			_animationState = 1;
 			_animationStateNext = 8;
-			_animationNext = 124;
+			_animationNext = kModelAnimationGordoDismissiveTalk;
 		}
-		var_45B078 = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 16:
-		if (_animationState) {
+		if (_animationState > 0) {
 			_animationState = 9;
 			_animationFrame = 0;
 		} else {
 			_animationState = 1;
 			_animationStateNext = 9;
-			_animationNext = 125;
+			_animationNext = kModelAnimationGordoUpsetTalk;
 		}
-		var_45B078 = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 17:
-		if (_animationState) {
+		if (_animationState > 0) {
 			_animationState = 10;
 			_animationFrame = 0;
 		} else {
 			_animationState = 1;
 			_animationStateNext = 10;
-			_animationNext = 126;
+			_animationNext = kModelAnimationGordoExplainAndPointTalk;
 		}
-		var_45B078 = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 18:
-		if (_animationState) {
+		if (_animationState > 0) {
 			_animationState = 11;
 			_animationFrame = 0;
 		} else {
 			_animationState = 1;
 			_animationStateNext = 11;
-			_animationNext = 127;
+			_animationNext = kModelAnimationGordoAdjustBowtieTalk;
 		}
-		var_45B078 = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 19:
-		if (_animationState) {
+		if (_animationState > 0) {
 			_animationState = 12;
 			_animationFrame = 0;
 		} else {
 			_animationState = 1;
 			_animationStateNext = 12;
-			_animationNext = 127;
+			_animationNext = kModelAnimationGordoAdjustBowtieTalk;
 		}
-		var_45B078 = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case kAnimationModeHit:
 		switch (_animationState) {
 		case 14:
+			// fall through
 		case 16:
+			// fall through
 		case 17:
+			// fall through
 		case 18:
 			if (Random_Query(0, 1)) {
 				_animationState = 21;
@@ -1420,11 +1481,16 @@ bool AIScriptGordo::ChangeAnimationMode(int mode) {
 			}
 			_animationFrame = 0;
 			break;
+
 		case 19:
+			// fall through
 		case 20:
+			// fall through
 		case 21:
+			// fall through
 		case 22:
 			return true;
+
 		default:
 			if (Random_Query(0, 1)) {
 				_animationState = 19;
@@ -1488,16 +1554,24 @@ bool AIScriptGordo::ChangeAnimationMode(int mode) {
 	case kAnimationModeDie:
 		switch (_animationState) {
 		case 14:
+			// fall through
 		case 16:
+			// fall through
 		case 17:
+			// fall through
 		case 18:
+			// fall through
 		case 19:
+			// fall through
 		case 20:
+			// fall through
 		case 21:
+			// fall through
 		case 22:
 			_animationState = 24;
 			_animationFrame = 0;
 			break;
+
 		default:
 			_animationState = 23;
 			_animationFrame = 0;
@@ -1523,13 +1597,13 @@ bool AIScriptGordo::ChangeAnimationMode(int mode) {
 	case 81:
 		_animationState = 36;
 		_animationFrame = 0;
-		var_45B078 = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 82:
 		_animationState = 37;
 		_animationFrame = 0;
-		var_45B078 = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 83:
@@ -1670,12 +1744,15 @@ void AIScriptGordo::talkToMcCoyInCity() {
 			case 1:
 				Actor_Says(kActorMcCoy, 6460, 13);
 				break;
+
 			case 2:
 				Actor_Says(kActorMcCoy, 6550, 14);
 				break;
+
 			case 3:
 				Actor_Says(kActorMcCoy, 365, 12);
 				break;
+
 			case 4:
 				Actor_Says(kActorMcCoy, 525, 12);
 				break;
@@ -1709,7 +1786,7 @@ void AIScriptGordo::talkToMcCoyAtNR02() {
 }
 
 void AIScriptGordo::dialogue2() {
-	Music_Stop(5);
+	Music_Stop(5u);
 	Dialogue_Menu_Clear_List();
 	DM_Add_To_List_Never_Repeat_Once_Selected(820, -1, 5,  7); // ARREST
 	DM_Add_To_List_Never_Repeat_Once_Selected(830,  7, 5, -1); // LET GO
@@ -1817,7 +1894,12 @@ void AIScriptGordo::dialogue1() {
 		Actor_Says(kActorGordo, 500, 13);
 		Actor_Says(kActorMcCoy, 3290, 16);
 		Actor_Says(kActorGordo, 510, 15);
+#if BLADERUNNER_ORIGINAL_BUGS
 		Actor_Says(kActorMcCoy, 3295, 14);
+#else
+		// McCoy is kind of interrupted here
+		Actor_Says_With_Pause(kActorMcCoy, 3295, 0.0f, 14);
+#endif // BLADERUNNER_ORIGINAL_BUGS
 		Actor_Says(kActorGordo, 520, 12);
 		Actor_Modify_Friendliness_To_Other(kActorGordo, kActorMcCoy, -4);
 		break;
@@ -1831,7 +1913,12 @@ void AIScriptGordo::dialogue1() {
 		Actor_Says(kActorGordo, 500, 13);
 		Actor_Says(kActorMcCoy, 3290, 16);
 		Actor_Says(kActorGordo, 510, 15);
+#if BLADERUNNER_ORIGINAL_BUGS
 		Actor_Says(kActorMcCoy, 3295, 14);
+#else
+		// McCoy is kind of interrupted here
+		Actor_Says_With_Pause(kActorMcCoy, 3295, 0.0f, 14);
+#endif // BLADERUNNER_ORIGINAL_BUGS
 		Actor_Says(kActorGordo, 520, 12);
 		Actor_Modify_Friendliness_To_Other(kActorGordo, kActorMcCoy, -1);
 		break;
@@ -1861,21 +1948,28 @@ void AIScriptGordo::unknown() {
 	switch (_animationState) {
 	case 0:
 		break;
+
 	case 1:
+		// fall through
 	case 3:
+		// fall through
 	case 38:
+		// fall through
 	case 39:
 		_animationState = 0;
 		_animationFrame = 0;
 		_state = 0;
 		_counterTarget = 0;
 		break;
+
 	case 2:
+		// fall through
 	case 13:
 		Actor_Change_Animation_Mode(kActorGordo, 53);
 		break;
+
 	default:
-		var_45B078 = 1;
+		_resumeIdleAfterFramesetCompletesFlag = true;
 		break;
 	}
 }
