@@ -25,13 +25,14 @@
 namespace BladeRunner {
 
 AIScriptGrigorian::AIScriptGrigorian(BladeRunnerEngine *vm) : AIScriptBase(vm) {
-	var_45CA10 = 0;
-	var_45CA14 = 0;
+	// _varChooseIdleAnimation can have valid values: 0, 1, 2
+	_varChooseIdleAnimation = 0;
+	_varNumOfTimesToHoldCurrentFrame = 0;
 }
 
 void AIScriptGrigorian::Initialize() {
-	var_45CA10 = 0;
-	var_45CA14 = 0;
+	_varChooseIdleAnimation = 0;
+	_varNumOfTimesToHoldCurrentFrame = 0;
 	_animationStateNext = 0;
 	_animationFrame = 0;
 	_animationState = 0;
@@ -102,106 +103,125 @@ bool AIScriptGrigorian::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 bool AIScriptGrigorian::UpdateAnimation(int *animation, int *frame) {
 	switch (_animationState) {
 	case 0:
-		if (var_45CA10 == 0) {
-			*animation = 478;
-			if (var_45CA14) {
-				--var_45CA14;
+		if (_varChooseIdleAnimation == 0) {
+			*animation = kModelAnimationGrigorianStandIdle;
+			if (_varNumOfTimesToHoldCurrentFrame > 0) {
+				--_varNumOfTimesToHoldCurrentFrame;
 			} else {
 				++_animationFrame;
 				if (_animationFrame == 5 || _animationFrame == 13) {
-					var_45CA14 = Random_Query(2, 4);
+					_varNumOfTimesToHoldCurrentFrame = Random_Query(2, 4);
 				}
-				if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(478)) {
+				if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGrigorianStandIdle)) {
 					_animationFrame = 0;
-					var_45CA10 = Random_Query(0, 2);
+					_varChooseIdleAnimation = Random_Query(0, 2);
 				}
 			}
-		} else if (var_45CA10 == 1) {
-			*animation = 479;
+		} else if (_varChooseIdleAnimation == 1) {
+			*animation = kModelAnimationGrigorianStandAnnoyedTalk;
 			++_animationFrame;
-			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(479)) {
-				*animation = 478;
+			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGrigorianStandAnnoyedTalk)) {
+				*animation = kModelAnimationGrigorianStandIdle;
 				_animationFrame = 0;
-				var_45CA10 = 0;
+				_varChooseIdleAnimation = 0;
 			}
-		} else if (var_45CA10 == 2) {
-			*animation = 480;
-			if (var_45CA14) {
-				--var_45CA14;
+		} else if (_varChooseIdleAnimation == 2) {
+			*animation = kModelAnimationGrigorianStandArmsCrossedTalk;
+			if (_varNumOfTimesToHoldCurrentFrame > 0) {
+				--_varNumOfTimesToHoldCurrentFrame;
 			} else {
 				++_animationFrame;
 				if (_animationFrame >= 8 && _animationFrame <= 10) {
-					var_45CA14 = Random_Query(2, 4);
+					_varNumOfTimesToHoldCurrentFrame = Random_Query(2, 4);
 				}
-				if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(478)) {
-					*animation = 478;
+#if BLADERUNNER_ORIGINAL_BUGS
+				if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGrigorianStandIdle)) {
+					*animation = kModelAnimationGrigorianStandIdle;
 					_animationFrame = 0;
-					var_45CA10 = 0;
+					_varChooseIdleAnimation = 0;
 				}
+#else
+				// bugfix set proper current animation here to get frameset number of frames
+				//        (could also use *animation)
+				if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGrigorianStandArmsCrossedTalk)) {
+					*animation = kModelAnimationGrigorianStandIdle;
+					_animationFrame = 0;
+					_varChooseIdleAnimation = 0;
+				}
+#endif // BLADERUNNER_ORIGINAL_BUGS
 			}
 		}
 		break;
+
 	case 1:
-		*animation = 479;
+		*animation = kModelAnimationGrigorianStandAnnoyedTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(479)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGrigorianStandAnnoyedTalk)) {
 			_animationFrame = 0;
 		}
 		break;
+
 	case 2:
-		*animation = 481;
+		*animation = kModelAnimationGrigorianStandProtestTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(481)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGrigorianStandProtestTalk)) {
 			_animationFrame = 0;
 		}
 		break;
+
 	case 3:
-		*animation = 482;
+		*animation = kModelAnimationGrigorianStandProtestMoreTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(482)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGrigorianStandProtestMoreTalk)) {
 			_animationState = 2;
 			_animationFrame = 0;
-			*animation = 481;
+			*animation = kModelAnimationGrigorianStandProtestTalk;
 		}
 		break;
+
 	case 4:
-		*animation = 483;
+		*animation = kModelAnimationGrigorianStandProtestEvenMoreTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(483)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGrigorianStandProtestEvenMoreTalk)) {
 			_animationState = 2;
 			_animationFrame = 0;
-			*animation = 481;
+			*animation = kModelAnimationGrigorianStandProtestTalk;
 		}
 		break;
+
 	case 5:
-		*animation = 484;
+		*animation = kModelAnimationGrigorianStandInsistentTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(484)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGrigorianStandInsistentTalk)) {
 			_animationState = 2;
 			_animationFrame = 0;
-			*animation = 481;
+			*animation = kModelAnimationGrigorianStandProtestTalk;
 		}
 		break;
+
 	case 6:
-		*animation = 485;
+		*animation = kModelAnimationGrigorianStandDismissOrAccuseTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(485)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGrigorianStandDismissOrAccuseTalk)) {
 			_animationState = 2;
 			_animationFrame = 0;
-			*animation = 481;
+			*animation = kModelAnimationGrigorianStandProtestTalk;
 		}
 		break;
+
 	case 7:
-		*animation = 486;
+		*animation = kModelAnimationGrigorianStandBegOrMockingTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(486)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationGrigorianStandBegOrMockingTalk)) {
 			_animationState = 2;
 			_animationFrame = 0;
-			*animation = 481;
+			*animation = kModelAnimationGrigorianStandProtestTalk;
 		}
 		break;
+
 	default:
-		*animation = 399;
+		// Dummy placeholder, kModelAnimationZubenWalking (399) is a Zuben animation
+		*animation = kModelAnimationZubenWalking;
 		break;
 	}
 	*frame = _animationFrame;
@@ -214,32 +234,40 @@ bool AIScriptGrigorian::ChangeAnimationMode(int mode) {
 		_animationState = 0;
 		_animationFrame = 0;
 		break;
+
 	case kAnimationModeWalk:
+		// TODO A bug? This animation state is not for walking. It is for kModelAnimationGrigorianStandAnnoyedTalk.
 		if (_animationState != 1) {
 			_animationState = 1;
 			_animationFrame = 0;
 		}
 		break;
+
 	case kAnimationModeTalk:
 		_animationState = 2;
 		_animationFrame = 0;
 		break;
+
 	case 12:
 		_animationState = 3;
 		_animationFrame = 0;
 		break;
+
 	case 13:
 		_animationState = 4;
 		_animationFrame = 0;
 		break;
+
 	case 14:
 		_animationState = 5;
 		_animationFrame = 0;
 		break;
+
 	case 15:
 		_animationState = 6;
 		_animationFrame = 0;
 		break;
+
 	case 16:
 		_animationState = 7;
 		_animationFrame = 0;
