@@ -25,7 +25,7 @@
 namespace BladeRunner {
 
 AIScriptMurray::AIScriptMurray(BladeRunnerEngine *vm) : AIScriptBase(vm) {
-	_flag = false;
+	_resumeIdleAfterFramesetCompletesFlag = false;
 }
 
 void AIScriptMurray::Initialize() {
@@ -34,7 +34,7 @@ void AIScriptMurray::Initialize() {
 	_animationStateNext = 0;
 	_animationNext = 0;
 
-	_flag = false;
+	_resumeIdleAfterFramesetCompletesFlag = false;
 	Actor_Put_In_Set(kActorMurray, kSetHF01);
 	Actor_Set_At_XYZ(kActorMurray, 566.07f, -0.01f, -205.43f, 271);
 	Actor_Set_Goal_Number(kActorMurray, 0);
@@ -123,68 +123,68 @@ bool AIScriptMurray::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 bool AIScriptMurray::UpdateAnimation(int *animation, int *frame) {
 	switch (_animationState) {
 	case 0:
-		*animation = 698;
+		*animation = kModelAnimationMurrayIdle;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(698))
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMurrayIdle))
 			_animationFrame = 0;
 		break;
 
 	case 1:
-		*animation = 700;
-		if (!_animationFrame && _flag) {
+		*animation = kModelAnimationMurrayCalmTalk;
+		if (_animationFrame == 0 && _resumeIdleAfterFramesetCompletesFlag) {
 			_animationState = 0;
 		} else {
 			++_animationFrame;
-			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(700))
+			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMurrayCalmTalk))
 				_animationFrame = 0;
 		}
 		break;
 
 	case 2:
-		*animation = 701;
+		*animation = kModelAnimationMurrayMoreCalmTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(701)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMurrayMoreCalmTalk)) {
 			_animationFrame = 0;
 			_animationState = 1;
-			*animation = 700;
+			*animation = kModelAnimationMurrayCalmTalk;
 		}
 		break;
 
 	case 3:
-		*animation = 702;
+		*animation = kModelAnimationMurrayExplainTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(702)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMurrayExplainTalk)) {
 			_animationFrame = 0;
 			_animationState = 1;
-			*animation = 700;
+			*animation = kModelAnimationMurrayCalmTalk;
 		}
 		break;
 
 	case 4:
-		*animation = 703;
+		*animation = kModelAnimationMurrayMoreExplainTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(703)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMurrayMoreExplainTalk)) {
 			_animationFrame = 0;
 			_animationState = 1;
-			*animation = 700;
+			*animation = kModelAnimationMurrayCalmTalk;
 		}
 		break;
 
 	case 5:
-		*animation = 704;
+		*animation = kModelAnimationMurrayCautionTalk;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(704)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMurrayCautionTalk)) {
 			_animationFrame = 0;
 			_animationState = 1;
-			*animation = 700;
+			*animation = kModelAnimationMurrayCalmTalk;
 		}
 		break;
 
 	case 6:
-		*animation = 699;
+		*animation = kModelAnimationMurrayGestureGive;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(699)) {
-			*animation = 698;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMurrayGestureGive)) {
+			*animation = kModelAnimationMurrayIdle;
 			_animationFrame = 0;
 			_animationState = 0;
 		}
@@ -203,7 +203,7 @@ bool AIScriptMurray::ChangeAnimationMode(int mode) {
 	switch (mode) {
 	case kAnimationModeIdle:
 		if (_animationState > 0 && _animationState <= 5) {
-			_flag = true;
+			_resumeIdleAfterFramesetCompletesFlag = true;
 		} else {
 			_animationState = 0;
 			_animationFrame = 0;
@@ -213,31 +213,31 @@ bool AIScriptMurray::ChangeAnimationMode(int mode) {
 	case kAnimationModeTalk:
 		_animationState = 1;
 		_animationFrame = 0;
-		_flag = false;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 12:
 		_animationState = 2;
 		_animationFrame = 0;
-		_flag = false;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 13:
 		_animationState = 3;
 		_animationFrame = 0;
-		_flag = false;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 14:
 		_animationState = 4;
 		_animationFrame = 0;
-		_flag = false;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 15:
 		_animationState = 5;
 		_animationFrame = 0;
-		_flag = false;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 	}
 
