@@ -25,7 +25,7 @@
 namespace BladeRunner {
 
 AIScriptMutant2::AIScriptMutant2(BladeRunnerEngine *vm) : AIScriptBase(vm) {
-	_flag = 0;
+	_resumeIdleAfterFramesetCompletesFlag = false;
 	_var1 = 1;
 }
 
@@ -35,7 +35,7 @@ void AIScriptMutant2::Initialize() {
 	_animationStateNext = 0;
 	_animationNext = 0;
 
-	_flag = 0;
+	_resumeIdleAfterFramesetCompletesFlag = false;
 	_var1 = 1;
 
 	Actor_Put_In_Set(kActorMutant2, kSetFreeSlotG);
@@ -71,7 +71,12 @@ bool AIScriptMutant2::Update() {
 
 		case 599:
 			if (Actor_Query_Which_Set_In(kActorMutant2) != Player_Query_Current_Set()) {
+#if BLADERUNNER_ORIGINAL_BUGS
 				Actor_Set_Goal_Number(kActorMutant2, 403);
+#else
+				// intermediate goal to set new Health (revive for reuse)
+				Actor_Set_Goal_Number(kActorMutant2, 411);
+#endif // BLADERUNNER_ORIGINAL_BUGS
 			}
 			break;
 		}
@@ -320,30 +325,35 @@ bool AIScriptMutant2::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			break;
 
 		case kSetUG04:
+			// fall through
 		case kSetUG05:
+			// fall through
 		case kSetUG06:
 			Non_Player_Actor_Combat_Mode_On(kActorMutant2, kActorCombatStateIdle, false, kActorMcCoy, 10, kAnimationModeCombatIdle, kAnimationModeCombatWalk, kAnimationModeCombatRun, -1, -1, -1, 10, 300, false);
 			break;
 
 		case kSetUG10:
+			// fall through
 		case kSetUG12:
+			// fall through
 		case kSetUG14:
 			Non_Player_Actor_Combat_Mode_On(kActorMutant2, kActorCombatStateIdle, false, kActorMcCoy, 14, kAnimationModeCombatIdle, kAnimationModeCombatWalk, kAnimationModeCombatRun, -1, -1, -1, 10, 300, false);
 			break;
 		}
 		return true;
 
-	case 590:
+#if BLADERUNNER_ORIGINAL_BUGS
+#else
+	case 411:
+		// We need the additional intermediate goal 411 (as mutant1 has)
+		// so that we set the health here, instead of the when the goal is set to 599 (dying)
+		// Setting the health "revives" the mutant, which would result in their bound box being reduced to a point
+		// (see Actor::setHealth() call to retire(false, 0, 0, -1))
+		// and thus their corpse being unclickable after McCoy shot them.
+		// Goal 411 does this, but is set only when McCoy is no longer present in the scene/set.
 		AI_Movement_Track_Flush(kActorMutant2);
-		AI_Movement_Track_Append(kActorMutant2, 39, 100);
-		AI_Movement_Track_Repeat(kActorMutant2);
-		return true;
-
-	case 599:
-		AI_Movement_Track_Flush(kActorMutant2);
-		Actor_Change_Animation_Mode(kActorMutant2, 48);
 		Actor_Set_Intelligence(kActorMutant2, 20);
-		Actor_Set_Health(71, 10 * Query_Difficulty_Level() + 50, 10 * Query_Difficulty_Level() + 50);
+		Actor_Set_Health(kActorMutant2, 10 * Query_Difficulty_Level() + 50, 10 * Query_Difficulty_Level() + 50);
 
 		if (Game_Flag_Query(kFlagCT04HomelessKilledByMcCoy)) {
 			Actor_Set_Combat_Aggressiveness(kActorMutant2, 60);
@@ -353,6 +363,39 @@ bool AIScriptMutant2::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			Actor_Set_Friendliness_To_Other(kActorMutant2, kActorMcCoy, 50);
 		}
 
+		// code repeated also in case 599 which precedes this one
+		// redundant?
+		// results in additional reduction in friendliness and increase of aggressiveness for the other two mutants
+		Actor_Modify_Friendliness_To_Other(kActorMutant1, kActorMcCoy, -15);
+		Actor_Modify_Friendliness_To_Other(kActorMutant3, kActorMcCoy, -20);
+		Actor_Modify_Combat_Aggressiveness(kActorMutant1, 10);
+		Actor_Modify_Combat_Aggressiveness(kActorMutant3, 15);
+		Actor_Set_Goal_Number(kActorMutant2, 403);
+		return true;
+#endif // BLADERUNNER_ORIGINAL_BUGS
+
+	case 590:
+		AI_Movement_Track_Flush(kActorMutant2);
+		AI_Movement_Track_Append(kActorMutant2, 39, 100);
+		AI_Movement_Track_Repeat(kActorMutant2);
+		return true;
+
+	case 599:
+		AI_Movement_Track_Flush(kActorMutant2);
+		Actor_Change_Animation_Mode(kActorMutant2, kAnimationModeDie);
+#if BLADERUNNER_ORIGINAL_BUGS
+		Actor_Set_Intelligence(kActorMutant2, 20);
+		Actor_Set_Health(kActorMutant2, 10 * Query_Difficulty_Level() + 50, 10 * Query_Difficulty_Level() + 50);
+
+		if (Game_Flag_Query(kFlagCT04HomelessKilledByMcCoy)) {
+			Actor_Set_Combat_Aggressiveness(kActorMutant2, 60);
+			Actor_Set_Friendliness_To_Other(kActorMutant2, kActorMcCoy, 30);
+		} else {
+			Actor_Set_Combat_Aggressiveness(kActorMutant2, 40);
+			Actor_Set_Friendliness_To_Other(kActorMutant2, kActorMcCoy, 50);
+		}
+#endif // BLADERUNNER_ORIGINAL_BUGS
+		// results in additional reduction in friendliness and increase of aggressiveness for the other two mutants
 		Actor_Modify_Friendliness_To_Other(kActorMutant1, kActorMcCoy, -15);
 		Actor_Modify_Friendliness_To_Other(kActorMutant3, kActorMcCoy, -20);
 		Actor_Modify_Combat_Aggressiveness(kActorMutant1, 10);
@@ -366,54 +409,54 @@ bool AIScriptMutant2::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 bool AIScriptMutant2::UpdateAnimation(int *animation, int *frame) {
 	switch (_animationState) {
 	case 0:
-		*animation = 903;
+		*animation = kModelAnimationMutant2Idle;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(903)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant2Idle)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 1:
-		*animation = 901;
+		*animation = kModelAnimationMutant2Walking;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(901)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant2Walking)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 2:
-		*animation = 902;
+		*animation = kModelAnimationMutant2Running;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(902)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant2Running)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 3:
-		if (!_animationFrame && _flag) {
-			*animation = 903;
+		if (_animationFrame == 0 && _resumeIdleAfterFramesetCompletesFlag) {
+			*animation = kModelAnimationMutant2Idle;
 			_animationState = 0;
 		} else {
-			*animation = 905;
+			*animation = kModelAnimationMutant2YellOrHurt;
 			++_animationFrame;
-			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(905)) {
+			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant2YellOrHurt)) {
 				_animationFrame = 0;
 			}
 		}
 		break;
 
 	case 4:
-		*animation = 905;
+		*animation = kModelAnimationMutant2YellOrHurt;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(905)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant2YellOrHurt)) {
 			_animationFrame = 0;
 			_animationState = 3;
-			*animation = 904;
+			*animation = kModelAnimationMutant2CalmTalk;
 		}
 		break;
 
 	case 5:
-		*animation = 906;
+		*animation = kModelAnimationMutant2MeleeAttack;
 		++_animationFrame;
 		if (_animationFrame == 7) {
 			int snd;
@@ -427,13 +470,13 @@ bool AIScriptMutant2::UpdateAnimation(int *animation, int *frame) {
 		if (_animationFrame == 9) {
 			Actor_Combat_AI_Hit_Attempt(kActorMutant2);
 		}
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(906)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant2MeleeAttack)) {
 			Actor_Change_Animation_Mode(kActorMutant2, kAnimationModeIdle);
 		}
 		break;
 
 	case 6:
-		*animation = 907;
+		*animation = kModelAnimationMutant2ShotDead;
 		++_animationFrame;
 		if (_animationFrame == 1) {
 			Sound_Play(kSfxYELL1M2, 100, 0, 0, 50);
@@ -444,18 +487,19 @@ bool AIScriptMutant2::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 7:
-		*animation = 907;
-		_animationFrame = Slice_Animation_Query_Number_Of_Frames(907) - 2;
+		*animation = kModelAnimationMutant2ShotDead;
+		// TODO why "- 2" here?
+		_animationFrame = Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant2ShotDead) - 2;
 		break;
 
 	case 8:
-		*animation = 907;
+		*animation = kModelAnimationMutant2ShotDead;
 		_animationFrame += _var1;
 		if (_animationFrame == 4) {
 			_var1 = -1;
 			Sound_Play(kSfxHURT1M2, 100, 0, 0, 50);
 		} else {
-			if (!_animationFrame) {
+			if (_animationFrame == 0) {
 				Actor_Change_Animation_Mode(kActorMutant2, kAnimationModeIdle);
 			}
 		}
@@ -473,7 +517,7 @@ bool AIScriptMutant2::ChangeAnimationMode(int mode) {
 	switch (mode) {
 	case 0:
 		if (_animationState >= 3 && _animationState <= 4) {
-			_flag = 1;
+			_resumeIdleAfterFramesetCompletesFlag = true;
 		} else {
 			_animationState = 0;
 			_animationFrame = 0;
@@ -481,12 +525,14 @@ bool AIScriptMutant2::ChangeAnimationMode(int mode) {
 		break;
 
 	case 1:
+		// fall through
 	case 7:
 		_animationState = 1;
 		_animationFrame = 0;
 		break;
 
 	case 2:
+		// fall through
 	case 8:
 		_animationState = 2;
 		_animationFrame = 0;
@@ -495,12 +541,12 @@ bool AIScriptMutant2::ChangeAnimationMode(int mode) {
 	case 3:
 		_animationState = 3;
 		_animationFrame = 0;
-		_flag = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 4:
 		if (_animationState >= 3 && _animationState <= 4) {
-			_flag = 1;
+			_resumeIdleAfterFramesetCompletesFlag = true;
 		} else {
 			_animationState = 0;
 			_animationFrame = 0;
@@ -515,10 +561,11 @@ bool AIScriptMutant2::ChangeAnimationMode(int mode) {
 	case 12:
 		_animationState = 3;
 		_animationFrame = 0;
-		_flag = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 21:
+		// fall through
 	case 22:
 		_animationState = 8;
 		_animationFrame = 0;
@@ -532,7 +579,7 @@ bool AIScriptMutant2::ChangeAnimationMode(int mode) {
 
 	case 88:
 		_animationState = 7;
-		_animationFrame = Slice_Animation_Query_Number_Of_Frames(907) - 1;
+		_animationFrame = Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant2ShotDead) - 1;
 		break;
 	}
 
