@@ -26,7 +26,7 @@ namespace BladeRunner {
 
 AIScriptMutant3::AIScriptMutant3(BladeRunnerEngine *vm) : AIScriptBase(vm) {
 	_var1 = 1;
-	_flag = 0;
+	_resumeIdleAfterFramesetCompletesFlag = false;
 }
 
 void AIScriptMutant3::Initialize() {
@@ -36,7 +36,7 @@ void AIScriptMutant3::Initialize() {
 	_animationNext = 0;
 
 	_var1 = 1;
-	_flag = 0;
+	_resumeIdleAfterFramesetCompletesFlag = false;
 
 	Actor_Put_In_Set(kActorMutant3, kSetFreeSlotG);
 	Actor_Set_At_Waypoint(kActorMutant3, 39, 0);
@@ -71,7 +71,12 @@ bool AIScriptMutant3::Update() {
 
 		case 599:
 			if (Actor_Query_Which_Set_In(kActorMutant3) != Player_Query_Current_Set()) {
+#if BLADERUNNER_ORIGINAL_BUGS
 				Actor_Set_Goal_Number(kActorMutant3, 403);
+#else
+				// intermediate goal to set new Health (revive for reuse)
+				Actor_Set_Goal_Number(kActorMutant3, 411);
+#endif // BLADERUNNER_ORIGINAL_BUGS
 			}
 			break;
 		}
@@ -331,28 +336,33 @@ bool AIScriptMutant3::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			break;
 
 		case kSetUG04:
+			// fall through
 		case kSetUG05:
+			// fall through
 		case kSetUG06:
 			Non_Player_Actor_Combat_Mode_On(kActorMutant3, kActorCombatStateIdle, false, kActorMcCoy, 10, kAnimationModeCombatIdle, kAnimationModeCombatWalk, kAnimationModeCombatRun, -1, -1, -1, 10, 300, false);
 			break;
 
 		case kSetUG10:
+			// fall through
 		case kSetUG12:
+			// fall through
 		case kSetUG14:
 			Non_Player_Actor_Combat_Mode_On(kActorMutant3, kActorCombatStateIdle, false, kActorMcCoy, 14, kAnimationModeCombatIdle, kAnimationModeCombatWalk, kAnimationModeCombatRun, -1, -1, -1, 10, 300, false);
 			break;
 		}
 		break;
 
-	case 590:
+#if BLADERUNNER_ORIGINAL_BUGS
+#else
+	case 411:
+		// We need the additional intermediate goal 411 (as mutant1 has)
+		// so that we set the health here, instead of the when the goal is set to 599 (dying)
+		// Setting the health "revives" the mutant, which would result in their bound box being reduced to a point
+		// (see Actor::setHealth() call to retire(false, 0, 0, -1))
+		// and thus their corpse being unclickable after McCoy shot them.
+		// Goal 411 does this, but is set only when McCoy is no longer present in the scene/set.
 		AI_Movement_Track_Flush(kActorMutant3);
-		AI_Movement_Track_Append(kActorMutant3, 39, 100);
-		AI_Movement_Track_Repeat(kActorMutant3);
-		break;
-
-	case 599:
-		AI_Movement_Track_Flush(kActorMutant3);
-		Actor_Change_Animation_Mode(kActorMutant3, 48);
 		Actor_Set_Intelligence(kActorMutant3, 40);
 		Actor_Set_Health(kActorMutant3, 10 * Query_Difficulty_Level() + 50, 10 * Query_Difficulty_Level() + 50);
 
@@ -364,6 +374,39 @@ bool AIScriptMutant3::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			Actor_Set_Friendliness_To_Other(kActorMutant3, kActorMcCoy, 40);
 		}
 
+		// code repeated also in case 599 which precedes this one
+		// redundant?
+		// results in additional reduction in friendliness and increase of aggressiveness for the other two mutants
+		Actor_Modify_Friendliness_To_Other(kActorMutant1, kActorMcCoy, 20);
+		Actor_Modify_Friendliness_To_Other(kActorMutant2, kActorMcCoy, 15);
+		Actor_Modify_Combat_Aggressiveness(kActorMutant1, 10);
+		Actor_Modify_Combat_Aggressiveness(kActorMutant2, 10);
+		Actor_Set_Goal_Number(kActorMutant3, 403);
+		return true;
+#endif // BLADERUNNER_ORIGINAL_BUGS
+
+	case 590:
+		AI_Movement_Track_Flush(kActorMutant3);
+		AI_Movement_Track_Append(kActorMutant3, 39, 100);
+		AI_Movement_Track_Repeat(kActorMutant3);
+		break;
+
+	case 599:
+		AI_Movement_Track_Flush(kActorMutant3);
+		Actor_Change_Animation_Mode(kActorMutant3, kAnimationModeDie);
+#if BLADERUNNER_ORIGINAL_BUGS
+		Actor_Set_Intelligence(kActorMutant3, 40);
+		Actor_Set_Health(kActorMutant3, 10 * Query_Difficulty_Level() + 50, 10 * Query_Difficulty_Level() + 50);
+
+		if (Game_Flag_Query(kFlagCT04HomelessKilledByMcCoy)) {
+			Actor_Set_Combat_Aggressiveness(kActorMutant3, 80);
+			Actor_Set_Friendliness_To_Other(kActorMutant3, kActorMcCoy, 20);
+		} else {
+			Actor_Set_Combat_Aggressiveness(kActorMutant3, 50);
+			Actor_Set_Friendliness_To_Other(kActorMutant3, kActorMcCoy, 40);
+		}
+#endif // BLADERUNNER_ORIGINAL_BUGS
+		// results in additional reduction in friendliness and increase of aggressiveness for the other two mutants
 		Actor_Modify_Friendliness_To_Other(kActorMutant1, kActorMcCoy, 20);
 		Actor_Modify_Friendliness_To_Other(kActorMutant2, kActorMcCoy, 15);
 		Actor_Modify_Combat_Aggressiveness(kActorMutant1, 10);
@@ -380,54 +423,54 @@ bool AIScriptMutant3::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 bool AIScriptMutant3::UpdateAnimation(int *animation, int *frame) {
 	switch (_animationState) {
 	case 0:
-		*animation = 910;
+		*animation = kModelAnimationMutant3Idle;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(910)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant3Idle)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 1:
-		*animation = 908;
+		*animation = kModelAnimationMutant3Walking;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(908)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant3Walking)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 2:
-		*animation = 909;
+		*animation = kModelAnimationMutant3Running;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(909)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant3Running)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 3:
-		if (!_animationFrame && _flag) {
-			*animation = 910;
+		if (_animationFrame == 0 && _resumeIdleAfterFramesetCompletesFlag) {
+			*animation = kModelAnimationMutant3Idle;
 			_animationState = 0;
 		} else {
-			*animation = 912;
+			*animation = kModelAnimationMutant3YellOrHurt;
 			++_animationFrame;
-			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(912)) {
+			if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant3YellOrHurt)) {
 				_animationFrame = 0;
 			}
 		}
 		break;
 
 	case 4:
-		*animation = 912;
+		*animation = kModelAnimationMutant3YellOrHurt;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(912)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant3YellOrHurt)) {
 			_animationFrame = 0;
 			_animationState = 3;
-			*animation = 911;
+			*animation = kModelAnimationMutant3CalmTalk;
 		}
 		break;
 
 	case 5:
-		*animation = 913;
+		*animation = kModelAnimationMutant3PicksUpAndThrowsRock;
 		++_animationFrame;
 		if (_animationFrame == 9) {
 			int snd;
@@ -447,61 +490,62 @@ bool AIScriptMutant3::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 6:
-		*animation = 917;
+		*animation = kModelAnimationMutant3ShotDead;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(917)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant3ShotDead)) {
 			Actor_Change_Animation_Mode(kActorMutant3, 88);
 		}
 		break;
 
 	case 7:
-		*animation = 917;
-		_animationFrame = Slice_Animation_Query_Number_Of_Frames(917) - 1;
+		*animation = kModelAnimationMutant3ShotDead;
+		_animationFrame = Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant3ShotDead) - 1;
 		break;
 
 	case 8:
-		*animation = 914;
+		*animation = kModelAnimationMutant3CrouchedWaiting;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(914)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant3CrouchedWaiting)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 9:
-		*animation = 916;
+		*animation = kModelAnimationMutant3CrouchedFromStanding;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(916)) {
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant3CrouchedFromStanding)) {
 			_animationFrame = 0;
 			_animationState = 8;
-			*animation = 914;
+			*animation = kModelAnimationMutant3CrouchedWaiting;
 		}
 		break;
 
 	case 10:
-		*animation = 915;
+		*animation = kModelAnimationMutant3CrouchedToStanding;
 		++_animationFrame;
-		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(915)) {
-			*animation = 910;
+		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant3CrouchedToStanding)) {
+			*animation = kModelAnimationMutant3Idle;
 			_animationFrame = 0;
 			_animationState = 0;
 		}
 		break;
 
 	case 11:
-		*animation = 917;
+		*animation = kModelAnimationMutant3ShotDead;
 		_animationFrame += _var1;
 		if (_animationFrame == 3) {
 			Sound_Play(kSfxHURT1M3, 100, 0, 0, 50);
 			_var1 = -1;
 		} else {
-			if (!_animationFrame) {
+			if (_animationFrame == 0) {
 				Actor_Change_Animation_Mode(kActorMutant3, kAnimationModeIdle);
 			}
 		}
 		break;
 
 	default:
-		*animation = 406;
+		// Dummy placeholder, kModelAnimationZubenIdle (406) is a Zuben animation
+		*animation = kModelAnimationZubenIdle;
 		break;
 	}
 	*frame = _animationFrame;
@@ -514,14 +558,14 @@ bool AIScriptMutant3::ChangeAnimationMode(int mode) {
 	case 0:
 		switch (_animationState) {
 		case 3:
+			// fall through
 		case 4:
-			_flag = 1;
+			_resumeIdleAfterFramesetCompletesFlag = true;
 			break;
 
 		case 8:
 			_animationState = 10;
 			_animationFrame = 0;
-
 			break;
 
 		case 10:
@@ -535,27 +579,30 @@ bool AIScriptMutant3::ChangeAnimationMode(int mode) {
 		break;
 
 	case 1:
+		// fall through
 	case 7:
 		_animationState = 1;
 		_animationFrame = 0;
 		break;
 
 	case 2:
+		// fall through
 	case 8:
 		_animationState = 2;
 		_animationFrame = 0;
 		break;
 
 	case 3:
+		// fall through
 	case 12:
 		_animationState = 3;
 		_animationFrame = 0;
-		_flag = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 4:
 		if (_animationState >= 3 && _animationState <= 4) {
-			_flag = 1;
+			_resumeIdleAfterFramesetCompletesFlag = true;
 		} else {
 			_animationState = 0;
 			_animationFrame = 0;
@@ -568,6 +615,7 @@ bool AIScriptMutant3::ChangeAnimationMode(int mode) {
 		break;
 
 	case 21:
+		// fall through
 	case 22:
 		_animationState = 11;
 		_animationFrame = 0;
@@ -576,7 +624,7 @@ bool AIScriptMutant3::ChangeAnimationMode(int mode) {
 
 	case 88:
 		_animationState = 7;
-		_animationFrame = Slice_Animation_Query_Number_Of_Frames(917) - 1;
+		_animationFrame = Slice_Animation_Query_Number_Of_Frames(kModelAnimationMutant3ShotDead) - 1;
 		break;
 
  	case 43:
