@@ -25,7 +25,7 @@
 namespace BladeRunner {
 
 AIScriptSebastian::AIScriptSebastian(BladeRunnerEngine *vm) : AIScriptBase(vm) {
-	_flag = false;
+	_resumeIdleAfterFramesetCompletesFlag = false;
 }
 
 void AIScriptSebastian::Initialize() {
@@ -34,7 +34,7 @@ void AIScriptSebastian::Initialize() {
 	_animationStateNext = 0;
 	_animationNext = 0;
 
-	_flag = false;
+	_resumeIdleAfterFramesetCompletesFlag = false;
 
 	Actor_Set_Goal_Number(kActorSebastian, 0);
 }
@@ -146,121 +146,121 @@ bool AIScriptSebastian::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 bool AIScriptSebastian::UpdateAnimation(int *animation, int *frame) {
 	switch (_animationState) {
 	case 0:
-		*animation = 811;
+		*animation = kModelAnimationSebastianIdle;
 		++_animationFrame;
-		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(811) - 1) {
+		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(kModelAnimationSebastianIdle) - 1) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 1:
-		*animation = 809;
+		*animation = kModelAnimationSebastianWalking;
 		++_animationFrame;
-		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(809) - 1) {
+		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(kModelAnimationSebastianWalking) - 1) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 2:
-		*animation = 810;
+		*animation = kModelAnimationSebastianStepsBack;
 		++_animationFrame;
-		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(810) - 1) {
+		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(kModelAnimationSebastianStepsBack) - 1) {
 			Actor_Change_Animation_Mode(kActorSebastian, kAnimationModeIdle);
-			*animation = 811;
+			*animation = kModelAnimationSebastianIdle;
 			_animationFrame = 0;
 			_animationState = 0;
 		}
 		break;
 
 	case 3:
-		*animation = 821;
-		if (_animationFrame < Slice_Animation_Query_Number_Of_Frames(821) - 1) {
+		*animation = kModelAnimationSebastianTriesToRunHitsHeadAndFalls;
+		if (_animationFrame < Slice_Animation_Query_Number_Of_Frames(kModelAnimationSebastianTriesToRunHitsHeadAndFalls) - 1) {
 			++_animationFrame;
 		}
 		break;
 
 	case 4:
-		if (!_animationFrame && _flag) {
+		if (_animationFrame == 0 && _resumeIdleAfterFramesetCompletesFlag) {
 			Actor_Change_Animation_Mode(kActorSebastian, kAnimationModeIdle);
-			*animation = 811;
+			*animation = kModelAnimationSebastianIdle;
 			_animationState = 0;
 			_animationFrame = 0;
 		} else {
-			*animation = 813;
+			*animation = kModelAnimationSebastianCalmHeadNodLeftTalk;
 			++_animationFrame;
-			if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(813) - 1) {
+			if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(kModelAnimationSebastianCalmHeadNodLeftTalk) - 1) {
 				_animationFrame = 0;
 			}
 		}
 		break;
 
 	case 5:
-		*animation = 814;
+		*animation = kModelAnimationSebastianCalmHeadNodRightTalk;
 		++_animationFrame;
-		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(814) - 1) {
+		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(kModelAnimationSebastianCalmHeadNodRightTalk) - 1) {
 			_animationFrame = 0;
 			_animationState = 4;
-			*animation = 813;
+			*animation = kModelAnimationSebastianCalmHeadNodLeftTalk;
 		}
 		break;
 
 	case 6:
-		*animation = 815;
+		*animation = kModelAnimationSebastianSuggestTalk;
 		++_animationFrame;
-		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(815) - 1) {
+		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(kModelAnimationSebastianSuggestTalk) - 1) {
 			_animationFrame = 0;
 			_animationState = 4;
-			*animation = 813;
+			*animation = kModelAnimationSebastianCalmHeadNodLeftTalk;
 		}
 		break;
 
 	case 7:
-		*animation = 816;
+		*animation = kModelAnimationSebastianWonderingTalk;
 		++_animationFrame;
-		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(816) - 1) {
+		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(kModelAnimationSebastianWonderingTalk) - 1) {
 			_animationFrame = 0;
 			_animationState = 4;
-			*animation = 813;
+			*animation = kModelAnimationSebastianCalmHeadNodLeftTalk;
 		}
 		break;
 
 	case 8:
-		*animation = 817;
+		*animation = kModelAnimationSebastianPointingToSelfTalk;
 		++_animationFrame;
-		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(817) - 1) {
+		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(kModelAnimationSebastianPointingToSelfTalk) - 1) {
 			_animationFrame = 0;
 			_animationState = 4;
-			*animation = 813;
+			*animation = kModelAnimationSebastianCalmHeadNodLeftTalk;
 		}
 		break;
 
 	case 9:
-		*animation = 818;
+		*animation = kModelAnimationSebastianScratchEarTalk;
 		++_animationFrame;
-		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(818) - 1) {
+		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(kModelAnimationSebastianScratchEarTalk) - 1) {
 			_animationFrame = 0;
 			_animationState = 4;
-			*animation = 813;
+			*animation = kModelAnimationSebastianCalmHeadNodLeftTalk;
 		}
 		break;
 
 	case 10:
-		*animation = 819;
+		*animation = kModelAnimationSebastianAnnoyedTalk;
 		++_animationFrame;
-		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(819) - 1) {
+		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(kModelAnimationSebastianAnnoyedTalk) - 1) {
 			_animationFrame = 0;
 			_animationState = 4;
-			*animation = 813;
+			*animation = kModelAnimationSebastianCalmHeadNodLeftTalk;
 		}
 		break;
 
 	case 11:
-		*animation = 820;
+		*animation = kModelAnimationSebastianWaitTalk;
 		++_animationFrame;
-		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(820) - 1) {
+		if (_animationFrame > Slice_Animation_Query_Number_Of_Frames(kModelAnimationSebastianWaitTalk) - 1) {
 			_animationFrame = 0;
 			_animationState = 4;
-			*animation = 813;
+			*animation = kModelAnimationSebastianCalmHeadNodLeftTalk;
 		}
 		break;
 
@@ -279,7 +279,7 @@ bool AIScriptSebastian::ChangeAnimationMode(int mode) {
 			_animationState = 0;
 			_animationFrame = 0;
 		} else {
-			_flag = true;
+			_resumeIdleAfterFramesetCompletesFlag = true;
 		}
 		break;
 
@@ -291,49 +291,49 @@ bool AIScriptSebastian::ChangeAnimationMode(int mode) {
 	case kAnimationModeTalk:
 		_animationState = 4;
 		_animationFrame = 0;
-		_flag = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 12:
 		_animationState = 5;
 		_animationFrame = 0;
-		_flag = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 13:
 		_animationState = 6;
 		_animationFrame = 0;
-		_flag = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 14:
 		_animationState = 7;
 		_animationFrame = 0;
-		_flag = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 15:
 		_animationState = 8;
 		_animationFrame = 0;
-		_flag = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 16:
 		_animationState = 9;
 		_animationFrame = 0;
-		_flag = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 17:
 		_animationState = 10;
 		_animationFrame = 0;
-		_flag = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 18:
 		_animationState = 11;
 		_animationFrame = 0;
-		_flag = 0;
+		_resumeIdleAfterFramesetCompletesFlag = false;
 		break;
 
 	case 20:
