@@ -129,14 +129,14 @@ void AIScriptZuben::TimerExpired(int timer) {
 		// return true;
 	} else if (timer == kActorTimerAIScriptCustomTask1) {
 		if (Actor_Query_Goal_Number(kActorZuben) == kGoalZubenCT02RunToFreeSlotG) { // Zuben fleeing, after 10s
-			Music_Stop(10);
+			Music_Stop(10u);
 			Actor_Set_Goal_Number(kActorZuben, kGoalZubenCT06HideAtFreeSlotA);
 			AI_Countdown_Timer_Reset(kActorZuben, kActorTimerAIScriptCustomTask1);
 			// return true;
 		}
 	} else if (timer == kActorTimerAIScriptCustomTask0) { // Zuben fleeing, after 70s
 		if (Player_Query_Current_Set() != kSetCT01_CT12) {
-			Music_Stop(2);
+			Music_Stop(2u);
 		}
 		Actor_Set_Goal_Number(kActorZuben, kGoalZubenFled); // Let Zuben flee completly, he will catch McCoy on MA01
 		AI_Countdown_Timer_Reset(kActorZuben, kActorTimerAIScriptCustomTask0);
@@ -162,7 +162,7 @@ void AIScriptZuben::CompletedMovementTrack() {
 		Game_Flag_Reset(kFlagCT02McCoyFell);
 		Game_Flag_Set(kFlagCT02McCoyCombatReady);
 		Game_Flag_Set(kFlagCT02McCoyShouldCommentOnDumpedSoup);
-		Music_Stop(2);
+		Music_Stop(2u);
 		Actor_Set_Goal_Number(kActorZuben, kGoalZubenFled);
 		Set_Enter(kSetCT02, kSceneCT02);
 		//return true;
@@ -171,7 +171,7 @@ void AIScriptZuben::CompletedMovementTrack() {
 		//return true;
 	} else {
 		if (Actor_Query_Goal_Number(kActorZuben) == kGoalZubenCT07RunToFreeSlotA) {
-			Music_Stop(2);
+			Music_Stop(2u);
 			Sound_Play(kSfxDOORLOCK, 40, 100, 100, 50);
 			Delay(2000);
 			Game_Flag_Set(kFlagCT07toCT06);
@@ -238,15 +238,15 @@ void AIScriptZuben::ClickedByPlayer() {
 	// return false;
 }
 
-void AIScriptZuben::EnteredScene(int sceneId) {
+void AIScriptZuben::EnteredSet(int setId) {
 	//return false;
 }
 
-void AIScriptZuben::OtherAgentEnteredThisScene(int otherActorId) {
+void AIScriptZuben::OtherAgentEnteredThisSet(int otherActorId) {
 	//return false;
 }
 
-void AIScriptZuben::OtherAgentExitedThisScene(int otherActorId) {
+void AIScriptZuben::OtherAgentExitedThisSet(int otherActorId) {
 	//return false;
 }
 
@@ -281,7 +281,7 @@ bool AIScriptZuben::ShotAtAndHit() {
 		Actor_Start_Speech_Sample(kActorMcCoy, 490);
 	}
 	if (Player_Query_Current_Scene() == kSceneCT07) {
-		Music_Stop(2);
+		Music_Stop(2u);
 	}
 	return false;
 }
@@ -303,7 +303,7 @@ void AIScriptZuben::Retired(int byActorId) {
 		Player_Set_Combat_Mode(false);
 		Loop_Actor_Walk_To_XYZ(kActorMcCoy, -12.0f, -41.58f, 72.0f, 0, true, false, false);
 		Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-		Ambient_Sounds_Remove_All_Looping_Sounds(1);
+		Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 		Game_Flag_Set(kFlagKP07toKP06);
 		Game_Flag_Reset(kFlagMcCoyIsHelpingReplicants);
 		Set_Enter(kSetKP05_KP06, kSceneKP06);
@@ -342,7 +342,7 @@ bool AIScriptZuben::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 	case kGoalZubenCT07Spared:
 		AI_Movement_Track_Flush(kActorZuben);
 		Actor_Face_Actor(kActorZuben, kActorMcCoy, true);
-		Music_Stop(3);
+		Music_Stop(3u);
 		Actor_Says(kActorZuben, 100, 19);
 		Actor_Says(kActorMcCoy, 470, 12);
 		Actor_Says(kActorZuben, 110, 18);
@@ -456,7 +456,7 @@ bool AIScriptZuben::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 		AI_Movement_Track_Flush(kActorZuben);
 #endif // BLADERUNNER_ORIGINAL_BUGS
 		Scene_Exits_Enable();
-		Music_Stop(2);
+		Music_Stop(2u);
 #if BLADERUNNER_ORIGINAL_BUGS
 #else
 		Actor_Set_Goal_Number(kActorZuben, kGoalZubenDie);
@@ -540,6 +540,7 @@ bool AIScriptZuben::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			}
 			return false;
 		}
+
 	case 106:
 		Actor_Set_Goal_Number(kActorZuben, 105);
 		return true;
@@ -564,6 +565,7 @@ bool AIScriptZuben::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			AI_Movement_Track_Append(kActorZuben, 39, 10); // kSetFreeSlotG
 			AI_Movement_Track_Repeat(kActorZuben);
 			break;
+
 		case 2:
 			AI_Movement_Track_Flush(kActorZuben);
 			AI_Movement_Track_Append(kActorZuben, 495, 0); // kSetNR02
@@ -571,6 +573,7 @@ bool AIScriptZuben::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			AI_Movement_Track_Append(kActorZuben, 33, Random_Query(15, 45));
 			AI_Movement_Track_Repeat(kActorZuben);
 			break;
+
 		case 3:
 			AI_Movement_Track_Append(kActorZuben, 498, 0); // kSetNR03
 			AI_Movement_Track_Append(kActorZuben, 497, 0);
@@ -579,6 +582,7 @@ bool AIScriptZuben::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			AI_Movement_Track_Append(kActorZuben, 39, 10);
 			AI_Movement_Track_Repeat(kActorZuben);
 			break;
+
 		case 4:
 			AI_Movement_Track_Flush(kActorZuben);
 			AI_Movement_Track_Append(kActorZuben, 499, 2); // kSetNR05_NR08
@@ -589,6 +593,7 @@ bool AIScriptZuben::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			AI_Movement_Track_Append(kActorZuben, 39, 10);
 			AI_Movement_Track_Repeat(kActorZuben);
 			break;
+
 		case 5:
 			AI_Movement_Track_Flush(kActorZuben);
 			AI_Movement_Track_Append(kActorZuben, 503, 0); // kSetNR05_NR08
@@ -599,6 +604,7 @@ bool AIScriptZuben::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			AI_Movement_Track_Append(kActorZuben, 39, 10);
 			AI_Movement_Track_Repeat(kActorZuben);
 			break;
+
 		case 6:
 			AI_Movement_Track_Flush(kActorZuben);
 			AI_Movement_Track_Append(kActorZuben, 508, 0); // kSetHF01
@@ -608,6 +614,7 @@ bool AIScriptZuben::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			AI_Movement_Track_Append(kActorZuben, 39, 10);
 			AI_Movement_Track_Repeat(kActorZuben);
 			break;
+
 		case 7:
 			AI_Movement_Track_Flush(kActorZuben);
 			AI_Movement_Track_Append(kActorZuben, 514, 0); // kSetHF03
@@ -617,6 +624,7 @@ bool AIScriptZuben::GoalChanged(int currentGoalNumber, int newGoalNumber) {
 			AI_Movement_Track_Append(kActorZuben, 39, 10);
 			AI_Movement_Track_Repeat(kActorZuben);
 			break;
+
 		case 8:
 			AI_Movement_Track_Flush(kActorZuben);
 			AI_Movement_Track_Append(kActorZuben, 510, 0); // kSetHF01
@@ -646,7 +654,7 @@ bool AIScriptZuben::UpdateAnimation(int *animation, int *frame) {
 	switch (_animationState) {
 	case 0:
 		if (Actor_Query_Goal_Number(kActorZuben) != kGoalZubenDefault) {
-			*animation = 408;
+			*animation = kModelAnimationZubenLooksAtSomeone;
 			if (_animationLoopCounter < _animationLoopLength) {
 				_animationFrame += _animationLoopDirection;
 				if (_animationFrame > _animationLoopFrameMax) {
@@ -656,7 +664,7 @@ bool AIScriptZuben::UpdateAnimation(int *animation, int *frame) {
 					_animationFrame = _animationLoopFrameMin;
 					_animationLoopDirection = 1;
 				}
-				_animationLoopCounter++;
+				++_animationLoopCounter;
 			} else {
 				_animationFrame += _animationLoopDirection;
 				_animationLoopLength = 0;
@@ -694,8 +702,8 @@ bool AIScriptZuben::UpdateAnimation(int *animation, int *frame) {
 				}
 			}
 		} else {
-			*animation = 418;
-			_animationFrame++;
+			*animation = kModelAnimationZubenPlayWithHands;
+			++_animationFrame;
 			if (_animationFrame >= 24) {
 				_animationFrame = 5;
 			}
@@ -704,40 +712,40 @@ bool AIScriptZuben::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 1:
-		*animation = 399;
-		_animationFrame++;
+		*animation = kModelAnimationZubenWalking;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 2:
-		*animation = 391;
-		_animationFrame++;
+		*animation = kModelAnimationZubenCombatWalking;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 3:
-		*animation = 400;
-		_animationFrame++;
+		*animation = kModelAnimationZubenRunning;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 4:
-		*animation = 392;
-		_animationFrame++;
+		*animation = kModelAnimationZubenCombatRunning;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 5:
-		*animation = 396;
-		_animationFrame++;
+		*animation = kModelAnimationZubenCombatUnholsterCleaver;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 			if (Actor_Query_Goal_Number(kActorZuben) == kGoalZubenCT02PotDodgeCheck) {
@@ -749,8 +757,8 @@ bool AIScriptZuben::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 6:
-		*animation = 397;
-		_animationFrame++;
+		*animation = kModelAnimationZubenCombatHolsterCleaver;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 			_animationState = 0;
@@ -758,16 +766,16 @@ bool AIScriptZuben::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 7:
-		*animation = 388;
-		_animationFrame++;
+		*animation = kModelAnimationZubenCombatIdle;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 8:
-		*animation = 398;
-		_animationFrame++;
+		*animation = kModelAnimationZubenCleaverAttack;
+		++_animationFrame;
 		if (_animationFrame == 8) {
 			int sentenceId;
 			if (Random_Query(1, 2) == 1) {
@@ -790,87 +798,87 @@ bool AIScriptZuben::UpdateAnimation(int *animation, int *frame) {
 			} else {
 				_animationFrame = 0;
 				_animationState = 7;
-				*animation = 388;
+				*animation = kModelAnimationZubenCombatIdle;
 				Actor_Change_Animation_Mode(kActorZuben, kAnimationModeCombatIdle);
 			}
 		}
 		break;
 
 	case 9:
-		*animation = 403;
-		_animationFrame++;
+		*animation = kModelAnimationZubenClimbShotFront;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			if (Actor_Query_Goal_Number(kActorZuben) == 99) {
 				_animationFrame = 0;
 				_animationState = 13;
-				*animation = 405;
+				*animation = kModelAnimationZubenShotDead;
 				Actor_Change_Animation_Mode(kActorZuben, kAnimationModeDie);
 			} else {
 				_animationFrame = 0;
 				_animationState = 0;
-				*animation = 406;
+				*animation = kModelAnimationZubenIdle;
 				Actor_Change_Animation_Mode(kActorZuben, kAnimationModeIdle);
 			}
 		}
 		break;
 
 	case 10:
-		*animation = 404;
-		_animationFrame++;
+		*animation = kModelAnimationZubenClimbShotBack;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			if (Actor_Query_Goal_Number(kActorZuben) == 99) {
 				_animationFrame = 0;
 				_animationState = 13;
-				*animation = 405;
+				*animation = kModelAnimationZubenShotDead;
 				Actor_Change_Animation_Mode(kActorZuben, kAnimationModeDie);
 			} else {
 				_animationFrame = 0;
 				_animationState = 0;
-				*animation = 406;
+				*animation = kModelAnimationZubenIdle;
 				Actor_Change_Animation_Mode(kActorZuben, kAnimationModeIdle);
 			}
 		}
 		break;
 
 	case 11:
-		*animation = 389;
-		_animationFrame++;
+		*animation = kModelAnimationZubenCombatHitFront;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			if (Actor_Query_Goal_Number(kActorZuben) == 99) {
 				_animationFrame = 0;
 				_animationState = 14;
-				*animation = 393;
+				*animation = kModelAnimationZubenCombatShotDead;
 				Actor_Change_Animation_Mode(kActorZuben, kAnimationModeDie);
 			} else {
 				_animationFrame = 0;
 				_animationState = 7;
-				*animation = 388;
+				*animation = kModelAnimationZubenCombatIdle;
 				Actor_Change_Animation_Mode(kActorZuben, kAnimationModeCombatIdle);
 			}
 		}
 		break;
 
 	case 12:
-		*animation = 390;
-		_animationFrame++;
+		*animation = kModelAnimationZubenCombatHitBack;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			if (Actor_Query_Goal_Number(kActorZuben) == 99) {
 				_animationFrame = 0;
 				_animationState = 14;
-				*animation = 393;
+				*animation = kModelAnimationZubenCombatShotDead;
 				Actor_Change_Animation_Mode(kActorZuben, kAnimationModeDie);
 			} else {
 				_animationFrame = 0;
 				_animationState = 7;
-				*animation = 388;
+				*animation = kModelAnimationZubenCombatIdle;
 				Actor_Change_Animation_Mode(kActorZuben, kAnimationModeCombatIdle);
 			}
 		}
 		break;
 
 	case 13:
-		*animation = 405;
-		_animationFrame++;
+		*animation = kModelAnimationZubenShotDead;
+		++_animationFrame;
 		if (_animationFrame == 7) {
 			Sound_Play(kSfxZUBDEAD1, 30, 0, 0, 50);
 		}
@@ -885,8 +893,8 @@ bool AIScriptZuben::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 14:
-		*animation = 393;
-		_animationFrame++;
+		*animation = kModelAnimationZubenCombatShotDead;
+		++_animationFrame;
 		if (_animationFrame == 7) {
 			Sound_Play(kSfxZUBDEAD1, 30, 0, 0, 50);
 		}
@@ -901,7 +909,7 @@ bool AIScriptZuben::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 15:
-		*animation = 405;
+		*animation = kModelAnimationZubenShotDead;
 		_animationFrame = Slice_Animation_Query_Number_Of_Frames(*animation) - 1;
 #if BLADERUNNER_ORIGINAL_BUGS
 		// This enables exits when it should not at the moonbus massacre
@@ -911,102 +919,102 @@ bool AIScriptZuben::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 16:
-		*animation = 393;
+		*animation = kModelAnimationZubenCombatShotDead;
 		_animationFrame = Slice_Animation_Query_Number_Of_Frames(*animation) - 1;
 		break;
 
 	case 17:
-		*animation = 409;
-		_animationFrame++;
+		*animation = kModelAnimationZubenCalmTalk;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 		}
 		break;
 
 	case 18:
-		*animation = 410;
-		_animationFrame++;
+		*animation = kModelAnimationZubenProtestTalk;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 			_animationState = 17;
-			*animation = 409;
+			*animation = kModelAnimationZubenCalmTalk;
 		}
 		break;
 
 	case 19:
-		*animation = 411;
-		_animationFrame++;
+		*animation = kModelAnimationZubenQuestionTalk;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 			_animationState = 17;
-			*animation = 409;
+			*animation = kModelAnimationZubenCalmTalk;
 		}
 		break;
 
 	case 20:
-		*animation = 412;
-		_animationFrame++;
+		*animation = kModelAnimationZubenMoreQuestionTalk;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 			_animationState = 17;
-			*animation = 409;
+			*animation = kModelAnimationZubenCalmTalk;
 		}
 		break;
 
 	case 21:
-		*animation = 413;
-		_animationFrame++;
+		*animation = kModelAnimationZubenPointingTalk;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 			_animationState = 17;
-			*animation = 409;
+			*animation = kModelAnimationZubenCalmTalk;
 		}
 		break;
 
 	case 22:
-		*animation = 414;
-		_animationFrame++;
+		*animation = kModelAnimationZubenYetMoreQuestiongTalk;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 			_animationState = 17;
-			*animation = 409;
+			*animation = kModelAnimationZubenCalmTalk;
 		}
 		break;
 
 	case 23:
-		*animation = 415;
-		_animationFrame++;
+		*animation = kModelAnimationZubenScratchEarTalk;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 			_animationState = 17;
-			*animation = 409;
+			*animation = kModelAnimationZubenCalmTalk;
 		}
 		break;
 
 	case 24:
-		*animation = 416;
-		_animationFrame++;
+		*animation = kModelAnimationZubenDontKnowTalk;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 			_animationState = 17;
-			*animation = 409;
+			*animation = kModelAnimationZubenCalmTalk;
 		}
 		break;
 
 	case 25:
-		*animation = 417;
-		 _animationFrame++;
+		*animation = kModelAnimationZubenThreatenTalk;
+		 ++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 			_animationState = 17;
-			*animation = 409;
+			*animation = kModelAnimationZubenCalmTalk;
 		}
 		break;
 
 	case 26:
 		Actor_Set_Frame_Rate_FPS(kActorZuben, -1);
-		*animation = 419;
-		_animationFrame++;
+		*animation = kModelAnimationZubenToppleSoupCauldron;
+		++_animationFrame;
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			// Time for McCoy to react and avoid tipping pot
 			Actor_Set_Frame_Rate_FPS(kActorZuben, -2);
@@ -1018,8 +1026,8 @@ bool AIScriptZuben::UpdateAnimation(int *animation, int *frame) {
 
 	case 27:  // Opening the door
 		Actor_Set_Frame_Rate_FPS(kActorZuben, -1);
-		*animation = 420;
-		_animationFrame++;
+		*animation = kModelAnimationZubenBashOnDoor;
+		++_animationFrame;
 		if (_animationFrame == 5) {
 			Overlay_Play("ct02over", 1, false, true, 0);
 		}
@@ -1035,21 +1043,21 @@ bool AIScriptZuben::UpdateAnimation(int *animation, int *frame) {
 		break;
 
 	case 28:
-		*animation = 421;
-		_animationFrame++;
+		*animation = kModelAnimationZubenJumpDownFromCeiling;
+		++_animationFrame;
 		if (_animationFrame == 1) {
 			Sound_Play(kSfxZUBLAND1, 80, 0, 0, 50);
 		}
 		if (_animationFrame >= Slice_Animation_Query_Number_Of_Frames(*animation)) {
 			_animationFrame = 0;
 			_animationState = 5;
-			*animation = 396;
+			*animation = kModelAnimationZubenCombatUnholsterCleaver;
 			Actor_Set_Goal_Number(kActorZuben, kGoalZubenCT06AttackMcCoy);
 		}
 		break;
 
 	default:
-		*animation = 399;
+		*animation = kModelAnimationZubenWalking;
 		break;
 	}
 	*frame = _animationFrame;
@@ -1062,84 +1070,108 @@ bool AIScriptZuben::ChangeAnimationMode(int mode) {
 		_animationState = 0;
 		_animationFrame = 0;
 		break;
+
 	case kAnimationModeWalk:
 		_animationState = 1;
 		_animationFrame = 0;
 		break;
+
 	case kAnimationModeRun:
 		_animationState = 3;
 		_animationFrame = 0;
 		break;
+
 	case kAnimationModeTalk:
 		_animationState = 17;
 		_animationFrame = 0;
 		break;
+
 	case kAnimationModeCombatIdle:
 		switch (_animationState) {
 		case 2:
+			// fall through
 		case 4:
 			_animationState = 7;
 			_animationFrame = 0;
 			break;
+
 		case 5:
+			// fall through
 		case 7:
 			break;
+
 		default:
 			_animationState = 5;
 			_animationFrame = 0;
 			break;
 		}
 		break;
+
 	case kAnimationModeCombatAttack:
 		_animationState = 8;
 		_animationFrame = 0;
 		break;
+
 	case kAnimationModeCombatWalk:
 		_animationState = 2;
 		_animationFrame = 0;
 		break;
+
 	case kAnimationModeCombatRun:
 		_animationState = 4;
 		_animationFrame = 0;
 		break;
+
 	case 12:
 		_animationState = 18;
 		_animationFrame = 0;
 		break;
+
 	case 13:
 		_animationState = 19;
 		_animationFrame = 0;
 		break;
+
 	case 14:
 		_animationState = 20;
 		_animationFrame = 0;
 		break;
+
 	case 15:
 		_animationState = 21;
 		_animationFrame = 0;
 		break;
+
 	case 16:
 		_animationState = 22;
 		_animationFrame = 0;
 		break;
+
 	case 17:
 		_animationState = 23;
 		_animationFrame = 0;
 		break;
+
 	case 18:
 		_animationState = 24;
 		_animationFrame = 0;
 		break;
+
 	case 19:
 		_animationState = 25;
 		_animationFrame = 0;
 		break;
+
 	case kAnimationModeHit:
 		switch (_animationState) {
 		case 2:
+			// fall through
 		case 4:
+			// fall through
 		case 5:
+			// fall through
 		case 7:
+			// fall through
 		case 8:
 			if (Random_Query(0, 1)) {
 				_animationState = 11;
@@ -1148,6 +1180,7 @@ bool AIScriptZuben::ChangeAnimationMode(int mode) {
 			}
 			_animationFrame = 0;
 			break;
+
 		default:
 			if (Random_Query(0, 1)) {
 				_animationState = 9;
@@ -1158,6 +1191,7 @@ bool AIScriptZuben::ChangeAnimationMode(int mode) {
 			break;
 		}
 		break;
+
 	case kAnimationModeCombatHit:
 		if (Random_Query(0, 1)) {
 			_animationState = 11;
@@ -1166,18 +1200,22 @@ bool AIScriptZuben::ChangeAnimationMode(int mode) {
 		}
 		_animationFrame = 0;
 		break;
+
 	case 24:
 		_animationState = 26;
 		_animationFrame = 0;
 		break;
+
 	case 25:
 		_animationState = 27;
 		_animationFrame = 0;
 		break;
+
 	case 26:
 		_animationState = 28;
 		_animationFrame = 0;
 		break;
+
 	case kAnimationModeDie:
 		Actor_Set_Targetable(kActorZuben, false);
 		if (_vm->_cutContent) {
@@ -1186,21 +1224,29 @@ bool AIScriptZuben::ChangeAnimationMode(int mode) {
 		}
 		switch (_animationState) {
 			case 2:
+				// fall through
 			case 4:
+				// fall through
 			case 5:
+				// fall through
 			case 7:
+				// fall through
 			case 8:
+				// fall through
 			case 11:
+				// fall through
 			case 12:
 				_animationState = 14;
 				_animationFrame = 0;
 				break;
+
 			default:
 				_animationState = 13;
 				_animationFrame = 0;
 				break;
 		}
 		break;
+
 	case kAnimationModeCombatDie:
 		Actor_Set_Targetable(kActorZuben, false);
 		_animationState = 14;
