@@ -49,8 +49,8 @@ void ESPERScript::SCRIPT_ESPER_DLL_Initialize() {
 	int v0 = 0;
 	if (Actor_Clue_Query(kActorMcCoy, kClueRuncitersVideo)) {
 		if (!Actor_Clue_Query(kActorMcCoy, kClueRuncitersViewA)) {
-			Actor_Says(kActorAnsweringMachine, 160, 3);
-			Actor_Says(kActorAnsweringMachine, 180, 3);
+			Actor_Says(kActorAnsweringMachine, 160, kAnimationModeTalk);
+			Actor_Says(kActorAnsweringMachine, 180, kAnimationModeTalk);
 			Actor_Clue_Acquire(kActorMcCoy, kClueRuncitersViewA, true, kActorRunciter);
 			v0 = 1;
 		}
@@ -62,8 +62,8 @@ void ESPERScript::SCRIPT_ESPER_DLL_Initialize() {
 	}
 	if (Actor_Clue_Query(kActorMcCoy, kClueEarlyQsClub)) {
 		if (!Actor_Clue_Query(kActorMcCoy, kClueOuterDressingRoom)) {
-			Actor_Says(kActorAnsweringMachine, 160, 3);
-			Actor_Says(kActorAnsweringMachine, 170, 3);
+			Actor_Says(kActorAnsweringMachine, 160, kAnimationModeTalk);
+			Actor_Says(kActorAnsweringMachine, 170, kAnimationModeTalk);
 			Actor_Clue_Acquire(kActorMcCoy, kClueOuterDressingRoom, true, -1);
 			v0 = 1;
 		}
@@ -83,8 +83,8 @@ void ESPERScript::SCRIPT_ESPER_DLL_Initialize() {
 	}
 	if (Actor_Clue_Query(kActorMcCoy, kClueChinaBarSecurityDisc)) {
 		if (!Actor_Clue_Query(kActorMcCoy, kClueChinaBarSecurityPhoto)) {
-			Actor_Says(kActorAnsweringMachine, 160, 3);
-			Actor_Says(kActorAnsweringMachine, 170, 3);
+			Actor_Says(kActorAnsweringMachine, 160, kAnimationModeTalk);
+			Actor_Says(kActorAnsweringMachine, 170, kAnimationModeTalk);
 			Actor_Clue_Acquire(kActorMcCoy, kClueChinaBarSecurityPhoto, true, kActorHawkersBarkeep);
 			v0 = 1;
 		}
@@ -92,8 +92,8 @@ void ESPERScript::SCRIPT_ESPER_DLL_Initialize() {
 	}
 	if (Actor_Clue_Query(kActorMcCoy, kClueTyrellSecurity)) {
 		if (!Actor_Clue_Query(kActorMcCoy, kClueTyrellSecurityPhoto)) {
-			Actor_Says(kActorAnsweringMachine, 160, 3);
-			Actor_Says(kActorAnsweringMachine, 170, 3);
+			Actor_Says(kActorAnsweringMachine, 160, kAnimationModeTalk);
+			Actor_Says(kActorAnsweringMachine, 170, kAnimationModeTalk);
 			Actor_Clue_Acquire(kActorMcCoy, kClueTyrellSecurityPhoto, true, kActorTyrellGuard);
 			v0 = 1;
 		}
@@ -103,21 +103,21 @@ void ESPERScript::SCRIPT_ESPER_DLL_Initialize() {
 		ESPER_Add_Photo("KP06.IMG", 9, 9);
 	}
 	if (v0) {
-		Actor_Says(kActorAnsweringMachine, 200, 3);
+		Actor_Says(kActorAnsweringMachine, 200, kAnimationModeTalk);
 	}
 }
 
 void ESPERScript::SCRIPT_ESPER_DLL_Photo_Selected(int photo) {
 	switch (photo) {
 	case 0:
-		Actor_Says(kActorAnsweringMachine, 220, 3);
+		Actor_Says(kActorAnsweringMachine, 220, kAnimationModeTalk);
 		ESPER_Define_Special_Region(0, 490, 511, 496, 517, 400, 440, 580, 580, 380, 260, 900, 710, "RC02ESP1");
 		ESPER_Define_Special_Region(1, 473, 342, 479, 349, 400, 300, 580, 580, 350, 250, 900, 710, "RC02ESP2");
 		ESPER_Define_Special_Region(2, 444, 215, 461, 223, 380, 120, 570, 340, 354, 160, 577, 354, "RC02ESP3");
 		break;
 
 	case 1:
-		Actor_Says(kActorAnsweringMachine, 220, 3);
+		Actor_Says(kActorAnsweringMachine, 220, kAnimationModeTalk);
 		ESPER_Define_Special_Region(3, 560, 210, 580, 220, 450, 130, 680, 540, 0, 0, 1279, 959, "RC02ESP4");
 		ESPER_Define_Special_Region(4, 584, 482, 595, 493, 460, 400, 660, 540, 0, 0, 1279, 959, "RC02ESP5");
 		ESPER_Define_Special_Region(5, 669, 322, 675, 329, 620, 230, 740, 390, 0, 0, 1279, 959, "RC02ESP6");
@@ -125,42 +125,42 @@ void ESPERScript::SCRIPT_ESPER_DLL_Photo_Selected(int photo) {
 		break;
 
 	case 2:
-		Actor_Says(kActorAnsweringMachine, 260, 3);
+		Actor_Says(kActorAnsweringMachine, 260, kAnimationModeTalk);
 		ESPER_Define_Special_Region(7, 102, 809, 108, 861, 20, 720, 200, 930, 191, 95, 1085, 870, "NR06ESP1");
 		ESPER_Define_Special_Region(8, 661, 437, 664, 443, 530, 320, 720, 600, 330, 200, 945, 750, "NR06ESP2");
 		break;
 
 	case 3:
-		Actor_Says(kActorAnsweringMachine, 260, 3);
+		Actor_Says(kActorAnsweringMachine, 260, kAnimationModeTalk);
 		ESPER_Define_Special_Region(9, 479, 381, 482, 385, 430, 320, 520, 470, 265, 200, 815, 720, "NR07ESP2");
 		ESPER_Define_Special_Region(10, 893, 298, 901, 306, 770, 230, 980, 500, 340, 216, 942, 747, "NR07ESP1");
 		break;
 
 	case 4:
-		Actor_Says(kActorAnsweringMachine, 240, 3);
+		Actor_Says(kActorAnsweringMachine, 240, kAnimationModeTalk);
 		ESPER_Define_Special_Region(11, 420, 436, 434, 450, 350, 380, 520, 680, 257, 94, 1013, 804, "HC01ESP1");
 		ESPER_Define_Special_Region(12, 407, 489, 410, 509, 370, 450, 500, 560, 257, 94, 1013, 804, "HC01ESP2");
 		break;
 
 	case 5:
-		Actor_Says(kActorAnsweringMachine, 240, 3);
+		Actor_Says(kActorAnsweringMachine, 240, kAnimationModeTalk);
 		ESPER_Define_Special_Region(13, 720, 485, 728, 491, 640, 390, 780, 630, 257, 94, 1013, 804, "HC01ESP3");
 		break;
 
 	case 6:
-		Actor_Says(kActorAnsweringMachine, 250, 3);
+		Actor_Says(kActorAnsweringMachine, 250, kAnimationModeTalk);
 		ESPER_Define_Special_Region(14, 879, 221, 882, 225, 640, 0, 1000, 512, 265, 146, 1014, 813, "HC02ESP5");
 		ESPER_Define_Special_Region(15, 660, 550, 678, 572, 560, 480, 850, 910, 265, 146, 1014, 813, "HC02ESP2");
 		break;
 
 	case 7:
-		Actor_Says(kActorAnsweringMachine, 250, 3);
+		Actor_Says(kActorAnsweringMachine, 250, kAnimationModeTalk);
 		ESPER_Define_Special_Region(16, 1171, 457, 1184, 466, 1060, 370, 1279, 730, 910, 300, 1279, 678, "HC02ESP3");
 		ESPER_Define_Special_Region(17, 328, 398, 340, 413, 250, 350, 460, 640, 100, 236, 530, 612, "HC02ESP4");
 		break;
 
 	case 8:
-		Actor_Says(kActorAnsweringMachine, 230, 3);
+		Actor_Says(kActorAnsweringMachine, 230, kAnimationModeTalk);
 		ESPER_Define_Special_Region(18, 166, 623, 177, 632, 38, 528, 320, 770, 26, 530, 313, 771, "TB06ESP1");
 		ESPER_Define_Special_Region(19, 156, 356, 164, 360, 60, 280, 250, 460, 14, 251, 257, 459, "TB06ESP2");
 		ESPER_Define_Special_Region(20, 395, 158, 410, 185, 270, 70, 760, 640, 125, 0, 560, 307, "TB06ESP3");
@@ -168,7 +168,7 @@ void ESPERScript::SCRIPT_ESPER_DLL_Photo_Selected(int photo) {
 		break;
 
 	case 9:
-		Actor_Says(kActorAnsweringMachine, 270, 3);
+		Actor_Says(kActorAnsweringMachine, 270, kAnimationModeTalk);
 		ESPER_Define_Special_Region(22, 1208, 330, 1218, 340, 1050, 160, 1279, 550, 956, 203, 1278, 497, "KP06ESP1");
 		ESPER_Define_Special_Region(23, 854, 371, 858, 375, 790, 320, 940, 560, 722, 220, 1000, 505, "KP06ESP2");
 		ESPER_Define_Special_Region(24, 615, 325, 648, 365, 440, 220, 820, 959, 326, 140, 948, 474, "KP06ESP3");
@@ -265,10 +265,10 @@ bool ESPERScript::SCRIPT_ESPER_DLL_Special_Region_Selected(int photo, int region
 	case 3:
 		if (region == 9) {
 			Actor_Voice_Over(4230, kActorVoiceOver);
-			if (!Actor_Clue_Query(kActorMcCoy, kClueClovisflowers)) {
+			if (!Actor_Clue_Query(kActorMcCoy, kClueClovisFlowers)) {
 				Actor_Says(kActorMcCoy, 6945, 3);
 				Sound_Play(kSfxBR034_1A, 50, 0, 0, 50);
-				Actor_Clue_Acquire(kActorMcCoy, kClueClovisflowers, true, -1);
+				Actor_Clue_Acquire(kActorMcCoy, kClueClovisFlowers, true, -1);
 			}
 			retValue = true;
 		} else if (region == 10) {
@@ -404,7 +404,11 @@ bool ESPERScript::SCRIPT_ESPER_DLL_Special_Region_Selected(int photo, int region
 			break;
 
 		case 23:
-			Actor_Voice_Over(4240, kActorVoiceOver);
+			if (_vm->_cutContent && Actor_Clue_Query(kActorMcCoy, kClueMoonbusReflection)) {
+				Actor_Voice_Over(4250, kActorVoiceOver);
+			} else {
+				Actor_Voice_Over(4240, kActorVoiceOver);
+			}
 			if (!Actor_Clue_Query(kActorMcCoy, kClueMcCoyAtMoonbus)) {
 				Actor_Says(kActorMcCoy, 6945, 3);
 				Sound_Play(kSfxBR034_1A, 50, 0, 0, 50);
