@@ -47,7 +47,7 @@ void SceneScriptDR02::InitializeScene() {
 	}
 
 	Ambient_Sounds_Remove_All_Non_Looping_Sounds(false);
-	Ambient_Sounds_Remove_All_Looping_Sounds(0);
+	Ambient_Sounds_Remove_All_Looping_Sounds(0u);
 	Ambient_Sounds_Add_Looping_Sound(kSfxCTRAIN1, 50, 0, 1);
 	Ambient_Sounds_Add_Looping_Sound(kSfxHUMMER3, 27, 85, 1);
 	Ambient_Sounds_Add_Looping_Sound(kSfxBIGFAN2, 38, 85, 1);
@@ -151,8 +151,8 @@ bool SceneScriptDR02::ClickedOnExit(int exitId) {
 			Game_Flag_Set(kFlagDR02toDR01);
 			Set_Enter(kSetDR01_DR02_DR04, kSceneDR01);
 		}
-		Ambient_Sounds_Adjust_Looping_Sound(kSfxHUMMER3, 12, -101, 1);
-		Ambient_Sounds_Adjust_Looping_Sound(kSfxBIGFAN2, 14, -101, 1);
+		Ambient_Sounds_Adjust_Looping_Sound(kSfxHUMMER3, 12, -101, 1u);
+		Ambient_Sounds_Adjust_Looping_Sound(kSfxBIGFAN2, 14, -101, 1u);
 		return true;
 	}
 
@@ -169,8 +169,8 @@ bool SceneScriptDR02::ClickedOnExit(int exitId) {
 			Game_Flag_Set(kFlagDR02toDR01);
 			Set_Enter(kSetDR01_DR02_DR04, kSceneDR01);
 		}
-		Ambient_Sounds_Adjust_Looping_Sound(kSfxHUMMER3, 12, -101, 1);
-		Ambient_Sounds_Adjust_Looping_Sound(kSfxBIGFAN2, 14, -101, 1);
+		Ambient_Sounds_Adjust_Looping_Sound(kSfxHUMMER3, 12, -101, 1u);
+		Ambient_Sounds_Adjust_Looping_Sound(kSfxBIGFAN2, 14, -101, 1u);
 		return true;
 	}
 
