@@ -91,7 +91,7 @@ bool SceneScriptKP05::ClickedOnExit(int exitId) {
 	if (exitId == 0) {
 		if (!Loop_Actor_Walk_To_XYZ(kActorMcCoy, -802.0f, 0.0f, 972.0f, 0, true, false, false)) {
 			Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-			Ambient_Sounds_Remove_All_Looping_Sounds(1);
+			Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 			Game_Flag_Set(kFlagKP05toKP03);
 			Set_Enter(kSetKP03, kSceneKP03);
 		}
@@ -101,7 +101,7 @@ bool SceneScriptKP05::ClickedOnExit(int exitId) {
 	if (exitId == 1) {
 		if (!Loop_Actor_Walk_To_XYZ(kActorMcCoy, -1142.0f, 0.0f, 932.0f, 0, true, false, false)) {
 			Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-			Ambient_Sounds_Remove_All_Looping_Sounds(1);
+			Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 			Game_Flag_Set(kFlagKP05toKP04);
 			Set_Enter(kSetKP04, kSceneKP04);
 		}
@@ -111,7 +111,7 @@ bool SceneScriptKP05::ClickedOnExit(int exitId) {
 	if (exitId == 2) {
 		if (!Loop_Actor_Walk_To_XYZ(kActorMcCoy, -868.0f, 0.0f, -68.0f, 0, true, false, false)) {
 			Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-			Ambient_Sounds_Remove_All_Looping_Sounds(1);
+			Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 			Game_Flag_Set(kFlagKP05toKP06);
 			Async_Actor_Walk_To_XYZ(kActorMcCoy, -868.0f, 0.0f, -216.0f, 0, false);
 			Set_Enter(kSetKP05_KP06, kSceneKP06);
@@ -143,7 +143,7 @@ void SceneScriptKP05::PlayerWalkedIn() {
 	}
 
 	if (Actor_Query_Goal_Number(kActorMaggie) == kGoalMaggieKP05Wait) {
-		Actor_Set_Goal_Number(kActorMaggie, kGoalMaggieKP05McCoyEntred);
+		Actor_Set_Goal_Number(kActorMaggie, kGoalMaggieKP05McCoyEntered);
 	}
 
 	if (Actor_Query_Goal_Number(kActorSteele) == 450) {
