@@ -38,7 +38,7 @@ void SceneScriptKP07::InitializeScene() {
 #if BLADERUNNER_ORIGINAL_BUGS
 #else
 			if (Game_Flag_Query(kFlagNR11DektoraBurning)) {
-				Game_Flag_Reset(kFlagNR11DektoraBurning); // resolves a bug of an original game, where Dektora would default to burning state
+				Game_Flag_Reset(kFlagNR11DektoraBurning); // resolves a bug of the original game, where Dektora would default to burning state
 				Actor_Change_Animation_Mode(kActorDektora, kAnimationModeTalk); // dummy animation change to ensure that the next will trigger the mode change case
 				Actor_Change_Animation_Mode(kActorDektora, kAnimationModeIdle);
 			}
@@ -146,7 +146,7 @@ void SceneScriptKP07::InitializeScene() {
 
 void SceneScriptKP07::SceneLoaded() {
 	if (!Game_Flag_Query(kFlagMcCoyIsHelpingReplicants)) {
-		Music_Play(kMusicClovDie1, 25, 0, 0, -1, 1, 0);
+		Music_Play(kMusicClovDie1, 25, 0, 0, -1, kMusicLoopRepeat, 0);
 	}
 	Obstacle_Object("BUNK_TRAY01", true);
 	Unobstacle_Object("BUNK_TRAY01", true);
@@ -177,7 +177,7 @@ bool SceneScriptKP07::ClickedOnActor(int actorId) {
 			if (Game_Flag_Query(kFlagMcCoyIsHelpingReplicants)) {
 				Actor_Set_Goal_Number(kActorClovis, kGoalClovisKP07FlyAway);
 			} else {
-				Music_Play(kMusicClovDies, 31, 0, 0, -1, 1, 0);
+				Music_Play(kMusicClovDies, 31, 0, 0, -1, kMusicLoopRepeat, 0);
 				Actor_Set_Goal_Number(kActorClovis, kGoalClovisKP07TalkToMcCoy);
 			}
 			return true;
@@ -207,7 +207,7 @@ bool SceneScriptKP07::ClickedOnExit(int exitId) {
 	if (exitId == 0) {
 		if (!Loop_Actor_Walk_To_XYZ(kActorMcCoy, -12.0f, -41.58f, 72.0f, 0, true, false, false)) {
 			Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-			Ambient_Sounds_Remove_All_Looping_Sounds(1);
+			Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 			Game_Flag_Set(kFlagKP07toKP06);
 			Set_Enter(kSetKP05_KP06, kSceneKP06);
 		}
@@ -250,7 +250,7 @@ void SceneScriptKP07::PlayerWalkedIn() {
 }
 
 void SceneScriptKP07::PlayerWalkedOut() {
-	Music_Stop(3);
+	Music_Stop(3u);
 }
 
 void SceneScriptKP07::DialogueQueueFlushed(int a1) {
