@@ -37,7 +37,7 @@ void SceneScriptMA06::InitializeScene() {
 
 #if BLADERUNNER_ORIGINAL_BUGS
 #else
-	Ambient_Sounds_Remove_All_Looping_Sounds(1);
+	Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 	Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
 #endif // BLADERUNNER_ORIGINAL_BUGS
 
@@ -66,6 +66,7 @@ void SceneScriptMA06::SceneLoaded() {
 		} else if (Actor_Query_Goal_Number(kActorRachael) == kGoalRachaelAtEndOfAct3IfMetWithMcCoy
 			&& Game_Flag_Query(kFlagMA02RajifTalk)) {
 			// Put Rachael in set for her second cut scene (Act 4)
+			AI_Movement_Track_Pause(kActorRachael); // don't allow her to "travel" anywhere
 			Actor_Put_In_Set(kActorRachael, kSetMA06);
 			Actor_Set_At_XYZ(kActorRachael, 30.15f, 0.0f, 50.16f, 170); // different rotation and slightly different placement
 			Actor_Set_Goal_Number(kActorRachael, kGoalRachaelIsInsideMcCoysElevatorAct4);
@@ -122,13 +123,16 @@ void SceneScriptMA06::PlayerWalkedIn() {
 			Game_Flag_Reset(kFlagMA06toMA01);
 			Game_Flag_Reset(kFlagMA06ToMA02);
 			Game_Flag_Reset(kFlagMA06toMA07);
-			Ambient_Sounds_Adjust_Looping_Sound(kSfxELEAMB3, 10, 0, 1);
-			Ambient_Sounds_Adjust_Looping_Sound(kSfxAPRTFAN1, 10, 0, 1);
+			Ambient_Sounds_Adjust_Looping_Sound(kSfxELEAMB3,  10, 0, 1u);
+			Ambient_Sounds_Adjust_Looping_Sound(kSfxAPRTFAN1, 10, 0, 1u);
 
-			Actor_Says(kActorAnsweringMachine, 80, 3);     // your floor number please
+			if (_vm->_cutContent) {
+				Actor_Says(kActorAnsweringMachine, 70, kAnimationModeTalk); // voice print identification
+			}
+			Actor_Says(kActorAnsweringMachine, 80, kAnimationModeTalk);     // your floor number please
 			Actor_Says(kActorMcCoy, 2940, 18);             // McCoy: McCoy 88F
 			Game_Flag_Set(kFlagMA06ToMA02);                // to McCoy's Apartment
-			Actor_Says(kActorAnsweringMachine, 90, 3);     // 88 thank you
+			Actor_Says(kActorAnsweringMachine, 90, kAnimationModeTalk);     // 88 thank you
 			Actor_Face_Actor(kActorMcCoy, kActorRachael, true);
 			Actor_Says(kActorMcCoy, 2710, 14);             // Excuse me
 
@@ -139,12 +143,12 @@ void SceneScriptMA06::PlayerWalkedIn() {
 			Game_Flag_Reset(kFlagMA01toMA06);
 			Game_Flag_Reset(kFlagMA02toMA06);
 			Game_Flag_Reset(kFlagMA07toMA06);
-			Ambient_Sounds_Adjust_Looping_Sound(kSfxSPINUP1,  0, 0, 1);
-			Ambient_Sounds_Adjust_Looping_Sound(kSfxAPRTFAN1, 0, 0, 1);
-			Ambient_Sounds_Adjust_Looping_Sound(kSfxELEAMB3,  0, 0, 1);
-			Ambient_Sounds_Remove_Looping_Sound(kSfxSPINUP1,  1);         // stop elev moving sound
-			Ambient_Sounds_Remove_Looping_Sound(kSfxAPRTFAN1, 1);         // stop other ambient
-			Ambient_Sounds_Remove_Looping_Sound(kSfxELEAMB3,  1);         // stop other ambient
+			Ambient_Sounds_Adjust_Looping_Sound(kSfxSPINUP1,  0, 0, 1u);
+			Ambient_Sounds_Adjust_Looping_Sound(kSfxAPRTFAN1, 0, 0, 1u);
+			Ambient_Sounds_Adjust_Looping_Sound(kSfxELEAMB3,  0, 0, 1u);
+			Ambient_Sounds_Remove_Looping_Sound(kSfxSPINUP1,  1u);         // stop elev moving sound
+			Ambient_Sounds_Remove_Looping_Sound(kSfxAPRTFAN1, 1u);         // stop other ambient
+			Ambient_Sounds_Remove_Looping_Sound(kSfxELEAMB3,  1u);         // stop other ambient
 			Actor_Says_With_Pause(kActorRachael, 300, 1.0f, 14);  // GoodbyeMcCoy
 			Actor_Says(kActorRachael, 310, 14);                   // Isnt ThisYourFloor --
 			Actor_Says(kActorMcCoy, 2860, 14);                    // YouTakeCareOfYoursel
@@ -164,22 +168,25 @@ void SceneScriptMA06::PlayerWalkedIn() {
 			Game_Flag_Reset(kFlagMA06toMA01);
 			Game_Flag_Reset(kFlagMA06ToMA02);
 			Game_Flag_Reset(kFlagMA06toMA07);
-			Ambient_Sounds_Adjust_Looping_Sound(kSfxELEAMB3, 10, 0, 1);
-			Ambient_Sounds_Adjust_Looping_Sound(kSfxAPRTFAN1, 10, 0, 1);
+			Ambient_Sounds_Adjust_Looping_Sound(kSfxELEAMB3,  10, 0, 1u);
+			Ambient_Sounds_Adjust_Looping_Sound(kSfxAPRTFAN1, 10, 0, 1u);
 
-			Actor_Says(kActorAnsweringMachine, 80, 3);      // your floor number please
+			if (_vm->_cutContent) {
+				Actor_Says(kActorAnsweringMachine, 70, kAnimationModeTalk); // voice print identification
+			}
+			Actor_Says(kActorAnsweringMachine, 80, kAnimationModeTalk);     // your floor number please
 			Actor_Set_Goal_Number(kActorRachael, kGoalRachaelIsInsideElevatorStartTalkAct4);
 			//
 			Delay(500);
 			Game_Flag_Reset(kFlagMA01toMA06);
 			Game_Flag_Reset(kFlagMA02toMA06);
 			Game_Flag_Reset(kFlagMA07toMA06);
-			Ambient_Sounds_Adjust_Looping_Sound(kSfxSPINUP1,  0, 0, 1);
-			Ambient_Sounds_Adjust_Looping_Sound(kSfxAPRTFAN1, 0, 0, 1);
-			Ambient_Sounds_Adjust_Looping_Sound(kSfxELEAMB3,  0, 0, 1);
-			Ambient_Sounds_Remove_Looping_Sound(kSfxSPINUP1,  1);         // stop elev moving sound
-			Ambient_Sounds_Remove_Looping_Sound(kSfxAPRTFAN1, 1);         // stop other ambient
-			Ambient_Sounds_Remove_Looping_Sound(kSfxELEAMB3,  1);         // stop other ambient
+			Ambient_Sounds_Adjust_Looping_Sound(kSfxSPINUP1,  0, 0, 1u);
+			Ambient_Sounds_Adjust_Looping_Sound(kSfxAPRTFAN1, 0, 0, 1u);
+			Ambient_Sounds_Adjust_Looping_Sound(kSfxELEAMB3,  0, 0, 1u);
+			Ambient_Sounds_Remove_Looping_Sound(kSfxSPINUP1,  1u);         // stop elev moving sound
+			Ambient_Sounds_Remove_Looping_Sound(kSfxAPRTFAN1, 1u);         // stop other ambient
+			Ambient_Sounds_Remove_Looping_Sound(kSfxELEAMB3,  1u);         // stop other ambient
 
 //			Player_Gains_Control();
 			Set_Enter(kSetMA07, kSceneMA07);
@@ -218,7 +225,7 @@ void SceneScriptMA06::PlayerWalkedIn() {
 
 void SceneScriptMA06::PlayerWalkedOut() {
 	Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-	Ambient_Sounds_Remove_All_Looping_Sounds(1);
+	Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 	Player_Gains_Control();
 	if (_vm->_cutContent) {
 		if (Actor_Query_Goal_Number(kActorRachael) == kGoalRachaelIsInsideElevatorStartTalkAct3) {
@@ -255,13 +262,16 @@ void SceneScriptMA06::activateElevator() {
 			break;
 		}
 
-		Actor_Says(kActorAnsweringMachine, 80, kAnimationModeTalk);
+		if (_vm->_cutContent) {
+			Actor_Says(kActorAnsweringMachine, 70, kAnimationModeTalk); // voice print identification
+		}
+		Actor_Says(kActorAnsweringMachine, 80, kAnimationModeTalk);     // your floor number please
 		Player_Gains_Control();
 		int floorLevel = Elevator_Activate(kElevatorMA);
 #if BLADERUNNER_ORIGINAL_BUGS
 #else
 		// Fix for a crash/ freeze bug;
-		//  To reproduce original issue: in Act 4, visit Rajiff, then exit to ground floor. Re-enter elevator and press Alt+F4
+		//  To reproduce original issue: in Act 4, visit Rajif, then exit to ground floor. Re-enter elevator and press Alt+F4
 		if (floorLevel < 0) {
 			break;
 		}
@@ -278,7 +288,7 @@ void SceneScriptMA06::activateElevator() {
 			} else {
 				Sound_Play(kSfxELEBAD1, 100, 0, 0, 50);
 				Delay(500);
-				Actor_Says(kActorAnsweringMachine, 610, 3);
+				Actor_Says(kActorAnsweringMachine, 610, kAnimationModeTalk);
 			}
 		} else { // floorLevel == 0
 			Actor_Says(kActorMcCoy, 2940, 18);
@@ -292,7 +302,7 @@ void SceneScriptMA06::activateElevator() {
 				Actor_Says(kActorMcCoy, 8527, kAnimationModeTalk);
 			} else {
 				Game_Flag_Set(kFlagMA06ToMA02);
-				Actor_Says(kActorAnsweringMachine, 90, 3);
+				Actor_Says(kActorAnsweringMachine, 90, kAnimationModeTalk);
 			}
 		}
 	}
