@@ -137,7 +137,7 @@ bool SceneScriptNR01::ClickedOnExit(int exitId) {
 				Actor_Says(kActorMcCoy, 8522, 12);
 			} else {
 				Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-				Ambient_Sounds_Remove_All_Looping_Sounds(1);
+				Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 				Game_Flag_Set(kFlagNR01toNR03);
 				Set_Enter(kSetNR03, kSceneNR03);
 			}
@@ -150,7 +150,7 @@ bool SceneScriptNR01::ClickedOnExit(int exitId) {
 			Actor_Face_Heading(kActorMcCoy, 45, false);
 			Loop_Actor_Travel_Stairs(kActorMcCoy, 3, false, kAnimationModeIdle);
 			Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-			Ambient_Sounds_Remove_All_Looping_Sounds(1);
+			Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 			Game_Flag_Set(kFlagNR01toUG06);
 			Set_Enter(kSetUG06, kSceneUG06);
 		}
@@ -160,7 +160,7 @@ bool SceneScriptNR01::ClickedOnExit(int exitId) {
 	if (exitId == 2) {
 		if (!Loop_Actor_Walk_To_XYZ(kActorMcCoy, 312.0f, 31.66f, -901.0f, 0, true, false, false)) {
 			Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-			Ambient_Sounds_Remove_All_Looping_Sounds(1);
+			Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 			Game_Flag_Set(kFlagNR01toNR02);
 			Set_Enter(kSetNR02, kSceneNR02);
 		}
@@ -462,7 +462,7 @@ void SceneScriptNR01::PlayerWalkedIn() {
 
 void SceneScriptNR01::PlayerWalkedOut() {
 	Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-	Ambient_Sounds_Remove_All_Looping_Sounds(1);
+	Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 	if (!Game_Flag_Query(kFlagNR01toUG06)
 	 && !Game_Flag_Query(kFlagNR01toNR02)
 	 && !Game_Flag_Query(kFlagNR01toNR03)
