@@ -25,7 +25,7 @@
 namespace BladeRunner {
 
 void SceneScriptNR04::InitializeScene() {
-	Music_Adjust(30, 80, 2);
+	Music_Adjust(30, 80, 2u);
 
 	Setup_Scene_Information(53.0f, 0.0f, -110.0f, 569);
 
@@ -155,7 +155,7 @@ bool SceneScriptNR04::ClickedOnExit(int exitId) {
 	if (exitId == 0) {
 		if (!Loop_Actor_Walk_To_XYZ(kActorMcCoy, 45.0f, 0.0f, -106.0f, 0, true, false, false)) {
 			Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-			Ambient_Sounds_Remove_All_Looping_Sounds(1);
+			Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 			Game_Flag_Set(kFlagNR04toNR03);
 			Set_Enter(kSetNR03, kSceneNR03);
 		}
@@ -250,6 +250,9 @@ void SceneScriptNR04::ActorChangedGoal(int actorId, int newGoal, int oldGoal, bo
 			Actor_Change_Animation_Mode(kActorEarlyQ, 85);
 			Actor_Face_Actor(kActorMcCoy, kActorEarlyQ, true);
 			Actor_Set_Goal_Number(kActorEarlyQ, kGoalEarlyQNR04ScorpionsCheck);
+			// The quotes corresponding to this clue are from kGoalEarlyQNR04McCoyPulledGun (previous goal of EarlyQ)
+			// That goal leads to this one (if McCoy does not shoot Early Q that is)
+			// TODO maybe move acquiring the clue to the kGoalEarlyQNR04McCoyPulledGun?
 			Actor_Clue_Acquire(kActorMcCoy, kClueEarlyQInterview, false, kActorEarlyQ);
 			//return true;
 			break;
@@ -316,8 +319,8 @@ void SceneScriptNR04::PlayerWalkedOut() {
 #else
 	if (Game_Flag_Query(kFlagNR03McCoyThrownOut)) {
 		Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-		Ambient_Sounds_Remove_All_Looping_Sounds(1);
-		Music_Stop(1);
+		Ambient_Sounds_Remove_All_Looping_Sounds(1u);
+		Music_Stop(1u);
 	}
 #endif // BLADERUNNER_ORIGINAL_BUGS
 }
@@ -394,12 +397,16 @@ void SceneScriptNR04::druggedEffect(int frame) {
 
 void SceneScriptNR04::playNextMusic() {
 	int track = Global_Variable_Query(kVariableEarlyQFrontMusic);
+	int loop = kMusicLoopPlayOnce;
+	if (_vm->_cutContent && Random_Query(0, 2) == 1) {
+		loop = kMusicLoopPlayOnceRandomStart;
+	}
 	if (track == 0) {
-		Music_Play(kMusicGothic2, 11, 80, 2, -1, 0, 0);
+		Music_Play(kMusicGothic2, 11, 80, 2, -1, loop, 0);
 	} else if (track == 1) {
-		Music_Play(kMusicGothic1, 11, 80, 2, -1, 0, 0);
+		Music_Play(kMusicGothic1, 11, 80, 2, -1, loop, 0);
 	} else if (track == 2) {
-		Music_Play(kMusicGothic3, 11, 80, 2, -1, 0, 0);
+		Music_Play(kMusicGothic3, 11, 80, 2, -1, loop, 0);
 	}
 	++track;
 	if (track > 2) {
