@@ -54,7 +54,7 @@ void SceneScriptRC03::InitializeScene() {
 #if BLADERUNNER_ORIGINAL_BUGS
 		Scene_Exit_Add_2D_Exit(2, 524, 350, 573, 359, 2);
 #else
-	// prevent Izo's corpse from blocking the exit hot-spot area
+		// prevent Izo's corpse from blocking the exit hot-spot area
 		Scene_Exit_Add_2D_Exit(2, 524, 340, 573, 359, 2);
 #endif // BLADERUNNER_ORIGINAL_BUGS
 	}
@@ -65,10 +65,10 @@ void SceneScriptRC03::InitializeScene() {
 	Ambient_Sounds_Add_Sound(kSfxRCCARBY1,  5,  30, 40,  70, -100, 100, -101, -101, 0, 0);
 	Ambient_Sounds_Add_Sound(kSfxRCCARBY2,  5,  30, 40,  75, -100, 100, -101, -101, 0, 0);
 	Ambient_Sounds_Add_Sound(kSfxRCCARBY3,  5,  30, 40,  70, -100, 100, -101, -101, 0, 0);
-	Ambient_Sounds_Add_Speech_Sound(kActorBlimpGuy,  0, 10, 260, 17, 24, -100, 100, -101, -101, 1, 1);
-	Ambient_Sounds_Add_Speech_Sound(kActorBlimpGuy, 20, 10, 260, 17, 24, -100, 100, -101, -101, 1, 1);
-	Ambient_Sounds_Add_Speech_Sound(kActorBlimpGuy, 40, 10, 260, 17, 24, -100, 100, -101, -101, 1, 1);
-	Ambient_Sounds_Add_Speech_Sound(kActorBlimpGuy, 50, 10, 260, 17, 24, -100, 100, -101, -101, 1, 1);
+	Ambient_Sounds_Add_Speech_Sound(kActorBlimpGuy,  0, 10u, 260u, 17, 24, -100, 100, -101, -101, 1, 1);
+	Ambient_Sounds_Add_Speech_Sound(kActorBlimpGuy, 20, 10u, 260u, 17, 24, -100, 100, -101, -101, 1, 1);
+	Ambient_Sounds_Add_Speech_Sound(kActorBlimpGuy, 40, 10u, 260u, 17, 24, -100, 100, -101, -101, 1, 1);
+	Ambient_Sounds_Add_Speech_Sound(kActorBlimpGuy, 50, 10u, 260u, 17, 24, -100, 100, -101, -101, 1, 1);
 	Ambient_Sounds_Add_Sound(kSfxSPIN2B,   60, 180, 16,  25,    0,   0, -101, -101, 0, 0);
 	Ambient_Sounds_Add_Sound(kSfxSPIN3A,   60, 180, 16,  25,    0,   0, -101, -101, 0, 0);
 	Ambient_Sounds_Add_Sound(kSfxTHNDER2,  60, 180, 50, 100,    0,   0, -101, -101, 0, 0);
@@ -91,6 +91,9 @@ void SceneScriptRC03::InitializeScene() {
 
 	if (Game_Flag_Query(kFlagHC04toRC03)
 	 && Actor_Query_Goal_Number(kActorIzo) != kGoalIzoWaitingAtRC03
+#if !BLADERUNNER_ORIGINAL_BUGS
+	 && Actor_Query_Goal_Number(kActorIzo) != kGoalIzoEscape
+#endif // !BLADERUNNER_ORIGINAL_BUGS
 	) {
 		if (Random_Query(1, 3) == 1) {
 			// enhancement: don't always play this scene when exiting Hawker's Circle
@@ -283,20 +286,23 @@ void SceneScriptRC03::ActorChangedGoal(int actorId, int newGoal, int oldGoal, bo
 
 void SceneScriptRC03::talkWithSteele() {
 	Actor_Face_Actor(kActorSteele, kActorMcCoy, true);
-	Actor_Says(kActorSteele, 1820, 3);
+	Actor_Says(kActorSteele, 1820, kAnimationModeTalk);
 	Actor_Face_Actor(kActorMcCoy, kActorSteele, true);
 	Actor_Says(kActorMcCoy, 4815, 14);
-	Actor_Says(kActorSteele, 1830, 3);
-	Actor_Says(kActorSteele, 1840, 3);
+	Actor_Says(kActorSteele, 1830, kAnimationModeTalk);
+	Actor_Says(kActorSteele, 1840, kAnimationModeTalk);
 	Actor_Says(kActorMcCoy, 4820, 12);
-	Actor_Says(kActorSteele, 1850, 3);
-	Actor_Says(kActorSteele, 1950, 3);
+	Actor_Says(kActorSteele, 1850, kAnimationModeTalk);
+	if (_vm->_cutContent) {
+		Actor_Says(kActorMcCoy, 4825, 13);
+	}
+	Actor_Says(kActorSteele, 1950, kAnimationModeTalk);
 	Actor_Says(kActorMcCoy, 4835, 14);
-	Actor_Says(kActorSteele, 1960, 3);
-	Actor_Says(kActorSteele, 1980, 3);
+	Actor_Says(kActorSteele, 1960, kAnimationModeTalk);
+	Actor_Says(kActorSteele, 1980, kAnimationModeTalk);
 	Actor_Says(kActorMcCoy, 4840, 15);
-	Actor_Says(kActorSteele, 1990, 3);
-	Actor_Says(kActorSteele, 2000, 3);
+	Actor_Says(kActorSteele, 1990, kAnimationModeTalk);
+	Actor_Says(kActorSteele, 2000, kAnimationModeTalk);
 }
 
 void SceneScriptRC03::PlayerWalkedIn() {
@@ -376,7 +382,7 @@ void SceneScriptRC03::PlayerWalkedIn() {
 		}
 		talkWithSteele();
 		Async_Actor_Walk_To_Waypoint(kActorSteele, 174, 0, false);
-		Actor_Set_Goal_Number(kActorIzo, 200);
+		Actor_Set_Goal_Number(kActorIzo, kGoalIzoEscapedSteeleKnows);
 		Player_Gains_Control();
 	}
 	Game_Flag_Reset(kFlagUG01toRC03);
@@ -396,7 +402,7 @@ void SceneScriptRC03::PlayerWalkedOut() {
 		Actor_Set_Goal_Number(kActorIzo, kGoalIzoDieHidden);
 	}
 	Ambient_Sounds_Remove_All_Non_Looping_Sounds(true);
-	Ambient_Sounds_Remove_All_Looping_Sounds(1);
+	Ambient_Sounds_Remove_All_Looping_Sounds(1u);
 }
 
 void SceneScriptRC03::DialogueQueueFlushed(int a1) {
