@@ -32,7 +32,7 @@ class CGE2Engine;
 class CGE2Console : public GUI::Debugger {
 public:
 	CGE2Console(CGE2Engine *vm);
-	virtual ~CGE2Console();
+	~CGE2Console() override;
 
 private:
 	bool doCarpetWorkaround(int argc, const char **argv);
