@@ -29,20 +29,20 @@
 
 namespace Cine {
 
+// Size of AnimHeaderStruct payload in bytes
+#define ANIM_HEADER_SIZE 0x16
+
 struct AnimHeaderStruct {
-	byte field_0;
-	byte field_1;
-	byte field_2;
-	byte field_3;
-	uint16 frameWidth;
-	uint16 frameHeight;
+	char idString[4];
+	int16 frameWidth;
+	int16 frameHeight;
 	byte field_8;
 	byte field_9;
 	byte field_A;
 	byte field_B;
 	byte field_C;
 	byte field_D;
-	uint16 numFrames;
+	int16 numFrames;
 	byte field_10;
 	byte field_11;
 	byte field_12;
@@ -55,6 +55,11 @@ struct AnimDataEntry {
 	byte color;
 };
 
+struct AnimDataMapping {
+	char from[9];
+	char to[9];
+};
+
 #define ANIM_RAW 0 // memcpy
 #define ANIM_MASK 1 // convertMask
 #define ANIM_SPRITE 2 // gfxConvertSpriteToRaw
@@ -84,6 +89,8 @@ public:
 
 	AnimData &operator=(const AnimData &src);
 
+	int size() { return _size; }
+	int16 frameIndex() { return _frameIdx; }
 	const byte *data() const { return _data; } ///< Image data
 	const byte *mask() const { return _mask; } ///< Image mask (may be NULL)
 	byte getColor(int x, int y);
