@@ -54,6 +54,17 @@ void addSpriteFilledToBGList(int16 objIdx) {
 	renderer->incrustMask(g_cine->_bgIncrustList.back());
 }
 
+void removeBgIncrustsWithBgIdx(int16 bgIdx) {
+	Common::List<BGIncrust>::iterator it;
+	for (it = g_cine->_bgIncrustList.begin(); it != g_cine->_bgIncrustList.end();) {
+		if (it->bgIdx == bgIdx) {
+			it = g_cine->_bgIncrustList.erase(it);
+		} else {
+			++it;
+		}
+	}
+}
+
 /**
  * Add new element to incrust list
  * @param objIdx Element description
@@ -68,7 +79,8 @@ void createBgIncrustListElement(int16 objIdx, int16 param) {
 	tmp.x = g_cine->_objectTable[objIdx].x;
 	tmp.y = g_cine->_objectTable[objIdx].y;
 	tmp.frame = g_cine->_objectTable[objIdx].frame;
-	tmp.part = g_cine->_objectTable[objIdx].part;
+	tmp.part = g_cine->_objectTable[objIdx].part & 0x0f;
+	tmp.bgIdx = renderer->currentBg();
 
 	g_cine->_bgIncrustList.push_back(tmp);
 }
@@ -84,7 +96,7 @@ void resetBgIncrustList() {
  * Restore incrust list from savefile
  * @param fHandle Savefile open for reading
  */
-void loadBgIncrustFromSave(Common::SeekableReadStream &fHandle) {
+void loadBgIncrustFromSave(Common::SeekableReadStream &fHandle, bool hasBgIdx) {
 	BGIncrust tmp;
 	int size = fHandle.readSint16BE();
 
@@ -99,6 +111,7 @@ void loadBgIncrustFromSave(Common::SeekableReadStream &fHandle) {
 		tmp.y = fHandle.readUint16BE();
 		tmp.frame = fHandle.readUint16BE();
 		tmp.part = fHandle.readUint16BE();
+		tmp.bgIdx = (hasBgIdx ? fHandle.readUint16BE() : 0);
 
 		g_cine->_bgIncrustList.push_back(tmp);
 
