@@ -49,10 +49,6 @@ CineEngine::CineEngine(OSystem *syst, const CINEGameDescription *gameDesc)
 	: Engine(syst),
 	_gameDescription(gameDesc),
 	_rnd("cine") {
-	DebugMan.addDebugChannel(kCineDebugScript,    "Script",    "Script debug level");
-	DebugMan.addDebugChannel(kCineDebugPart,      "Part",      "Part debug level");
-	DebugMan.addDebugChannel(kCineDebugSound,     "Sound",     "Sound debug level");
-	DebugMan.addDebugChannel(kCineDebugCollision, "Collision", "Collision debug level");
 
 	// Setup mixer
 	syncSoundSettings();
@@ -74,8 +70,6 @@ CineEngine::~CineEngine() {
 	if (getGameType() == Cine::GType_OS) {
 		freeErrmessDat();
 	}
-
-	DebugMan.clearAllDebugChannels();
 }
 
 void CineEngine::syncSoundSettings() {
@@ -106,8 +100,12 @@ Common::Error CineEngine::run() {
 	// Initialize backend
 	initGraphics(320, 200);
 
-	if (g_cine->getGameType() == GType_FW && (g_cine->getFeatures() & GF_CD))
-		checkCD();
+	if (g_cine->getGameType() == GType_FW && (g_cine->getFeatures() & GF_CD)) {
+		if (!existExtractedCDAudioFiles()
+		    && !isDataAndCDAudioReadFromSameCD()) {
+			warnMissingExtractedCDAudio();
+		}
+	}
 
 	if (getPlatform() == Common::kPlatformDOS) {
 		g_sound = new PCSound(_mixer, this);
