@@ -23,7 +23,7 @@
 namespace Composer {
 
 static const ComposerGameDescription gameDescriptions[] = {
-	// Magic Tales: Baba Yaga and the Magic Geese - from bug #3485018
+	// Magic Tales: Baba Yaga and the Magic Geese - from bug #5964
 	{
 		{
 			"babayaga",
@@ -40,7 +40,7 @@ static const ComposerGameDescription gameDescriptions[] = {
 		GType_ComposerV1
 	},
 
-	// Magic Tales: Baba Yaga and the Magic Geese Mac - from bug #3466402, #7025
+	// Magic Tales: Baba Yaga and the Magic Geese Mac - from bug #5934, #7025
 	{
 		{
 			"babayaga",
@@ -75,7 +75,24 @@ static const ComposerGameDescription gameDescriptions[] = {
 		GType_ComposerV1
 	},
 
-	// Magic Tales: Imo and the King - from bug #3485018
+	// Magic Tales: Baba Yaga and the Magic Geese French- from bug #12122
+	{
+		{
+			"babayaga",
+			0,
+			{
+				{"book.ini", GAME_CONFIGFILE, "966a4ee9226d96085c953bb4f9426c06", 3940},
+				AD_LISTEND
+			},
+			Common::FR_FRA,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			GUIO2(GUIO_NOASPECT, GUIO_NOMIDI)
+		},
+		GType_ComposerV1
+	},
+
+	// Magic Tales: Imo and the King - from bug #5964
 	{
 		{
 			"imoking",
@@ -109,6 +126,23 @@ static const ComposerGameDescription gameDescriptions[] = {
 		GType_ComposerV1
 	},
 
+	// Magic Tales: Imo and the King French Windows. Bugreport #12123
+	{
+		{
+			"imoking",
+			0,
+			{
+				{"book.ini", GAME_CONFIGFILE, "753d3be27f54d564d8d1bff2b9f0d14f", 3375},
+				AD_LISTEND
+			},
+			Common::FR_FRA,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			GUIO2(GUIO_NOASPECT, GUIO_NOMIDI)
+		},
+		GType_ComposerV1
+	},
+
 	// Magic Tales: Imo and the King Hebrew Macintosh
 	{
 		{
@@ -194,7 +228,7 @@ static const ComposerGameDescription gameDescriptions[] = {
 		GType_ComposerV1
 	},
 
-	// Magic Tales: Imo and the King Mac - from bug #3466402
+	// Magic Tales: Imo and the King Mac - from bug #5934
 	{
 		{
 			"imoking",
@@ -229,7 +263,7 @@ static const ComposerGameDescription gameDescriptions[] = {
 		GType_ComposerV1
 	},
 
-	// Magic Tales: The Little Samurai - from bug #3485018
+	// Magic Tales: The Little Samurai - from bug #5964
 	{
 		{
 			"littlesamurai",
@@ -246,7 +280,24 @@ static const ComposerGameDescription gameDescriptions[] = {
 		GType_ComposerV1
 	},
 
-	// Magic Tales: The Little Samurai Mac - from bug #3466402
+	// Magic Tales: The Little Samurai - French from bug #12124
+	{
+		{
+			"littlesamurai",
+			0,
+			{
+				{"book.ini", GAME_CONFIGFILE, "1e9199e31b4f93c5e5caeedd3c2e7c0b", 3833},
+				AD_LISTEND
+			},
+			Common::FR_FRA,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			GUIO2(GUIO_NOASPECT, GUIO_NOMIDI)
+		},
+		GType_ComposerV1
+	},
+
+	// Magic Tales: The Little Samurai Mac - from bug #5934
 	{
 		{
 			"littlesamurai",
@@ -365,7 +416,7 @@ static const ComposerGameDescription gameDescriptions[] = {
 		GType_ComposerV2
 	},
 
-	// Liam Finds a Story Mac - from bug #3463201
+	// Liam Finds a Story Mac - from bug #5931
 	{
 		{
 			"liam",
@@ -581,7 +632,7 @@ static const ComposerGameDescription gameDescriptions[] = {
 		GType_ComposerV2
 	},
 
-	// The Princess and the Crab Mac - From Bug #3461984
+	// The Princess and the Crab Mac - From Bug #5928
 	{
 		{
 			"princess",
@@ -616,7 +667,7 @@ static const ComposerGameDescription gameDescriptions[] = {
 		GType_ComposerV2
 	},
 
-	// Sleeping Cub Mac - From Bug #3461369
+	// Sleeping Cub Mac - From Bug #5927
 	{
 		{
 			"sleepingcub",
