@@ -71,14 +71,6 @@ struct color_t {
 	uint16   a, r, g, b;
 };
 
-struct HNMHeader {
-	int32   _signature;
-	uint16  _width;
-	uint16  _height;
-	int32   _numbFrame;
-	int32   _bufferSize;
-};
-
 void SysBeep(int x);
 void FlushEvents(int16 arg1, int16 arg2);
 
@@ -86,7 +78,7 @@ void CLBlitter_CopyViewRect(View *view1, View *view2, Common::Rect *rect1, Commo
 void CLBlitter_Send2ScreenNextCopy(color_t *palette, uint16 first, uint16 count);
 void CLBlitter_OneBlackFlash();
 void CLBlitter_CopyView2ViewSimpleSize(byte *src, int16 srcw, int16 srcp, int16 srch,
-                                       byte *dst, int16 dstw, int16 dstp, int16 dsth);
+									   byte *dst, int16 dstw, int16 dstp, int16 dsth);
 void CLBlitter_CopyView2ScreenCUSTOM(View *view);
 void CLBlitter_CopyView2Screen(View *view);
 void CLBlitter_UpdateScreen();
