@@ -24,16 +24,18 @@
 #include "cryo/platdefs.h"
 #include "cryo/cryolib.h"
 #include "cryo/eden.h"
-#include "cryo/sound.h"
 #include "cryo/eden_graphics.h"
-#include "cryo/video.h"
+
+#include "graphics/conversion.h"
+#include "graphics/palette.h"
+#include "video/hnm_decoder.h"
 
 namespace Cryo {
 
-EdenGraphics::EdenGraphics(EdenGame *game, HnmPlayer *video) : _game(game), _video(video) {
+EdenGraphics::EdenGraphics(EdenGame *game) : _game(game) {
 	_glowH = _glowW = _glowY = _glowX = 0;
 	_showVideoSubtitle = false;
-	_showBlackBars = false;	
+	_showBlackBars = false;
 	_mainView = nullptr;
 	_mainViewBuf = nullptr;
 	_hnmView = nullptr;
@@ -45,6 +47,20 @@ EdenGraphics::EdenGraphics(EdenGame *game, HnmPlayer *video) : _game(game), _vid
 	_subtitlesView = nullptr;
 	_underBarsView = nullptr;
 	_needToFade = false;
+	
+	_savedUnderSubtitles = false;
+	_underSubtitlesViewBuf = nullptr;
+	_hnmViewBuf = nullptr;
+	_hnmFrameNum = 0;
+	_videoCanceledFlag = false;
+
+	for (int i = 0; i < 256; ++i) {
+		_globalPalette[i].a = _globalPalette[i].r = _globalPalette[i].g = _globalPalette[i].b = 0;
+		_oldPalette[i].a = _oldPalette[i].r = _oldPalette[i].g = _oldPalette[i].b = 0;
+		_newPalette[i].a = _newPalette[i].r = _newPalette[i].g = _newPalette[i].b = 0; 
+	}
+
+	_newColor.r = _newColor.g = _newColor.b = 0;
 }
 
 void EdenGraphics::SendPalette2Screen(int16 value) {
@@ -208,25 +224,25 @@ void EdenGraphics::loadMouthRectFromCurChar() {
 void EdenGraphics::paneltobuf() {
 	setSrcRect(0, 16, 320 - 1, 169 - 1);
 	setDestRect(320, 16, 640 - 1, 169 - 1);
-	CLBlitter_CopyViewRect(getMainView(), getMainView(), &_rect_src, &_rect_dst);	
+	CLBlitter_CopyViewRect(getMainView(), getMainView(), &_rect_src, &_rect_dst);
 }
 
 void EdenGraphics::cursbuftopanel() {
 	setSrcRect(434, 40, 525 - 1, 111 - 1);
 	setDestRect(114, 40, 205 - 1, 111 - 1);
-	CLBlitter_CopyViewRect(getMainView(), getMainView(), &_rect_src, &_rect_dst);	
+	CLBlitter_CopyViewRect(getMainView(), getMainView(), &_rect_src, &_rect_dst);
 }
 
 void EdenGraphics::langbuftopanel() {
 	setSrcRect(328, 42, 407 - 1, 97 - 1);
 	setDestRect(8, 42,  87 - 1, 97 - 1);
-	CLBlitter_CopyViewRect(getMainView(), getMainView(), &_rect_src, &_rect_dst);	
+	CLBlitter_CopyViewRect(getMainView(), getMainView(), &_rect_src, &_rect_dst);
 }
 
 // Original name: sauvefondbouche
 void EdenGraphics::saveMouthBackground() {
 	loadMouthRectFromCurChar();
-	CLBlitter_CopyViewRect(getMainView(), getMainView(), &_rect_src, &_rect_dst);	
+	CLBlitter_CopyViewRect(getMainView(), getMainView(), &_rect_src, &_rect_dst);
 }
 
 // Original name: restaurefondbouche
@@ -262,7 +278,7 @@ void EdenGraphics::sundcurs(int16 x, int16 y) {
 			*keep++ = *scr++;
 		scr += 640 - 48;
 	}
-	_game->setCursorSaved(true);;
+	_game->setCursorSaved(true);
 }
 
 void EdenGraphics::rundcurs() {
@@ -1167,21 +1183,40 @@ void EdenGraphics::effetpix() {
 
 ////// film.c
 // Original name: showfilm
-void EdenGraphics::showMovie(char arg1) {
-	_video->readHeader();
-	if (_game->_globals->_curVideoNum == 92) {
-		// _hnmContext->_header._unusedFlag2 = 0; CHECKME: Useless?
-		_game->setVolume(0);
+void EdenGraphics::showMovie(int16 num, char arg1) {
+	Common::SeekableReadStream *stream = _game->loadSubStream(num - 1 + 485);
+	if (!stream) {
+		warning("Could not load movie %d", num);
+		return;
 	}
 
-	if (_video->getVersion() != 4)
-		return;
+	int16 j = 0;
+	color_t palette16[256];
+	byte *palette = new byte[256 * 3];
+	CLPalette_GetLastPalette(palette16);
+	for (int16 i = 0; i < 256; i++) {
+		palette[j++] = palette16[i].r >> 8;
+		palette[j++] = palette16[i].g >> 8;
+		palette[j++] = palette16[i].b >> 8;
+	}
 
-	bool playing = true;
-	_video->allocMemory();
-	_hnmView = new View(_video->_header._width, _video->_header._height);
+	Video::VideoDecoder *decoder = new Video::HNMDecoder(false, palette);
+	if (!decoder->loadStream(stream)) {
+		warning("Could not load movie %d", num);
+		delete decoder;
+		delete stream;
+		return;
+	}
+
+	if (_game->_globals->_curVideoNum == 92) {
+		decoder->setVolume(0);
+	}
+
+	decoder->start();
+
+	_hnmView = new View(decoder->getWidth(), decoder->getHeight());
 	_hnmView->setSrcZoomValues(0, 0);
-	_hnmView->setDisplayZoomValues(_video->_header._width * 2, _video->_header._height * 2);
+	_hnmView->setDisplayZoomValues(decoder->getWidth() * 2, decoder->getHeight() * 2);
 	_hnmView->centerIn(_game->_vm->_screenView);
 	_hnmViewBuf = _hnmView->_bufferPtr;
 	if (arg1) {
@@ -1190,15 +1225,30 @@ void EdenGraphics::showMovie(char arg1) {
 		_hnmView->_normal._dstTop = _mainView->_normal._dstTop + 16;
 		_hnmView->_zoom._dstTop = _mainView->_zoom._dstTop + 32;
 	}
-	_video->setFinalBuffer(_hnmView->_bufferPtr);
+
 	do {
-		_hnmFrameNum = _video->getFrameNum();
-		_video->waitLoop();
-		playing = _video->nextElement();
+		if (decoder->needsUpdate()) {
+			const Graphics::Surface *frame = decoder->decodeNextFrame();
+			if (frame) {
+				Graphics::copyBlit(_hnmView->_bufferPtr, (const byte *)frame->getPixels(), _hnmView->_pitch, frame->pitch, frame->w, frame->h, 1);
+			}
+			if (decoder->hasDirtyPalette()) {
+				const byte *framePalette = decoder->getPalette();
+				for (int i = 0; i < 256; i++) {
+					palette16[i].r = framePalette[(i * 3) + 0] << 8;
+					palette16[i].g = framePalette[(i * 3) + 1] << 8;
+					palette16[i].b = framePalette[(i * 3) + 2] << 8;
+				}
+				CLBlitter_Send2ScreenNextCopy(palette16, 0, 256);
+			}
+		}
+		_hnmFrameNum = decoder->getCurFrame();
+
 		if (_game->getSpecialTextMode())
 			handleHNMSubtitles();
 		else
 			_game->musicspy();
+
 		CLBlitter_CopyView2Screen(_hnmView);
 		assert(_game->_vm->_screenView->_pitch == 320);
 		_game->_vm->pollEvents();
@@ -1213,9 +1263,12 @@ void EdenGraphics::showMovie(char arg1) {
 			else
 				_game->setMouseNotHeld();
 		}
-	} while (playing && !_videoCanceledFlag);
+
+		g_system->delayMillis(10);
+	} while (!_game->_vm->shouldQuit() && !decoder->endOfVideo() && !_videoCanceledFlag);
+
 	delete _hnmView;
-	_video->deallocMemory();
+	delete decoder;
 }
 
 bool EdenGraphics::getShowBlackBars() {
@@ -1247,20 +1300,20 @@ void EdenGraphics::playHNM(int16 num) {
 	}
 	_showVideoSubtitle = false;
 	_videoCanceledFlag = false;
-	_game->loadHnm(num);
-	_video->reset();
+
 	if (_needToFade) {
 		fadeToBlack(4);
 		clearScreen();
 		_needToFade = false;
 	}
 	if (num == 2012 || num == 98 || num == 171)
-		showMovie(0);
+		showMovie(num, 0);
 	else
-		showMovie(1);
+		showMovie(num, 1);
+
 	_cursKeepPos = Common::Point(-1, -1);
 	if (_game->getSpecialTextMode()) {
-		_game->setMusicFade(3);;
+		_game->setMusicFade(3);
 		_game->musicspy();
 		_game->_globals->_characterPtr = perso;
 		_game->_globals->_dialogType = oldDialogType;
@@ -1289,7 +1342,7 @@ void EdenGraphics::initGlobals() {
 	_underSubtitlesBackupRect.top = 0;
 	_underSubtitlesBackupRect.left = _subtitlesXScrMargin;
 	_underSubtitlesBackupRect.right = _subtitlesXScrMargin + _subtitlesXWidth - 1;
-	_underSubtitlesBackupRect.bottom = 60 - 1;	
+	_underSubtitlesBackupRect.bottom = 60 - 1;
 }
 
 // Original name: sauvefondbulle
