@@ -36,6 +36,7 @@
 #include "gui/ThemeEngine.h"
 #include "gui/ThemeEval.h"
 #include "gui/widget.h"
+#include "gui/widgets/tab.h"
 
 #include "graphics/font.h"
 
@@ -43,23 +44,6 @@
 #include "engines/engine.h"
 #include "engines/metaengine.h"
 
-#ifdef GUI_ENABLE_KEYSDIALOG
-#include "gui/KeysDialog.h"
-#endif
-
-class ConfigDialog : public GUI::OptionsDialog {
-protected:
-#ifdef GUI_ENABLE_KEYSDIALOG
-	GUI::Dialog		*_keysDialog;
-#endif
-
-public:
-	ConfigDialog(bool subtitleControls);
-	~ConfigDialog();
-
-	virtual void handleCommand(GUI::CommandSender *sender, uint32 cmd, uint32 data);
-};
-
 MainMenuDialog::MainMenuDialog(Engine *engine)
 	: GUI::Dialog("GlobalMenu"), _engine(engine) {
 	_backgroundType = GUI::ThemeEngine::kDialogBackgroundSpecial;
@@ -71,54 +55,52 @@ MainMenuDialog::MainMenuDialog(Engine *engine)
 		_logo->useThemeTransparency(true);
 		_logo->setGfx(g_gui.theme()->getImageSurface(GUI::ThemeEngine::kImageLogoSmall));
 	} else {
-		GUI::StaticTextWidget *title = new GUI::StaticTextWidget(this, "GlobalMenu.Title", "ScummVM");
+		GUI::StaticTextWidget *title = new GUI::StaticTextWidget(this, "GlobalMenu.Title", Common::U32String("ScummVM"));
 		title->setAlign(Graphics::kTextAlignCenter);
 	}
 #else
-	GUI::StaticTextWidget *title = new GUI::StaticTextWidget(this, "GlobalMenu.Title", "ScummVM");
+	GUI::StaticTextWidget *title = new GUI::StaticTextWidget(this, "GlobalMenu.Title", Common::U32String("ScummVM"));
 	title->setAlign(Graphics::kTextAlignCenter);
 #endif
 
-	GUI::StaticTextWidget *version = new GUI::StaticTextWidget(this, "GlobalMenu.Version", gScummVMVersionDate);
+	GUI::StaticTextWidget *version = new GUI::StaticTextWidget(this, "GlobalMenu.Version", Common::U32String(gScummVMVersionDate));
 	version->setAlign(Graphics::kTextAlignCenter);
 
-	new GUI::ButtonWidget(this, "GlobalMenu.Resume", _("~R~esume"), 0, kPlayCmd, 'P');
+	new GUI::ButtonWidget(this, "GlobalMenu.Resume", _("~R~esume"), Common::U32String(), kPlayCmd, 'P');
 
-	_loadButton = new GUI::ButtonWidget(this, "GlobalMenu.Load", _("~L~oad"), 0, kLoadCmd);
+	_loadButton = new GUI::ButtonWidget(this, "GlobalMenu.Load", _("~L~oad"), Common::U32String(), kLoadCmd);
 	_loadButton->setVisible(_engine->hasFeature(Engine::kSupportsLoadingDuringRuntime));
 	_loadButton->setEnabled(_engine->hasFeature(Engine::kSupportsLoadingDuringRuntime));
 
-	_saveButton = new GUI::ButtonWidget(this, "GlobalMenu.Save", _("~S~ave"), 0, kSaveCmd);
+	_saveButton = new GUI::ButtonWidget(this, "GlobalMenu.Save", _("~S~ave"), Common::U32String(), kSaveCmd);
 	_saveButton->setVisible(_engine->hasFeature(Engine::kSupportsSavingDuringRuntime));
 	_saveButton->setEnabled(_engine->hasFeature(Engine::kSupportsSavingDuringRuntime));
 
-	new GUI::ButtonWidget(this, "GlobalMenu.Options", _("~O~ptions"), 0, kOptionsCmd);
+	new GUI::ButtonWidget(this, "GlobalMenu.Options", _("~O~ptions"), Common::U32String(), kOptionsCmd);
 
 	// The help button is disabled by default.
 	// To enable "Help", an engine needs to use a subclass of MainMenuDialog
 	// (at least for now, we might change how this works in the future).
-	_helpButton = new GUI::ButtonWidget(this, "GlobalMenu.Help", _("~H~elp"), 0, kHelpCmd);
+	_helpButton = new GUI::ButtonWidget(this, "GlobalMenu.Help", _("~H~elp"), Common::U32String(), kHelpCmd);
 
-	new GUI::ButtonWidget(this, "GlobalMenu.About", _("~A~bout"), 0, kAboutCmd);
+	new GUI::ButtonWidget(this, "GlobalMenu.About", _("~A~bout"), Common::U32String(), kAboutCmd);
 
-	if (g_system->getOverlayWidth() > 320)
-		_rtlButton = new GUI::ButtonWidget(this, "GlobalMenu.RTL", _("~R~eturn to Launcher"), 0, kRTLCmd);
+	if (g_gui.getGUIWidth() > 320)
+		_returnToLauncherButton = new GUI::ButtonWidget(this, "GlobalMenu.ReturnToLauncher", _("~R~eturn to Launcher"), Common::U32String(), kLauncherCmd);
 	else
-		_rtlButton = new GUI::ButtonWidget(this, "GlobalMenu.RTL", _c("~R~eturn to Launcher", "lowres"), 0, kRTLCmd);
-	_rtlButton->setEnabled(_engine->hasFeature(Engine::kSupportsRTL));
+		_returnToLauncherButton = new GUI::ButtonWidget(this, "GlobalMenu.ReturnToLauncher", _c("~R~eturn to Launcher", "lowres"), Common::U32String(), kLauncherCmd);
+	_returnToLauncherButton->setEnabled(_engine->hasFeature(Engine::kSupportsReturnToLauncher));
 
-
-	new GUI::ButtonWidget(this, "GlobalMenu.Quit", _("~Q~uit"), 0, kQuitCmd);
+	if (!g_system->hasFeature(OSystem::kFeatureNoQuit) && (!(ConfMan.getBool("gui_return_to_launcher_at_exit")) || !_engine->hasFeature(Engine::kSupportsReturnToLauncher)))
+		new GUI::ButtonWidget(this, "GlobalMenu.Quit", _("~Q~uit"), Common::U32String(), kQuitCmd);
 
 	_aboutDialog = new GUI::AboutDialog();
-	_optionsDialog = new ConfigDialog(_engine->hasFeature(Engine::kSupportsSubtitleOptions));
 	_loadDialog = new GUI::SaveLoadChooser(_("Load game:"), _("Load"), false);
 	_saveDialog = new GUI::SaveLoadChooser(_("Save game:"), _("Save"), true);
 }
 
 MainMenuDialog::~MainMenuDialog() {
 	delete _aboutDialog;
-	delete _optionsDialog;
 	delete _loadDialog;
 	delete _saveDialog;
 }
@@ -134,9 +116,11 @@ void MainMenuDialog::handleCommand(GUI::CommandSender *sender, uint32 cmd, uint3
 	case kSaveCmd:
 		save();
 		break;
-	case kOptionsCmd:
-		_optionsDialog->runModal();
+	case kOptionsCmd: {
+		GUI::ConfigDialog configDialog;
+		configDialog.runModal();
 		break;
+	}
 	case kAboutCmd:
 		_aboutDialog->runModal();
 		break;
@@ -148,10 +132,10 @@ void MainMenuDialog::handleCommand(GUI::CommandSender *sender, uint32 cmd, uint3
 		dialog.runModal();
 		}
 		break;
-	case kRTLCmd: {
-		Common::Event eventRTL;
-		eventRTL.type = Common::EVENT_RTL;
-		g_system->getEventManager()->pushEvent(eventRTL);
+	case kLauncherCmd: {
+		Common::Event eventReturnToLauncher;
+		eventReturnToLauncher.type = Common::EVENT_RETURN_TO_LAUNCHER;
+		g_system->getEventManager()->pushEvent(eventReturnToLauncher);
 		close();
 		}
 		break;
@@ -177,10 +161,10 @@ void MainMenuDialog::reflowLayout() {
 	// Update labels when it might be needed
 	// FIXME: it might be better to declare GUI::StaticTextWidget::setLabel() virtual
 	// and to reimplement it in GUI::ButtonWidget to handle the hotkey.
-	if (g_system->getOverlayWidth() > 320)
-		_rtlButton->setLabel(_rtlButton->cleanupHotkey(_("~R~eturn to Launcher")));
+	if (g_gui.getGUIWidth() > 320)
+		_returnToLauncherButton->setLabel(_returnToLauncherButton->cleanupHotkey(_("~R~eturn to Launcher")));
 	else
-		_rtlButton->setLabel(_rtlButton->cleanupHotkey(_c("~R~eturn to Launcher", "lowres")));
+		_returnToLauncherButton->setLabel(_returnToLauncherButton->cleanupHotkey(_c("~R~eturn to Launcher", "lowres")));
 
 #ifndef DISABLE_FANCY_THEMES
 	if (g_gui.xmlEval()->getVar("Globals.ShowGlobalMenuLogo", 0) == 1 && g_gui.theme()->supportsImages()) {
@@ -198,7 +182,7 @@ void MainMenuDialog::reflowLayout() {
 	} else {
 		GUI::StaticTextWidget *title = (GUI::StaticTextWidget *)findWidget("GlobalMenu.Title");
 		if (!title) {
-			title = new GUI::StaticTextWidget(this, "GlobalMenu.Title", "ScummVM");
+			title = new GUI::StaticTextWidget(this, "GlobalMenu.Title", Common::U32String("ScummVM"));
 			title->setAlign(Graphics::kTextAlignCenter);
 		}
 
@@ -217,11 +201,6 @@ void MainMenuDialog::reflowLayout() {
 void MainMenuDialog::save() {
 	int slot = _saveDialog->runModalWithCurrentTarget();
 
-	#if defined(__PLAYSTATION2__) && defined(DYNAMIC_MODULES)
-	char pokeme[32];
-	snprintf(pokeme,32,"hack");
-	#endif
-
 	if (slot >= 0) {
 		Common::String result(_saveDialog->getResultString());
 		if (result.empty()) {
@@ -231,7 +210,7 @@ void MainMenuDialog::save() {
 
 		Common::Error status = _engine->saveGameState(slot, result);
 		if (status.getCode() != Common::kNoError) {
-			Common::String failMessage = Common::String::format(_("Failed to save game (%s)! "
+			Common::U32String failMessage = Common::U32String::format(_("Failed to save game (%s)! "
 				  "Please consult the README for basic information, and for "
 				  "instructions on how to obtain further assistance."), status.getDesc().c_str());
 			GUI::MessageDialog dialog(failMessage);
@@ -251,9 +230,7 @@ void MainMenuDialog::load() {
 		close();
 }
 
-enum {
-	kKeysCmd = 'KEYS'
-};
+namespace GUI {
 
 // FIXME: We use the empty string as domain name here. This tells the
 // ConfigManager to use the 'default' domain for all its actions. We do that
@@ -280,60 +257,183 @@ enum {
 // These changes will achieve two things at once: Allow us to get rid of using
 //  "" as value for the domain, and in fact provide a somewhat better user
 // experience at the same time.
-ConfigDialog::ConfigDialog(bool subtitleControls)
-	: GUI::OptionsDialog("", "GlobalConfig") {
+ConfigDialog::ConfigDialog() :
+		GUI::OptionsDialog("", "GlobalConfig"),
+		_engineOptions(nullptr) {
+	assert(g_engine);
+
+	const Common::String &gameDomain = ConfMan.getActiveDomainName();
+	const MetaEngine *metaEngine = g_engine->getMetaEngine();
+	const MetaEngineDetection &metaEngineDetection = g_engine->getMetaEngineDetection();
+
+	// GUI:  Add tab widget
+	GUI::TabWidget *tab = new GUI::TabWidget(this, "GlobalConfig.TabWidget");
+
+	//
+	// The game specific options tab
+	//
+
+	int tabId = tab->addTab(_("Game"), "GlobalConfig_Engine");
+
+	if (g_engine->hasFeature(Engine::kSupportsChangingOptionsDuringRuntime)) {
+		_engineOptions = metaEngine->buildEngineOptionsWidgetDynamic(tab, "GlobalConfig_Engine.Container", gameDomain);
+		if (!_engineOptions)
+			_engineOptions = metaEngineDetection.buildEngineOptionsWidgetStatic(tab, "GlobalConfig_Engine.Container", gameDomain);
+	}
+
+	if (_engineOptions) {
+		_engineOptions->setParentDialog(this);
+	} else {
+		tab->removeTab(tabId);
+	}
+
+	//
+	// The Audio / Subtitles tab
+	//
+
+	tab->addTab(_("Audio"), "GlobalConfig_Audio");
 
 	//
 	// Sound controllers
 	//
 
-	addVolumeControls(this, "GlobalConfig.");
+	addVolumeControls(tab, "GlobalConfig_Audio.");
 	setVolumeSettingsState(true); // could disable controls by GUI options
 
 	//
 	// Subtitle speed and toggle controllers
 	//
 
-	if (subtitleControls) {
+	if (g_engine->hasFeature(Engine::kSupportsSubtitleOptions)) {
 		// Global talkspeed range of 0-255
-		addSubtitleControls(this, "GlobalConfig.", 255);
+		addSubtitleControls(tab, "GlobalConfig_Audio.", 255);
 		setSubtitleSettingsState(true); // could disable controls by GUI options
 	}
 
+	//
+	// The Keymap tab
+	//
+
+	Common::KeymapArray keymaps = metaEngine->initKeymaps(gameDomain.c_str());
+	if (!keymaps.empty()) {
+		tab->addTab(_("Keymaps"), "GlobalConfig_KeyMapper");
+		addKeyMapperControls(tab, "GlobalConfig_KeyMapper.", keymaps, gameDomain);
+	}
+
+	//
+	// The backend tab (shown only if the backend implements one)
+	//
+	int backendTabId = tab->addTab(_("Backend"), "GlobalConfig_Backend");
+
+	_backendOptions = g_system->buildBackendOptionsWidget(tab, "GlobalConfig_Backend.Container", _domain);
+
+	if (_backendOptions) {
+		_backendOptions->setParentDialog(this);
+	} else {
+		tab->removeTab(backendTabId);
+	}
+
+	//
+	// The Achievements & The Statistics tabs
+	//
+	AchMan.setActiveDomain(metaEngine->getAchievementsInfo(gameDomain));
+	if (AchMan.getAchievementCount()) {
+		tab->addTab(_("Achievements"), "GlobalConfig_Achievements");
+		addAchievementsControls(tab, "GlobalConfig_Achievements.");
+	}
+	if (AchMan.getStatCount()) {
+		tab->addTab(_("Statistics"), "GlobalConfig_Achievements");
+		addStatisticsControls(tab, "GlobalConfig_Achievements.");
+	}
+
+	// Activate the first tab
+	tab->setActiveTab(0);
+
 	//
 	// Add the buttons
 	//
 
-	new GUI::ButtonWidget(this, "GlobalConfig.Ok", _("~O~K"), 0, GUI::kOKCmd);
-	new GUI::ButtonWidget(this, "GlobalConfig.Cancel", _("~C~ancel"), 0, GUI::kCloseCmd);
-
-#ifdef GUI_ENABLE_KEYSDIALOG
-	new GUI::ButtonWidget(this, "GlobalConfig.Keys", _("~K~eys"), 0, kKeysCmd);
-	_keysDialog = NULL;
-#endif
+	new GUI::ButtonWidget(this, "GlobalConfig.Ok", _("~O~K"), Common::U32String(), GUI::kOKCmd);
+	new GUI::ButtonWidget(this, "GlobalConfig.Cancel", _("~C~ancel"), Common::U32String(), GUI::kCloseCmd);
 }
 
 ConfigDialog::~ConfigDialog() {
-#ifdef GUI_ENABLE_KEYSDIALOG
-	delete _keysDialog;
-#endif
 }
 
-void ConfigDialog::handleCommand(GUI::CommandSender *sender, uint32 cmd, uint32 data) {
-	switch (cmd) {
-	case kKeysCmd:
+void ConfigDialog::build() {
+	OptionsDialog::build();
 
-#ifdef GUI_ENABLE_KEYSDIALOG
-	//
-	// Create the sub dialog(s)
-	//
-	_keysDialog = new GUI::KeysDialog();
-	_keysDialog->runModal();
-	delete _keysDialog;
-	_keysDialog = NULL;
-#endif
-		break;
-	default:
-		GUI::OptionsDialog::handleCommand (sender, cmd, data);
+	// Engine options
+	if (_engineOptions) {
+		_engineOptions->load();
 	}
 }
+
+void ConfigDialog::apply() {
+	if (_engineOptions) {
+		_engineOptions->save();
+	}
+
+	OptionsDialog::apply();
+}
+
+ExtraGuiOptionsWidget::ExtraGuiOptionsWidget(GuiObject *containerBoss, const Common::String &name, const Common::String &domain, const ExtraGuiOptions &options) :
+		OptionsContainerWidget(containerBoss, name, dialogLayout(domain), true, domain),
+		_options(options) {
+
+	for (uint i = 0; i < _options.size(); i++) {
+		Common::String id = Common::String::format("%d", i + 1);
+		_checkboxes.push_back(new CheckboxWidget(widgetsBoss(),
+			_dialogLayout + ".customOption" + id + "Checkbox", _(_options[i].label), _(_options[i].tooltip)));
+	}
+}
+
+ExtraGuiOptionsWidget::~ExtraGuiOptionsWidget() {
+}
+
+Common::String ExtraGuiOptionsWidget::dialogLayout(const Common::String &domain) {
+	if (ConfMan.getActiveDomainName().equals(domain)) {
+		return "GlobalConfig_Engine_Container";
+	} else {
+		return "GameOptions_Engine_Container";
+	}
+}
+
+void ExtraGuiOptionsWidget::load() {
+	// Set the state of engine-specific checkboxes
+	for (uint j = 0; j < _options.size() && j < _checkboxes.size(); ++j) {
+		// The default values for engine-specific checkboxes are not set when
+		// ScummVM starts, as this would require us to load and poll all of the
+		// engine plugins on startup. Thus, we set the state of each custom
+		// option checkbox to what is specified by the engine plugin, and
+		// update it only if a value has been set in the configuration of the
+		// currently selected game.
+		bool isChecked = _options[j].defaultState;
+		if (ConfMan.hasKey(_options[j].configOption, _domain))
+			isChecked = ConfMan.getBool(_options[j].configOption, _domain);
+		_checkboxes[j]->setState(isChecked);
+	}
+}
+
+bool ExtraGuiOptionsWidget::save() {
+	// Set the state of engine-specific checkboxes
+	for (uint i = 0; i < _options.size() && i < _checkboxes.size(); i++) {
+		ConfMan.setBool(_options[i].configOption, _checkboxes[i]->getState(), _domain);
+	}
+
+	return true;
+}
+
+void ExtraGuiOptionsWidget::defineLayout(ThemeEval& layouts, const Common::String& layoutName, const Common::String& overlayedLayout) const {
+	layouts.addDialog(layoutName, overlayedLayout);
+	layouts.addLayout(GUI::ThemeLayout::kLayoutVertical).addPadding(8, 8, 8, 8);
+
+	for (uint i = 0; i < _options.size(); i++) {
+		Common::String id = Common::String::format("%d", i + 1);
+		layouts.addWidget("customOption" + id + "Checkbox", "Checkbox");
+	}
+
+	layouts.closeLayout().closeDialog();
+}
+
+} // End of namespace GUI
