@@ -46,21 +46,43 @@ class ScriptCastMember;
 class ShapeCastMember;
 class TextCastMember;
 
+typedef Common::HashMap<byte, byte> CharMap;
+typedef Common::HashMap<uint16, uint16> FontSizeMap;
+struct FontXPlatformInfo {
+	Common::String toFont;
+		bool remapChars;
+	FontSizeMap sizeMap;
+
+	FontXPlatformInfo() : remapChars(false) {}
+};
+typedef Common::HashMap<Common::String, FontXPlatformInfo *> FontXPlatformMap;
+
+struct FontMapEntry {
+	uint16 toFont;
+	bool remapChars;
+	FontSizeMap sizeMap;
+
+	FontMapEntry() : toFont(0), remapChars(false) {}
+};
+typedef Common::HashMap<uint16, FontMapEntry *> FontMap;
+
 class Cast {
 public:
-	Cast(Movie *movie, bool shared = false);
+	Cast(Movie *movie, uint16 castLibID, bool shared = false);
 	~Cast();
 
-	bool loadArchive();
+	void loadArchive();
 	void setArchive(Archive *archive);
 	Archive *getArchive() const { return _castArchive; };
 	Common::String getMacName() const { return _macName; }
 
-	void loadConfig(Common::SeekableReadStreamEndian &stream);
+	bool loadConfig();
+	void loadCast();
 	void loadCastDataVWCR(Common::SeekableReadStreamEndian &stream);
 	void loadCastData(Common::SeekableReadStreamEndian &stream, uint16 id, Resource *res);
 	void loadCastInfo(Common::SeekableReadStreamEndian &stream, uint16 id);
 	void loadLingoContext(Common::SeekableReadStreamEndian &stream);
+	void loadExternalSound(Common::SeekableReadStreamEndian &stream);
 
 	void loadCastChildren();
 	void loadSoundCasts();
@@ -75,17 +97,33 @@ public:
 	const Stxt *getStxt(int castId);
 	Common::String getVideoPath(int castId);
 
+	// release all castmember's widget, should be called when we are changing movie.
+	// because widget is handled by channel, thus we should clear all of those run-time info when we are switching the movie. (because we will create new widgets for cast)
+	void releaseCastMemberWidget();
+
 	void dumpScript(const char *script, ScriptType type, uint16 id);
+	PaletteV4 loadPalette(Common::SeekableReadStreamEndian &stream);
+
+	Common::CodePage getPlatformEncoding();
+	Common::U32String decodeString(const Common::String &str);
 
 private:
-	PaletteV4 loadPalette(Common::SeekableReadStreamEndian &stream);
-	void loadScriptText(Common::SeekableReadStreamEndian &stream);
+	void loadScriptText(Common::SeekableReadStreamEndian &stream, uint16 id);
 	void loadFontMap(Common::SeekableReadStreamEndian &stream);
-	Common::String getString(Common::String str);
+	void loadFontMapV4(Common::SeekableReadStreamEndian &stream);
+	void loadFXmp(Common::SeekableReadStreamEndian &stream);
+	bool readFXmpLine(Common::SeekableReadStreamEndian &stream);
 
 public:
 	Archive *_castArchive;
-	Common::HashMap<uint16, Common::String> _fontMap;
+	uint16 _version;
+	Common::Platform _platform;
+	uint16 _castLibID;
+
+	CharMap _macCharsToWin;
+	CharMap _winCharsToMac;
+	FontXPlatformMap _fontXPlatformMap;
+	FontMap _fontMap;
 
 	Common::HashMap<int, CastMember *> *_loadedCast;
 	Common::HashMap<int, const Stxt *> *_loadedStxts;
@@ -93,9 +131,10 @@ public:
 	uint16 _castArrayStart;
 	uint16 _castArrayEnd;
 
+	Common::Rect _movieRect;
+	uint16 _stageColor;
 	int _defaultPalette;
 
-	uint16 _movieScriptCount;
 	LingoArchive *_lingoArchive;
 
 private:
