@@ -36,6 +36,7 @@
 
 #include "director/types.h"
 #include "director/util.h"
+#include "director/detection.h"
 
 namespace Common {
 class MacResManager;
@@ -46,6 +47,7 @@ class SeekableReadStreamEndian;
 namespace Graphics {
 class MacWindowManager;
 struct MacPlotData;
+struct WinCursorGroup;
 typedef Common::Array<byte *> MacPatterns;
 
 class ManagedSurface;
@@ -53,15 +55,8 @@ class ManagedSurface;
 
 namespace Director {
 
-enum DirectorGameGID {
-	GID_GENERIC,
-	GID_TEST,
-	GID_TESTALL
-};
-
 class Archive;
 class Cast;
-struct DirectorGameDescription;
 class DirectorSound;
 class Lingo;
 class Movie;
@@ -103,6 +98,12 @@ struct MovieReference {
 struct StartMovie {
 	Common::String startMovie;
 	int16 startFrame;
+
+};
+
+struct StartOptions {
+	StartMovie startMovie;
+	Common::String startupPath;
 };
 
 struct PaletteV4 {
@@ -193,19 +194,23 @@ public:
 	void setVersion(uint16 version);
 	Common::Platform getPlatform() const;
 	Common::Language getLanguage() const;
+	Common::String getTargetName() { return _targetName; }
 	const char *getExtra();
 	Common::String getEXEName() const;
 	StartMovie getStartMovie() const;
-	DirectorSound *getSoundManager() const { return _soundManager; }
+	void parseOptions();
 	Graphics::MacWindowManager *getMacWindowManager() const { return _wm; }
 	Archive *getMainArchive() const;
 	Lingo *getLingo() const { return _lingo; }
 	Window *getStage() const { return _stage; }
 	Window *getCurrentWindow() const { return _currentWindow; }
 	void setCurrentWindow(Window *window) { _currentWindow = window; };
+	Window *getCursorWindow() const { return _cursorWindow; }
+	void setCursorWindow(Window *window) { _cursorWindow = window; }
 	Movie *getCurrentMovie() const;
 	void setCurrentMovie(Movie *movie);
 	Common::String getCurrentPath() const;
+	Common::String getStartupPath() const;
 
 	// graphics.cpp
 	bool hasFeature(EngineFeature f) const override;
@@ -226,17 +231,18 @@ public:
 	void loadPatterns();
 	uint32 transformColor(uint32 color);
 	Graphics::MacPatterns &getPatterns();
-	void setCursor(int type);
+	void setCursor(DirectorCursor type);
 	void draw();
 
 	Graphics::MacDrawPixPtr getInkDrawPixel();
 
 	void loadKeyCodes();
+	Common::CodePage getPlatformEncoding();
 
 	Archive *createArchive();
 
 	// events.cpp
-	void processEvents();
+	bool processEvents(bool captureClick = false);
 	uint32 getMacTicks();
 
 public:
@@ -246,14 +252,15 @@ public:
 
 public:
 	int _colorDepth;
-	Common::HashMap<int, int> _macKeyCodes;
+	Common::HashMap<int, int> _KeyCodes;
 	int _machineType;
 	bool _playbackPaused;
 	bool _skipFrameAdvance;
 	bool _centerStage;
+	char _dirSeparator;
 
 	Common::HashMap<Common::String, Archive *, Common::IgnoreCase_Hash, Common::IgnoreCase_EqualTo> _openResFiles;
-	Common::String _sharedCastFile;
+	Common::Array<Graphics::WinCursorGroup *> _winCursor;
 
 protected:
 	Common::Error run() override;
@@ -262,7 +269,6 @@ private:
 	const DirectorGameDescription *_gameDescription;
 	Common::FSNode _gameDataDir;
 
-	DirectorSound *_soundManager;
 	byte *_currentPalette;
 	uint16 _currentPaletteLength;
 	Lingo *_lingo;
@@ -271,11 +277,16 @@ private:
 	Window *_stage;
 	Datum *_windowList; // Lingo list
 	Window *_currentWindow;
+	Window *_cursorWindow;
 
 	Graphics::MacPatterns _director3Patterns;
 	Graphics::MacPatterns _director3QuickDrawPatterns;
 
 	Common::HashMap<int, PaletteV4> _loadedPalettes;
+
+	Graphics::ManagedSurface *_surface;
+
+	StartOptions _options;
 };
 
 extern DirectorEngine *g_director;
