@@ -36,63 +36,58 @@
 
 namespace Director {
 
-bool processQuitEvent(bool click) {
-	Common::Event event;
-
-	while (g_system->getEventManager()->pollEvent(event)) {
-		if (event.type == Common::EVENT_QUIT) {
-			g_director->getCurrentMovie()->getScore()->_playState = kPlayStopped;
-			return true;
-		}
-
-		if (click) {
-			if (event.type == Common::EVENT_LBUTTONDOWN)
-				return true;
-		}
-	}
-
-	return false;
-}
-
 uint32 DirectorEngine::getMacTicks() { return g_system->getMillis() * 60 / 1000.; }
 
-void DirectorEngine::processEvents() {
+bool DirectorEngine::processEvents(bool captureClick) {
 	debugC(3, kDebugEvents, "\n@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@");
 	debugC(3, kDebugEvents, "@@@@   Processing events");
 	debugC(3, kDebugEvents, "@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@\n");
 
 	Common::Event event;
-
-	uint endTime = g_system->getMillis() + 10;
-
-	while (g_system->getMillis() < endTime) {
-		while (g_system->getEventManager()->pollEvent(event)) {
-			if (_wm->processEvent(event)) {
-				// window manager has done something! update the channels
-				continue;
-			}
-
+	while (g_system->getEventManager()->pollEvent(event)) {
+		if (!_wm->processEvent(event)) {
+			// We only want to handle these events if the event
+			// wasn't handled by the window manager.
 			switch (event.type) {
-			case Common::EVENT_QUIT:
-				_stage->getCurrentMovie()->getScore()->_playState = kPlayStopped;
+			case Common::EVENT_MOUSEMOVE:
+				if (_cursorWindow) {
+					// The cursor is no longer in a window.
+					// Set it to the default arrow cursor.
+					_wm->replaceCursor(Graphics::kMacCursorArrow);
+					_cursorWindow = nullptr;
+				}
 				break;
 			default:
 				break;
 			}
 		}
 
-		g_system->delayMillis(10);
+		// We want to handle these events regardless.
+		switch (event.type) {
+		case Common::EVENT_QUIT:
+			_stage->getCurrentMovie()->getScore()->_playState = kPlayStopped;
+			if (captureClick)
+				return true;
+			break;
+		case Common::EVENT_LBUTTONDOWN:
+			if (captureClick)
+				return true;
+			break;
+		default:
+			break;
+		}
 	}
+
+	return false;
 }
 
 bool Window::processEvent(Common::Event &event) {
-	if (MacWindow::processEvent(event))
-		return true;
+	bool flag = MacWindow::processEvent(event);
 
 	if (_currentMovie && _currentMovie->processEvent(event))
-		return true;
+		flag = true;
 
-	return false;
+	return flag;
 }
 
 bool Movie::processEvent(Common::Event &event) {
@@ -112,7 +107,35 @@ bool Movie::processEvent(Common::Event &event) {
 		_lastEventTime = g_director->getMacTicks();
 		_lastRollTime =	 _lastEventTime;
 
-		sc->renderCursor(pos);
+		if (_vm->getCursorWindow() != _window) {
+			// Cursor just entered this window. Force a cursor update.
+			_vm->setCursorWindow(_window);
+			sc->renderCursor(pos, true);
+		} else {
+			sc->renderCursor(pos);
+		}
+
+		// hiliteChannelId is specified for BitMap castmember, so we deal with them separately with other castmember
+		// if we are moving out of bounds, then we don't hilite it anymore
+		if (_currentHiliteChannelId && !sc->_channels[_currentHiliteChannelId]->isMouseIn(pos)) {
+			g_director->getCurrentWindow()->setDirty(true);
+			g_director->getCurrentWindow()->addDirtyRect(sc->_channels[_currentHiliteChannelId]->getBbox());
+			_currentHiliteChannelId = 0;
+		}
+
+		// for the list style button, we still have chance to trigger events though button.
+		if (!(g_director->_wm->_mode & Graphics::kWMModeButtonDialogStyle) && g_director->_wm->_mouseDown && g_director->_wm->_hilitingWidget) {
+			if (g_director->getVersion() < 400)
+				spriteId = sc->getActiveSpriteIDFromPos(pos);
+			else
+				spriteId = sc->getMouseSpriteIDFromPos(pos);
+
+			if (spriteId > 0 && sc->_channels[spriteId]->_sprite->shouldHilite()) {
+				_currentHiliteChannelId = spriteId;
+				g_director->getCurrentWindow()->setDirty(true);
+				g_director->getCurrentWindow()->addDirtyRect(sc->_channels[_currentHiliteChannelId]->getBbox());
+			}
+		}
 
 		if (_currentDraggedChannel) {
 			if (_currentDraggedChannel->_sprite->_moveable) {
@@ -129,24 +152,41 @@ bool Movie::processEvent(Common::Event &event) {
 	case Common::EVENT_LBUTTONDOWN:
 		if (sc->_waitForClick) {
 			sc->_waitForClick = false;
-			_vm->setCursor(kCursorDefault);
+			sc->renderCursor(_window->getMousePos(), true);
 		} else {
 			pos = _window->getMousePos();
 
 			// D3 doesn't have both mouse up and down.
 			// But we still want to know if the mouse is down for press effects.
-			spriteId = sc->getMouseSpriteIDFromPos(pos);
+			// Since we don't have mouse up and down before D3, then we use ActiveSprite
+			if (g_director->getVersion() < 400)
+				spriteId = sc->getActiveSpriteIDFromPos(pos);
+			else
+				spriteId = sc->getMouseSpriteIDFromPos(pos);
+
+			// Set `the clickOn` Lingo property.
+			// Even in D4, `the clickOn` uses the old "active" sprite instead of mouse sprite.
 			_currentClickOnSpriteId = sc->getActiveSpriteIDFromPos(pos);
 
-			if (spriteId > 0 && sc->_channels[spriteId]->_sprite->shouldHilite())
-				g_director->getCurrentWindow()->invertChannel(sc->_channels[spriteId]);
+			if (spriteId > 0 && sc->_channels[spriteId]->_sprite->shouldHilite()) {
+				_currentHiliteChannelId = spriteId;
+				g_director->_wm->_hilitingWidget = true;
+				g_director->getCurrentWindow()->setDirty(true);
+				g_director->getCurrentWindow()->addDirtyRect(sc->_channels[_currentHiliteChannelId]->getBbox());
+			}
+
+			CastMember *cast = getCastMember(sc->_channels[spriteId]->_sprite->_castId);
+			if (cast && cast->_type == kCastButton)
+				_mouseDownWasInButton = true;
 
 			_lastEventTime = g_director->getMacTicks();
 			_lastClickTime = _lastEventTime;
 			_lastClickPos = pos;
+			if (_timeOutMouse)
+				_lastTimeOut = _lastEventTime;
 
 			debugC(3, kDebugEvents, "event: Button Down @(%d, %d), movie '%s', sprite id: %d", pos.x, pos.y, _macName.c_str(), spriteId);
-			registerEvent(kEventMouseDown, spriteId);
+			queueUserEvent(kEventMouseDown, spriteId);
 
 			if (sc->_channels[spriteId]->_sprite->_moveable) {
 				_draggingSpritePos = _window->getMousePos();
@@ -159,28 +199,42 @@ bool Movie::processEvent(Common::Event &event) {
 	case Common::EVENT_LBUTTONUP:
 		pos = _window->getMousePos();
 
-		spriteId = sc->getMouseSpriteIDFromPos(pos);
-		_currentClickOnSpriteId = sc->getActiveSpriteIDFromPos(pos);
+		if (g_director->getVersion() < 400)
+			spriteId = sc->getActiveSpriteIDFromPos(pos);
+		else
+			spriteId = sc->getMouseSpriteIDFromPos(pos);
 
-		if (spriteId > 0 && sc->_channels[spriteId]->_sprite->shouldHilite())
-			g_director->getCurrentWindow()->invertChannel(sc->_channels[spriteId]);
+		if (_currentHiliteChannelId && sc->_channels[_currentHiliteChannelId]) {
+			g_director->getCurrentWindow()->setDirty(true);
+			g_director->getCurrentWindow()->addDirtyRect(sc->_channels[_currentHiliteChannelId]->getBbox());
+		}
+
+		g_director->_wm->_hilitingWidget = false;
 
 		debugC(3, kDebugEvents, "event: Button Up @(%d, %d), movie '%s', sprite id: %d", pos.x, pos.y, _macName.c_str(), spriteId);
 
 		_currentDraggedChannel = nullptr;
 
-		{
-			CastMember *cast = getCastMember(sc->getSpriteById(spriteId)->_castId);
+		// If this is a button cast member, and the last mouse down event was in a button
+		// (any button), flip this button's hilite flag.
+		// Now you might think, "Wait, we don't flip this flag in the mouseDown event.
+		// And why any button??? This doesn't make any sense."
+		// No, it doesn't make sense, but it's what Director does.
+		if (_mouseDownWasInButton) {
+			CastMember *cast = getCastMember(sc->_channels[spriteId]->_sprite->_castId);
 			if (cast && cast->_type == kCastButton)
 				cast->_hilite = !cast->_hilite;
 		}
 
-		registerEvent(kEventMouseUp, spriteId);
+		queueUserEvent(kEventMouseUp, spriteId);
 		sc->renderCursor(pos);
+
+		_currentHiliteChannelId = 0;
+		_mouseDownWasInButton = false;
 		return true;
 
 	case Common::EVENT_KEYDOWN:
-		_keyCode = _vm->_macKeyCodes.contains(event.kbd.keycode) ? _vm->_macKeyCodes[event.kbd.keycode] : 0;
+		_keyCode = _vm->_KeyCodes.contains(event.kbd.keycode) ? _vm->_KeyCodes[event.kbd.keycode] : 0;
 		_key = (unsigned char)(event.kbd.ascii & 0xff);
 		_keyFlags = event.kbd.flags;
 
@@ -188,7 +242,10 @@ bool Movie::processEvent(Common::Event &event) {
 
 		_lastEventTime = g_director->getMacTicks();
 		_lastKeyTime = _lastEventTime;
-		registerEvent(kEventKeyDown);
+		if (_timeOutKeyDown)
+			_lastTimeOut = _lastEventTime;
+
+		queueUserEvent(kEventKeyDown);
 		return true;
 
 	case Common::EVENT_KEYUP:
