@@ -62,14 +62,31 @@ Movie::Movie(Window *window) {
 	_keyFlags = 0;
 
 	_currentDraggedChannel = nullptr;
+	_currentHiliteChannelId = 0;
+	_mouseDownWasInButton = false;
 
+	_version = 0;
+	_platform = Common::kPlatformMacintosh;
 	_allowOutdatedLingo = false;
 
 	_movieArchive = nullptr;
 
-	_cast = new Cast(this);
+	_cast = new Cast(this, 0);
 	_sharedCast = nullptr;
 	_score = new Score(this);
+
+	_selEnd = -1;
+	_selStart = -1;
+
+	_checkBoxType = 0;
+	_checkBoxAccess = 0;
+
+	_lastTimeOut = _lastEventTime;
+	_timeOutLength = 10800;	// D4 dictionary p297, default value is 3minutes
+	// default value of keydown and mouse is true, for timeOutPlay is false. check D4 dictionary p297
+	_timeOutKeyDown = true;
+	_timeOutMouse = true;
+	_timeOutPlay = false;
 }
 
 Movie::~Movie() {
@@ -101,6 +118,15 @@ void Movie::setArchive(Archive *archive) {
 bool Movie::loadArchive() {
 	Common::SeekableReadStreamEndian *r = nullptr;
 
+	// Config
+	if (!_cast->loadConfig())
+		return false;
+
+	_version = _cast->_version;
+	_platform = _cast->_platform;
+	_movieRect = _cast->_movieRect;
+	// Wait to handle _stageColor until palette is loaded in loadCast...
+
 	// File Info
 	if (_movieArchive->hasResource(MKTAG('V', 'W', 'F', 'I'), -1)) {
 		loadFileInfo(*(r = _movieArchive->getFirstResource(MKTAG('V', 'W', 'F', 'I'))));
@@ -108,9 +134,8 @@ bool Movie::loadArchive() {
 	}
 
 	// Cast
-	_cast->loadArchive();
-
-	// _movieRect and _stageColor are in VWCF, which the cast handles
+	_cast->loadCast();
+	_stageColor = _vm->transformColor(_cast->_stageColor);
 
 	bool recenter = false;
 	// If the stage dimensions are different, delete it and start again.
@@ -125,7 +150,7 @@ bool Movie::loadArchive() {
 		uint16 windowWidth = debugChannelSet(-1, kDebugDesktop) ? 1024 : _movieRect.width();
 		uint16 windowHeight = debugChannelSet(-1, kDebugDesktop) ? 768 : _movieRect.height();
 		if (_vm->_wm->_screenDims.width() != windowWidth || _vm->_wm->_screenDims.height() != windowHeight) {
-			_vm->_wm->_screenDims = Common::Rect(windowWidth, windowHeight);
+			_vm->_wm->resizeScreen(windowWidth, windowHeight);
 			recenter = true;
 
 			initGraphics(windowWidth, windowHeight, &_vm->_pixelformat);
@@ -142,7 +167,7 @@ bool Movie::loadArchive() {
 		warning("Movie::loadArchive(): Wrong movie format. VWSC resource missing");
 		return false;
 	}
-	_score->loadFrames(*(r = _movieArchive->getFirstResource(MKTAG('V', 'W', 'S', 'C'))));
+	_score->loadFrames(*(r = _movieArchive->getFirstResource(MKTAG('V', 'W', 'S', 'C'))), _version);
 	delete r;
 
 	// Action list
@@ -158,15 +183,15 @@ bool Movie::loadArchive() {
 
 Common::Rect Movie::readRect(Common::ReadStreamEndian &stream) {
 	Common::Rect rect;
-	rect.top = stream.readUint16();
-	rect.left = stream.readUint16();
-	rect.bottom = stream.readUint16();
-	rect.right = stream.readUint16();
+	rect.top = stream.readSint16();
+	rect.left = stream.readSint16();
+	rect.bottom = stream.readSint16();
+	rect.right = stream.readSint16();
 
 	return rect;
 }
 
-InfoEntries Movie::loadInfoEntries(Common::SeekableReadStreamEndian &stream) {
+InfoEntries Movie::loadInfoEntries(Common::SeekableReadStreamEndian &stream, uint16 version) {
 	uint32 offset = stream.pos();
 	offset += stream.readUint32();
 
@@ -175,7 +200,7 @@ InfoEntries Movie::loadInfoEntries(Common::SeekableReadStreamEndian &stream) {
 	res.unk2 = stream.readUint32();
 	res.flags = stream.readUint32();
 
-	if (g_director->getVersion() >= 400)
+	if (version >= kFileVer400)
 		res.scriptId = stream.readUint32();
 
 	stream.seek(offset);
@@ -209,19 +234,18 @@ InfoEntries Movie::loadInfoEntries(Common::SeekableReadStreamEndian &stream) {
 void Movie::loadFileInfo(Common::SeekableReadStreamEndian &stream) {
 	debugC(2, kDebugLoading, "****** Loading FileInfo VWFI");
 
-	InfoEntries fileInfo = Movie::loadInfoEntries(stream);
+	InfoEntries fileInfo = Movie::loadInfoEntries(stream, _version);
 
 	_allowOutdatedLingo = (fileInfo.flags & kMovieFlagAllowOutdatedLingo) != 0;
 
 	_script = fileInfo.strings[0].readString(false);
 
 	if (!_script.empty() && ConfMan.getBool("dump_scripts"))
-		_cast->dumpScript(_script.c_str(), kMovieScript, _cast->_movieScriptCount);
+		_cast->dumpScript(_script.c_str(), kMovieScript, 0);
 
 	if (!_script.empty())
-		_cast->_lingoArchive->addCode(_script.c_str(), kMovieScript, _cast->_movieScriptCount);
+		_cast->_lingoArchive->addCode(_script, kMovieScript, 0);
 
-	_cast->_movieScriptCount++;
 	_changedBy = fileInfo.strings[1].readString();
 	_createdBy = fileInfo.strings[2].readString();
 	_createdBy = fileInfo.strings[3].readString();
@@ -277,47 +301,59 @@ void Movie::loadSharedCastsFrom(Common::String filename) {
 	debug(0, "@@@@   Loading shared cast '%s'", filename.c_str());
 	debug(0, "@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@\n");
 
-	_sharedCast = new Cast(this, true);
+	_sharedCast = new Cast(this, 0, true);
 	_sharedCast->setArchive(sharedCast);
 	_sharedCast->loadArchive();
 }
 
-CastMember *Movie::getCastMember(int castId) {
-	CastMember *result = _cast->getCastMember(castId);
-	if (result == nullptr && _sharedCast) {
-		result = _sharedCast->getCastMember(castId);
+CastMember *Movie::getCastMember(CastMemberID memberID) {
+	CastMember *result = nullptr;
+	if (memberID.castLib == 0) {
+		result = _cast->getCastMember(memberID.member);
+		if (result == nullptr && _sharedCast) {
+			result = _sharedCast->getCastMember(memberID.member);
+		}
+	} else {
+		warning("Movie::getCastMember: Unknown castLib %d", memberID.castLib);
 	}
 	return result;
 }
 
-CastMember *Movie::getCastMemberByName(const Common::String &name) {
-	CastMember *result = _cast->getCastMemberByName(name);
-	if (result == nullptr && _sharedCast) {
-		result = _sharedCast->getCastMemberByName(name);
+CastMember *Movie::getCastMemberByName(const Common::String &name, int castLib) {
+	CastMember *result = nullptr;
+	if (castLib == 0) {
+		result = _cast->getCastMemberByName(name);
+		if (result == nullptr && _sharedCast) {
+			result = _sharedCast->getCastMemberByName(name);
+		}
+	} else {
+		warning("Movie::getCastMemberByName: Unknown castLib %d", castLib);
 	}
 	return result;
 }
 
-CastMember *Movie::getCastMemberByScriptId(int scriptId) {
-	CastMember *result = _cast->getCastMemberByScriptId(scriptId);
-	if (result == nullptr && _sharedCast) {
-		result = _sharedCast->getCastMemberByScriptId(scriptId);
+CastMemberInfo *Movie::getCastMemberInfo(CastMemberID memberID) {
+	CastMemberInfo *result = nullptr;
+	if (memberID.castLib == 0) {
+		result = _cast->getCastMemberInfo(memberID.member);
+		if (result == nullptr && _sharedCast) {
+			result = _sharedCast->getCastMemberInfo(memberID.member);
+		}
+	} else {
+		warning("Movie::getCastMemberInfo: Unknown castLib %d", memberID.castLib);
 	}
 	return result;
 }
 
-CastMemberInfo *Movie::getCastMemberInfo(int castId) {
-	CastMemberInfo *result = _cast->getCastMemberInfo(castId);
-	if (result == nullptr && _sharedCast) {
-		result = _sharedCast->getCastMemberInfo(castId);
-	}
-	return result;
-}
-
-const Stxt *Movie::getStxt(int castId) {
-	const Stxt *result = _cast->getStxt(castId);
-	if (result == nullptr && _sharedCast) {
-		result = _sharedCast->getStxt(castId);
+const Stxt *Movie::getStxt(CastMemberID memberID) {
+	const Stxt *result = nullptr;
+	if (memberID.castLib == 0) {
+		result = _cast->getStxt(memberID.member);
+		if (result == nullptr && _sharedCast) {
+			result = _sharedCast->getStxt(memberID.member);
+		}
+	} else {
+		warning("Movie::getStxt: Unknown castLib %d", memberID.castLib);
 	}
 	return result;
 }
@@ -330,23 +366,45 @@ LingoArchive *Movie::getSharedLingoArch() {
 	return _sharedCast ? _sharedCast->_lingoArchive : nullptr;
 }
 
-ScriptContext *Movie::getScriptContext(ScriptType type, uint16 id) {
-	ScriptContext *result = _cast->_lingoArchive->getScriptContext(type, id);
-	if (result == nullptr && _sharedCast) {
-		result = _sharedCast->_lingoArchive->getScriptContext(type, id);
+ScriptContext *Movie::getScriptContext(ScriptType type, CastMemberID id) {
+	ScriptContext *result = nullptr;
+	if (id.castLib == 0) {
+		result = _cast->_lingoArchive->getScriptContext(type, id.member);
+		if (result == nullptr && _sharedCast) {
+			result = _sharedCast->_lingoArchive->getScriptContext(type, id.member);
+		}
+	} else {
+		warning("Movie::getScriptContext: Unknown castLib %d", id.castLib);
 	}
 	return result;
 }
 
 Symbol Movie::getHandler(const Common::String &name) {
-	if (!g_lingo->_eventHandlerTypeIds.contains(name)) {
-		if (_cast->_lingoArchive->functionHandlers.contains(name))
-			return _cast->_lingoArchive->functionHandlers[name];
+	if (_cast->_lingoArchive->functionHandlers.contains(name))
+		return _cast->_lingoArchive->functionHandlers[name];
+
+	if (_sharedCast && _sharedCast->_lingoArchive->functionHandlers.contains(name))
+		return _sharedCast->_lingoArchive->functionHandlers[name];
 
-		if (_sharedCast && _sharedCast->_lingoArchive->functionHandlers.contains(name))
-			return _sharedCast->_lingoArchive->functionHandlers[name];
-	}
 	return Symbol();
 }
 
+Common::String InfoEntry::readString(bool pascal) {
+	Common::String res;
+
+	if (len == 0)
+		return res;
+
+	uint start = pascal ? 1 : 0; // skip length for Pascal string
+
+	Common::String encodedStr;
+	for (uint i = start; i < len; i++) {
+		if (!Common::isCntrl(data[i]) || Common::isSpace(data[i]))
+			encodedStr += data[i];
+	}
+
+	// FIXME: Use the case which contains this string, not the main cast.
+	return g_director->getCurrentMovie()->getCast()->decodeString(encodedStr).encode(Common::kUtf8);
+}
+
 } // End of namespace Director
