@@ -68,22 +68,7 @@ struct InfoEntry {
 		return *this;
 	}
 
-	Common::String readString(bool pascal = true) {
-		Common::String res;
-
-		if (len == 0)
-			return res;
-
-		int start = pascal ? 1 : 0;
-
-		for (uint i = start; i < len; i++)
-			if (data[i] == '\r')
-				res += '\n';
-			else if (data[i] >= 0x20)
-				res += data[i];
-
-		return res;
-	}
+	Common::String readString(bool pascal = true);
 };
 
 struct InfoEntries {
@@ -102,7 +87,7 @@ public:
 	~Movie();
 
 	static Common::Rect readRect(Common::ReadStreamEndian &stream);
-	static InfoEntries loadInfoEntries(Common::SeekableReadStreamEndian &stream);
+	static InfoEntries loadInfoEntries(Common::SeekableReadStreamEndian &stream, uint16 version);
 
 	bool loadArchive();
 	void setArchive(Archive *archive);
@@ -117,15 +102,14 @@ public:
 	void clearSharedCast();
 	void loadSharedCastsFrom(Common::String filename);
 
-	CastMember *getCastMember(int castId);
-	CastMember *getCastMemberByName(const Common::String &name);
-	CastMember *getCastMemberByScriptId(int scriptId);
-	CastMemberInfo *getCastMemberInfo(int castId);
-	const Stxt *getStxt(int castId);
+	CastMember *getCastMember(CastMemberID memberID);
+	CastMember *getCastMemberByName(const Common::String &name, int castLib);
+	CastMemberInfo *getCastMemberInfo(CastMemberID memberID);
+	const Stxt *getStxt(CastMemberID memberID);
 
 	LingoArchive *getMainLingoArch();
 	LingoArchive *getSharedLingoArch();
-	ScriptContext *getScriptContext(ScriptType type, uint16 id);
+	ScriptContext *getScriptContext(ScriptType type, CastMemberID id);
 	Symbol getHandler(const Common::String &name);
 
 	// events.cpp
@@ -133,19 +117,21 @@ public:
 
 	// lingo/lingo-events.cpp
 	void setPrimaryEventHandler(LEvent event, const Common::String &code);
-	int getEventCount();
 	void processEvent(LEvent event, int targetId = 0);
-	void registerEvent(LEvent event, int targetId = 0);
+	void queueUserEvent(LEvent event, int targetId = 0);
 
 private:
 	void loadFileInfo(Common::SeekableReadStreamEndian &stream);
 
-	void queueSpriteEvent(LEvent event, int eventId, int spriteId);
-	void queueFrameEvent(LEvent event, int eventId);
-	void queueMovieEvent(LEvent event, int eventId);
+	void queueEvent(Common::Queue<LingoEvent> &queue, LEvent event, int targetId = 0);
+	void queueSpriteEvent(Common::Queue<LingoEvent> &queue, LEvent event, int eventId, int spriteId);
+	void queueFrameEvent(Common::Queue<LingoEvent> &queue, LEvent event, int eventId);
+	void queueMovieEvent(Common::Queue<LingoEvent> &queue, LEvent event, int eventId);
 
 public:
 	Archive *_movieArchive;
+	uint16 _version;
+	Common::Platform _platform;
 	Common::Rect _movieRect;
 	uint16 _currentClickOnSpriteId;
 	uint16 _currentEditableTextChannel;
@@ -162,12 +148,26 @@ public:
 	bool _videoPlayback;
 
 	int _nextEventId;
-	Common::Queue<LingoEvent> _eventQueue;
+	Common::Queue<LingoEvent> _userEventQueue;
 
 	unsigned char _key;
 	int _keyCode;
 	byte _keyFlags;
 
+	int _selStart;
+	int _selEnd;
+
+	int _checkBoxType;
+	int _checkBoxAccess;
+
+	uint16 _currentHiliteChannelId;
+
+	uint _lastTimeOut;
+	uint _timeOutLength;
+	bool _timeOutKeyDown;
+	bool _timeOutMouse;
+	bool _timeOutPlay;
+
 private:
 	Window *_window;
 	DirectorEngine *_vm;
@@ -183,6 +183,7 @@ private:
 	Common::String _script;
 	Common::String _directory;
 
+	bool _mouseDownWasInButton;
 	Channel *_currentDraggedChannel;
 	Common::Point _draggingSpritePos;
 };
