@@ -643,8 +643,8 @@ void Game::loop(LoopSubstatus substatus, bool shouldExit) {
 			case kStatusDialogue:
 				handleDialogueLoop();
 				break;
-			case kStatusGate:
-				// cannot happen when isCursonOn; added for completeness
+			case kStatusGate: // cannot happen when isCursonOn; added for completeness
+			default:
 				break;
 			}
 		}
@@ -1000,6 +1000,8 @@ void Game::inventorySwitch(int keycode) {
 			removeItem(new_item);
 		}
 		break;
+	default:
+		break;
 	}
 	if (getLoopStatus() == kStatusOrdinary) {
 		updateOrdinaryCursor();
