@@ -1139,7 +1139,7 @@ void Script::run(const GPL2Program &program, uint16 offset) {
 		if (_jump != 0) {
 			debugC(3, kDraciBytecodeDebugLevel,
 				"Jumping from offset %d to %d (%d bytes)",
-				reader.pos(), reader.pos() + _jump, _jump);
+				(int)reader.pos(), (int)reader.pos() + _jump, _jump);
 			reader.seek(_jump, SEEK_CUR);
 		}
 
