@@ -55,17 +55,6 @@ void DrasculaEngine::placeDrascula() {
 		copyRect(drX, 122, drasculaX, drasculaY, 45, 77, backSurface, screenSurface);
 }
 
-void DrasculaEngine::placeBJ() {
-	int bX = 0;
-
-	if (trackBJ == 3)
-		bX = 10;
-	else if (trackBJ == 0)
-		bX = 37;
-
-	copyRect(bX, 99, bjX, bjY, 26, 76, drawSurface3, screenSurface);
-}
-
 void DrasculaEngine::hiccup(int counter) {
 	int y = 0, trackCharacter = 0;
 	if (currentChapter == 3)
@@ -105,7 +94,7 @@ void DrasculaEngine::hiccup(int counter) {
 }
 
 void DrasculaEngine::startWalking() {
-	characterMoved = 1;
+	_characterMoved = true;
 
 	stepX = STEP_X;
 	stepY = STEP_Y;
@@ -124,7 +113,7 @@ void DrasculaEngine::startWalking() {
 		else if (roomY > curY + curHeight)
 			walkDown();
 		else
-			characterMoved = 0;
+			_characterMoved = false;
 	} else {
 		if ((roomX < curX + curWidth / 2 ) && (roomY <= (curY + curHeight)))
 			quadrant_1();
@@ -135,7 +124,7 @@ void DrasculaEngine::startWalking() {
 		else if ((roomX > curX + curWidth / 2) && (roomY > (curY + curHeight)))
 			quadrant_4();
 		else
-			characterMoved = 0;
+			_characterMoved = false;
 	}
 	_startTime = getTime();
 }
@@ -144,16 +133,16 @@ void DrasculaEngine::moveCharacters() {
 	int curPos[6];
 	int r;
 
-	if (characterMoved == 1 && stepX == STEP_X) {
+	if (_characterMoved && stepX == STEP_X) {
 		for (r = 0; r < stepX; r++) {
 			if (currentChapter != 2) {
 				if (trackProtagonist == 0 && roomX - r == curX + curWidth / 2) {
-					characterMoved = 0;
+					_characterMoved = false;
 					stepX = STEP_X;
 					stepY = STEP_Y;
 				}
 				if (trackProtagonist == 1 && roomX + r == curX + curWidth / 2) {
-					characterMoved = 0;
+					_characterMoved = false;
 					stepX = STEP_X;
 					stepY = STEP_Y;
 					curX = roomX - curWidth / 2;
@@ -161,12 +150,12 @@ void DrasculaEngine::moveCharacters() {
 				}
 			} else if (currentChapter == 2) {
 				if (trackProtagonist == 0 && roomX - r == curX) {
-					characterMoved = 0;
+					_characterMoved = false;
 					stepX = STEP_X;
 					stepY = STEP_Y;
 				}
 				if (trackProtagonist == 1 && roomX + r == curX + curWidth) {
-					characterMoved = 0;
+					_characterMoved = false;
 					stepX = STEP_X;
 					stepY = STEP_Y;
 					curX = roomX - curWidth + 4;
@@ -175,15 +164,15 @@ void DrasculaEngine::moveCharacters() {
 			}
 		}
 	}
-	if (characterMoved == 1 && stepY == STEP_Y) {
+	if (_characterMoved && stepY == STEP_Y) {
 		for (r = 0; r < stepY; r++) {
 			if (trackProtagonist == 2 && roomY - r == curY + curHeight) {
-				characterMoved = 0;
+				_characterMoved = false;
 				stepX = STEP_X;
 				stepY = STEP_Y;
 			}
 			if (trackProtagonist == 3 && roomY + r == curY + curHeight) {
-				characterMoved = 0;
+				_characterMoved = false;
 				stepX = STEP_X;
 				stepY = STEP_Y;
 			}
@@ -191,13 +180,13 @@ void DrasculaEngine::moveCharacters() {
 	}
 
 	if (currentChapter != 2 && currentChapter != 3) {
-		if (characterVisible == 0) {
+		if (!_characterVisible) {
 			increaseFrameNum();
 			return;
 		}
 	}
 
-	if (characterMoved == 0) {
+	if (!_characterMoved) {
 		curPos[0] = 0;
 		curPos[1] = DIF_MASK_HARE;
 		curPos[2] = curX;
@@ -240,7 +229,7 @@ void DrasculaEngine::moveCharacters() {
 				reduce_hare_chico(curPos[0], curPos[1], curPos[2], curPos[3], curPos[4], curPos[5],
 									factor_red[curY + curHeight], frontSurface, screenSurface);
 		}
-	} else if (characterMoved == 1) {
+	} else if (_characterMoved) {
 		curPos[0] = _frameX[_characterFrame];
 		curPos[1] = frame_y + DIF_MASK_HARE;
 		curPos[2] = curX;
