@@ -100,34 +100,31 @@ class DreamWebSound;
 
 class DreamWebEngine : public Engine {
 private:
-	DreamWebConsole			*_console;
 	DreamWebSound *_sound;
-	bool					_vSyncInterrupt;
+	uint32 _vSyncPrevTick;
 
 protected:
 	// Engine APIs
-	virtual Common::Error run();
-	virtual bool hasFeature(EngineFeature f) const;
-
-	GUI::Debugger *getDebugger() { return _console; }
+	Common::Error run() override;
+	bool hasFeature(EngineFeature f) const override;
+	void pauseEngineIntern(bool pause) override;
 
 public:
 	DreamWebEngine(OSystem *syst, const DreamWebGameDescription *gameDesc);
-	virtual ~DreamWebEngine();
+	~DreamWebEngine() override;
 
-	void setVSyncInterrupt(bool flag);
 	void waitForVSync();
 
-	Common::Error loadGameState(int slot);
-	Common::Error saveGameState(int slot, const Common::String &desc);
+	Common::Error loadGameState(int slot) override;
+	Common::Error saveGameState(int slot, const Common::String &desc, bool isAutosave = false) override;
 
-	bool canLoadGameStateCurrently();
-	bool canSaveGameStateCurrently();
+	bool canLoadGameStateCurrently() override;
+	bool canSaveGameStateCurrently() override;
 
 	uint8 randomNumber() { return _rnd.getRandomNumber(255); }
 
 	void mouseCall(uint16 *x, uint16 *y, uint16 *state); //fill mouse pos and button state
-	void processEvents();
+	void processEvents(bool processSoundEvents = true);
 	void blit(const uint8 *src, int pitch, int x, int y, int w, int h);
 	void cls();
 	bool isCD();
@@ -143,8 +140,6 @@ public:
 
 	void quit();
 
-	bool loadSpeech(const Common::String &filename);
-
 	Common::Language getLanguage() const;
 	uint8 modifyChar(uint8 c) const;
 	Common::String modifyFileName(const char *);
@@ -238,7 +233,6 @@ protected:
 	Common::List<ObjPos> _exList;
 	Common::List<People> _peopleList;
 	uint8 _zoomSpace[46*40];
-	// _printedList (unused?)
 	Change _listOfChanges[kNumChanges]; // Note: this array is saved
 	uint8 _underTimedText[kUnderTimedTextBufSize];
 	Common::List<Rain> _rainList;
@@ -300,8 +294,6 @@ protected:
 	TextFile _exText;
 
 public:
-	DreamWebEngine(/*DreamWeb::DreamWebEngine *en*/);
-
 	bool _quitRequested;
 	bool _subtitles;
 	bool _foreignRelease;
@@ -757,7 +749,6 @@ public:
 	uint16 readMouseState();
 	void hangOn(uint16 frameCount);
 	void lockMon();
-	uint8 *textUnder();
 	void readKey();
 	void findOrMake(uint8 index, uint8 value, uint8 type);
 	DynObject *getFreeAd(uint8 index);
@@ -784,6 +775,9 @@ public:
 	void loadRoomData(const Room &room, bool skipDat);
 	void useTempCharset(GraphicsFile *charset);
 	void useCharset1();
+	void useCharsetIcons1();
+	void useCharsetTempgraphics();
+	void resetCharset();
 	void printMessage(uint16 x, uint16 y, uint8 index, uint8 maxWidth, bool centered);
 	void printMessage2(uint16 x, uint16 y, uint8 index, uint8 maxWidth, bool centered, uint8 count);
 	bool isItDescribed(const ObjPos *objPos);
@@ -916,7 +910,6 @@ public:
 	void dreamweb();
 	void screenUpdate();
 	void startup1();
-	void readOneBlock();
 	bool checkIfPerson(uint8 x, uint8 y);
 	bool checkIfFree(uint8 x, uint8 y);
 	bool checkIfEx(uint8 x, uint8 y);
