@@ -26,7 +26,7 @@
 /* Utility functions for the Alan interpreter */
 
 #include "glk/alan3/types.h"
-#include "glk/alan3/jumps.h"
+#include "glk/jumps.h"
 
 namespace Glk {
 namespace Alan3 {
