@@ -680,26 +680,22 @@ PerformJump: /* goto label for successful jumping... ironic, no? */
 				protectend = val1;
 				break;
 
-			case op_save:
+			case op_save: {
 				push_callstub(inst[1].desttype, inst[1].value);
-#ifdef TODO
-				value = saveGameData(find_stream_by_id(inst[0].value), "Savegame").getCode() == Common::kNoError ? 0 : 1;
-#else
-				error("TODO");
-#endif
+				strid_t saveStream = find_stream_by_id(inst[0].value);
+				value = writeGameData(*saveStream).getCode() == Common::kNoError ? 0 : 1;
 				pop_callstub(value);
 				break;
+			}
+
+			case op_restore: {
+				strid_t stream = find_stream_by_id(inst[0].value);
+				value = readSaveData(*stream).getCode() == Common::kNoError ? 0 : 1;
 
-			case op_restore:
-#ifdef TODO
-				value = loadGameData(find_stream_by_id(inst[0].value)).getCode() == Common::kNoError ? 0 : 1;
-#else
-				error("TODO");
-#endif
 				if (value == 0) {
 					/* We've succeeded, and the stack now contains the callstub
 					   saved during saveundo. Ignore this opcode's operand. */
-					value = (uint) - 1;
+					value = (uint)-1;
 					pop_callstub(value);
 				} else {
 					/* We've failed, so we must store the failure in this opcode's
@@ -707,6 +703,7 @@ PerformJump: /* goto label for successful jumping... ironic, no? */
 					store_operand(inst[1].desttype, inst[1].value, value);
 				}
 				break;
+			}
 
 			case op_saveundo:
 				push_callstub(inst[0].desttype, inst[0].value);
