@@ -33,6 +33,7 @@ const PlainGameDescriptor HUGO_GAME_LIST[] = {
 	{ "acs", "A Crimson Spring" },
 	{ "annoyotron2", "Aggravatron: Annoyotron II" },
 	{ "cb2", "The Clockwork Boy 2" },
+	{ "cryptozookeeper", "Cryptozookeeper" },
 	{ "hugoclock", "The Hugo Clock" },
 	{ "adv350h", "Adventure, 350 point Colossal Cave" },
 	{ "distress", "Distress" },
@@ -81,6 +82,7 @@ const GlkDetectionEntry HUGO_GAMES[] = {
 	DT_ENTRY1("acs", "0.09.0 Beta",  "8788f1e28a4cd875f220155b2aeae8c8", 356450),
 	DT_ENTRY0("annoyotron2", "944056721054fd1c9af9d1e95e63ce52", 66762),
 	DT_ENTRY0("cb2", "232827c10abd45c98d77ceffaf9ac9fa", 155732),
+	DT_ENTRY0("cryptozookeeper", "1b8301b969882c46ffa9f635e1695c41", 840567),
 	DT_ENTRY0("hugoclock", "53a0b99011ccb14ddc45cfeb8c23d417", 120887),
 	DT_ENTRY0("adv350h", "d6735640ca21797f24e3cadb12be4ae2", 124148),
 	DT_ENTRY0("distress", "fe61c8722d8625d3d196b3d390346a55", 188317),
