@@ -23,6 +23,7 @@
 #include "glk/hugo/hugo.h"
 #include "glk/hugo/resource_archive.h"
 #include "common/config-manager.h"
+#include "common/translation.h"
 
 namespace Glk {
 namespace Hugo {
@@ -30,7 +31,7 @@ namespace Hugo {
 Hugo *g_vm;
 
 Hugo::Hugo(OSystem *syst, const GlkGameDescription &gameDesc) : GlkAPI(syst, gameDesc),
-		mainwin(nullptr), currentwin(nullptr), secondwin(nullptr), auxwin(nullptr), 
+		mainwin(nullptr), currentwin(nullptr), secondwin(nullptr), auxwin(nullptr),
 		runtime_warnings(false), dbnest(0), address_scale(16),
 		SCREENWIDTH(0), SCREENHEIGHT(0), FIXEDCHARWIDTH(0), FIXEDLINEHEIGHT(0),
 		// heexpr
@@ -40,9 +41,9 @@ Hugo::Hugo(OSystem *syst, const GlkGameDescription &gameDesc) : GlkAPI(syst, gam
 		// hemisc
 		game_version(0), object_size(24), game(nullptr), script(nullptr),
 		playback(nullptr), record(nullptr), io(nullptr), ioblock('\0'), ioerror('\0'),
-		codestart(0), objtable(0), eventtable(0), proptable(0), arraytable(0), dicttable(0), 
-		syntable(0), initaddr(0), mainaddr(0), parseaddr(0), parseerroraddr(0), 
-		findobjectaddr(0), endgameaddr(0), speaktoaddr(0), performaddr(0), 
+		codestart(0), objtable(0), eventtable(0), proptable(0), arraytable(0), dicttable(0),
+		syntable(0), initaddr(0), mainaddr(0), parseaddr(0), parseerroraddr(0),
+		findobjectaddr(0), endgameaddr(0), speaktoaddr(0), performaddr(0),
 		objects(0), events(0), dictcount(0), syncount(0), mem(nullptr), loaded_in_memory(true),
 		defseg(0), gameseg(0), codeptr(0), codeend(0), currentpos(0), currentline(0), full(0),
 		def_fcolor(0), def_bgcolor(0), def_slfcolor(0), def_slbgcolor(0), fcolor(0), bgcolor(0),
@@ -93,13 +94,13 @@ Hugo::Hugo(OSystem *syst, const GlkGameDescription &gameDesc) : GlkAPI(syst, gam
 	Common::fill(&resids[0][0], &resids[2][0], 0);
 	numres[0] = numres[1] = 0;
 
-	// hemisc		
+	// hemisc
 	Common::fill(&context_command[0][0], &context_command[MAX_CONTEXT_COMMANDS][0], 0);
 	Common::fill(&id[0], &id[3], '\0');
 	Common::fill(&serial[0], &serial[9], '\0');
 	Common::fill(&pbuffer[0], &pbuffer[MAXBUFFER * 2 + 1], 0);
 	Common::fill(&undostack[0][0], &undostack[MAXUNDO][0], 0);
-	
+
 	// heparse
 	Common::fill(&buffer[0], &buffer[MAXBUFFER + MAXWORDS], '\0');
 	Common::fill(&errbuf[0], &errbuf[MAXBUFFER + 1], 0);
@@ -179,14 +180,14 @@ Common::Error Hugo::readSaveData(Common::SeekableReadStream *rs) {
 	if (hugo_ferror(rs)) goto RestoreError;
 
 	if (strcmp(testid, id)) {
-		GUIErrorMessage("Incorrect rs file.");
+		GUIErrorMessage(_("Incorrect rs file."));
 		goto RestoreError;
 	}
 
 	/* Check serial number */
 	if (!hugo_fgets(testserial, 9, rs)) goto RestoreError;
 	if (strcmp(testserial, serial)) {
-		GUIErrorMessage("Save file created by different version.");
+		GUIErrorMessage(_("Save file created by different version."));
 		goto RestoreError;
 	}
 
@@ -247,7 +248,7 @@ Common::Error Hugo::readSaveData(Common::SeekableReadStream *rs) {
 	else undoinvalid = true;
 
 	return Common::kNoError;
-	
+
 RestoreError:
 	return Common::kReadingFailed;
 }
