@@ -20,6 +20,8 @@
  *
  */
 
+/* Based on the Hugo interpreter version 3.3.0 */
+
 #ifndef GLK_HUGO_HUGO
 #define GLK_HUGO_HUGO
 
@@ -34,10 +36,13 @@
 namespace Glk {
 namespace Hugo {
 
+class ResourceArchive;
+
 /**
  * Hugo game interpreter
  */
 class Hugo : public GlkAPI, public HTokens, public StringFunctions {
+	friend class ResourceArchive;
 private:
 	int _savegameSlot;
 	winid_t mainwin, currentwin;
@@ -637,8 +642,6 @@ private:
 
 	int hugo_hasgraphics();
 
-	int hugo_displaypicture(HUGO_FILE infile, long reslen);
-
 	void initsound();
 
 	void initmusic();
@@ -788,7 +791,7 @@ private:
 	 * 5.  If all is well, return to match the objects that were previously skipped over,
 	 * loading them into objlist[]. Once again, this is done by MatchObject().
 	 *
-	 * (The reason the objects are initially skipped is because it may be necessary to know 
+	 * (The reason the objects are initially skipped is because it may be necessary to know
 	 * where to look for them--this may require knowing what the xobject is, if the syntax
 	 * is something like:
 	 *
@@ -903,7 +906,7 @@ private:
 	 * and on-disk resources in (if not the given directory) "source" or "resource" (where these are the
 	 * environment variables "HUGO_...", not actual on-disk directories).
 	 */
-	long FindResource(char *filename, char *resname);
+	long FindResource(const char *filename, const char *resname);
 
 	/**
 	 * Processes resourcefile/filename (and resource, if applicable).
@@ -945,7 +948,7 @@ private:
 	/**
 	 * This is the main loop for running each line of code in sequence;
 	 * the main switch statement is based on the first token in each line.
-	 * 
+	 *
 	 * This routine is relatively complex, especially given the addition of debugger control.
 	 * Basically it is structured like this:
 	 *
@@ -1159,7 +1162,7 @@ private:
 	void SwitchtoDebugger() {}
 
 	void Debugger() {}
-	
+
 	void UpdateDebugScreen() {}
 
 	void SwitchtoGame() {}
@@ -1180,28 +1183,35 @@ public:
 	 */
 	Hugo(OSystem *syst, const GlkGameDescription &gameDesc);
 
+	/**
+	 * Destructor
+	 */
+	~Hugo();
+
 	/**
 	 * Run the game
 	 */
-	void runGame();
+	void runGame() override;
 
 	/**
 	 * Returns the running interpreter type
 	 */
-	virtual InterpreterType getInterpreterType() const override { return INTERPRETER_HUGO; }
+	InterpreterType getInterpreterType() const override { return INTERPRETER_HUGO; }
 
 	/**
 	 * Load a savegame from the passed Quetzal file chunk stream
 	 */
-	virtual Common::Error readSaveData(Common::SeekableReadStream *rs) override;
+	Common::Error readSaveData(Common::SeekableReadStream *rs) override;
 
 	/**
 	 * Save the game. The passed write stream represents access to the UMem chunk
 	 * in the Quetzal save file that will be created
 	 */
-	virtual Common::Error writeGameData(Common::WriteStream *ws) override;
+	Common::Error writeGameData(Common::WriteStream *ws) override;
 };
 
+extern Hugo *g_vm;
+
 } // End of namespace Hugo
 } // End of namespace Glk
 
