@@ -84,7 +84,7 @@ public:
 			++_index;
 			return *this;
 		}
-		
+
 		/**
 		 * Decrementer
 		 */
@@ -108,7 +108,9 @@ public:
 		 */
 		Common::SeekableReadStream *getStream() {
 			_stream->seek(_chunks[_index]._offset);
-			return _stream->readStream(_chunks[_index]._size);
+			return (_chunks[_index]._size == 0) ?
+				new Common::MemoryReadStream((byte *)malloc(0), 0, DisposeAfterUse::YES) :
+				_stream->readStream(_chunks[_index]._size);
 		}
 	};
 private:
