@@ -24,6 +24,7 @@
 #include "glk/quetzal.h"
 #include "common/config-manager.h"
 #include "common/translation.h"
+#include "common/ustr.h"
 
 namespace Glk {
 namespace Scott {
@@ -96,10 +97,10 @@ void Scott::runGame() {
 
 		switch (performActions(vb, no)) {
 		case -1:
-			output("I don't understand your command. ");
+			output(_("I don't understand your command. "));
 			break;
 		case -2:
-			output("I can't do that yet. ");
+			output(_("I can't do that yet. "));
 			break;
 		default:
 			break;
@@ -115,9 +116,9 @@ void Scott::runGame() {
 				if (_items[LIGHT_SOURCE]._location == CARRIED ||
 						_items[LIGHT_SOURCE]._location == MY_LOC) {
 					if (_options & SCOTTLIGHT)
-						output("Light has run out! ");
+						output(_("Light has run out! "));
 					else
-						output("Your light has run out. ");
+						output(_("Your light has run out. "));
 				}
 				if (_options & PREHISTORIC_LAMP)
 					_items[LIGHT_SOURCE]._location = DESTROYED;
@@ -126,12 +127,12 @@ void Scott::runGame() {
 						_items[LIGHT_SOURCE]._location == MY_LOC) {
 
 					if (_options & SCOTTLIGHT) {
-						output("Light runs out in ");
+						output(_("Light runs out in "));
 						outputNumber(_gameHeader._lightTime);
-						output(" turns. ");
+						output(_(" turns. "));
 					} else {
 						if (_gameHeader._lightTime % 5 == 0)
-							output("Your light is growing dim. ");
+							output(_("Your light is growing dim. "));
 					}
 				}
 			}
@@ -166,6 +167,18 @@ void Scott::display(winid_t w, const char *fmt, ...) {
 	glk_put_string_stream(glk_window_get_stream(w), msg.c_str());
 }
 
+void Scott::display(winid_t w, const Common::U32String fmt, ...) {
+	Common::U32String msg;
+
+	va_list ap;
+
+	va_start(ap, fmt);
+	Common::U32String::vformat(fmt.begin(), fmt.end(), msg, ap);
+	va_end(ap);
+
+	glk_put_string_stream_uni(glk_window_get_stream(w), msg.u32_str());
+}
+
 void Scott::delay(int seconds) {
 	event_t ev;
 
@@ -385,13 +398,18 @@ void Scott::output(const Common::String &a) {
 		display(_bottomWindow, "%s", a.c_str());
 }
 
+void Scott::output(const Common::U32String &a) {
+	if (_saveSlot == -1)
+		display(_bottomWindow, Common::U32String("%S"), a.c_str());
+}
+
 void Scott::outputNumber(int a) {
 	display(_bottomWindow, "%d", a);
 }
 
 void Scott::look(void) {
 	const char *const ExitNames[6] = {
-		"North", "South", "East", "West", "Up", "Down"
+		_s("North"), _s("South"), _s("East"), _s("West"), _s("Up"), _s("Down")
 	};
 	Room *r;
 	int ct, f;
@@ -403,9 +421,9 @@ void Scott::look(void) {
 	if ((_bitFlags & (1 << DARKBIT)) && _items[LIGHT_SOURCE]._location != CARRIED
 			&& _items[LIGHT_SOURCE]._location != MY_LOC) {
 		if (_options & YOUARE)
-			display(_topWindow, "You can't see. It is too dark!\n");
+			display(_topWindow, _("You can't see. It is too dark!\n"));
 		else
-			display(_topWindow, "I can't see. It is too dark!\n");
+			display(_topWindow, _("I can't see. It is too dark!\n"));
 		if (_options & TRS80_STYLE)
 			display(_topWindow, TRS80_LINE);
 		return;
@@ -415,27 +433,27 @@ void Scott::look(void) {
 		display(_topWindow, "%s\n", r->_text.c_str() + 1);
 	else {
 		if (_options & YOUARE)
-			display(_topWindow, "You are in a %s\n", r->_text.c_str());
+			display(_topWindow, _("You are in a %s\n"), r->_text.c_str());
 		else
-			display(_topWindow, "I'm in a %s\n", r->_text.c_str());
+			display(_topWindow, _("I'm in a %s\n"), r->_text.c_str());
 	}
 
 	ct = 0;
 	f = 0;
-	display(_topWindow, "\nObvious exits: ");
+	display(_topWindow, _("\nObvious exits: "));
 	while (ct < 6) {
 		if (r->_exits[ct] != 0) {
 			if (f == 0)
 				f = 1;
 			else
 				display(_topWindow, ", ");
-			display(_topWindow, "%s", ExitNames[ct]);
+			display(_topWindow, Common::U32String("%S"), _(ExitNames[ct]).c_str());
 		}
 		ct++;
 	}
 
 	if (f == 0)
-		display(_topWindow, "none");
+		display(_topWindow, _("none"));
 	display(_topWindow, ".\n");
 	ct = 0;
 	f = 0;
@@ -444,10 +462,10 @@ void Scott::look(void) {
 		if (_items[ct]._location == MY_LOC) {
 			if (f == 0) {
 				if (_options & YOUARE) {
-					display(_topWindow, "\nYou can also see: ");
+					display(_topWindow, _("\nYou can also see: "));
 					pos = 18;
 				} else {
-					display(_topWindow, "\nI can also see: ");
+					display(_topWindow, _("\nI can also see: "));
 					pos = 16;
 				}
 				f++;
@@ -530,7 +548,7 @@ Common::Error Scott::writeGameData(Common::WriteStream *ws) {
 		ws->writeByte(0);
 	}
 
-	output("Saved.\n");
+	output(_("Saved.\n"));
 	return Common::kNoError;
 }
 
@@ -623,7 +641,7 @@ int Scott::getInput(int *vb, int *no) {
 		*vb = vc;
 		*no = nc;
 		if (vc == -1) {
-			output("You use word(s) I don't know! ");
+			output(_("You use word(s) I don't know! "));
 		}
 	} while (vc == -1);
 
@@ -753,9 +771,9 @@ int Scott::performLine(int ct) {
 			case 52:
 				if (countCarried() == _gameHeader._maxCarry) {
 					if (_options & YOUARE)
-						output("You are carrying too much. ");
+						output(_("You are carrying too much. "));
 					else
-						output("I've too much to carry! ");
+						output(_("I've too much to carry! "));
 					break;
 				}
 				_items[param[pptr++]]._location = CARRIED;
@@ -786,9 +804,9 @@ int Scott::performLine(int ct) {
 				break;
 			case 61:
 				if (_options & YOUARE)
-					output("You are dead.\n");
+					output(_("You are dead.\n"));
 				else
-					output("I am dead.\n");
+					output(_("I am dead.\n"));
 				_bitFlags &= ~(1 << DARKBIT);
 				MY_LOC = _gameHeader._numRooms;// It seems to be what the code says!
 				break;
@@ -800,7 +818,7 @@ int Scott::performLine(int ct) {
 			}
 			case 63:
 doneit:
-				output("The game is now over.\n");
+				output(_("The game is now over.\n"));
 				glk_exit();
 				return 0;
 			case 64:
@@ -815,15 +833,15 @@ doneit:
 					i++;
 				}
 				if (_options & YOUARE)
-					output("You have stored ");
+					output(_("You have stored "));
 				else
-					output("I've stored ");
+					output(_("I've stored "));
 				outputNumber(n);
-				output(" treasures.  On a scale of 0 to 100, that rates ");
+				output(_(" treasures.  On a scale of 0 to 100, that rates "));
 				outputNumber((n * 100) / _gameHeader._treasures);
 				output(".\n");
 				if (n == _gameHeader._treasures) {
-					output("Well done.\n");
+					output(_("Well done.\n"));
 					goto doneit;
 				}
 				break;
@@ -832,9 +850,9 @@ doneit:
 				int i = 0;
 				int f = 0;
 				if (_options & YOUARE)
-					output("You are carrying:\n");
+					output(_("You are carrying:\n"));
 				else
-					output("I'm carrying:\n");
+					output(_("I'm carrying:\n"));
 				while (i <= _gameHeader._numItems) {
 					if (_items[i]._location == CARRIED) {
 						if (f == 1) {
@@ -849,7 +867,7 @@ doneit:
 					i++;
 				}
 				if (f == 0)
-					output("Nothing");
+					output(_("Nothing"));
 				output(".\n");
 				break;
 			}
@@ -978,7 +996,7 @@ int Scott::performActions(int vb, int no) {
 	int fl;
 	int doagain = 0;
 	if (vb == 1 && no == -1) {
-		output("Give me a direction too.");
+		output(_("Give me a direction too."));
 		return 0;
 	}
 	if (vb == 1 && no >= 1 && no <= 6) {
@@ -987,7 +1005,7 @@ int Scott::performActions(int vb, int no) {
 				_items[LIGHT_SOURCE]._location == CARRIED)
 			d = 0;
 		if (d)
-			output("Dangerous to move in the dark! ");
+			output(_("Dangerous to move in the dark! "));
 		nl = _rooms[MY_LOC]._exits[no - 1];
 		if (nl != 0) {
 			MY_LOC = nl;
@@ -995,16 +1013,16 @@ int Scott::performActions(int vb, int no) {
 		}
 		if (d) {
 			if (_options & YOUARE)
-				output("You fell down and broke your neck. ");
+				output(_("You fell down and broke your neck. "));
 			else
-				output("I fell down and broke my neck. ");
+				output(_("I fell down and broke my neck. "));
 			glk_exit();
 			return 0;
 		}
 		if (_options & YOUARE)
-			output("You can't go in that direction. ");
+			output(_("You can't go in that direction. "));
 		else
-			output("I can't go in that direction. ");
+			output(_("I can't go in that direction. "));
 		return 0;
 	}
 
@@ -1062,7 +1080,7 @@ int Scott::performActions(int vb, int no) {
 					int f = 0;
 
 					if (d) {
-						output("It is dark.\n");
+						output(_("It is dark.\n"));
 						return 0;
 					}
 					while (i <= _gameHeader._numItems) {
@@ -1076,43 +1094,43 @@ int Scott::performActions(int vb, int no) {
 
 							if (countCarried() == _gameHeader._maxCarry) {
 								if (_options & YOUARE)
-									output("You are carrying too much. ");
+									output(_("You are carrying too much. "));
 								else
-									output("I've too much to carry. ");
+									output(_("I've too much to carry. "));
 								return 0;
 							}
 							_items[i]._location = CARRIED;
 							output(_items[i]._text);
-							output(": O.K.\n");
+							output(_(": O.K.\n"));
 							f = 1;
 						}
 						i++;
 					}
 					if (f == 0)
-						output("Nothing taken.");
+						output(_("Nothing taken."));
 					return 0;
 				}
 				if (no == -1) {
-					output("What ? ");
+					output(_("What ? "));
 					return 0;
 				}
 				if (countCarried() == _gameHeader._maxCarry) {
 					if (_options & YOUARE)
-						output("You are carrying too much. ");
+						output(_("You are carrying too much. "));
 					else
-						output("I've too much to carry. ");
+						output(_("I've too much to carry. "));
 					return 0;
 				}
 				item = matchUpItem(_nounText, MY_LOC);
 				if (item == -1) {
 					if (_options & YOUARE)
-						output("It is beyond your power to do that. ");
+						output(_("It is beyond your power to do that. "));
 					else
-						output("It's beyond my power to do that. ");
+						output(_("It's beyond my power to do that. "));
 					return 0;
 				}
 				_items[item]._location = CARRIED;
-				output("O.K. ");
+				output(_("O.K. "));
 				return 0;
 			}
 			if (vb == 18) {
@@ -1131,25 +1149,25 @@ int Scott::performActions(int vb, int no) {
 
 							_items[i]._location = MY_LOC;
 							output(_items[i]._text);
-							output(": O.K.\n");
+							output(_(": O.K.\n"));
 							f = 1;
 						}
 						i++;
 					}
 					if (f == 0)
-						output("Nothing dropped.\n");
+						output(_("Nothing dropped.\n"));
 					return 0;
 				}
 				if (no == -1) {
-					output("What ? ");
+					output(_("What ? "));
 					return 0;
 				}
 				item = matchUpItem(_nounText, CARRIED);
 				if (item == -1) {
 					if (_options & YOUARE)
-						output("It's beyond your power to do that.\n");
+						output(_("It's beyond your power to do that.\n"));
 					else
-						output("It's beyond my power to do that.\n");
+						output(_("It's beyond my power to do that.\n"));
 					return 0;
 				}
 				_items[item]._location = MY_LOC;
