@@ -25,23 +25,59 @@
 
 #include "common/events.h"
 #include "glk/glk_types.h"
+#include "common/ustr.h"
+
+#if defined(USE_TTS)
+#include "common/text-to-speech.h"
+#endif
 
 namespace Glk {
 
-/**
- * Currently not implemented
- */
+class Speech;
+
+class SpeechManager {
+public:
+	static SpeechManager* getSpeechManagerInstance();
+	void releaseSpeechManagerInstance();
+
+	void speak(const Common::U32String &, Speech *);
+	void stopSpeech(Speech *);
+
+	static void syncSoundSettings();
+
+private:
+	SpeechManager();
+	~SpeechManager();
+
+	static SpeechManager *_instance;
+	int _refCount;
+
+#if defined(USE_TTS)
+	Common::TextToSpeechManager *_ttsMan;
+	Speech *_lastSpeechSource;
+#endif
+};
+
+
 class Speech {
+private:
+	SpeechManager *_speechManager;
+	Common::U32String _speechBuffer;
+
 protected:
-	void gli_initialize_tts(void) {}
+	Speech();
+	~Speech();
 
-	void gli_tts_flush(void) {}
+	void gli_initialize_tts(void);
 
-	void gli_tts_purge(void) {}
+	void gli_tts_flush(void);
 
-	void gli_tts_speak(const uint32 *buf, size_t len) {}
+	void gli_tts_purge(void);
 
-	void gli_free_tts(void) {}
+	void gli_tts_speak(const uint32 *buf, size_t len);
+	void gli_tts_speak(const char *buf, size_t len);
+
+	void gli_free_tts(void);
 };
 
 } // End of namespace Glk
