@@ -24,12 +24,12 @@
  * All of the functions and macros in here are named ERRxxx because
  * this file was based on the TADS err.h, which used the ERRxxx naming
  * convention, and it would be a lot of trouble to change.
- * 
+ *
  * This package defines a set of macros that allows code to raise and
  * handle exceptions.  A macro is provided which signals an error, which
  * does a non-local goto to the innermost enclosing exception handler.
  * A set of macros sets up exception handling code.
- * 
+ *
  * To catch exceptions that occur inside a block of code (i.e., in the
  * code or in any subroutines called by the code), begin the block with
  * ERRBEGIN.  At the end of the protected code, place the exception
@@ -37,7 +37,7 @@
  * handler, place ERREND.  If no exception occurs, execution goes
  * through the protected code, then resumes at the code following
  * the ERREND.
- * 
+ *
  * The exception handler can signal another error, which will cause
  * the next enclosing frame to catch the error.  Alternatively, if
  * the exception handler doesn't signal an error or return, execution
@@ -45,14 +45,14 @@
  * signalled during exception handling will be caught by the next
  * enclosing frame, unless the exception handler code is itself
  * protected by another ERRBEGIN-ERREND block.
- * 
+ *
  * To signal an error, use errsig().
- * 
+ *
  * To use a string argument in a signalled error, cover the string
  * with errstr(ctx, str, len); for example:
- * 
+ *
  * errsig1(ctx, ERR_XYZ, ERRTSTR, errstr(ctx, buf, strlen(buf)));
- * 
+ *
  * This copies the string into a buffer that is unaffected by
  * stack resetting during error signalling.
  */
@@ -73,16 +73,16 @@ namespace TADS2 {
 #define ERRFACMAX    6
 
 union erradef {
-    int   erraint;                                      /* integer argument */
-    const char *errastr;                            /* text string argument */
+	int   erraint;                                      /* integer argument */
+	const char *errastr;                            /* text string argument */
 };
 
 struct errdef {
-    struct errdef *errprv;                          /* previous error frame */
-    int            errcode;        /* error code of exception being handled */
-    char           errfac[ERRFACMAX+1];        /* facility of current error */
-    erradef        erraav[10];                      /* parameters for error */
-    int            erraac;                   /* count of parameters in argc */
+	struct errdef *errprv;                          /* previous error frame */
+	int            errcode;        /* error code of exception being handled */
+	char           errfac[ERRFACMAX+1];        /* facility of current error */
+	erradef        erraav[10];                      /* parameters for error */
+	int            erraac;                   /* count of parameters in argc */
 };
 
 #define ERRBUFSIZ 512
@@ -91,23 +91,23 @@ struct errdef {
  * Seek location record for an error message by number
  */
 struct errmfdef {
-    uint  errmfnum;                                         /* error number */
-    ulong errmfseek;                       /* seek location of this message */
+	uint  errmfnum;                                         /* error number */
+	ulong errmfseek;                       /* seek location of this message */
 };
 typedef struct errmfdef errmfdef;
 
 struct errcxdef {
-    errdef   *errcxptr;                              /* current error frame */
-    void    (*errcxlog)(void *, const char *fac, int err, int argc, erradef *);
-                                         /* error logging callback function */
-    void     *errcxlgc;               /* context for error logging callback */
-    int       errcxofs;                        /* offset in argument buffer */
-    char      errcxbuf[ERRBUFSIZ];            /* space for argument strings */
-    osfildef *errcxfp;                /* message file, if one is being used */
-    errmfdef *errcxseek;              /* seek locations of messages in file */
-    uint      errcxsksz;                         /* size of errcxseek array */
-    ulong     errcxbase;   /* offset in physical file of logical error file */
-    struct appctxdef *errcxappctx;              /* host application context */
+	errdef   *errcxptr;                              /* current error frame */
+	void    (*errcxlog)(void *, const char *fac, int err, int argc, erradef *);
+										 /* error logging callback function */
+	void     *errcxlgc;               /* context for error logging callback */
+	int       errcxofs;                        /* offset in argument buffer */
+	char      errcxbuf[ERRBUFSIZ];            /* space for argument strings */
+	osfildef *errcxfp;                /* message file, if one is being used */
+	errmfdef *errcxseek;              /* seek locations of messages in file */
+	uint      errcxsksz;                         /* size of errcxseek array */
+	ulong     errcxbase;   /* offset in physical file of logical error file */
+	struct appctxdef *errcxappctx;              /* host application context */
 };
 
 /**
@@ -115,47 +115,56 @@ struct errcxdef {
  */
 #define ERRBEGIN(ctx) \
   { \
-    errdef fr_; \
-    if (1 /*(fr_.errcode = setjmp(fr_.errbuf)) == 0 */) \
-    { \
-      fr_.errprv = (ctx)->errcxptr; \
-      (ctx)->errcxptr = &fr_;
+	errdef fr_; \
+	if (1 /*(fr_.errcode = setjmp(fr_.errbuf)) == 0 */) \
+	{ \
+	  fr_.errprv = (ctx)->errcxptr; \
+	  (ctx)->errcxptr = &fr_;
 
 /**
  * End protected code, begin error handler
  */
 #define ERRCATCH(ctx, e) \
-      assert(1==1 && (ctx)->errcxptr != fr_.errprv); \
-      (ctx)->errcxptr = fr_.errprv; \
-    } \
-    else \
-    { \
-      assert(2==2 && (ctx)->errcxptr != fr_.errprv); \
-      (e) = fr_.errcode; \
-      (ctx)->errcxptr = fr_.errprv;
-        
+	  assert(1==1 && (ctx)->errcxptr != fr_.errprv); \
+	  (ctx)->errcxptr = fr_.errprv; \
+	} \
+	else \
+	{ \
+	  assert(2==2 && (ctx)->errcxptr != fr_.errprv); \
+	  (e) = fr_.errcode; \
+	  (ctx)->errcxptr = fr_.errprv;
+
+#define ERRCATCH_ERRCODE_UNUSED(ctx) \
+	  assert(1==1 && (ctx)->errcxptr != fr_.errprv); \
+	  (ctx)->errcxptr = fr_.errprv; \
+	} \
+	else \
+	{ \
+	  assert(2==2 && (ctx)->errcxptr != fr_.errprv); \
+	  (ctx)->errcxptr = fr_.errprv;
+
 /* retrieve argument (int, string) in current error frame */
 #define errargint(argnum) (fr_.erraav[argnum].erraint)
 #define errargstr(argnum) (fr_.erraav[argnum].errastr)
 
-    
+
 #define ERREND(ctx) \
-    } \
+	} \
   }
 
 /* end protected code, begin cleanup (no handling; just cleaning up) */
 #define ERRCLEAN(ctx) \
-      assert((ctx)->errcxptr != fr_.errprv); \
-      (ctx)->errcxptr = fr_.errprv; \
-    } \
-    else \
-    { \
-      assert((ctx)->errcxptr != fr_.errprv); \
-      (ctx)->errcxptr = fr_.errprv;
+	  assert((ctx)->errcxptr != fr_.errprv); \
+	  (ctx)->errcxptr = fr_.errprv; \
+	} \
+	else \
+	{ \
+	  assert((ctx)->errcxptr != fr_.errprv); \
+	  (ctx)->errcxptr = fr_.errprv;
 
 #define ERRENDCLN(ctx) \
-      errrse(ctx); \
-    } \
+	  errrse(ctx); \
+	} \
   }
 
 
@@ -171,7 +180,7 @@ struct errcxdef {
 #ifdef ERR_NO_MACRO
 char *errstr(errcxdef *ctx, const char *str, int len);
 #else /* ERR_NO_MACRO */
-  
+
 #define errstr(ctx,str,len) \
   ((memcpy(&(ctx)->errcxbuf[(ctx)->errcxofs],str,(size_t)len), \
    (ctx)->errcxofs += (len), \
@@ -192,13 +201,13 @@ void errsign(errcxdef *ctx, int e, const char *facility);
 void errjmp(jump_buf buf, int e);
 #  define errsign(ctx, e, fac) \
    (strncpy((ctx)->errcxptr->errfac, fac, ERRFACMAX),\
-    (ctx)->errcxptr->errfac[ERRFACMAX]='\0',\
-    (ctx)->errcxofs=0, errjmp((ctx)->errcxptr->errbuf, e))
+	(ctx)->errcxptr->errfac[ERRFACMAX]='\0',\
+	(ctx)->errcxofs=0, errjmp((ctx)->errcxptr->errbuf, e))
 # else /* DEBUG */
 #  define errsign(ctx, e, fac) \
    (strncpy((ctx)->errcxptr->errfac, fac, ERRFACMAX),\
-    (ctx)->errcxptr->errfac[ERRFACMAX]='\0',\
-    (ctx)->errcxofs=0, longjmp((ctx)->errcxptr->errbuf, e))
+	(ctx)->errcxptr->errfac[ERRFACMAX]='\0',\
+	(ctx)->errcxofs=0, longjmp((ctx)->errcxptr->errbuf, e))
 # endif /* DEBUG */
 #endif /* ERR_NO_MACRO */
 
@@ -209,7 +218,7 @@ void errsigf(errcxdef *ctx, const char *facility, int err);
 #else /* ERR_NO_MACRO */
 #define errsigf(ctx, fac, e) (errargc(ctx,0),errsign(ctx,e,fac))
 #endif /* ERR_NO_MACRO */
-  
+
 /* signal an error with one argument */
 #define errsigf1(ctx, fac, e, typ1, arg1) \
   (errargv(ctx,0,typ1,arg1),errargc(ctx,1),errsign(ctx,e,fac))
@@ -229,7 +238,7 @@ void errrse1(errcxdef *ctx, errdef *fr);
 # define errrse(ctx) \
   (errargc(ctx, fr_.erraac),\
    memcpy((ctx)->errcxptr->erraav, fr_.erraav, \
-    (size_t)(fr_.erraac*sizeof(erradef))),\
+	(size_t)(fr_.erraac*sizeof(erradef))),\
    errsign(ctx, fr_.errcode, fr_.errfac))
 
 #endif /* ERR_NO_MACRO */
@@ -239,22 +248,22 @@ void errrse1(errcxdef *ctx, errdef *fr);
  *   parameters from the error currently being handled to the enclosing
  *   frame.  This is useful when "keeping" an error being handled - i.e.,
  *   the arguments will continue to be used outside of the
- *   ERRCATCH..ERREND code. 
+ *   ERRCATCH..ERREND code.
  */
 /* void errkeepargs(errcxdef *ctx); */
 #define errkeepargs(ctx) errcopyargs(ctx, &fr_)
 
-/* 
+/*
  *   copy the parameters for an error from another frame into the current
  *   frame - this can be used when we want to be able to display an error
  *   that occurred in an inner frame within code that is protected by a
- *   new enclosing error frame 
+ *   new enclosing error frame
  */
 /* void errcopyargs(errcxdef *ctx, errdef *fr); */
 #define errcopyargs(ctx, fr) \
    (errargc((ctx), (fr)->erraac), \
-    memcpy((ctx)->errcxptr->erraav, (fr)->erraav, \
-           (size_t)((fr)->erraac*sizeof(erradef))))
+	memcpy((ctx)->errcxptr->erraav, (fr)->erraav, \
+		   (size_t)((fr)->erraac*sizeof(erradef))))
 
 /* log error that's been caught, using arguments already caught */
 #define errclog(ctx) \
@@ -292,7 +301,7 @@ void errlogf(errcxdef *ctx, const char *facility, int err);
 /* log an error with one argument */
 #define errlogf1(ctx, fac, e, typ1, arg1) \
  (errargv(ctx,0,typ1,arg1),errargc(ctx,1),errlogn(ctx,e,fac))
-  
+
 /* log an error with two arguments */
 #define errlogf2(ctx, fac, e, typ1, arg1, typ2, arg2) \
  (errargv(ctx,0,typ1,arg1),errargv(ctx,1,typ2,arg2),\
@@ -309,11 +318,11 @@ void errlogf(errcxdef *ctx, const char *facility, int err);
  *   will be computed and returned.)
  */
 int errfmt(char *outbuf, int outbufl, char *fmt, int argc,
-           erradef *argv);
-  
+		   erradef *argv);
+
 /* get the text of an error */
 void errmsg(errcxdef *ctx, char *outbuf, uint outbufl, uint err);
-  
+
 /* initialize error subsystem, opening error message file if necessary */
 void errini(errcxdef *ctx, osfildef *fp);
 
@@ -323,8 +332,8 @@ void      lerfre(errcxdef *ctx);
 
 /* error message structure - number + text */
 struct errmdef {
-    uint   errmerr;                                         /* error number */
-    char  *errmtxt;                                /* text of error message */
+	uint   errmerr;                                         /* error number */
+	char  *errmtxt;                                /* text of error message */
 };
 
 } // End of namespace TADS2
