@@ -243,8 +243,8 @@ void runhcmp(runcxdef *ctx, uint siz, uint below,
 
 		/* check the explicitly referenced value pointers as well */
 #define CHECK_VAL(val) \
-        if (val && val->runsv.runsvstr == hp) \
-            ref = TRUE, val->runsv.runsvstr = dst;
+		if (val && val->runsv.runsvstr == hp) \
+			ref = TRUE, val->runsv.runsvstr = dst;
 		CHECK_VAL(val1);
 		CHECK_VAL(val2);
 		CHECK_VAL(val3);
@@ -1571,8 +1571,11 @@ resume_from_error:
 					(prpnum)0, binum, nargc);
 				(*ctx->runcxbi[binum])((struct bifcxdef *)ctx->runcxbcx,
 					nargc);
-				dbgleave(ctx->runcxdbg,
-					ctx->runcxsp != stkp ? DBGEXVAL : DBGEXRET);
+				if (ctx->runcxsp != stkp) {
+					dbgleave(ctx->runcxdbg, DBGEXVAL);
+				} else {
+					dbgleave(ctx->runcxdbg, DBGEXRET);
+				}
 
 				p = runcprst(ctx, ofs, target, targprop);
 				p += 2;
@@ -1901,13 +1904,14 @@ resume_from_error:
 			case OPCBP:
 			{
 				uchar *ptr = mcmobjptr(ctx->runcxmem, (mcmon)target);
-				uchar  instr;
 
 				/* set up the debugger frame record for this line */
 				dbgframe(ctx->runcxdbg, osrp2(p + 1), p - ptr);
 
+#ifndef DBG_OFF
 				/* remember the instruction */
-				instr = *(p - 1);
+				uchar instr = *(p - 1);
+#endif
 
 				/* remember the offset of the line record */
 				ctx->runcxlofs = ofs = (p + 2 - ptr);
@@ -1915,8 +1919,10 @@ resume_from_error:
 				/* skip to the next instruction */
 				p += *p;
 
+#ifndef DBG_OFF
 				/* let the debugger take over, if it wants to */
 				dbgssi(ctx->runcxdbg, ofs, instr, 0, &p);
+#endif
 				break;
 			}
 
