@@ -50,9 +50,9 @@ protected:
 class Cheater_Geisha : public Cheater {
 public:
 	Cheater_Geisha(GobEngine *vm, Geisha::Diving *diving, Geisha::Penetration *penetration);
-	~Cheater_Geisha();
+	~Cheater_Geisha() override;
 
-	bool cheat(GUI::Debugger &console);
+	bool cheat(GUI::Debugger &console) override;
 
 private:
 	Geisha::Diving      *_diving;
