@@ -23,28 +23,43 @@
 #include "base/plugins.h"
 #include "engines/advancedDetector.h"
 
-#include "gob/gob.h"
 #include "gob/dataio.h"
-
+#include "gob/detection/detection.h"
 #include "gob/detection/tables.h"
+#include "gob/gob.h"
 
-class GobMetaEngine : public AdvancedMetaEngine {
+static const DebugChannelDef debugFlagList[] = {
+	{Gob::kDebugFuncOp, "FuncOpcodes", "Script FuncOpcodes debug level"},
+	{Gob::kDebugDrawOp, "DrawOpcodes", "Script DrawOpcodes debug level"},
+	{Gob::kDebugGobOp, "GoblinOpcodes", "Script GoblinOpcodes debug level"},
+	{Gob::kDebugSound, "Sound", "Sound output debug level"},
+	{Gob::kDebugExpression, "Expression", "Expression parser debug level"},
+	{Gob::kDebugGameFlow, "Gameflow", "Gameflow debug level"},
+	{Gob::kDebugFileIO, "FileIO", "File Input/Output debug level"},
+	{Gob::kDebugSaveLoad, "SaveLoad", "Saving/Loading debug level"},
+	{Gob::kDebugGraphics, "Graphics", "Graphics debug level"},
+	{Gob::kDebugVideo, "Video", "IMD/VMD video debug level"},
+	{Gob::kDebugHotspots, "Hotspots", "Hotspots debug level"},
+	{Gob::kDebugDemo, "Demo", "Demo script debug level"},
+	DEBUG_CHANNEL_END
+};
+
+class GobMetaEngineDetection : public AdvancedMetaEngineDetection {
 public:
-	GobMetaEngine();
+	GobMetaEngineDetection();
 
 	const char *getEngineId() const override {
 		return "gob";
 	}
 
-	ADDetectedGame fallbackDetect(const FileMap &allFiles, const Common::FSList &fslist) const override;
-
 	const char *getName() const override;
 	const char *getOriginalCopyright() const override;
 
-	bool hasFeature(MetaEngineFeature f) const override;
+	const DebugChannelDef *getDebugChannels() const override {
+		return debugFlagList;
+	}
 
-	Common::Error createInstance(OSystem *syst, Engine **engine) const override;
-	bool createInstance(OSystem *syst, Engine **engine, const ADGameDescription *desc) const override;
+	ADDetectedGame fallbackDetect(const FileMap &allFiles, const Common::FSList &fslist, ADDetectedGameExtraInfo **extra) const override;
 
 private:
 	/**
@@ -53,14 +68,14 @@ private:
 	static const Gob::GOBGameDescription *detectOnceUponATime(const Common::FSList &fslist);
 };
 
-GobMetaEngine::GobMetaEngine() :
-	AdvancedMetaEngine(Gob::gameDescriptions, sizeof(Gob::GOBGameDescription), gobGames) {
+GobMetaEngineDetection::GobMetaEngineDetection() :
+	AdvancedMetaEngineDetection(Gob::gameDescriptions, sizeof(Gob::GOBGameDescription), gobGames) {
 
 	_guiOptions = GUIO1(GUIO_NOLAUNCHLOAD);
 }
 
-ADDetectedGame GobMetaEngine::fallbackDetect(const FileMap &allFiles, const Common::FSList &fslist) const {
-	ADDetectedGame detectedGame = detectGameFilebased(allFiles, fslist, Gob::fileBased);
+ADDetectedGame GobMetaEngineDetection::fallbackDetect(const FileMap &allFiles, const Common::FSList &fslist, ADDetectedGameExtraInfo **extra) const {
+	ADDetectedGame detectedGame = detectGameFilebased(allFiles, Gob::fileBased);
 	if (!detectedGame.desc) {
 		return ADDetectedGame();
 	}
@@ -77,7 +92,7 @@ ADDetectedGame GobMetaEngine::fallbackDetect(const FileMap &allFiles, const Comm
 	return detectedGame;
 }
 
-const Gob::GOBGameDescription *GobMetaEngine::detectOnceUponATime(const Common::FSList &fslist) {
+const Gob::GOBGameDescription *GobMetaEngineDetection::detectOnceUponATime(const Common::FSList &fslist) {
 	// Add the game path to the search manager
 	SearchMan.clear();
 	SearchMan.addDirectory(fslist.begin()->getParent().getPath(), fslist.begin()->getParent());
@@ -146,7 +161,7 @@ const Gob::GOBGameDescription *GobMetaEngine::detectOnceUponATime(const Common::
 	SearchMan.clear();
 
 	if ((gameType == Gob::kOnceUponATimeInvalid) || (platform == Gob::kOnceUponATimePlatformInvalid)) {
-		warning("GobMetaEngine::detectOnceUponATime(): Detection failed (%d, %d)",
+		warning("GobMetaEngineDetection::detectOnceUponATime(): Detection failed (%d, %d)",
 		        (int)gameType, (int)platform);
 		return 0;
 	}
@@ -154,62 +169,12 @@ const Gob::GOBGameDescription *GobMetaEngine::detectOnceUponATime(const Common::
 	return &Gob::fallbackOnceUpon[gameType][platform];
 }
 
-const char *GobMetaEngine::getName() const {
+const char *GobMetaEngineDetection::getName() const {
 	return "Gob";
 }
 
-const char *GobMetaEngine::getOriginalCopyright() const {
+const char *GobMetaEngineDetection::getOriginalCopyright() const {
 	return "Goblins Games (C) Coktel Vision";
 }
 
-bool GobMetaEngine::hasFeature(MetaEngineFeature f) const {
-	return false;
-}
-
-bool Gob::GobEngine::hasFeature(EngineFeature f) const {
-	return
-		(f == kSupportsReturnToLauncher);
-}
-
-Common::Error GobMetaEngine::createInstance(OSystem *syst, Engine **engine) const {
-	return AdvancedMetaEngine::createInstance(syst, engine);
-}
-
-bool GobMetaEngine::createInstance(OSystem *syst, Engine **engine, const ADGameDescription *desc) const {
-	const Gob::GOBGameDescription *gd = (const Gob::GOBGameDescription *)desc;
-	if (gd) {
-		*engine = new Gob::GobEngine(syst);
-		((Gob::GobEngine *)*engine)->initGame(gd);
-	}
-	return gd != 0;
-}
-
-
-#if PLUGIN_ENABLED_DYNAMIC(GOB)
-	REGISTER_PLUGIN_DYNAMIC(GOB, PLUGIN_TYPE_ENGINE, GobMetaEngine);
-#else
-	REGISTER_PLUGIN_STATIC(GOB, PLUGIN_TYPE_ENGINE, GobMetaEngine);
-#endif
-
-namespace Gob {
-
-void GobEngine::initGame(const GOBGameDescription *gd) {
-	if (gd->startTotBase == 0)
-		_startTot = "intro.tot";
-	else
-		_startTot = gd->startTotBase;
-
-	if (gd->startStkBase == 0)
-		_startStk = "intro.stk";
-	else
-		_startStk = gd->startStkBase;
-
-	_demoIndex = gd->demoIndex;
-
-	_gameType = gd->gameType;
-	_features = gd->features;
-	_language = gd->desc.language;
-	_platform = gd->desc.platform;
-}
-
-} // End of namespace Gob
+REGISTER_PLUGIN_STATIC(GOB_DETECTION, PLUGIN_TYPE_ENGINE_DETECTION, GobMetaEngineDetection);
