@@ -86,6 +86,20 @@
 	kFeaturesCD,
 	0, 0, 0
 },
+{
+	{
+		"inca2",
+		"v1.07",
+		AD_ENTRY1s("intro.stk", "b56e4147acc5852c6fc2de5985ab94b0", 804796),
+		EN_USA,
+		kPlatformDOS,
+		ADGF_NO_FLAGS,
+		GUIO2(GUIO_NOSUBTITLES, GUIO_NOSPEECH)
+	},
+	kGameTypeInca2,
+	kFeaturesCD,
+	0, 0, 0
+},
 {
 	{
 		"inca2",
