@@ -116,19 +116,6 @@ void PauseDialog::handleKeyDown(Common::KeyState state) {
 
 
 GobEngine::GobEngine(OSystem *syst) : Engine(syst), _rnd("gob") {
-	DebugMan.addDebugChannel(kDebugFuncOp, "FuncOpcodes", "Script FuncOpcodes debug level");
-	DebugMan.addDebugChannel(kDebugDrawOp, "DrawOpcodes", "Script DrawOpcodes debug level");
-	DebugMan.addDebugChannel(kDebugGobOp, "GoblinOpcodes", "Script GoblinOpcodes debug level");
-	DebugMan.addDebugChannel(kDebugSound, "Sound", "Sound output debug level");
-	DebugMan.addDebugChannel(kDebugExpression, "Expression", "Expression parser debug level");
-	DebugMan.addDebugChannel(kDebugGameFlow, "Gameflow", "Gameflow debug level");
-	DebugMan.addDebugChannel(kDebugFileIO, "FileIO", "File Input/Output debug level");
-	DebugMan.addDebugChannel(kDebugSaveLoad, "SaveLoad", "Saving/Loading debug level");
-	DebugMan.addDebugChannel(kDebugGraphics, "Graphics", "Graphics debug level");
-	DebugMan.addDebugChannel(kDebugVideo, "Video", "IMD/VMD video debug level");
-	DebugMan.addDebugChannel(kDebugHotspots, "Hotspots", "Hotspots debug level");
-	DebugMan.addDebugChannel(kDebugDemo, "Demo", "Demo script debug level");
-
 	_sound     = 0; _mult     = 0; _game    = 0;
 	_global    = 0; _dataIO   = 0; _goblin  = 0;
 	_vidPlayer = 0; _init     = 0; _inter   = 0;
@@ -295,8 +282,12 @@ Common::Error GobEngine::run() {
 		return err;
 
 	// On some systems it's not safe to run CD audio games from the CD.
-	if (isCD())
-		checkCD();
+	if (isCD()) {
+		if (!existExtractedCDAudioFiles()
+		    && !isDataAndCDAudioReadFromSameCD()) {
+			warnMissingExtractedCDAudio();
+		}
+	}
 
 	_system->getAudioCDManager()->open();
 
@@ -320,7 +311,6 @@ Common::Error GobEngine::run() {
 
 	switch (_language) {
 	case Common::FR_FRA:
-	case Common::RU_RUS:
 		_global->_language = kLanguageFrench;
 		break;
 	case Common::DE_DEU:
@@ -355,6 +345,12 @@ Common::Error GobEngine::run() {
 	case Common::JA_JPN:
 		_global->_language = kLanguageJapanese;
 		break;
+	case Common::RU_RUS:
+		if (_gameType == kGameTypeWoodruff || _gameType == kGameTypeBargon)
+			_global->_language = kLanguageBritish;
+		else
+			_global->_language = kLanguageFrench;
+		break;
 	default:
 		_global->_language = kLanguageBritish;
 		break;
