@@ -159,13 +159,13 @@ private:
 
 class Map_v1 : public Map {
 public:
-	virtual void loadMapObjects(const char *avjFile);
-	virtual void findNearestToGob(Mult::Mult_Object *obj);
-	virtual void findNearestToDest(Mult::Mult_Object *obj);
-	virtual void optimizePoints(Mult::Mult_Object *obj, int16 x, int16 y);
+	void loadMapObjects(const char *avjFile) override;
+	void findNearestToGob(Mult::Mult_Object *obj) override;
+	void findNearestToDest(Mult::Mult_Object *obj) override;
+	void optimizePoints(Mult::Mult_Object *obj, int16 x, int16 y) override;
 
 	Map_v1(GobEngine *vm);
-	virtual ~Map_v1();
+	~Map_v1() override;
 
 protected:
 	void init();
@@ -177,13 +177,13 @@ protected:
 
 class Map_v2 : public Map_v1 {
 public:
-	virtual void loadMapObjects(const char *avjFile);
-	virtual void findNearestToGob(Mult::Mult_Object *obj);
-	virtual void findNearestToDest(Mult::Mult_Object *obj);
-	virtual void optimizePoints(Mult::Mult_Object *obj, int16 x, int16 y);
+	void loadMapObjects(const char *avjFile) override;
+	void findNearestToGob(Mult::Mult_Object *obj) override;
+	void findNearestToDest(Mult::Mult_Object *obj) override;
+	void optimizePoints(Mult::Mult_Object *obj, int16 x, int16 y) override;
 
 	Map_v2(GobEngine *vm);
-	virtual ~Map_v2();
+	~Map_v2() override;
 
 protected:
 	void loadGoblinStates(Common::SeekableReadStream &data, int index);
