@@ -34,10 +34,10 @@ private:
 
 public:
 	LzssReadStream(Common::ReadStream *indata, uint8 lengthmask, uint8 lengthbits);
-	~LzssReadStream();
+	~LzssReadStream() override;
 
-	bool eos() const;
-	uint32 read(void *buf, uint32 size);
+	bool eos() const override;
+	uint32 read(void *buf, uint32 size) override;
 };
 
 } // End of Groovie namespace
