@@ -81,8 +81,8 @@ HDBGame::HDBGame(OSystem *syst, const ADGameDescription *gameDesc) : Engine(syst
 
 	_timePlayed = _timeSlice = _prevTimeSlice = _timeSeconds = _tiempo = 0;
 
-	_currentOutSaveFile = NULL;
-	_currentInSaveFile = NULL;
+	_currentOutSaveFile = nullptr;
+	_currentInSaveFile = nullptr;
 
 	_progressActive = false;
 
@@ -127,17 +127,17 @@ HDBGame::~HDBGame() {
 	delete _rnd;
 
 	delete _progressGfx;
-	_progressGfx = NULL;
+	_progressGfx = nullptr;
 	delete _progressMarkGfx;
-	_progressMarkGfx = NULL;
+	_progressMarkGfx = nullptr;
 	delete _loadingScreenGfx;
-	_loadingScreenGfx = NULL;
+	_loadingScreenGfx = nullptr;
 	if (_logoGfx) {
 		delete _logoGfx;
-		_logoGfx = NULL;
+		_logoGfx = nullptr;
 	}
 	delete _debugLogo;
-	_debugLogo = NULL;
+	_debugLogo = nullptr;
 }
 
 bool HDBGame::init() {
@@ -171,7 +171,7 @@ bool HDBGame::init() {
 	_debugLogo = _gfx->loadIcon("icon_debug_logo");
 	_progressGfx = _gfx->loadPic(PIC_LOADBAR);
 	_progressMarkGfx = _gfx->loadPic(PIC_LOADSTAR);
-	_logoGfx = NULL;
+	_logoGfx = nullptr;
 
 	_changeLevel = false;
 	_changeMapname[0] = 0;
@@ -185,7 +185,7 @@ bool HDBGame::init() {
 	if (!g_hdb->isPPC())
 		_loadingScreenGfx = _gfx->loadPic(PIC_LOADSCREEN);
 	else
-		_loadingScreenGfx = NULL;
+		_loadingScreenGfx = nullptr;
 
 	return true;
 }
@@ -225,6 +225,8 @@ void HDBGame::changeGameState() {
 		break;
 	case GAME_LOADING:
 		break;
+	default:
+		break;
 	}
 }
 
@@ -254,7 +256,7 @@ bool HDBGame::restartMap() {
 
 		_lua->saveGlobalNumber("map12_complete", 1);
 
-		strcpy(_lastMapname, "MAP12");
+		Common::strlcpy(_lastMapname, "MAP12", 64);
 	}
 
 	if (!strcmp(_currentLuaName, "MAP06.LUA")) {
@@ -361,17 +363,21 @@ void HDBGame::paint() {
 		_gfx->drawPointer();
 		break;
 	case GAME_LOADING:
-		// clear video, then draw HDB logo
-		drawLoadingScreen();
+		{
+			// clear video, then draw HDB logo
+			drawLoadingScreen();
 
-		// if the graphic has never been loaded, load it now and leave it in memory
-		if (!_logoGfx)
-			_logoGfx = _gfx->loadPic(TITLELOGO);
-		_logoGfx->drawMasked(_screenWidth / 2 - _logoGfx->_width / 2, 10);
+			// if the graphic has never been loaded, load it now and leave it in memory
+			if (!_logoGfx)
+				_logoGfx = _gfx->loadPic(TITLELOGO);
+			_logoGfx->drawMasked(_screenWidth / 2 - _logoGfx->_width / 2, 10);
 
-		int	x = _screenWidth / 2 - _progressGfx->_width / 2;
-		int pixels = _progressGfx->_width - _progressMarkGfx->_width;
-		_progressXOffset = (int)(((double)pixels / _progressMax) * (double)_progressCurrent) + x;
+			int	x = _screenWidth / 2 - _progressGfx->_width / 2;
+			int pixels = _progressGfx->_width - _progressMarkGfx->_width;
+			_progressXOffset = (int)(((double)pixels / _progressMax) * (double)_progressCurrent) + x;
+		}
+		break;
+	default:
 		break;
 	}
 
@@ -725,6 +731,7 @@ void HDBGame::useEntity(AIEntity *e) {
 				e->state = STATE_DIVERTER_TR;
 				break;
 			case DIR_NONE:
+			default:
 				break;
 			}
 		}
@@ -760,6 +767,7 @@ void HDBGame::useEntity(AIEntity *e) {
 			p->drawXOff = 10;
 			break;
 		case DIR_NONE:
+		default:
 			break;
 		}
 
@@ -880,13 +888,13 @@ void HDBGame::setInMapName(const char *name) {
 	for (uint i = 0; i < ARRAYSIZE(mapNames); i++) {
 		if (!scumm_stricmp(name, mapNames[i].fName)) {
 			memset(&_inMapName, 0, 32);
-			strcpy(_inMapName, mapNames[i].printName);
+			Common::strlcpy(_inMapName, mapNames[i].printName, 32);
 			return;
 		}
 	}
 
 	memset(&_inMapName, 0, 32);
-	strcpy(_inMapName, name);
+	Common::strlcpy(_inMapName, name, 32);
 }
 
 Common::Error HDBGame::run() {
@@ -902,7 +910,7 @@ Common::Error HDBGame::run() {
 
 #if 0
 	Common::SeekableReadStream *titleStream = _fileMan->findFirstData("monkeylogoscreen", TYPE_PIC);
-	if (titleStream == NULL) {
+	if (titleStream == nullptr) {
 		debug("The TitleScreen MPC entry can't be found.");
 		delete titleStream;
 		return Common::kReadingFailed;
@@ -913,7 +921,7 @@ Common::Error HDBGame::run() {
 	delete titleStream;
 
 	Common::SeekableReadStream *tileStream = _fileMan->findFirstData("t32_ground1", TYPE_TILE32);
-	if (tileStream == NULL) {
+	if (tileStream == nullptr) {
 		debug("The t32_shipwindow_lr MPC entry can't be found.");
 		delete tileStream;
 		return Common::kReadingFailed;
@@ -952,7 +960,7 @@ Common::Error HDBGame::run() {
 			_gameState = GAME_PLAY;
 	}
 
-	//_window->openDialog("Sgt. Filibuster", 0, "You address me as 'sarge' or 'sergeant' or get your snappin' teeth kicked in! Got me?", 0, NULL);
+	//_window->openDialog("Sgt. Filibuster", 0, "You address me as 'sarge' or 'sergeant' or get your snappin' teeth kicked in! Got me?", 0, nullptr);
 
 #if 0
 	lua->executeFile("test.lua");
@@ -967,28 +975,16 @@ Common::Error HDBGame::run() {
 				_input->updateMouse(event.mouse.x, event.mouse.y);
 				break;
 			case Common::EVENT_LBUTTONDOWN:
-				_input->updateMouseButtons(1, 0, 0);
+				_input->updateMouseButtons(true);
 				break;
 			case Common::EVENT_LBUTTONUP:
-				_input->updateMouseButtons(-1, 0, 0);
+				_input->updateMouseButtons(false);
 				break;
-			case Common::EVENT_MBUTTONDOWN:
-				_input->updateMouseButtons(0, 1, 0);
+			case Common::EVENT_CUSTOM_ENGINE_ACTION_START:
+				_input->updateActions(event, true, true);
 				break;
-			case Common::EVENT_MBUTTONUP:
-				_input->updateMouseButtons(0, -1, 0);
-				break;
-			case Common::EVENT_RBUTTONDOWN:
-				_input->updateMouseButtons(0, 0, 1);
-				break;
-			case Common::EVENT_RBUTTONUP:
-				_input->updateMouseButtons(0, 0, -1);
-				break;
-			case Common::EVENT_KEYDOWN:
-				_input->updateKeys(event, true);
-				break;
-			case Common::EVENT_KEYUP:
-				_input->updateKeys(event, false);
+			case Common::EVENT_CUSTOM_ENGINE_ACTION_END:
+				_input->updateActions(event, false, true);
 				break;
 			default:
 				break;
