@@ -128,16 +128,13 @@ private:
 	bool displayAdultDisclaimer();
 protected:
 	// Engine APIs
-	virtual Common::Error run();
-	virtual bool hasFeature(EngineFeature f) const;
-
-	GUI::Debugger *getDebugger() { return _debug; }
+	Common::Error run() override;
+	bool hasFeature(EngineFeature f) const override;
 
 public:
 	AnimationManager *_animMan;
 	ComputerManager *_computer;
 	DialogsManager *_dialog;
-	Debugger *_debug;
 	EventsManager *_events;
 	FileManager *_fileIO;
 	FontManager *_fontMan;
@@ -153,7 +150,7 @@ public:
 
 public:
 	HopkinsEngine(OSystem *syst, const HopkinsGameDescription *gameDesc);
-	virtual ~HopkinsEngine();
+	~HopkinsEngine() override;
 	void GUIError(const Common::String &msg);
 
 	uint32 getFeatures() const;
@@ -164,12 +161,13 @@ public:
 	const Common::String &getTargetName() const;
 
 	int getRandomNumber(int maxNumber);
-	Common::String generateSaveName(int slotNumber);
-	virtual bool canLoadGameStateCurrently();
-	virtual bool canSaveGameStateCurrently();
-	virtual Common::Error loadGameState(int slot);
-	virtual Common::Error saveGameState(int slot, const Common::String &desc);
+	bool canLoadGameStateCurrently() override;
+	bool canSaveGameStateCurrently() override;
+	Common::Error loadGameState(int slot) override;
+	Common::Error saveGameState(int slot, const Common::String &desc, bool isAutosave = false) override;
+
 	int _startGameSlot;
+
 	/**
 	 * Run the introduction sequence
 	 */
@@ -178,7 +176,7 @@ public:
 	/**
 	 * Synchronizes the sound settings from ScummVM into the engine
 	 */
-	virtual void syncSoundSettings();
+	void syncSoundSettings() override;
 };
 
 } // End of namespace Hopkins
