@@ -133,11 +133,11 @@ private:
 class Parser_v1d : public Parser {
 public:
 	Parser_v1d(HugoEngine *vm);
-	~Parser_v1d();
+	~Parser_v1d() override;
 
-	virtual void lineHandler();
-	virtual void showInventory() const;
-	virtual void takeObject(Object *obj);
+	void lineHandler() override;
+	void showInventory() const override;
+	void takeObject(Object *obj) override;
 
 protected:
 	virtual void dropObject(Object *obj);
@@ -153,35 +153,35 @@ protected:
 class Parser_v2d : public Parser_v1d {
 public:
 	Parser_v2d(HugoEngine *vm);
-	~Parser_v2d();
+	~Parser_v2d() override;
 
-	void lineHandler();
+	void lineHandler() override;
 };
 
 class Parser_v3d : public Parser_v1d {
 public:
 	Parser_v3d(HugoEngine *vm);
-	~Parser_v3d();
+	~Parser_v3d() override;
 
-	virtual void lineHandler();
+	void lineHandler() override;
 protected:
-	void  dropObject(Object *obj);
+	void  dropObject(Object *obj) override;
 	bool  isBackgroundWord_v3(ObjectList obj) const;
 	bool  isCatchallVerb_v3(ObjectList obj) const;
 	bool  isGenericVerb_v3(Object *obj, char *comment);
 	bool  isNear_v3(Object *obj, const char *verb, char *comment) const;
 	bool  isObjectVerb_v3(Object *obj, char *comment);
-	void  takeObject(Object *obj);
+	void  takeObject(Object *obj) override;
 };
 
 class Parser_v1w : public Parser_v3d {
 public:
 	Parser_v1w(HugoEngine *vm);
-	~Parser_v1w();
+	~Parser_v1w() override;
 
-	virtual void showInventory() const;
+	void showInventory() const override;
 
-	void  lineHandler();
+	void  lineHandler() override;
 };
 
 } // End of namespace Hugo
