@@ -208,6 +208,11 @@ Common::Error IllusionsEngine_Duckman::run() {
 
 	unloadSpecialCode(0);
 
+	_resSys->unloadResourceById(0x120001);
+	_resSys->unloadResourceById(0x120002);
+	_resSys->unloadResourceById(0x120003);
+	_resSys->unloadResourceById(0x000D0001);
+
 	delete _stack;
 	delete _scriptOpcodes;
 
@@ -241,7 +246,7 @@ Common::Error IllusionsEngine_Duckman::run() {
 
 bool IllusionsEngine_Duckman::hasFeature(EngineFeature f) const {
 	return
-		(f == kSupportsRTL) ||
+		(f == kSupportsReturnToLauncher) ||
 		(f == kSupportsLoadingDuringRuntime) ||
 		(f == kSupportsSavingDuringRuntime);
 }
@@ -790,6 +795,8 @@ void IllusionsEngine_Duckman::cursorControlRoutine(Control *control, uint32 delt
 		case 4:
 			_menuSystem->update(_cursor._control);
 			break;
+		default:
+			break;
 		}
 	}
 }
@@ -1188,9 +1195,13 @@ void IllusionsEngine_Duckman::playSoundEffect(int index) {
 	case 18:
 		soundEffectId = soundIds[26];
 		break;
+	default:
+		break;
 	}
-	if (soundEffectId)
+
+	if (soundEffectId) {
 		_soundMan->playSound(soundEffectId, 255, 0);
+	}
 }
 
 bool IllusionsEngine_Duckman::getTriggerCause(uint32 verbId, uint32 objectId2, uint32 objectId, uint32 &outThreadId) {
