@@ -26,6 +26,7 @@
 #include "illusions/graphics.h"
 #include "audio/mixer.h"
 #include "audio/decoders/aiff.h"
+
 #include "common/array.h"
 #include "common/events.h"
 #include "common/file.h"
@@ -34,8 +35,10 @@
 #include "common/str.h"
 #include "common/substream.h"
 #include "common/system.h"
+
 #include "engines/engine.h"
 #include "graphics/surface.h"
+#include "illusions/detection.h"
 
 namespace Illusions {
 
@@ -60,7 +63,6 @@ class Cursor;
 class Dictionary;
 struct Fader;
 class FramesList;
-struct IllusionsGameDescription;
 class Input;
 class Screen;
 class ScreenText;
@@ -76,11 +78,6 @@ class UpdateFunctions;
 class GameState;
 class ScreenPaletteBase;
 
-enum {
-	kGameIdBBDOU   = 1,
-	kGameIdDuckman = 2
-};
-
 class IllusionsEngine : public Engine {
 public:
 	IllusionsEngine(OSystem *syst, const IllusionsGameDescription *gd);
