@@ -62,6 +62,13 @@ KyraEngine_MR::KyraEngine_MR(OSystem *system, const GameFlags &flags) : KyraEngi
 	_itemFile = 0;
 	_gamePlayBuffer = 0;
 	_interface = _interfaceCommandLine = 0;
+	// The slightly larger interface is used in the Chinese version regardless of the actual language setting.
+	_interfaceCommandLineSize = flags.hasExtraLanguage ? 4800 : 3840;
+	_interfaceCommandLineH = _interfaceCommandLineSize / Screen::SCREEN_W;
+	_interfaceCommandLineY1 = Screen::SCREEN_H - _interfaceCommandLineH;
+	_interfaceCommandLineY2 = 156 - _interfaceCommandLineH;
+	_interfaceSize = flags.hasExtraLanguage ? 18880 : 17920;
+	_interfaceH = _interfaceSize / Screen::SCREEN_W;
 	_costPalBuffer = 0;
 	memset(_sceneShapes, 0, sizeof(_sceneShapes));
 	memset(_sceneAnimMovie, 0, sizeof(_sceneAnimMovie));
@@ -222,6 +229,18 @@ Common::Error KyraEngine_MR::init() {
 	_screen->loadFont(Screen::FID_8_FNT, "8FAT.FNT");
 	_screen->loadFont(Screen::FID_BOOKFONT_FNT, "BOOKFONT.FNT");
 	_screen->setFont(Screen::FID_8_FNT);
+
+	if (_flags.hasExtraLanguage) {
+		// We don't check the language setting here, since we want to load the file even if the language is currently set to English, French or German.
+		if (_res->exists("MALCOLM.PAK")) {
+			_screen->loadFont(Screen::FID_CHINESE_FNT, "MALCOLM.PAK");
+			if (_lang == 3) {
+				_screen->setFont(Screen::FID_CHINESE_FNT);
+				_screen->_lineSpacing = 2;
+			}
+		}
+	}
+
 	_screen->setAnimBlockPtr(3500);
 	_screen->setScreenDim(0);
 
@@ -282,7 +301,7 @@ Common::Error KyraEngine_MR::go() {
 
 		_eventList.clear();
 
-		switch (_menu->handle(3)) {
+		switch (_menu->handle(_lang == 3 ? 4 : 3)) {
 		case 2:
 			_menuDirectlyToLoad = true;
 			// fall through
@@ -330,20 +349,12 @@ void KyraEngine_MR::initMainMenu() {
 
 	_menu = new MainMenu(this);
 	MainMenu::StaticData data = {
-		{ _mainMenuStrings[_lang*4+0], _mainMenuStrings[_lang*4+1], _mainMenuStrings[_lang*4+2], _mainMenuStrings[_lang*4+3], 0 },
+		{ _mainMenuStrings[0], _mainMenuStrings[1], _mainMenuStrings[2], _mainMenuStrings[3], 0 },
 		{ 0x01, 0x04, 0x0C, 0x04, 0x00, 0x80, 0xFF },
 		{ 0x16, 0x19, 0x1A, 0x16 },
-		Screen::FID_8_FNT, 240
+		_lang == 3 ? Screen::FID_CHINESE_FNT : Screen::FID_8_FNT, 240
 	};
 
-	if (_flags.lang == Common::ES_ESP) {
-		for (int i = 0; i < 4; ++i)
-			data.strings[i] = _mainMenuSpanishFan[i];
-	} else if (_flags.lang == Common::IT_ITA) {
-		for (int i = 0; i < 4; ++i)
-			data.strings[i] = _mainMenuItalianFan[i];
-	}
-
 	MainMenu::Animation anim;
 	anim.anim = _menuAnim;
 	anim.startFrame = 29;
@@ -475,8 +486,15 @@ void KyraEngine_MR::playStudioSFX(const char *str) {
 		return;
 
 	const int strSize = strlen(str) - 1;
-	if (str[strSize] != '?' && str[strSize] != '!')
-		return;
+	if (_flags.lang == Common::ZH_CNA) {
+		// WORKAROUND: The studio sfx is broken in the original, since it still has the
+		// check for '!' and '?' even if the language is set to Chinese. I have fixed this here...
+		if (str[strSize] != '\x80' || !(str[strSize - 1] == '\x81' || str[strSize - 1] == '\x91'))
+			return;
+	} else {
+		if (str[strSize] != '?' && str[strSize] != '!')
+			return;
+	}
 
 	snd_playSoundEffect(_curStudioSFX++, 128);
 
@@ -513,10 +531,10 @@ void KyraEngine_MR::startup() {
 
 	_gamePlayBuffer = new uint8[64000];
 
-	_interface = new uint8[17920];
-	_interfaceCommandLine = new uint8[3840];
+	_interface = new uint8[_interfaceSize];
+	_interfaceCommandLine = new uint8[_interfaceCommandLineSize];
 
-	_screen->setFont(Screen::FID_8_FNT);
+	_screen->setFont(_lang == 3 ? Screen::FID_CHINESE_FNT : Screen::FID_8_FNT);
 
 	_stringBuffer = new char[500];
 	allocAnimObjects(1, 16, 50);
@@ -641,8 +659,8 @@ void KyraEngine_MR::loadInterfaceShapes() {
 
 void KyraEngine_MR::loadInterface() {
 	_screen->loadBitmap("INTRFACE.CPS", 3, 3, 0);
-	memcpy(_interface, _screen->getCPagePtr(3), 17920);
-	memcpy(_interfaceCommandLine, _screen->getCPagePtr(3), 3840);
+	memcpy(_interface, _screen->getCPagePtr(3), _interfaceSize);
+	memcpy(_interfaceCommandLine, _screen->getCPagePtr(3), _interfaceCommandLineSize);
 }
 
 void KyraEngine_MR::initItems() {
@@ -971,7 +989,7 @@ void KyraEngine_MR::handleInput(int x, int y) {
 	} else if (_itemInHand >= 0 && _savedMouseState >= 0) {
 		if (_itemInHand == 27) {
 			makeCharFacingMouse();
-		} else if (y <= 187) {
+		} else if (y < _interfaceCommandLineY1) {
 			if (_itemInHand == 43)
 				removeHandItem();
 			else
@@ -981,7 +999,7 @@ void KyraEngine_MR::handleInput(int x, int y) {
 	} else if (_savedMouseState == -3) {
 		return;
 	} else {
-		if (y > 187 && _savedMouseState > -4)
+		if (y >= _interfaceCommandLineY1 && _savedMouseState > -4)
 			return;
 		if (_unk5) {
 			_unk5 = 0;
@@ -1065,7 +1083,7 @@ void KyraEngine_MR::updateWithText() {
 
 	restorePage3();
 	drawAnimObjects();
-	if (_chatTextEnabled && _chatText) {
+	if (_chatTextEnabled && !_chatText.empty()) {
 		int curPage = _screen->_curPage;
 		_screen->_curPage = 2;
 		objectChatPrintText(_chatText, _chatObject);
@@ -1081,7 +1099,7 @@ void KyraEngine_MR::updateMouse() {
 	Common::Point mouse = getMousePos();
 	bool hasItemCollision = checkItemCollision(mouse.x, mouse.y) != -1;
 
-	if (mouse.y > 187) {
+	if (mouse.y >= _interfaceCommandLineY1) {
 		bool setItemCursor = false;
 		if (_mouseState == -6) {
 			if (mouse.x < 311)
@@ -1189,7 +1207,7 @@ void KyraEngine_MR::updateMouse() {
 		_screen->setMouseCursor(offsetX, offsetY, _gameShapes[shape]);
 	} else if (type == 0 && _mouseState != _itemInHand && mouse.x > 8 && mouse.x < 311 && mouse.y < 171 && mouse.y > 8) {
 		setItemMouseCursor();
-	} else if (mouse.y > 187 && _mouseState > -4 && type == 0 && !_inventoryState) {
+	} else if (mouse.y >= _interfaceCommandLineY1 && _mouseState > -4 && type == 0 && !_inventoryState) {
 		showInventory();
 	}
 }
@@ -1397,6 +1415,10 @@ void KyraEngine_MR::writeSettings() {
 		_flags.lang = Common::DE_DEU;
 		break;
 
+	case 3:
+		_flags.lang = Common::ZH_CNA;
+		break;
+
 	case 0:
 	default:
 		_flags.lang = Common::EN_ANY;
