@@ -40,9 +40,9 @@ KyraEngine_v1::KyraEngine_v1(OSystem *system, const GameFlags &flags)
 	_staticres = 0;
 	_timer = 0;
 	_emc = 0;
-	_debugger = 0;
 
 	_configRenderMode = Common::kRenderDefault;
+	_configNullSound = false;
 
 	if (_flags.platform == Common::kPlatformAmiga)
 		_gameSpeed = 50;
@@ -54,6 +54,7 @@ KyraEngine_v1::KyraEngine_v1(OSystem *system, const GameFlags &flags)
 	_trackMapSize = 0;
 	_lastMusicCommand = -1;
 	_curSfxFile = _curMusicTheme = -1;
+	_preventScriptSfx = false;
 
 	_gameToLoad = -1;
 
@@ -65,24 +66,8 @@ KyraEngine_v1::KyraEngine_v1(OSystem *system, const GameFlags &flags)
 	_isSaveAllowed = false;
 
 	_mouseX = _mouseY = 0;
+	_transOffsY = 0;
 	_asciiCodeEvents = _kbEventSkip = false;
-
-	// sets up all engine specific debug levels
-	DebugMan.addDebugChannel(kDebugLevelScriptFuncs, "ScriptFuncs", "Script function debug level");
-	DebugMan.addDebugChannel(kDebugLevelScript, "Script", "Script interpreter debug level");
-	DebugMan.addDebugChannel(kDebugLevelSprites, "Sprites", "Sprite debug level");
-	DebugMan.addDebugChannel(kDebugLevelScreen, "Screen", "Screen debug level");
-	DebugMan.addDebugChannel(kDebugLevelSound, "Sound", "Sound debug level");
-	DebugMan.addDebugChannel(kDebugLevelAnimator, "Animator", "Animator debug level");
-	DebugMan.addDebugChannel(kDebugLevelMain, "Main", "Generic debug level");
-	DebugMan.addDebugChannel(kDebugLevelGUI, "GUI", "GUI debug level");
-	DebugMan.addDebugChannel(kDebugLevelSequence, "Sequence", "Sequence debug level");
-	DebugMan.addDebugChannel(kDebugLevelMovie, "Movie", "Movie debug level");
-	DebugMan.addDebugChannel(kDebugLevelTimer, "Timer", "Timer debug level");
-}
-
-::GUI::Debugger *KyraEngine_v1::getDebugger() {
-	return _debugger;
 }
 
 void KyraEngine_v1::pauseEngineIntern(bool pause) {
@@ -119,22 +104,22 @@ Common::Error KyraEngine_v1::init() {
 			// Users who want PC speaker sound always have to select this individually for all
 			// Kyra games.
 			MidiDriver::DeviceHandle dev = MidiDriver::detectDevice(MDT_PCSPK | MDT_MIDI | MDT_ADLIB | ((_flags.gameID == GI_KYRA2 || _flags.gameID == GI_LOL) ? MDT_PREFER_GM : MDT_PREFER_MT32));
-			if (MidiDriver::getMusicType(dev) == MT_ADLIB) {
-				_sound = new SoundAdLibPC(this, _mixer);
+			const MusicType musicType = MidiDriver::getMusicType(dev);
+			if (musicType == MT_ADLIB) {
+				_sound = new SoundPC_v1(this, _mixer, Sound::kAdLib);
 			} else {
 				Sound::kType type;
-				const MusicType midiType = MidiDriver::getMusicType(dev);
 
-				if (midiType == MT_PCSPK || midiType == MT_NULL)
+				if (musicType == MT_PCSPK || musicType == MT_NULL)
 					type = Sound::kPCSpkr;
-				else if (midiType == MT_MT32 || ConfMan.getBool("native_mt32"))
+				else if (musicType == MT_MT32 || ConfMan.getBool("native_mt32"))
 					type = Sound::kMidiMT32;
 				else
 					type = Sound::kMidiGM;
 
 				MidiDriver *driver = 0;
 
-				if (MidiDriver::getMusicType(dev) == MT_PCSPK) {
+				if (musicType == MT_PCSPK) {
 					driver = new MidiDriver_PCSpeaker(_mixer);
 				} else {
 					driver = MidiDriver::createMidi(dev);
@@ -152,7 +137,7 @@ Common::Error KyraEngine_v1::init() {
 				// missing. It's just that at least at the time of writing they
 				// are decidedly inferior to the AdLib ones.
 				if (ConfMan.getBool("multi_midi")) {
-					SoundAdLibPC *adlib = new SoundAdLibPC(this, _mixer);
+					SoundPC_v1 *adlib = new SoundPC_v1(this, _mixer, Sound::kAdLib);
 					assert(adlib);
 
 					_sound = new MixedSoundDriver(this, _mixer, soundMidiPc, adlib);
@@ -197,9 +182,6 @@ Common::Error KyraEngine_v1::init() {
 
 	setupKeyMap();
 
-	// Prevent autosave on game startup
-	_lastAutosave = _system->getMillis();
-
 	return Common::kNoError;
 }
 
@@ -215,11 +197,11 @@ KyraEngine_v1::~KyraEngine_v1() {
 	delete _text;
 	delete _timer;
 	delete _emc;
-	delete _debugger;
 }
 
 Common::Point KyraEngine_v1::getMousePos() {
 	Common::Point mouse = _eventMan->getMousePos();
+	mouse.y -= -_transOffsY;
 
 	if (_flags.useHiRes) {
 		mouse.x >>= 1;
@@ -255,9 +237,6 @@ int KyraEngine_v1::checkInput(Button *buttonList, bool mainLoop, int eventFlag)
 	updateInput();
 	_isSaveAllowed = false;
 
-	if (mainLoop)
-		checkAutosave();
-
 	int keys = 0;
 	int8 mouseWheel = 0;
 
@@ -282,11 +261,7 @@ int KyraEngine_v1::checkInput(Button *buttonList, bool mainLoop, int eventFlag)
 					saveGameStateIntern(saveLoadSlot, savegameName, 0);
 				}
 			} else if (event.kbd.hasFlags(Common::KBD_CTRL)) {
-				if (event.kbd.keycode == Common::KEYCODE_d) {
-					if (_debugger)
-						_debugger->attach();
-					breakLoop = true;
-				} else if (event.kbd.keycode == Common::KEYCODE_q) {
+				if (event.kbd.keycode == Common::KEYCODE_q) {
 					quitGame();
 				}
 			} else {
@@ -299,7 +274,7 @@ int KyraEngine_v1::checkInput(Button *buttonList, bool mainLoop, int eventFlag)
 						keys |= 0x100;
 				} else {
 					keys = 0;
-				}				
+				}
 
 				// When we got an keypress, which we might need to handle,
 				// break the event loop and pass it to GUI code.
@@ -311,7 +286,7 @@ int KyraEngine_v1::checkInput(Button *buttonList, bool mainLoop, int eventFlag)
 		case Common::EVENT_LBUTTONDOWN:
 		case Common::EVENT_LBUTTONUP: {
 			_mouseX = event.mouse.x;
-			_mouseY = event.mouse.y;
+			_mouseY = event.mouse.y - _transOffsY;
 			if (_flags.useHiRes) {
 				_mouseX >>= 1;
 				_mouseY >>= 1;
@@ -323,7 +298,7 @@ int KyraEngine_v1::checkInput(Button *buttonList, bool mainLoop, int eventFlag)
 		case Common::EVENT_RBUTTONDOWN:
 		case Common::EVENT_RBUTTONUP: {
 			_mouseX = event.mouse.x;
-			_mouseY = event.mouse.y;
+			_mouseY = event.mouse.y - _transOffsY;
 			if (_flags.useHiRes) {
 				_mouseX >>= 1;
 				_mouseY >>= 1;
@@ -344,9 +319,6 @@ int KyraEngine_v1::checkInput(Button *buttonList, bool mainLoop, int eventFlag)
 			break;
 		}
 
-		if (_debugger)
-			_debugger->onFrame();
-
 		if (breakLoop)
 			break;
 
@@ -452,12 +424,12 @@ void KyraEngine_v1::setupKeyMap() {
 	// If we have an engine that wants ASCII codes instead of key codes, we can skip the setup of the key map.
 	// In that case we simply return the ASCII codes from the event manager. At least until I know better I
 	// trust that the ASCII codes we get from our event manager are the same identical codes. If that assumption
-	// turns out to be wrong I can still implement the original conversion method... 
+	// turns out to be wrong I can still implement the original conversion method...
 	if (_asciiCodeEvents)
 		return;
 
 	for (int i = 0; i < ARRAYSIZE(keys); i++)
-		_keyMap[keys[i].kcScummVM] = (_flags.platform == Common::kPlatformPC98) ? keys[i].kcPC98 : ((_flags.platform == Common::kPlatformFMTowns) ? keys[i].kcFMTowns : keys[i].kcDOS);
+		_keyMap[keys[i].kcScummVM] = (_flags.gameID != GI_EOB1 && _flags.platform == Common::kPlatformPC98) ? keys[i].kcPC98 : ((_flags.platform == Common::kPlatformFMTowns) ? keys[i].kcFMTowns : keys[i].kcDOS);
 }
 
 void KyraEngine_v1::updateInput() {
@@ -510,6 +482,11 @@ void KyraEngine_v1::removeInputTop() {
 		_eventList.erase(_eventList.begin());
 }
 
+void KyraEngine_v1::transposeScreenOutputY(int yAdd) {
+	_transOffsY = yAdd;
+	screen()->transposeScreenOutputY(yAdd);
+}
+
 bool KyraEngine_v1::skipFlag() const {
 	for (Common::List<Event>::const_iterator i = _eventList.begin(); i != _eventList.end(); ++i) {
 		if (i->causedSkip)
@@ -576,7 +553,7 @@ void KyraEngine_v1::registerDefaultSettings() {
 		// the global subtitles settings, we're using this hack to enable subtitles
 		// for fan translations
 		const Common::ConfigManager::Domain *cur = ConfMan.getActiveDomain();
-		if (!cur || (cur && cur->getVal("subtitles").empty()))
+		if (!cur || (cur && !cur->contains("subtitles")))
 			ConfMan.setBool("subtitles", true);
 	}
 }
@@ -594,16 +571,16 @@ void KyraEngine_v1::readSettings() {
 	_configSounds = ConfMan.getBool("sfx_mute") ? 0 : 1;
 
 	if (_sound) {
-		_sound->enableMusic(_configMusic);
-		_sound->enableSFX(_configSounds);
+		_sound->enableMusic(_configNullSound ? false : _configMusic);
+		_sound->enableSFX(_configNullSound ? false : _configSounds);
 	}
 
 	bool speechMute = ConfMan.getBool("speech_mute");
 	bool subtitles = ConfMan.getBool("subtitles");
 
-	if (!speechMute && subtitles)
+	if (!_configNullSound && !speechMute && subtitles)
 		_configVoice = 2;   // Voice & Text
-	else if (!speechMute && !subtitles)
+	else if (!_configNullSound && !speechMute && !subtitles)
 		_configVoice = 1;   // Voice only
 	else
 		_configVoice = 0;   // Text only
@@ -637,8 +614,8 @@ void KyraEngine_v1::writeSettings() {
 	if (_sound) {
 		if (!_configMusic)
 			_sound->beginFadeOut();
-		_sound->enableMusic(_configMusic);
-		_sound->enableSFX(_configSounds);
+		_sound->enableMusic(_configNullSound ? false : _configMusic);
+		_sound->enableSFX(_configNullSound ? false : _configSounds);
 	}
 
 	ConfMan.setBool("speech_mute", speechMute);
@@ -677,6 +654,9 @@ void KyraEngine_v1::setVolume(kVolumeEntry vol, uint8 value) {
 	case kVolumeSpeech:
 		ConfMan.setInt("speech_volume", convertVolumeToMixer(value));
 		break;
+
+	default:
+		break;
 	}
 
 	// Resetup mixer
@@ -701,6 +681,9 @@ uint8 KyraEngine_v1::getVolume(kVolumeEntry vol) {
 		else
 			return 2;
 		break;
+
+	default:
+		break;
 	}
 
 	return 2;
