@@ -42,6 +42,8 @@ void EoBCoreEngine::loadLevel(int level, int sub) {
 	disableSysTimer(2);
 	uint32 end = _system->getMillis() + 500;
 
+	resetWallData();
+
 	readLevelFileData(level);
 
 	Common::String gfxFile;
@@ -90,12 +92,12 @@ void EoBCoreEngine::loadLevel(int level, int sub) {
 		pos += 2;
 	}
 
-	// WORKAROUND for bug #3596547 (EOB1: Door Buttons Don't Work)
+	// WORKAROUND for bug #6211 (EOB1: Door Buttons Don't Work)
 	if (_flags.gameID == GI_EOB1 && level == 7 && _levelBlockProperties[0x035C].assignedObjects == 0x0E89)
 		_levelBlockProperties[0x035C].assignedObjects = 0x0E8D;
 
-	loadVcnData(gfxFile.c_str(), (_flags.gameID == GI_EOB1 && _flags.platform == Common::kPlatformDOS) ? _cgaMappingLevel[_cgaLevelMappingIndex[level - 1]] : 0);
-	_screen->loadEoBBitmap("INVENT", _cgaMappingInv, 5, 3, 2);
+	loadVcnData(gfxFile.c_str(), _cgaLevelMappingIndex ? _cgaMappingLevel[_cgaLevelMappingIndex[level - 1]] : 0);
+	gui_setupPlayFieldHelperPages();
 	if (_flags.platform == Common::kPlatformAmiga && _flags.gameID == GI_EOB1)
 		_screen->getPalette(0).copy(_screen->getPalette(1), 1, 5, 1);
 
@@ -107,12 +109,14 @@ void EoBCoreEngine::loadLevel(int level, int sub) {
 	_sceneDrawPage2 = 1;
 	_screen->setCurPage(0);
 	setHandItem(_itemInHand);
+
+	snd_playLevelScore();
 }
 
 void EoBCoreEngine::readLevelFileData(int level) {
 	Common::String file;
 	Common::SeekableReadStream *s = 0;
-	static const char *const suffix[] = { "INF", "DRO", "ELO", "JOT", 0 };
+	static const char *const suffix[] = { "DRO", "INF", "ELO", "JOT", 0 };
 
 	for (const char *const *sf = suffix; *sf && !s; sf++) {
 		file = Common::String::format("LEVEL%d.%s", level, *sf);
@@ -123,7 +127,8 @@ void EoBCoreEngine::readLevelFileData(int level) {
 		error("Failed to load level file LEVEL%d.INF/DRO/ELO/JOT", level);
 
 	if (s->readUint16LE() + 2 == s->size()) {
-		if (s->readUint16LE() == 4) {
+		// check for valid compression type
+		if (s->readUint16LE() <= 4) {
 			delete s;
 			s = 0;
 			_screen->loadBitmap(file.c_str(), 5, 5, 0, true);
@@ -159,9 +164,9 @@ Common::String EoBCoreEngine::initLevelData(int sub) {
 		loadBlockProperties((const char *)pos);
 		pos += slen;
 
-		const char *vmpPattern = (_flags.gameID == GI_EOB1 && (_configRenderMode == Common::kRenderEGA || _configRenderMode == Common::kRenderCGA)) ? "%s.EMP" : "%s.VMP";
-		Common::SeekableReadStreamEndian *s = _res->createEndianAwareReadStream(Common::String::format(vmpPattern, (const char *)pos));
-		uint16 size = (_flags.platform == Common::kPlatformFMTowns) ? 2916 : s->readUint16();
+		Common::SeekableReadStreamEndian *s = getVmpData((const char*)pos);
+		assert(s);
+		uint16 size = (_flags.platform == Common::kPlatformFMTowns || _flags.platform == Common::kPlatformSegaCD) ? 2916 : s->readUint16();
 		delete[] _vmpPtr;
 		_vmpPtr = new uint16[size];
 		if (_flags.gameID == GI_EOB1) {
@@ -193,6 +198,8 @@ Common::String EoBCoreEngine::initLevelData(int sub) {
 		if (_flags.gameID == GI_EOB2 || (_flags.platform != Common::kPlatformAmiga && _configRenderMode != Common::kRenderCGA && _configRenderMode != Common::kRenderEGA))
 			_screen->loadPalette(tmpStr.c_str(), _screen->getPalette(_flags.platform == Common::kPlatformAmiga ? 6 : 0));
 
+		setLevelPalettes(_currentLevel);
+
 		if (_flags.platform == Common::kPlatformFMTowns) {
 			uint16 *src = (uint16*)_screen->getPalette(0).getData();
 			_screen->createFadeTable16bit(src, (uint16*)_greenFadingTable, 4, 75);
@@ -201,9 +208,7 @@ Common::String EoBCoreEngine::initLevelData(int sub) {
 			_screen->createFadeTable16bit(src, (uint16*)_lightBlueFadingTable, 11, 125);
 			_screen->createFadeTable16bit(src, (uint16*)_greyFadingTable, 0, 85);
 			_screen->setScreenPalette(_screen->getPalette(0));
-		} else if (_flags.platform == Common::kPlatformAmiga) {
-			// Amiga versions don't have shape shading
-		} else if (_configRenderMode != Common::kRenderCGA) {
+		} else if (_configRenderMode != Common::kRenderCGA && _flags.platform != Common::kPlatformAmiga && _flags.platform != Common::kPlatformSegaCD && !(_flags.gameID == GI_EOB1 && _flags.platform == Common::kPlatformPC98)) {
 			Palette backupPal(256);
 			backupPal.copy(_screen->getPalette(0), 224, 32, 224);
 			_screen->getPalette(0).fill(224, 32, 0x3F);
@@ -312,32 +317,9 @@ void EoBCoreEngine::addLevelItems() {
 	}
 }
 
-void EoBCoreEngine::loadVcnData(const char *file, const uint8 *cgaMapping) {	
-	if (file)
-		strcpy(_lastBlockDataFile, file);
-
-	delete[] _vcnBlocks;
+void EoBCoreEngine::loadVcnData(const char *file, const uint8 *cgaMapping) {
 	uint32 vcnSize = 0;
-
-	if (_flags.platform == Common::kPlatformFMTowns) {
-		_vcnBlocks = _res->fileData(Common::String::format("%s.VCC", _lastBlockDataFile).c_str(), &vcnSize);
-		return;
-	}
-
-	const char *filePattern = ((_flags.gameID == GI_EOB1 && (_configRenderMode == Common::kRenderEGA || _configRenderMode == Common::kRenderCGA)) ? "%s.ECN" : "%s.VCN");
-	Common::String fn = Common::String::format(filePattern, _lastBlockDataFile);
-
-	if (_flags.gameID == GI_EOB1 && _flags.platform == Common::kPlatformAmiga) {
-		Common::SeekableReadStream *in = _res->createReadStream(fn);
-		vcnSize = in->readUint16LE() * (_vcnSrcBitsPerPixel << 3);
-		_vcnBlocks = new uint8[vcnSize];
-		_screen->getPalette(1).loadAmigaPalette(*in, 1, 5);
-		in->seek(22, SEEK_CUR);
-		in->read(_vcnBlocks, vcnSize);
-		delete in;
-		return;
-	}
-
+	Common::String fn = Common::String::format(_vcnFilePattern.c_str(), _lastBlockDataFile);
 	_screen->loadBitmap(fn.c_str(), 3, 3, 0, true);
 
 	const uint8 *pos = _screen->getCPagePtr(3);
@@ -372,11 +354,15 @@ void EoBCoreEngine::loadVcnData(const char *file, const uint8 *cgaMapping) {
 	} else {
 		if (_flags.platform != Common::kPlatformAmiga && !(_flags.gameID == GI_EOB1 && _configRenderMode == Common::kRenderEGA))
 			memcpy(_vcnColTable, colMap, 32);
-		
+
 		memcpy(_vcnBlocks, pos, vcnSize);
 	}
 }
 
+Common::SeekableReadStreamEndian *EoBCoreEngine::getVmpData(const char *file) {
+	return _res->createEndianAwareReadStream(Common::String::format(_vmpFilePattern.c_str(), file));
+}
+
 void EoBCoreEngine::loadBlockProperties(const char *mazFile) {
 	memset(_levelBlockProperties, 0, 1024 * sizeof(LevelBlockProperty));
 	const uint8 *p = getBlockFileData(mazFile) + 6;
@@ -421,14 +407,23 @@ Common::String EoBCoreEngine::getBlockFileName(int levelIndex, int sub) {
 
 const uint8 *EoBCoreEngine::getBlockFileData(const char *mazFile) {
 	_curBlockFile = mazFile;
-	return getBlockFileData();
+	return getBlockFileData(_currentLevel);
+}
+
+
+Common::SeekableReadStreamEndian *EoBCoreEngine::getDecDefinitions(const char *decFile) {
+	return _res->createEndianAwareReadStream(decFile, Resource::kForceLE);
+}
+
+void EoBCoreEngine::loadDecShapesToPage3(const char *shpFile) {
+	_screen->loadShapeSetBitmap(shpFile, 5, 3);
 }
 
 void EoBCoreEngine::loadDecorations(const char *cpsFile, const char *decFile) {
-	_screen->loadShapeSetBitmap(cpsFile, 5, 3);
-	Common::SeekableReadStream *s = _res->createReadStream(decFile);
+	loadDecShapesToPage3(cpsFile);
+	Common::SeekableReadStreamEndian *s = getDecDefinitions(decFile);
 
-	_levelDecorationDataSize = s->readUint16LE();
+	_levelDecorationDataSize = s->readUint16();
 	delete[] _levelDecorationData;
 	_levelDecorationData = new LevelDecorationProperty[_levelDecorationDataSize];
 	memset(_levelDecorationData, 0, _levelDecorationDataSize * sizeof(LevelDecorationProperty));
@@ -443,20 +438,20 @@ void EoBCoreEngine::loadDecorations(const char *cpsFile, const char *decFile) {
 		l->next = s->readByte();
 		l->flags = s->readByte();
 		for (int ii = 0; ii < 10; ii++)
-			l->shapeX[ii] = s->readSint16LE();
+			l->shapeX[ii] = s->readSint16();
 		for (int ii = 0; ii < 10; ii++)
-			l->shapeY[ii] = s->readSint16LE();
+			l->shapeY[ii] = s->readSint16();
 	}
 
-	int len = s->readUint16LE();
+	int len = s->readUint16();
 	delete[] _levelDecorationRects;
 	_levelDecorationRects = new EoBRect8[len];
 	for (int i = 0; i < len; i++) {
 		EoBRect8 *l = &_levelDecorationRects[i];
-		l->x = s->readUint16LE();
-		l->y = s->readUint16LE();
-		l->w = s->readUint16LE();
-		l->h = s->readUint16LE();
+		l->x = s->readUint16();
+		l->y = s->readUint16();
+		l->w = s->readUint16();
+		l->h = s->readUint16();
 	}
 
 	delete s;
@@ -495,7 +490,12 @@ void EoBCoreEngine::assignWallsAndDecorations(int wallIndex, int vmpIndex, int d
 			if (r->w == 0 || r->h == 0)
 				error("Error trying to make decoration %d (x: %d, y: %d, w: %d, h: %d)", decIndex, r->x, r->y, r->w, r->h);
 
-			_levelDecorationShapes[t] = _screen->encodeShape(r->x, r->y, r->w, r->h, false, (_flags.gameID == GI_EOB1 && _flags.platform == Common::kPlatformDOS) ? _cgaMappingLevel[_cgaLevelMappingIndex[_currentLevel - 1]] : 0);
+			if (_flags.platform == Common::kPlatformSegaCD) {
+				_levelDecorationShapes[t] = _screen->sega_convertShape(_dcrShpDataPos, r->w << 3, r->h, 0);
+				_dcrShpDataPos += ((r->w << 2) * r->h);
+			} else {
+				_levelDecorationShapes[t] = _screen->encodeShape(r->x, r->y, r->w, r->h, false, _cgaLevelMappingIndex ? _cgaMappingLevel[_cgaLevelMappingIndex[_currentLevel - 1]] : 0);
+			}
 		}
 
 		decIndex = _levelDecorationProperties[_mappedDecorationsCount++].next;
@@ -516,6 +516,7 @@ void EoBCoreEngine::releaseDecorations() {
 		}
 	}
 	_mappedDecorationsCount = 0;
+	_dcrShpDataPos = 0;
 }
 
 void EoBCoreEngine::releaseDoorShapes() {
@@ -527,6 +528,24 @@ void EoBCoreEngine::releaseDoorShapes() {
 	}
 }
 
+void EoBCoreEngine::resetWallData() {
+	memset(_wllVmpMap, 0, 256);
+	_wllVmpMap[1] = 1;
+	_wllVmpMap[2] = 2;
+	memset(&_wllVmpMap[3], 3, 20);
+	_wllVmpMap[23] = 4;
+	_wllVmpMap[24] = 5;
+	memset(_wllShapeMap, 0, 256);
+	memset(&_wllShapeMap[3], -1, 5);
+	memset(&_wllShapeMap[13], -1, 5);
+	memset(_wllWallFlags, 0, 256);
+	memcpy(_wllWallFlags, _wllFlagPreset, _wllFlagPresetSize);
+	memset(_specialWallTypes, 0, 256);
+	memset(&_specialWallTypes[3], 1, 5);
+	memset(&_specialWallTypes[13], 1, 5);
+	_specialWallTypes[8] = _specialWallTypes[18] = 6;
+}
+
 void EoBCoreEngine::toggleWallState(int wall, int toggle) {
 	wall = wall * 10 + 3;
 
@@ -537,7 +556,7 @@ void EoBCoreEngine::toggleWallState(int wall, int toggle) {
 		if (toggle)
 			_wllWallFlags[wall + i] |= 2;
 		else
-			_wllWallFlags[wall + i] &= 0xFD;
+			_wllWallFlags[wall + i] &= ~2;
 	}
 }
 
@@ -548,7 +567,7 @@ void EoBCoreEngine::drawScene(int refresh) {
 
 	if (_sceneDrawPage2) {
 		if (refresh)
-			_screen->fillRect(0, 0, 176, 120, guiSettings()->colors.guiColorBlack);
+			_screen->fillRect(0, 0, 175, 119, guiSettings()->colors.guiColorBlack);
 
 		if (!_loading)
 			_screen->setScreenPalette(_screen->getPalette(0));
@@ -561,6 +580,7 @@ void EoBCoreEngine::drawScene(int refresh) {
 		int diff = _flashShapeTimer - ct;
 		while ((diff > 0) && !shouldQuit()) {
 			updateInput();
+			updateAnimTimers();
 			uint32 step = MIN<uint32>(diff, _tickLength / 5);
 			_system->delayMillis(step);
 			diff -= step;
@@ -573,7 +593,7 @@ void EoBCoreEngine::drawScene(int refresh) {
 	if (refresh && !_partyResting)
 		_screen->copyRegion(0, 0, 0, 0, 176, 120, 2, 0, Screen::CR_NO_P_CHECK);
 
-	updateEnvironmentalSfx(0);
+	snd_updateEnvironmentalSfx(0);
 
 	if (!_dialogueField && refresh && !_updateFlags)
 		gui_drawCompass(false);
@@ -582,15 +602,15 @@ void EoBCoreEngine::drawScene(int refresh) {
 		_screen->updateScreen();
 
 	if (_sceneDefaultUpdate) {
-		_sceneDefaultUpdate = false;
+		_sceneDefaultUpdate = 0;
 		_drawSceneTimer = _system->getMillis() + 4 * _tickLength;
 	}
 
 	_sceneUpdateRequired = false;
 }
 
-void EoBCoreEngine::drawSceneShapes(int start) {
-	for (int i = start; i < 18; i++) {
+void EoBCoreEngine::drawSceneShapes(int start, int end, int drawFlags) {
+	for (int i = start; i < end; i++) {
 		uint8 t = _dscTileIndex[i];
 		uint8 s = _visibleBlocks[t]->walls[_sceneDrawVarDown];
 
@@ -602,31 +622,33 @@ void EoBCoreEngine::drawSceneShapes(int start) {
 		if (_shpDmX2 <= _shpDmX1)
 			continue;
 
-		drawDecorations(t);
+		if (drawFlags & 0x01)
+			drawDecorations(t);
 
-		if (_visibleBlocks[t]->drawObjects)
+		if ((drawFlags & 0x02) && _visibleBlocks[t]->drawObjects)
 			drawBlockItems(t);
 
 		if (t < 15) {
 			uint16 w = _wllWallFlags[s];
 
-			if (w & 8)
+			if ((drawFlags & 0x04) && (w & 8))
 				drawDoor(t);
 
-			if (_visibleBlocks[t]->flags & 7) {
+			if ((drawFlags & 0x08) && (_visibleBlocks[t]->flags & 7)) {
 				const ScreenDim *dm = _screen->getScreenDim(5);
 				_screen->modifyScreenDim(5, dm->sx, _lvlShapeTop[t], dm->w, _lvlShapeBottom[t] - _lvlShapeTop[t]);
 				drawMonsters(t);
 				drawLevelModifyScreenDim(5, _lvlShapeLeftRight[(t << 1)], 0, _lvlShapeLeftRight[(t << 1) + 1], 15);
 			}
 
-			if (_flags.gameID == GI_EOB2 && s == 74)
+			if ((drawFlags & 0x10) && _flags.gameID == GI_EOB2 && s == 74)
 				drawWallOfForce(t);
 		}
 
-		drawFlyingObjects(t);
+		if (drawFlags & 0x20)
+			drawFlyingObjects(t);
 
-		if (s == _teleporterWallId)
+		if ((drawFlags & 0x40) && s == _teleporterWallId)
 			drawTeleporter(t);
 	}
 }
@@ -638,7 +660,7 @@ void EoBCoreEngine::drawDecorations(int index) {
 			int16 d = *_dscWallMapping[s];
 			int8 l = _wllShapeMap[_visibleBlocks[index]->walls[d]];
 
-			uint8 *shapeData = 0;
+			const uint8 *shapeData = 0;
 
 			int x = 0;
 
@@ -706,10 +728,15 @@ int EoBCoreEngine::calcNewBlockPositionAndTestPassability(uint16 curBlock, uint1
 
 void EoBCoreEngine::notifyBlockNotPassable() {
 	_txt->printMessage(_warningStrings[0]);
-	snd_playSoundEffect(29);
+	snd_playSoundEffect(_flags.gameID == GI_EOB1 && _flags.platform == Common::kPlatformPC98 ? 45 : 29);
 	removeInputTop();
 }
 
+void EoBCoreEngine::increaseStepsCounter() {
+	if (_totalSteps < 0xFFFFFFFF)
+		_totalSteps++;
+}
+
 void EoBCoreEngine::moveParty(uint16 block) {
 	updateAllMonsterDests();
 	uint16 old = _currentBlock;
