@@ -79,33 +79,36 @@ void KyraEngine_HoF::setupLangButtonShapes() {
 GUI_HoF::GUI_HoF(KyraEngine_HoF *vm) : GUI_v2(vm), _vm(vm), _screen(_vm->_screen) {
 }
 
-const char *GUI_HoF::getMenuTitle(const Menu &menu) {
+Common::String GUI_HoF::getMenuTitle(const Menu &menu) {
 	if (!menu.menuNameId)
-		return 0;
+		return Common::String();
 
-	return _vm->getTableString(menu.menuNameId, _vm->_optionsBuffer, 1);
+	return _vm->getTableString(menu.menuNameId, _vm->_optionsBuffer, true);
 }
 
-const char *GUI_HoF::getMenuItemTitle(const MenuItem &menuItem) {
+Common::String GUI_HoF::getMenuItemTitle(const MenuItem &menuItem) {
+	if (menuItem.useItemString)
+		return menuItem.itemString;
+
 	if (!menuItem.itemId)
-		return 0;
+		return Common::String();
 
 	// Strings 41-45 are menu labels, those must be handled uncompressed!
 	if (menuItem.itemId >= 41 && menuItem.itemId <= 45)
-		return _vm->getTableString(menuItem.itemId, _vm->_optionsBuffer, 0);
+		return _vm->getTableString(menuItem.itemId, _vm->_optionsBuffer, false);
 	else
-		return _vm->getTableString(menuItem.itemId, _vm->_optionsBuffer, 1);
+		return _vm->getTableString(menuItem.itemId, _vm->_optionsBuffer, true);
 }
 
-const char *GUI_HoF::getMenuItemLabel(const MenuItem &menuItem) {
+Common::String GUI_HoF::getMenuItemLabel(const MenuItem &menuItem) {
 	if (!menuItem.labelId)
-		return 0;
+		return Common::String();
 
 	return _vm->getTableString(menuItem.labelId, _vm->_optionsBuffer, 1);
 }
 
-char *GUI_HoF::getTableString(int id) {
-	return _vm->getTableString(id, _vm->_optionsBuffer, 0);
+Common::String GUI_HoF::getTableString(int id, bool decode) {
+	return _vm->getTableString(id, _vm->_optionsBuffer, decode);
 }
 
 #pragma mark -
@@ -293,7 +296,7 @@ void KyraEngine_HoF::scrollInventoryWheel() {
 
 int KyraEngine_HoF::bookButton(Button *button) {
 	if (!queryGameFlag(1)) {
-		objectChat(getTableString(0xEB, _cCodeBuffer, 1), 0, 0x83, 0xEB);
+		objectChat(getTableString(0xEB, _cCodeBuffer, true), 0, 0x83, 0xEB);
 		return 0;
 	}
 
@@ -368,10 +371,10 @@ int KyraEngine_HoF::bookButton(Button *button) {
 	_screen->showMouse();
 
 	if (!queryGameFlag(4) && !queryGameFlag(0xB8)) {
-		objectChat(getTableString(0xEC, _cCodeBuffer, 1), 0, 0x83, 0xEC);
-		objectChat(getTableString(0xED, _cCodeBuffer, 1), 0, 0x83, 0xED);
-		objectChat(getTableString(0xEE, _cCodeBuffer, 1), 0, 0x83, 0xEE);
-		objectChat(getTableString(0xEF, _cCodeBuffer, 1), 0, 0x83, 0xEF);
+		objectChat(getTableString(0xEC, _cCodeBuffer, true), 0, 0x83, 0xEC);
+		objectChat(getTableString(0xED, _cCodeBuffer, true), 0, 0x83, 0xED);
+		objectChat(getTableString(0xEE, _cCodeBuffer, true), 0, 0x83, 0xEE);
+		objectChat(getTableString(0xEF, _cCodeBuffer, true), 0, 0x83, 0xEF);
 		setGameFlag(4);
 	}
 
@@ -521,7 +524,23 @@ void KyraEngine_HoF::bookPrintText(int dstPage, const uint8 *str, int x, int y,
 	Screen::FontId oldFont = _screen->setFont(_flags.lang == Common::JA_JPN ? Screen::FID_SJIS_FNT : Screen::FID_BOOKFONT_FNT);
 	_screen->_charSpacing = -2;
 
-	_screen->printText((const char *)str, x, y, color, (_flags.lang == Common::JA_JPN) ? 0xF6 : 0);
+	Common::String strr((const char *)str);
+	Common::String revBuffer;
+	Common::String lineBuffer;
+	const char *tmp = strr.c_str();
+	if (_flags.lang == Common::HE_ISR) {
+		for (int i = strr.size() - 1; i >= 0; --i) {
+			if (str[i] != '\r') {
+				lineBuffer += str[i];
+			} else {
+				revBuffer = lineBuffer + '\r' + revBuffer;
+				lineBuffer.clear();
+			}
+		}
+		tmp = revBuffer.c_str();
+	}
+
+	_screen->printText(tmp, x, y, color, (_flags.lang == Common::JA_JPN) ? 0xF6 : 0);
 
 	_screen->_charSpacing = 0;
 	_screen->setFont(oldFont);
@@ -548,7 +567,7 @@ int KyraEngine_HoF::bookClose(Button *button) {
 int KyraEngine_HoF::cauldronClearButton(Button *button) {
 	if (!queryGameFlag(2)) {
 		updateCharFacing();
-		objectChat(getTableString(0xF0, _cCodeBuffer, 1), 0, 0x83, 0xF0);
+		objectChat(getTableString(0xF0, _cCodeBuffer, true), 0, 0x83, 0xF0);
 		return 0;
 	}
 
@@ -573,7 +592,7 @@ int KyraEngine_HoF::cauldronClearButton(Button *button) {
 
 int KyraEngine_HoF::cauldronButton(Button *button) {
 	if (!queryGameFlag(2)) {
-		objectChat(getTableString(0xF0, _cCodeBuffer, 1), 0, 0x83, 0xF0);
+		objectChat(getTableString(0xF0, _cCodeBuffer, true), 0, 0x83, 0xF0);
 		return 0;
 	}
 
@@ -981,7 +1000,7 @@ int GUI_HoF::gameOptionsTalkie(Button *caller) {
 int GUI_HoF::changeLanguage(Button *caller) {
 	updateMenuButton(caller);
 	++_vm->_lang;
-	_vm->_lang %= 3;
+	_vm->_lang %= _vm->_numLang;
 	setupOptionsButtons();
 	renewHighlight(_gameOptions);
 	return 0;
