@@ -26,6 +26,7 @@
 #include "kyra/resource/resource.h"
 #include "kyra/engine/timer.h"
 #include "kyra/sound/sound_digital_mr.h"
+#include "kyra/graphics/screen.h"
 
 #include "common/system.h"
 
@@ -112,7 +113,20 @@ void KyraEngine_MR::showMessage(const char *string, uint8 c0, uint8 c1) {
 		int x = _text->getCenterStringX(string, 0, 320);
 		int pageBackUp = _screen->_curPage;
 		_screen->_curPage = 0;
-		_text->printText(string, x, _commandLineY, c0, c1, 0);
+		int y = _commandLineY;
+
+		if (_lang == 3) {
+			_screen->setFontStyles(_screen->_currentFont, Font::kStyleNone);
+			y -= 3;
+			_text->printText(string, x, y, 0, 0, 0);
+			x++;
+		}
+
+		_text->printText(string, x, y, c0, c1, 0);
+
+		if (_lang == 3)
+			_screen->setFontStyles(_screen->_currentFont, Font::kStyleBorder);
+
 		_screen->_curPage = pageBackUp;
 		_screen->updateScreen();
 		setCommandLineRestoreTimer(7);
@@ -127,14 +141,18 @@ void KyraEngine_MR::updateItemCommand(Item item, int str, uint8 c0) {
 	char buffer[100];
 	char *src = (char *)getTableEntry(_itemFile, item);
 
-	while (*src != ' ')
+	if (_lang != 3) {
+		while (*src != ' ')
+			++src;
 		++src;
-	++src;
-
-	*src = toupper(*src);
+		*src = toupper(*src);
+	}
 
 	strcpy(buffer, src);
-	strcat(buffer, " ");
+
+	if (_lang != 3)
+		strcat(buffer, " ");
+
 	strcat(buffer, (const char *)getTableEntry(_cCodeFile, str));
 
 	showMessage(buffer, c0, 0xF0);
@@ -148,8 +166,8 @@ void KyraEngine_MR::updateCommandLine() {
 }
 
 void KyraEngine_MR::restoreCommandLine() {
-	int y = _inventoryState ? 144 : 188;
-	_screen->copyBlockToPage(0, 0, y, 320, 12, _interfaceCommandLine);
+	int y = _inventoryState ? _interfaceCommandLineY2 : _interfaceCommandLineY1;
+	_screen->copyBlockToPage(0, 0, y, 320, _interfaceCommandLineH, _interfaceCommandLine);
 }
 
 void KyraEngine_MR::updateCLState() {
@@ -165,7 +183,7 @@ void KyraEngine_MR::showInventory() {
 	if (queryGameFlag(3))
 		return;
 
-	_screen->copyBlockToPage(3, 0, 0, 320, 56, _interface);
+	_screen->copyBlockToPage(3, 0, 0, 320, _interfaceH, _interface);
 	drawMalcolmsMoodText();
 
 	_inventoryState = true;
@@ -185,14 +203,14 @@ void KyraEngine_MR::showInventory() {
 		_screen->setMouseCursor(0, 0, getShapePtr(0));
 	}
 
-	_screen->copyRegion(0, 188, 0, 0, 320, 12, 0, 2, Screen::CR_NO_P_CHECK);
+	_screen->copyRegion(0, _interfaceCommandLineY1, 0, 0, 320, _interfaceCommandLineH, 0, 2, Screen::CR_NO_P_CHECK);
 
 	if (_inventoryScrollSpeed == -1) {
 		uint32 endTime = _system->getMillis() + _tickLength * 15;
 		int times = 0;
 		while (_system->getMillis() < endTime) {
-			_screen->copyRegion(0, 188, 0, 0, 320, 12, 0, 2, Screen::CR_NO_P_CHECK);
-			_screen->copyRegion(0, 188, 0, 0, 320, 12, 0, 2, Screen::CR_NO_P_CHECK);
+			_screen->copyRegion(0, _interfaceCommandLineY1, 0, 0, 320, _interfaceCommandLineH, 0, 2, Screen::CR_NO_P_CHECK);
+			_screen->copyRegion(0, _interfaceCommandLineY1, 0, 0, 320, _interfaceCommandLineH, 0, 2, Screen::CR_NO_P_CHECK);
 			++times;
 		}
 
@@ -207,16 +225,16 @@ void KyraEngine_MR::showInventory() {
 			_inventoryScrollSpeed = speed;
 	}
 
-	int height = 12;
-	int y = 188;
+	int height = _interfaceCommandLineH;
+	int y = _interfaceCommandLineY1;
 	int times = 0;
 	uint32 waitTill = _system->getMillis() + _tickLength;
 
-	while (y > 144) {
+	while (y > _interfaceCommandLineY2) {
 		_screen->copyRegion(0, 0, 0, y, 320, height, 2, 0, Screen::CR_NO_P_CHECK);
-		_screen->updateScreen();
-
-		++times;
+		if (times++ == 0)
+			_screen->updateScreen();
+	
 		if (_inventoryScrollSpeed == 1 && times == 3) {
 			while (waitTill > _system->getMillis())
 				_system->delayMillis(10);
@@ -228,7 +246,7 @@ void KyraEngine_MR::showInventory() {
 		y -= _inventoryScrollSpeed;
 	}
 
-	_screen->copyRegion(0, 0, 0, 144, 320, 56, 2, 0, Screen::CR_NO_P_CHECK);
+	_screen->copyRegion(0, 0, 0, _interfaceCommandLineY2, 320, _interfaceH, 2, 0, Screen::CR_NO_P_CHECK);
 	_screen->updateScreen();
 
 	initMainButtonList(false);
@@ -245,20 +263,20 @@ void KyraEngine_MR::hideInventory() {
 	updateCLState();
 	initMainButtonList(true);
 
-	_screen->copyBlockToPage(3, 0, 0, 320, 56, _interface);
+	_screen->copyBlockToPage(3, 0, 0, 320, _interfaceH, _interface);
 	_screen->hideMouse();
 
 	restorePage3();
 	flagAnimObjsForRefresh();
 	drawAnimObjects();
-	_screen->copyRegion(0, 144, 0, 0, 320, 56, 0, 2, Screen::CR_NO_P_CHECK);
+	_screen->copyRegion(0, _interfaceCommandLineY2, 0, 0, 320, _interfaceH, 0, 2, Screen::CR_NO_P_CHECK);
 
 	if (_inventoryScrollSpeed == -1) {
 		uint32 endTime = _system->getMillis() + _tickLength * 15;
 		int times = 0;
 		while (_system->getMillis() < endTime) {
-			_screen->copyRegion(0, 144, 0, 0, 320, 12, 0, 2, Screen::CR_NO_P_CHECK);
-			_screen->copyRegion(0, 144, 0, 0, 320, 12, 0, 2, Screen::CR_NO_P_CHECK);
+			_screen->copyRegion(0, _interfaceCommandLineY2, 0, 0, 320, _interfaceCommandLineH, 0, 2, Screen::CR_NO_P_CHECK);
+			_screen->copyRegion(0, _interfaceCommandLineY2, 0, 0, 320, _interfaceCommandLineH, 0, 2, Screen::CR_NO_P_CHECK);
 			++times;
 		}
 
@@ -273,17 +291,17 @@ void KyraEngine_MR::hideInventory() {
 			_inventoryScrollSpeed = speed;
 	}
 
-	int y = 144;
-	int y2 = 144 + _inventoryScrollSpeed;
+	int y = _interfaceCommandLineY2;
+	int y2 = _interfaceCommandLineY2 + _inventoryScrollSpeed;
 	uint32 waitTill = _system->getMillis() + _tickLength;
 	int times = 0;
 
-	while (y2 < 188) {
-		_screen->copyRegion(0, 0, 0, y2, 320, 56, 2, 0, Screen::CR_NO_P_CHECK);
+	while (y2 < _interfaceCommandLineY1) {
+		_screen->copyRegion(0, 0, 0, y2, 320, _interfaceH, 2, 0, Screen::CR_NO_P_CHECK);
 		_screen->copyRegion(0, y, 0, y, 320, _inventoryScrollSpeed, 2, 0, Screen::CR_NO_P_CHECK);
-		_screen->updateScreen();
+		if (times++ == 0)
+			_screen->updateScreen();
 
-		++times;
 		if (_inventoryScrollSpeed == 1 && times == 3) {
 			while (waitTill > _system->getMillis())
 				_system->delayMillis(10);
@@ -295,8 +313,8 @@ void KyraEngine_MR::hideInventory() {
 		y2 += _inventoryScrollSpeed;
 	}
 
-	_screen->copyRegion(0, 0, 0, 188, 320, 56, 2, 0, Screen::CR_NO_P_CHECK);
-	_screen->copyRegion(0, y, 0, y, 320, 188-y, 2, 0, Screen::CR_NO_P_CHECK);
+	_screen->copyRegion(0, 0, 0, _interfaceCommandLineY1, 320, _interfaceH, 2, 0, Screen::CR_NO_P_CHECK);
+	_screen->copyRegion(0, y, 0, y, 320, _interfaceCommandLineY1 - y, 2, 0, Screen::CR_NO_P_CHECK);
 	_screen->showMouse();
 }
 
@@ -308,7 +326,7 @@ void KyraEngine_MR::drawMalcolmsMoodText() {
 
 	const char *string = (const char *)getTableEntry(_cCodeFile, stringId[_malcolmsMood]);
 
-	Screen::FontId oldFont = _screen->setFont(Screen::FID_8_FNT);
+	Screen::FontId oldFont = _screen->setFont(_lang == 3 ? Screen::FID_CHINESE_FNT : Screen::FID_8_FNT);
 	_screen->_charSpacing = -2;
 
 	int width = _screen->getTextWidth(string);
@@ -320,15 +338,23 @@ void KyraEngine_MR::drawMalcolmsMoodText() {
 	const int x = 280 - (width / 2);
 	int y = 0;
 	if (_inventoryState) {
-		y = 189;
+		y = _interfaceCommandLineY1 + 1;
 		_screen->_curPage = 0;
 	} else {
 		y = 45;
 		_screen->_curPage = 2;
 	}
 
-	_screen->drawShape(_screen->_curPage, getShapePtr(432), 244, 189, 0, 0);
-	_text->printText(string, x, y+1, 0xFF, 0xF0, 0x00);
+	_screen->drawShape(_screen->_curPage, getShapePtr(432), 244, _interfaceCommandLineY1 + 1, 0, 0);
+
+	if (_lang == 3) {
+		_screen->setFontStyles(_screen->_currentFont, Font::kStyleNone);
+		_text->printText(string, x, y, 0x00, 0x00, 0x00);
+		_text->printText(string, x + 1, y, 0xFF, 0x00, 0x00);
+		_screen->setFontStyles(_screen->_currentFont, Font::kStyleBorder);
+	} else {
+		_text->printText(string, x, y + (_flags.hasExtraLanguage ? 3 : 1), 0xFF, 0xF0, 0x00);
+	}
 	_screen->_curPage = pageBackUp;
 }
 
@@ -346,7 +372,7 @@ void KyraEngine_MR::drawMalcolmsMoodPointer(int frame, int page) {
 		_invWsa->displayFrame(frame, 0, 0, 0, 0, 0, 0);
 		_screen->updateScreen();
 	} else if (page == 30) {
-		_invWsa->displayFrame(frame, 2, 0, -144, 0, 0, 0);
+		_invWsa->displayFrame(frame, 2, 0, -_interfaceCommandLineY2, 0, 0, 0);
 	}
 
 	_invWsaFrame = frame;
@@ -356,7 +382,7 @@ void KyraEngine_MR::drawJestersStaff(int type, int page) {
 	int y = 155;
 	if (page == 30) {
 		page = 2;
-		y -= 144;
+		y -= _interfaceCommandLineY2;
 	}
 
 	int shape = (type != 0) ? 454 : 453;
@@ -366,18 +392,18 @@ void KyraEngine_MR::drawJestersStaff(int type, int page) {
 void KyraEngine_MR::drawScore(int page, int x, int y) {
 	if (page == 30) {
 		page = 2;
-		y -= 144;
+		y -= _interfaceCommandLineY2;
 	}
 
 	int shape1 = _score / 100;
 	int shape2 = (_score - shape1*100) / 10;
 	int shape3 = _score % 10;
 
-	_screen->drawShape(page, getShapePtr(shape1+433), x, y, 0, 0);
+	_screen->drawShape(page, getShapePtr(shape1 + 433), x, y, 0, 0);
 	x += 8;
-	_screen->drawShape(page, getShapePtr(shape2+433), x, y, 0, 0);
+	_screen->drawShape(page, getShapePtr(shape2 + 433), x, y, 0, 0);
 	x += 8;
-	_screen->drawShape(page, getShapePtr(shape3+433), x, y, 0, 0);
+	_screen->drawShape(page, getShapePtr(shape3 + 433), x, y, 0, 0);
 }
 
 void KyraEngine_MR::drawScoreCounting(int oldScore, int newScore, int drawOld, const int x) {
@@ -431,7 +457,7 @@ void KyraEngine_MR::redrawInventory(int page) {
 
 	if (page == 30) {
 		page = 2;
-		yOffset = -144;
+		yOffset = -_interfaceCommandLineY2;
 	}
 
 	int pageBackUp = _screen->_curPage;
@@ -455,7 +481,7 @@ void KyraEngine_MR::clearInventorySlot(int slot, int page) {
 	int yOffset = 0;
 	if (page == 30) {
 		page = 2;
-		yOffset = -144;
+		yOffset = -_interfaceCommandLineY2;
 	}
 
 	_screen->drawShape(page, getShapePtr(slot+422), _inventoryX[slot], _inventoryY[slot] + yOffset, 0, 0);
@@ -465,10 +491,10 @@ void KyraEngine_MR::drawInventorySlot(int page, Item item, int slot) {
 	int yOffset = 0;
 	if (page == 30) {
 		page = 2;
-		yOffset = -144;
+		yOffset = -_interfaceCommandLineY2;
 	}
 
-	_screen->drawShape(page, getShapePtr(item+248), _inventoryX[slot], _inventoryY[slot] + yOffset, 0, 0);
+	_screen->drawShape(page, getShapePtr(item + 248), _inventoryX[slot], _inventoryY[slot] + yOffset, 0, 0);
 }
 
 int KyraEngine_MR::buttonInventory(Button *button) {
@@ -489,7 +515,7 @@ int KyraEngine_MR::buttonInventory(Button *button) {
 		_itemInHand = slotItem;
 		_mainCharacter.inventory[slot] = kItemNone;
 	} else if (_itemInHand == 27) {
-		if (_chatText)
+		if (!_chatText.empty())
 			return 0;
 		return buttonJesterStaff(&_mainButtonData[3]);
 	} else {
@@ -752,13 +778,13 @@ void KyraEngine_MR::printAlbumPageText() {
 
 	for (int i = 0; i < 5; ++i) {
 		const char *str = (const char *)getTableEntry(_album.file, _album.curPage*5+i);
-		int y = i * 10 + leftY + 20;
+		int y = i * (_screen->getFontHeight() + _screen->_lineSpacing) + leftY + 20;
 		printAlbumText(2, str, 20, y, 10);
 	}
 
 	for (int i = 0; i < 5; ++i) {
 		const char *str = (const char *)getTableEntry(_album.file, (_album.curPage+1)*5+i);
-		int y = i * 10 + rightY + 20;
+		int y = i * (_screen->getFontHeight() + _screen->_lineSpacing) + rightY + 20;
 		printAlbumText(2, str, 176, y, 10);
 	}
 
@@ -774,9 +800,14 @@ void KyraEngine_MR::printAlbumText(int page, const char *str, int x, int y, uint
 
 	Screen::FontId oldFont = _screen->setFont(Screen::FID_BOOKFONT_FNT);
 	_screen->_charSpacing = -2;
+	if (_lang == 3) {
+		_screen->setFont(Screen::FID_CHINESE_FNT);
+		_screen->setFontStyles(_screen->_currentFont, Font::kStyleNone);
+	}
 
 	_screen->printText(str, x, y, c0, 0);
 
+	_screen->setFontStyles(_screen->_currentFont, Font::kStyleBorder);
 	_screen->_charSpacing = 0;
 	_screen->setFont(oldFont);
 	_screen->_curPage = oldPage;
@@ -1062,29 +1093,32 @@ void GUI_MR::flagButtonDisable(Button *button) {
 	}
 }
 
-const char *GUI_MR::getMenuTitle(const Menu &menu) {
+Common::String GUI_MR::getMenuTitle(const Menu &menu) {
 	if (!menu.menuNameId)
-		return 0;
+		return Common::String();
 
 	return (const char *)_vm->getTableEntry(_vm->_optionsFile, menu.menuNameId);
 }
 
-const char *GUI_MR::getMenuItemTitle(const MenuItem &menuItem) {
+Common::String GUI_MR::getMenuItemTitle(const MenuItem &menuItem) {
+	if (menuItem.useItemString)
+		return menuItem.itemString;
+
 	if (!menuItem.itemId)
-		return 0;
+		return Common::String();
 
 	return (const char *)_vm->getTableEntry(_vm->_optionsFile, menuItem.itemId);
 }
 
-const char *GUI_MR::getMenuItemLabel(const MenuItem &menuItem) {
+Common::String GUI_MR::getMenuItemLabel(const MenuItem &menuItem) {
 	if (!menuItem.labelId)
-		return 0;
+		return Common::String();
 
 	return (const char *)_vm->getTableEntry(_vm->_optionsFile, menuItem.labelId);
 }
 
-char *GUI_MR::getTableString(int id) {
-	return (char *)_vm->getTableEntry(_vm->_optionsFile, id);
+Common::String GUI_MR::getTableString(int id, bool) {
+	return Common::String((char *)_vm->getTableEntry(_vm->_optionsFile, id));
 }
 
 int GUI_MR::redrawButtonCallback(Button *button) {
@@ -1152,6 +1186,8 @@ int GUI_MR::optionsButton(Button *button) {
 	if (!_screen->isMouseVisible() && button && !_vm->_menuDirectlyToLoad)
 		return 0;
 
+	_screen->setFontStyles(_screen->_currentFont, Font::kStyleNone);
+
 	_vm->showMessage(0, 0xF0, 0xF0);
 
 	if (_vm->_mouseState < -1) {
@@ -1175,15 +1211,7 @@ int GUI_MR::optionsButton(Button *button) {
 		_menuButtons[i].data1Callback = _menuButtons[i].data2Callback = _redrawButtonFunctor;
 	}
 
-	initMenuLayout(_mainMenu);
-	initMenuLayout(_gameOptions);
-	initMenuLayout(_audioOptions);
-	initMenuLayout(_choiceMenu);
-	_loadMenu.numberOfItems = 6;
-	initMenuLayout(_loadMenu);
-	initMenuLayout(_saveMenu);
-	initMenuLayout(_savenameMenu);
-	initMenuLayout(_deathMenu);
+	fontBasedMenuResize();
 
 	_currentMenu = &_mainMenu;
 
@@ -1341,6 +1369,15 @@ int GUI_MR::gameOptions(Button *caller) {
 		_vm->saveGameStateIntern(999, "Autosave", &thumb);
 		thumb.free();
 
+		if (_vm->_lang == 3) {
+			_screen->setFont(Screen::FID_CHINESE_FNT);
+			_screen->setFontStyles(Screen::FID_CHINESE_FNT, Font::kStyleNone);
+			_screen->_lineSpacing = 2;
+		} else {
+			_screen->setFont(Screen::FID_8_FNT);
+			_screen->_lineSpacing = 0;
+		}
+
 		if (!_vm->loadLanguageFile("ITEMS.", _vm->_itemFile))
 			error("Couldn't load ITEMS");
 		if (!_vm->loadLanguageFile("SCORE.", _vm->_scoreFile))
@@ -1353,6 +1390,9 @@ int GUI_MR::gameOptions(Button *caller) {
 			error("Couldn't load OPTIONS");
 		if (!_vm->loadLanguageFile("_ACTOR.", _vm->_actorFile))
 			error("couldn't load _ACTOR");
+
+		if (_vm->_lang == 3 || lang == 3)
+			fontBasedMenuResize();
 	}
 
 	_vm->writeSettings();
@@ -1386,6 +1426,10 @@ void GUI_MR::setupOptionsButtons() {
 		_gameOptions.item[1].itemId = 33;
 		break;
 
+	case 3:
+		_gameOptions.item[1].itemId = 48;
+		break;
+
 	default:
 		break;
 	}
@@ -1401,11 +1445,54 @@ void GUI_MR::setupOptionsButtons() {
 		_gameOptions.item[3].itemId = 17;
 }
 
+void GUI_MR::resizeMenu(Menu &menu, int menuHeight, int menuTitleY, int menuItemYstart, int menuItemYinc, int menuItemHeight, int menuItemYend, int labelYstart, int labelYend) {
+	menu.x = menu.y = -1;
+	menu.height = menuHeight;
+	menu.titleY = menuTitleY;
+	for (int i = 0; i < menu.numberOfItems - 1; ++i) {
+		menu.item[i].y = menuItemYstart + i * menuItemYinc;
+		menu.item[i].height = menuItemHeight;
+		menu.item[i].labelY = labelYstart ? (labelYstart + i * menuItemYinc) : 0;
+	}
+	menu.item[menu.numberOfItems - 1].y = menuItemYend;
+	menu.item[menu.numberOfItems - 1].height = menuItemHeight;
+	menu.item[menu.numberOfItems - 1].labelY = labelYend;
+	initMenuLayout(menu);
+}
+
+void GUI_MR::fontBasedMenuResize() {
+	if (_vm->_lang == 3) {
+		resizeMenu(_mainMenu, 192, 6, 26, 22, 20, 161, 0, 0);
+		resizeMenu(_gameOptions, 174, 8, 30, 22, 20, 145, 32, 0);
+		resizeMenu(_audioOptions, 140, 8, 28, 22, 20, 110, 30, 0);
+		_audioOptions.item[3].y = 81;
+		_audioOptions.item[3].labelY = 83;
+		resizeMenu(_choiceMenu, 56, 8, 30, 0, 20, 30, 0, 0);
+		_loadMenu.numberOfItems = 6;
+		resizeMenu(_loadMenu, 182, 6, 39, 22, 20, 155, 0, 0);
+		resizeMenu(_saveMenu, 182, 6, 39, 22, 20, 155, 0, 0);
+		_loadMenu.scrollDownButtonY = _saveMenu.scrollDownButtonY = 149;
+		resizeMenu(_savenameMenu, 72, 8, 44, 0, 20, 44, 0, 0);
+		resizeMenu(_deathMenu, 80, 8, 30, 0, 20, 52, 0, 0);
+	} else {
+		resizeMenu(_mainMenu, 172, 8, 30, 17, 15, 144, 0, 0);
+		resizeMenu(_gameOptions, 154, 8, 30, 17, 15, 127, 32, 0);
+		resizeMenu(_audioOptions, 136, 8, 30, 17, 15, 110, 32, 0);
+		resizeMenu(_choiceMenu, 56, 8, 30, 0, 15, 30, 0, 0);
+		_loadMenu.numberOfItems = 6;
+		resizeMenu(_loadMenu, 160, 8, 39, 17, 15, 134, 0, 0);
+		resizeMenu(_saveMenu, 160, 8, 39, 17, 15, 134, 0, 0);
+		_loadMenu.scrollDownButtonY = _saveMenu.scrollDownButtonY = 124;
+		resizeMenu(_savenameMenu, 67, 8, 44, 0, 15, 44, 0, 0);
+		resizeMenu(_deathMenu, 76, 8, 30, 0, 15, 47, 0, 0);
+	}
+}
+
 int GUI_MR::changeLanguage(Button *caller) {
 	updateMenuButton(caller);
 	if (!_vm->queryGameFlag(0x1B2)) {
 		++_vm->_lang;
-		_vm->_lang %= 3;
+		_vm->_lang %= _vm->_numLang;
 		setupOptionsButtons();
 		renewHighlight(_gameOptions);
 	}
