@@ -430,7 +430,8 @@ void GUI_v2::restorePage1(const uint8 *buffer) {
 
 void GUI_v2::setupSavegameNames(Menu &menu, int num) {
 	for (int i = 0; i < num; ++i) {
-		strcpy(getTableString(menu.item[i].itemId), "");
+		menu.item[i].useItemString = true;
+		menu.item[i].itemString = "";
 		menu.item[i].saveSlot = -1;
 		menu.item[i].enabled = false;
 	}
@@ -443,36 +444,43 @@ void GUI_v2::setupSavegameNames(Menu &menu, int num) {
 	Common::InSaveFile *in;
 	for (int i = startSlot; i < num && uint(_savegameOffset + i) < _saveSlots.size(); ++i) {
 		if ((in = _vm->openSaveForReading(_vm->getSavegameFilename(_saveSlots[i + _savegameOffset]), header)) != 0) {
-			char *s = getTableString(menu.item[i].itemId);
-			Common::strlcpy(s, header.description.c_str(), 80);
-			Util::convertISOToDOS(s);
+			Common::String s = header.description;
+			s = Util::convertUTF8ToDOS(s);
+
+			if (_vm->gameFlags().lang == Common::JA_JPN || _vm->gameFlags().lang == Common::ZH_CNA || _vm->gameFlags().lang == Common::ZH_TWN) {
+				// Strip special characters from GMM save dialog which might get misinterpreted as 2-byte characters
+				for (Common::String::iterator ii = s.begin(); ii != s.end(); ++ii) {
+					if (*ii < 32) // due to the signed char type this will also clean up everything >= 0x80
+						*ii = ' ';
+				}
+			}
 
 			// Trim long GMM save descriptions to fit our save slots
 			_screen->_charSpacing = -2;
-			int fC = _screen->getTextWidth(s);
-			while (s[0] && fC > 240) {
-				s[strlen(s) - 1]  = 0;
-				fC = _screen->getTextWidth(s);
+			int fC = _screen->getTextWidth(s.c_str());
+			while (!s.empty() && fC > 240) {
+				s.deleteLastChar();
+				fC = _screen->getTextWidth(s.c_str());
 			}
 			_screen->_charSpacing = 0;
 
 			menu.item[i].saveSlot = _saveSlots[i + _savegameOffset];
 			menu.item[i].enabled = true;
+			menu.item[i].useItemString = true;
+			menu.item[i].itemString = s;
 			delete in;
 		}
 	}
 
 	if (_savegameOffset == 0) {
 		if (_isSaveMenu) {
-			char *dst = getTableString(menu.item[0].itemId);
-			const char *src = getTableString(_vm->gameFlags().isTalkie ? 10 : 18);
-			strcpy(dst, src);
 			menu.item[0].saveSlot = -2;
 			menu.item[0].enabled = true;
+			menu.item[0].useItemString = true;
+			menu.item[0].itemString = getTableString(_vm->gameFlags().isTalkie ? 10 : 18);
 		} else {
-			char *dst = getTableString(menu.item[0].itemId);
-			const char *src = getTableString(_vm->gameFlags().isTalkie ? 34 : 42);
-			strcpy(dst, src);
+			menu.item[0].useItemString = true;
+			menu.item[0].itemString = getTableString(_vm->gameFlags().isTalkie ? 34 : 42, _vm->gameFlags().lang == Common::RU_RUS);
 		}
 	}
 }
@@ -520,6 +528,7 @@ int GUI_v2::scrollDownButton(Button *button) {
 int GUI_v2::resumeGame(Button *caller) {
 	updateMenuButton(caller);
 	_displayMenu = false;
+	_screen->setFontStyles(_screen->_currentFont, Font::kStyleBorder);
 	return 0;
 }
 
@@ -620,11 +629,12 @@ int GUI_v2::saveMenu(Button *caller) {
 
 	Graphics::Surface thumb;
 	createScreenThumbnail(thumb);
-	Util::convertDOSToISO(_saveDescription);
+	Util::convertDOSToUTF8(_saveDescription, 81);
 	_vm->saveGameStateIntern(_saveSlot, _saveDescription, &thumb);
 	thumb.free();
 
 	_displayMenu = false;
+	_screen->setFontStyles(_screen->_currentFont, Font::kStyleBorder);
 	_madeSave = true;
 
 	return 0;
@@ -644,7 +654,7 @@ int GUI_v2::clickSaveSlot(Button *caller) {
 			return 0;
 		} else {
 			_saveSlot = item.saveSlot;
-			strcpy(_saveDescription, getTableString(item.itemId));
+			Common::strlcpy(_saveDescription, item.itemString.c_str(), sizeof(_saveDescription));
 		}
 	} else if (item.saveSlot == -2) {
 		_saveSlot = getNextSavegameSlot();
