@@ -74,7 +74,14 @@ public:
 	uint32 getFileSize(const char *file);
 	uint8 *fileData(const char *file, uint32 *size);
 	Common::SeekableReadStream *createReadStream(const Common::String &file);
-	Common::SeekableReadStreamEndian *createEndianAwareReadStream(const Common::String &file);
+
+	enum Endianness {
+		kPlatformEndianness = 0,
+		kForceLE,
+		kForceBE
+	};
+
+	Common::SeekableReadStreamEndian *createEndianAwareReadStream(const Common::String &file, int endianness = kPlatformEndianness);
 
 	bool loadFileToBuf(const char *file, void *buf, uint32 maxSize);
 protected:
@@ -95,6 +102,7 @@ protected:
 	typedef Common::List<Common::SharedPtr<ResArchiveLoader> > LoaderList;
 	LoaderList _loaders;
 
+	const bool _bigEndianPlatForm;
 	KyraEngine_v1 *_vm;
 };
 
@@ -250,6 +258,10 @@ enum KyraResources {
 	k3ItemAnimData,
 	k3ItemMagicTable,
 	k3ItemStringMap,
+	k3FontData,
+
+	k3VqaSubtitlesIntro,
+	k3VqaSubtitlesBoat,
 
 #if defined(ENABLE_EOB) || defined(ENABLE_LOL)
 	kRpgCommonMoreStrings,
@@ -396,7 +408,30 @@ enum KyraResources {
 	kEoBBaseMonsterDistAttStrings,
 
 	kEoBBaseEncodeMonsterDefs,
+	kEoBBaseEncodeMonsterDefs00,
+	kEoBBaseEncodeMonsterDefs01,
+	kEoBBaseEncodeMonsterDefs02,
+	kEoBBaseEncodeMonsterDefs03,
+	kEoBBaseEncodeMonsterDefs04,
+	kEoBBaseEncodeMonsterDefs05,
+	kEoBBaseEncodeMonsterDefs06,
+	kEoBBaseEncodeMonsterDefs07,
+	kEoBBaseEncodeMonsterDefs08,
+	kEoBBaseEncodeMonsterDefs09,
+	kEoBBaseEncodeMonsterDefs10,
+	kEoBBaseEncodeMonsterDefs11,
+	kEoBBaseEncodeMonsterDefs12,
+	kEoBBaseEncodeMonsterDefs13,
+	kEoBBaseEncodeMonsterDefs14,
+	kEoBBaseEncodeMonsterDefs15,
+	kEoBBaseEncodeMonsterDefs16,
+	kEoBBaseEncodeMonsterDefs17,
+	kEoBBaseEncodeMonsterDefs18,
+	kEoBBaseEncodeMonsterDefs19,
+	kEoBBaseEncodeMonsterDefs20,
+	kEoBBaseEncodeMonsterDefs21,
 	kEoBBaseNpcPresets,
+	kEoBBaseNpcPresetsNames,
 
 	kEoBBaseWllFlagPreset,
 	kEoBBaseDscShapeCoords,
@@ -448,6 +483,8 @@ enum KyraResources {
 	kEoBBaseBookNumbers,
 	kEoBBaseMageSpellsList,
 	kEoBBaseClericSpellsList,
+	kEoBBaseMageSpellsList2,
+	kEoBBaseClericSpellsList2,
 	kEoBBaseSpellNames,
 	kEoBBaseMagicStrings1,
 	kEoBBaseMagicStrings2,
@@ -495,6 +532,13 @@ enum KyraResources {
 	kEoBBaseLevelSounds1,
 	kEoBBaseLevelSounds2,
 
+	kEoBBaseTextInputCharacterLines,
+	kEoBBaseTextInputSelectStrings,
+
+	kEoBBaseSaveNamePatterns,
+
+	kEoB1DefaultPartyStats,
+	kEoB1DefaultPartyNames,
 	kEoB1MainMenuStrings,
 	kEoB1BonusStrings,
 
@@ -506,6 +550,17 @@ enum KyraResources {
 	kEoB1IntroFilesHands,
 	kEoB1IntroFilesWdExit,
 	kEoB1IntroFilesTunnel,
+
+	kEoB1IntroStringsTower,
+	kEoB1IntroStringsOrb,
+	kEoB1IntroStringsWdEntry,
+	kEoB1IntroStringsKing,
+	kEoB1IntroStringsHands,
+	kEoB1IntroStringsWdExit,
+	kEoB1IntroStringsTunnel,
+
+	kEoB1FinaleStrings,
+
 	kEoB1IntroOpeningFrmDelay,
 	kEoB1IntroWdEncodeX,
 	kEoB1IntroWdEncodeY,
@@ -526,7 +581,14 @@ enum KyraResources {
 	kEoB1FinaleCouncilAnim4,
 	kEoB1FinaleEyesAnim,
 	kEoB1FinaleHandsAnim,
+	kEoB1FinaleHandsAnim2,
+	kEoB1FinaleHandsAnim3,
 	kEoB1FinaleTextDuration,
+	kEoB1CreditsStrings,
+	kEoB1CreditsCharWdth,
+
+	kEoB1CreditsStrings2,
+	kEoB1CreditsTileGrid,
 
 	kEoB1DoorShapeDefs,
 	kEoB1DoorSwitchShapeDefs,
@@ -554,6 +616,131 @@ enum KyraResources {
 	kEoB1CgaMappingLevel3,
 	kEoB1CgaMappingLevel4,
 
+	kEoB1Palettes16c,
+	kEoB1PalCycleData,
+	kEoB1PalCycleStyle1,
+	kEoB1PalCycleStyle2,
+	kEoB1PalettesSega,
+	kEoB1PatternTable0,
+	kEoB1PatternTable1,
+	kEoB1PatternTable2,
+	kEoB1PatternTable3,
+	kEoB1PatternTable4,
+	kEoB1PatternTable5,
+	kEoB1PatternAddTable1,
+	kEoB1PatternAddTable2,
+
+	kEoB1MonsterAnimFrames00,
+	kEoB1MonsterAnimFrames01,
+	kEoB1MonsterAnimFrames02,
+	kEoB1MonsterAnimFrames03,
+	kEoB1MonsterAnimFrames04,
+	kEoB1MonsterAnimFrames05,
+	kEoB1MonsterAnimFrames06,
+	kEoB1MonsterAnimFrames07,
+	kEoB1MonsterAnimFrames08,
+	kEoB1MonsterAnimFrames09,
+	kEoB1MonsterAnimFrames10,
+	kEoB1MonsterAnimFrames11,
+	kEoB1MonsterAnimFrames12,
+	kEoB1MonsterAnimFrames13,
+	kEoB1MonsterAnimFrames14,
+	kEoB1MonsterAnimFrames15,
+	kEoB1MonsterAnimFrames16,
+	kEoB1MonsterAnimFrames17,
+	kEoB1MonsterAnimFrames18,
+	kEoB1MonsterAnimFrames19,
+	kEoB1MonsterAnimFrames20,
+	kEoB1MonsterAnimFrames21,
+	kEoB1MonsterAnimFrames22,
+	kEoB1MonsterAnimFrames23,
+	kEoB1MonsterAnimFrames24,
+	kEoB1MonsterAnimFrames25,
+	kEoB1MonsterAnimFrames26,
+	kEoB1MonsterAnimFrames27,
+	kEoB1MonsterAnimFrames28,
+	kEoB1MonsterAnimFrames29,
+	kEoB1MonsterAnimFrames30,
+	kEoB1MonsterAnimFrames31,
+	kEoB1MonsterAnimFrames32,
+	kEoB1MonsterAnimFrames33,
+	kEoB1MonsterAnimFrames34,
+	kEoB1MonsterAnimFrames35,
+	kEoB1MonsterAnimFrames36,
+	kEoB1MonsterAnimFrames37,
+	kEoB1MonsterAnimFrames38,
+	kEoB1MonsterAnimFrames39,
+	kEoB1MonsterAnimFrames40,
+	kEoB1MonsterAnimFrames41,
+	kEoB1MonsterAnimFrames42,
+	kEoB1MonsterAnimFrames43,
+	kEoB1MonsterAnimFrames44,
+	kEoB1MonsterAnimFrames45,
+	kEoB1MonsterAnimFrames46,
+	kEoB1MonsterAnimFrames47,
+	kEoB1MonsterAnimFrames48,
+	kEoB1MonsterAnimFrames49,
+	kEoB1MonsterAnimFrames50,
+	kEoB1MonsterAnimFrames51,
+	kEoB1MonsterAnimFrames52,
+	kEoB1MonsterAnimFrames53,
+	kEoB1MonsterAnimFrames54,
+	kEoB1MonsterAnimFrames55,
+	kEoB1MonsterAnimFrames56,
+	kEoB1MonsterAnimFrames57,
+	kEoB1MonsterAnimFrames58,
+	kEoB1MonsterAnimFrames59,
+	kEoB1MonsterAnimFrames60,
+	kEoB1MonsterAnimFrames61,
+	kEoB1MonsterAnimFrames62,
+	kEoB1MonsterAnimFrames63,
+	kEoB1MonsterAnimFrames64,
+	kEoB1MonsterAnimFrames65,
+	kEoB1MonsterAnimFrames66,
+	kEoB1MonsterAnimFrames67,
+	kEoB1MonsterAnimFrames68,
+	kEoB1MonsterAnimFrames69,
+	kEoB1MonsterAnimFrames70,
+	kEoB1MonsterAnimFrames71,
+	kEoB1MonsterAnimFrames72,
+	kEoB1MonsterAnimFrames73,
+	kEoB1MonsterAnimFrames74,
+	kEoB1MonsterAnimFrames75,
+	kEoB1MonsterAnimFrames76,
+	kEoB1MonsterAnimFrames77,
+	kEoB1MonsterAnimFrames78,
+	kEoB1MonsterAnimFrames79,
+	kEoB1MonsterAnimFrames80,
+	kEoB1MonsterAnimFrames81,
+	kEoB1MonsterAnimFrames82,
+	kEoB1MonsterAnimFrames83,
+	kEoB1MonsterAnimFrames84,
+	kEoB1MonsterAnimFrames85,
+	kEoB1MonsterAnimFrames86,
+	kEoB1MonsterAnimFrames87,
+	kEoB1MonsterAnimFrames88,
+	kEoB1MonsterAnimFrames89,
+	kEoB1MonsterAnimFrames90,
+	kEoB1MonsterAnimFrames91,
+	kEoB1MonsterAnimFrames92,
+	kEoB1MonsterAnimFrames93,
+	kEoB1MonsterAnimFrames94,
+	kEoB1MonsterAnimFrames95,
+	kEoB1MonsterAnimFrames96,
+	kEoB1MonsterAnimFrames97,
+	kEoB1MonsterAnimFrames98,
+	kEoB1MonsterAnimFrames99,
+	kEoB1MonsterAnimFrames100,
+	kEoB1MonsterAnimFrames101,
+	kEoB1MonsterAnimFrames102,
+	kEoB1MonsterAnimFrames103,
+	kEoB1MonsterAnimFrames104,
+	kEoB1MonsterAnimFrames105,
+	kEoB1MonsterAnimFrames106,
+	kEoB1MonsterAnimFrames107,
+	kEoB1MonsterAnimFrames108,
+	kEoB1MonsterAnimFrames109,
+
 	kEoB1NpcShpData,
 	kEoB1NpcSubShpIndex1,
 	kEoB1NpcSubShpIndex2,
@@ -570,6 +757,25 @@ enum KyraResources {
 	kEoB1Npc6Strings,
 	kEoB1Npc7Strings,
 
+	kEoB1ParchmentStrings,
+	kEoB1ItemNames,
+	kEoB1SpeechAnimData,
+	kEoB1WdAnimSprites,
+	kEoB1SequenceTrackMap,
+
+	kEoB1MapStrings1,
+	kEoB1MapStrings2,
+	kEoB1MapStrings3,
+	kEoB1MapLevelData,
+
+	kEoB1Ascii2SjisTable1,
+	kEoB1Ascii2SjisTable2,
+	kEoB1FontLookupTable,
+	kEoB1CharWidthTable1,
+	kEoB1CharWidthTable2,
+	kEoB1CharWidthTable3,
+	kEoB1CharTilesTable,
+
 	kEoB2MainMenuStrings,
 	kEoB2MainMenuUtilStrings,
 
@@ -923,12 +1129,9 @@ enum KyraResources {
 
 	kEoB2UtilMenuStrings,
 	kEoB2Config2431Strings,
-	kEoB2KatakanaLines,
-	kEoB2KanaSelectStrings,
 	kEoB2FontDmpSearchTbl,
 	kEoB2Ascii2SjisTables,
 	kEoB2Ascii2SjisTables2,
-	kEoB2SaveNamePatterns,
 	kEoB2PcmSoundEffectsIngame,
 	kEoB2PcmSoundEffectsIntro,
 	kEoB2PcmSoundEffectsFinale,
