@@ -37,7 +37,8 @@ PlainArchive::PlainArchive(Common::ArchiveMemberPtr file)
 	: _file(file), _files() {
 }
 
-bool PlainArchive::hasFile(const Common::String &name) const {
+bool PlainArchive::hasFile(const Common::Path &path) const {
+	Common::String name = path.toString();
 	return (_files.find(name) != _files.end());
 }
 
@@ -52,14 +53,16 @@ int PlainArchive::listMembers(Common::ArchiveMemberList &list) const {
 	return count;
 }
 
-const Common::ArchiveMemberPtr PlainArchive::getMember(const Common::String &name) const {
+const Common::ArchiveMemberPtr PlainArchive::getMember(const Common::Path &path) const {
+	Common::String name = path.toString();
 	if (!hasFile(name))
 		return Common::ArchiveMemberPtr();
 
 	return Common::ArchiveMemberPtr(new Common::GenericArchiveMember(name, this));
 }
 
-Common::SeekableReadStream *PlainArchive::createReadStreamForMember(const Common::String &name) const {
+Common::SeekableReadStream *PlainArchive::createReadStreamForMember(const Common::Path &path) const {
+	Common::String name = path.toString();
 	FileMap::const_iterator fDesc = _files.find(name);
 	if (fDesc == _files.end())
 		return 0;
@@ -92,7 +95,8 @@ TlkArchive::~TlkArchive() {
 	delete[] _fileEntries;
 }
 
-bool TlkArchive::hasFile(const Common::String &name) const {
+bool TlkArchive::hasFile(const Common::Path &path) const {
+	Common::String name = path.toString();
 	return (findFile(name) != 0);
 }
 
@@ -107,14 +111,16 @@ int TlkArchive::listMembers(Common::ArchiveMemberList &list) const {
 	return count;
 }
 
-const Common::ArchiveMemberPtr TlkArchive::getMember(const Common::String &name) const {
+const Common::ArchiveMemberPtr TlkArchive::getMember(const Common::Path &path) const {
+	Common::String name = path.toString();
 	if (!hasFile(name))
 		return Common::ArchiveMemberPtr();
 
 	return Common::ArchiveMemberPtr(new Common::GenericArchiveMember(name, this));
 }
 
-Common::SeekableReadStream *TlkArchive::createReadStreamForMember(const Common::String &name) const {
+Common::SeekableReadStream *TlkArchive::createReadStreamForMember(const Common::Path &path) const {
+	Common::String name = path.toString();
 	const uint32 *fileDesc = findFile(name);
 	if (!fileDesc)
 		return 0;
@@ -186,7 +192,8 @@ CachedArchive::~CachedArchive() {
 	_files.clear();
 }
 
-bool CachedArchive::hasFile(const Common::String &name) const {
+bool CachedArchive::hasFile(const Common::Path &path) const {
+	Common::String name = path.toString();
 	return (_files.find(name) != _files.end());
 }
 
@@ -201,14 +208,16 @@ int CachedArchive::listMembers(Common::ArchiveMemberList &list) const {
 	return count;
 }
 
-const Common::ArchiveMemberPtr CachedArchive::getMember(const Common::String &name) const {
+const Common::ArchiveMemberPtr CachedArchive::getMember(const Common::Path &path) const {
+	Common::String name = path.toString();
 	if (!hasFile(name))
 		return Common::ArchiveMemberPtr();
 
 	return Common::ArchiveMemberPtr(new Common::GenericArchiveMember(name, this));
 }
 
-Common::SeekableReadStream *CachedArchive::createReadStreamForMember(const Common::String &name) const {
+Common::SeekableReadStream *CachedArchive::createReadStreamForMember(const Common::Path &path) const {
+	Common::String name = path.toString();
 	FileMap::const_iterator fDesc = _files.find(name);
 	if (fDesc == _files.end())
 		return 0;
@@ -241,7 +250,7 @@ Common::String readString(Common::SeekableReadStream &stream) {
 
 bool ResLoaderPak::isLoadable(const Common::String &filename, Common::SeekableReadStream &stream) const {
 	int32 filesize = stream.size();
-	if (filesize < 0)
+	if (filesize < 4)
 		return false;
 
 	int32 offset = 0;
@@ -287,7 +296,7 @@ bool ResLoaderPak::isLoadable(const Common::String &filename, Common::SeekableRe
 
 Common::Archive *ResLoaderPak::load(Common::ArchiveMemberPtr memberFile, Common::SeekableReadStream &stream) const {
 	int32 filesize = stream.size();
-	if (filesize < 0)
+	if (filesize < 4)
 		return 0;
 
 	Common::ScopedPtr<PlainArchive> result(new PlainArchive(memberFile));
@@ -309,21 +318,21 @@ Common::Archive *ResLoaderPak::load(Common::ArchiveMemberPtr memberFile, Common:
 	while (!stream.eos()) {
 		// The start offset of a file should never be in the filelist
 		if (startoffset < stream.pos() || startoffset > filesize || startoffset < 0) {
-			warning("PAK file '%s' is corrupted", memberFile->getDisplayName().c_str());
+			warning("PAK file '%s' is corrupted", memberFile->getName().c_str());
 			return 0;
 		}
 
 		file = readString(stream);
 
 		if (stream.eos()) {
-			warning("PAK file '%s' is corrupted", memberFile->getDisplayName().c_str());
+			warning("PAK file '%s' is corrupted", memberFile->getName().c_str());
 			return 0;
 		}
 
 		// Quit now if we encounter an empty string
 		if (file.empty()) {
 			if (firstFile) {
-				warning("PAK file '%s' is corrupted", memberFile->getDisplayName().c_str());
+				warning("PAK file '%s' is corrupted", memberFile->getName().c_str());
 				return 0;
 			} else {
 				break;
@@ -334,7 +343,7 @@ Common::Archive *ResLoaderPak::load(Common::ArchiveMemberPtr memberFile, Common:
 		endoffset = switchEndian ? stream.readUint32BE() : stream.readUint32LE();
 
 		if (endoffset < 0 && stream.pos() != firstOffset) {
-			warning("PAK file '%s' is corrupted", memberFile->getDisplayName().c_str());
+			warning("PAK file '%s' is corrupted", memberFile->getName().c_str());
 			return 0;
 		}
 
@@ -394,11 +403,11 @@ bool ResLoaderInsMalcolm::isLoadable(const Common::String &filename, Common::See
 	if (size + 7 > stream.size())
 		return false;
 
-	stream.seek(size + 5, SEEK_SET);
-	uint8 buffer[2];
-	stream.read(&buffer, 2);
+	stream.seek(size + 4, SEEK_SET);
+	uint8 buffer[3];
+	stream.read(&buffer, 3);
 
-	return (buffer[0] == 0x0D && buffer[1] == 0x0A);
+	return (buffer[0] == 0x0D && buffer[1] == 0x0A) || (buffer[1] == 0x0D && buffer[2] == 0x0A);
 }
 
 Common::Archive *ResLoaderInsMalcolm::load(Common::ArchiveMemberPtr memberFile, Common::SeekableReadStream &stream) const {
@@ -426,6 +435,7 @@ Common::Archive *ResLoaderInsMalcolm::load(Common::ArchiveMemberPtr memberFile,
 			++i;
 
 			filenames.push_back(temp);
+			temp.clear();
 		} else {
 			temp += (char)c;
 		}
@@ -450,6 +460,8 @@ bool ResLoaderTlk::checkFilename(Common::String filename) const {
 }
 
 bool ResLoaderTlk::isLoadable(const Common::String &filename, Common::SeekableReadStream &stream) const {
+	if (stream.size() < 2)
+		return false;
 	uint16 entries = stream.readUint16LE();
 	int32 entryTableSize = (entries * 8);
 
