@@ -599,9 +599,14 @@ bool SeqPlayer::playSequence(const uint8 *seqData, bool skipSeq) {
 		_seqLoopTable[i].count = 0xFFFF;
 	}
 
-	memset(_seqMovies, 0, sizeof(_seqMovies));
+	for (uint i = 0; i < ARRAYSIZE(_seqMovies); i++) {
+		_seqMovies[i].clear();
+	}
 
 	_screen->_curPage = 0;
+	char revBuffer[384];
+	memset(revBuffer, 0, sizeof(revBuffer));
+	int charIdx = 0;
 	while (!_seqQuitFlag && !_vm->shouldQuit()) {
 		if (skipSeq && _vm->seq_skipSequence()) {
 			while (1) {
@@ -619,17 +624,36 @@ bool SeqPlayer::playSequence(const uint8 *seqData, bool skipSeq) {
 			if (_seqDisplayedTextTimer < _system->getMillis()) {
 				char charStr[3];
 				charStr[0] = _vm->seqTextsTable()[_seqDisplayedText][_seqDisplayedChar];
+				if (_vm->gameFlags().lang == Common::HE_ISR) {
+					for (int k = charIdx; k > 0; k--) {
+						revBuffer[k] = revBuffer[k - 1];
+					}
+					revBuffer[0] = charStr[0];
+					if (!charIdx) {
+						int w = _screen->getTextWidth(_vm->seqTextsTable()[_seqDisplayedText] + _seqDisplayedChar);
+						_seqDisplayedTextX += w;
+					}
+					charIdx++;
+				}
 				charStr[1] = charStr[2] = '\0';
 				if (_vm->gameFlags().lang == Common::JA_JPN)
 					charStr[1] = _vm->seqTextsTable()[_seqDisplayedText][++_seqDisplayedChar];
-				_screen->printText(charStr, _seqDisplayedTextX, 180, 0xF, 0xC);
-				_seqDisplayedTextX += _screen->getCharWidth((uint8)charStr[0]);
+				if (_vm->gameFlags().lang == Common::HE_ISR) {
+					_seqDisplayedTextX -= _screen->getCharWidth((uint8)charStr[0]);
+					_screen->printText(revBuffer, _seqDisplayedTextX, 180, 0xF, 0xC);
+				} else {
+					_screen->printText(charStr, _seqDisplayedTextX, 180, 0xF, 0xC);
+					_seqDisplayedTextX += _screen->getCharWidth((uint8)charStr[0]);
+				}
 				++_seqDisplayedChar;
 
-				if (_vm->seqTextsTable()[_seqDisplayedText][_seqDisplayedChar] == '\0')
+				if (_vm->seqTextsTable()[_seqDisplayedText][_seqDisplayedChar] == '\0') {
 					_seqDisplayedTextTimer = 0xFFFFFFFF;
-				else
+					memset(revBuffer, 0, sizeof(revBuffer));
+					charIdx = 0;
+				} else {
 					_seqDisplayedTextTimer = _system->getMillis() + 1000 / ((_vm->gameFlags().lang == Common::FR_FRA) ? 120 : 60);
+				}
 			}
 		}
 
