@@ -71,7 +71,7 @@ private:
 	OSystem *_system;
 	DarkMoonEngine *_vm;
 	Screen_EoB *_screen;
-	
+
 	struct Config {
 		Config(const char *const *str, const char *const *cpsfiles, const uint8 **cpsdata, const char *const *pal, const DarkMoonShapeDef **shp, const DarkMoonAnimCommand **anim, bool loadScenePalette, bool paletteFading, bool animCmdRestorePalette, bool shapeBackgroundFading, int animPalOffset, int animType1ShapeDim, bool animCmd5SetPalette, int animCmd5ExtraPage) : strings(str), cpsFiles(cpsfiles), cpsData(cpsdata), palFiles(pal), shapeDefs(shp), animData(anim), loadScenePal(loadScenePalette), palFading(paletteFading), animCmdRestorePal(animCmdRestorePalette), shpBackgroundFading(shapeBackgroundFading), animPalOffs(animPalOffset), animCmd1ShapeFrame(animType1ShapeDim), animCmd5SetPal(animCmd5SetPalette), animCmd5AltPage(animCmd5ExtraPage) {}
 		const char *const *strings;
@@ -89,7 +89,7 @@ private:
 		bool animCmd5SetPal;
 		int animCmd5AltPage;
 	};
-	
+
 	const Config *_config;
 
 	Palette *_palettes[13];
@@ -193,6 +193,9 @@ int DarkMoonEngine::mainMenu() {
 			// quit
 			menuChoice = -5;
 			break;
+
+		default:
+			break;
 		}
 	}
 
@@ -203,7 +206,8 @@ int DarkMoonEngine::mainMenuLoop() {
 	int sel = -1;
 	do {
 		_screen->setScreenDim(6);
-		_gui->simpleMenu_setup(6, 0, _mainMenuStrings, -1, 0, 0);
+		_gui->simpleMenu_setup(6, 0, _mainMenuStrings, -1, 0, 0, _configRenderMode == Common::kRenderCGA ? 1 : guiSettings()->colors.guiColorWhite, guiSettings()->colors.guiColorLightRed, guiSettings()->colors.guiColorBlack);
+		_screen->updateScreen();
 
 		while (sel == -1 && !shouldQuit())
 			sel = _gui->simpleMenu_process(6, _mainMenuStrings, 0, -1, 0);
@@ -221,7 +225,8 @@ void DarkMoonEngine::townsUtilitiesMenu() {
 	_screen->copyRegion(78, 99, 78, 99, 172, 43, 2, 0, Screen::CR_NO_P_CHECK);
 	int sel = -1;
 	do {
-		_gui->simpleMenu_setup(8, 0, _utilMenuStrings, -1, 0, 0);
+		_gui->simpleMenu_setup(8, 0, _utilMenuStrings, -1, 0, 0, _configRenderMode == Common::kRenderCGA ? 1 : guiSettings()->colors.guiColorWhite, guiSettings()->colors.guiColorLightRed, guiSettings()->colors.guiColorBlack);
+		_screen->updateScreen();
 		while (sel == -1 && !shouldQuit())
 			sel = _gui->simpleMenu_process(8, _utilMenuStrings, 0, -1, 0);
 		if (sel == 0) {
@@ -295,7 +300,7 @@ void DarkMoonEngine::seq_playIntro() {
 	_screen->setCurPage(2);
 	_screen->setClearScreenDim(17);
 	_screen->setCurPage(0);
-	
+
 	sq.animCommand(_flags.platform == Common::kPlatformAmiga ? 38 : (_configRenderMode == Common::kRenderEGA ? 41 : 40));
 	sq.animCommand(7, 18);
 
@@ -370,7 +375,7 @@ void DarkMoonEngine::seq_playIntro() {
 	sq.animCommand(_flags.platform == Common::kPlatformAmiga ? 12 : 13);
 	_screen->copyRegion(104, 16, 96, 8, 120, 100, 0, 2, Screen::CR_NO_P_CHECK);
 	sq.fadeText();
-	
+
 	if (_flags.platform == Common::kPlatformAmiga)
 		sq.animCommand(9);
 
@@ -824,6 +829,8 @@ void DarkMoonEngine::seq_playFinale() {
 	sq.printText(15, textColor1);           // The temple ceases to exist
 	if (_flags.platform != Common::kPlatformAmiga) {
 		sq.initDelayedPaletteFade(6, 1);
+	} else if (skipFlag()) {
+		_screen->fadeToBlack();
 	} else {
 		_screen->fadePalette(_screen->getPalette(5), 127);
 		sq.copyPalette(5, 0);
@@ -836,7 +843,7 @@ void DarkMoonEngine::seq_playFinale() {
 	sq.delay(54);
 	sq.fadeText();
 	sq.loadScene(12, 2);
-	
+
 	sq.waitForSongNotifier(5);
 
 	if (!skipFlag() && !shouldQuit())
@@ -937,9 +944,9 @@ void DarkMoonEngine::seq_playFinale() {
 
 	int temp = 0;
 	const uint8 *creditsData = (_flags.platform != Common::kPlatformDOS) ? _res->fileData("CREDITS.TXT", 0) : _staticres->loadRawData(kEoB2CreditsData, temp);
-	
+
 	seq_playCredits(&sq, creditsData, 18, 2, 6, 2);
-	
+
 	if (_flags.platform != Common::kPlatformDOS)
 		delete[] creditsData;
 
@@ -1026,7 +1033,7 @@ void DarkMoonEngine::seq_playCredits(DarkmoonSequenceHelper *sq, const uint8 *da
 			delay(MIN<uint32>(_tickLength, end - cur));
 		}
 
-		end = _system->getMillis() + speed * _tickLength;
+		end = _system->getMillis() + ((speed * _tickLength) >> 1);
 
 		for (; i < 35 && *pos; i++) {
 			int16 nextY = i ? items[i].y + items[i].size + (items[i].size >> 2) : dm->h;
@@ -1095,7 +1102,7 @@ void DarkMoonEngine::seq_playCredits(DarkmoonSequenceHelper *sq, const uint8 *da
 				}
 			}
 
-			items[h + 1].y -= 2;
+			items[h + 1].y -= MAX<int>(1, speed >> 1);
 		}
 
 		_screen->copyRegion(dm->sx << 3, dm->sy, dm->sx << 3, dm->sy, dm->w << 3, dm->h, tempPage, 0, Screen::CR_NO_P_CHECK);
@@ -1136,7 +1143,7 @@ DarkmoonSequenceHelper::~DarkmoonSequenceHelper() {
 	for (int i = 0; i < 7; i++)
 		delete[] _fadingTables[i];
 
-	for (int i = 0; i < 30; i++)
+	for (int i = 0; i < 54; i++)
 		delete[] _shapes[i];
 	delete[] _shapes;
 
@@ -1165,7 +1172,7 @@ void DarkmoonSequenceHelper::loadScene(int index, int pageNum, bool ignorePalett
 		file = _config->cpsFiles[index];
 		s = _vm->resource()->createReadStream(file);
 	}
-	
+
 	if (s) {
 		chunkID = s->readUint32LE();
 		s->seek(0);
@@ -1175,7 +1182,7 @@ void DarkmoonSequenceHelper::loadScene(int index, int pageNum, bool ignorePalett
 		// Tolerance for diffenrences up to 2 bytes is needed in some cases
 		if ((((int32)(chunkID & 0xFFFF) + 5) & ~3) != (((s->size()) + 3) & ~3))
 			isRawData = true;
-	} else if (file.firstChar() == 'X') {
+	} else if (file.firstChar() == 'X' && _vm->gameFlags().lang == Common::DE_DEU) {
 		isRawData = true;
 	}
 
@@ -1450,14 +1457,17 @@ void DarkmoonSequenceHelper::printText(int index, int color) {
 }
 
 void DarkmoonSequenceHelper::fadeText() {
-	if (_vm->skipFlag() || _vm->shouldQuit())
+	uint8 col = _vm->gameFlags().platform == Common::kPlatformAmiga ? 31 : 255;
+
+	if (_vm->skipFlag() || _vm->shouldQuit()) {
+		_screen->clearCurDim();
+		_screen->setPaletteIndex(col, 0, 0, 0);
 		return;
+	}
+
+	if (_vm->_configRenderMode != Common::kRenderEGA)
+		_screen->fadeTextColor(_palettes[0], col, 8);
 
-	if (_vm->gameFlags().platform == Common::kPlatformAmiga)
-		_screen->fadeTextColor(_palettes[0], 31, 8);
-	else if (_vm->_configRenderMode != Common::kRenderEGA)
-		_screen->fadeTextColor(_palettes[0], 255, 8);
-	
 	memset(_textColor, 0, 3);
 	_screen->clearCurDim();
 }
@@ -1557,7 +1567,7 @@ void DarkmoonSequenceHelper::init(DarkmoonSequenceHelper::Mode mode) {
 	}
 
 	_screen->enableHiColorMode(false);
-	_screen->disableDualPalettesSplitScreen();
+	_screen->disableDualPaletteMode();
 	int numColors = 256;
 
 	if (_vm->_flags.platform == Common::kPlatformAmiga) {
@@ -1614,7 +1624,7 @@ void DarkmoonSequenceHelper::init(DarkmoonSequenceHelper::Mode mode) {
 	delete[] fadeData;
 
 	_shapes = new const uint8*[54];
-	memset(_shapes, 0, 54 * sizeof(uint8 *));
+	memset(_shapes, 0, 54 * sizeof(uint8*));
 
 	_fadePalTimer = 0;
 	_fadePalRate = 0;
@@ -1718,12 +1728,12 @@ void DarkmoonSequenceHelper::delay(uint32 ticks) {
 void DarkmoonSequenceHelper::waitForSongNotifier(int index, bool introUpdateAnim) {
 	if (_vm->gameFlags().platform == Common::kPlatformFMTowns)
 		index = _sndMarkersFMTowns[index - 1];
-	else if (_vm->gameFlags().platform == Common::kPlatformAmiga)
+	else if (_vm->sound()->getMusicType() != Sound::kAdLib)
 		return;
 
 	int seq = 0;
 
-	while (_vm->sound()->checkTrigger() < index && !(_vm->skipFlag() || _vm->shouldQuit())) {
+	while (_vm->sound()->musicEnabled() && _vm->sound()->checkTrigger() < index && !(_vm->skipFlag() || _vm->shouldQuit())) {
 		if (introUpdateAnim) {
 			animCommand(30 | seq);
 			seq ^= 1;
@@ -1737,7 +1747,7 @@ void DarkmoonSequenceHelper::waitForSongNotifier(int index, bool introUpdateAnim
 }
 
 void DarkmoonSequenceHelper::updateAmigaSound() {
-	if (_vm->gameFlags().platform != Common::kPlatformAmiga)
+	if (_vm->gameFlags().platform != Common::kPlatformAmiga || !_vm->sound()->musicEnabled())
 		return;
 
 	int ct = _vm->sound()->checkTrigger();
@@ -1801,10 +1811,8 @@ const char *const DarkmoonSequenceHelper::_palFilesFinaleAmiga[] = {
 
 void DarkMoonEngine::seq_nightmare() {
 	Screen::FontId of = _screen->setFont(Screen::FID_6_FNT);
-	if (_flags.lang == Common::JA_JPN)
-		_screen->clearCurDim();
+	_screen->clearCurDimOvl(0);
 	_screen->copyRegion(0, 0, 0, 120, 176, 24, 12, 2, Screen::CR_NO_P_CHECK);
-
 	initDialogueSequence();
 	gui_drawDialogueBox();
 
