@@ -68,7 +68,7 @@ public:
 	void clearChain();
 	void deployChannels(IOUnit **dest);
 	IOUnit *requestFreeUnit();
-	
+
 	void fadeOut();
 	bool isFading();
 
@@ -85,7 +85,7 @@ friend class AudioMaster2IOManager;
 private:
 	AudioMaster2Internal(Audio::Mixer *mixer);
 public:
-	~AudioMaster2Internal();
+	~AudioMaster2Internal() override;
 
 	static AudioMaster2Internal *open(Audio::Mixer *mixer);
 	static void close();
@@ -105,7 +105,7 @@ public:
 	void setMusicVolume(int volume);
 	void setSoundEffectVolume(int volume);
 
-	void interrupt();
+	void interrupt() override;
 
 	void resetCounter();
 	int getPlayDuration();
@@ -180,18 +180,18 @@ class SoundResource8SVX : public SoundResource {
 public:
 	SoundResource8SVX(AudioMaster2ResourceManager *res);
 private:
-	virtual ~SoundResource8SVX();
+	~SoundResource8SVX() override;
 public:
 	void loadHeader(Common::ReadStream *stream, uint32 size);
 	void loadData(Common::ReadStream *stream, uint32 size);
 
-	void setupMusicNote(AudioMaster2IOManager::IOUnit *unit, uint8 note, uint16 volume);
-	void setupSoundEffect(AudioMaster2IOManager::IOUnit *unit, uint32 sync, uint32 tempo);
+	void setupMusicNote(AudioMaster2IOManager::IOUnit *unit, uint8 note, uint16 volume) override;
+	void setupSoundEffect(AudioMaster2IOManager::IOUnit *unit, uint32 sync, uint32 tempo) override;
 
 private:
-	void release();
+	void release() override;
 
-	void setupEnvelopes(AudioMaster2IOManager::IOUnit *unit);
+	void setupEnvelopes(AudioMaster2IOManager::IOUnit *unit) override;
 
 	uint32 _numSamplesOnce;
 	uint32 _numSamplesRepeat;
@@ -211,14 +211,14 @@ class SoundResourceINST : public SoundResource {
 public:
 	SoundResourceINST(AudioMaster2ResourceManager *res) : SoundResource(res, 2), _samplesResource(0), _transpose(0), _levelAdjust(0) {}
 private:
-	virtual ~SoundResourceINST();
+	~SoundResourceINST() override;
 public:
 	void loadPitchData(Common::ReadStream *stream, uint32 size);
 	void loadSamples(Common::ReadStream *stream, uint32 size);
 	void loadVolumeData(Common::ReadStream *stream, uint32 size);
 
-	void setupMusicNote(AudioMaster2IOManager::IOUnit *unit, uint8 note, uint16 volume);
-	void setupSoundEffect(AudioMaster2IOManager::IOUnit *unit, uint32 sync, uint32 rate);
+	void setupMusicNote(AudioMaster2IOManager::IOUnit *unit, uint8 note, uint16 volume) override;
+	void setupSoundEffect(AudioMaster2IOManager::IOUnit *unit, uint32 sync, uint32 rate) override;
 
 	struct EnvelopeData {
 		EnvelopeData(const uint8 *data, uint32 size) : volume(0x40), _data(data), _dataSize(size) {}
@@ -229,9 +229,9 @@ public:
 	};
 
 private:
-	void release();
+	void release() override;
 
-	void setupEnvelopes(AudioMaster2IOManager::IOUnit *unit);
+	void setupEnvelopes(AudioMaster2IOManager::IOUnit *unit) override;
 
 	EnvelopeData *_transpose;
 	EnvelopeData *_levelAdjust;
@@ -242,20 +242,20 @@ class SoundResourceSMUS : public SoundResource {
 public:
 	SoundResourceSMUS(AudioMaster2ResourceManager *res) : SoundResource(res, 1), _tempo(0), _songVolume(0), _playFlags(0) {}
 private:
-	virtual ~SoundResourceSMUS();
+	~SoundResourceSMUS() override;
 public:
 	void loadHeader(Common::ReadStream *stream, uint32 size);
 	void loadInstrument(Common::ReadStream *stream, uint32 size);
 	void loadTrack(Common::ReadStream *stream, uint32 size);
 
-	void prepare();
+	void prepare() override;
 	uint16 getTempo() const;
-	void setSync(uint32 sync);
+	void setSync(uint32 sync) override;
 
-	void interrupt(AudioMaster2IOManager *io);
+	void interrupt(AudioMaster2IOManager *io) override;
 
 private:
-	void release();
+	void release() override;
 
 	struct Track {
 		Track() : _dataStart(0), _dataEnd(0), _dataCur(0), _instrument(0), _volume(0), _sync(0) {}
@@ -281,7 +281,7 @@ private:
 	};
 
 	bool parse(AudioMaster2IOManager *io, Track *track);
-	
+
 	uint16 _tempo;
 	uint8 _songVolume;
 
@@ -311,7 +311,7 @@ public:
 	void setMasterVolume(int type, int volume);
 
 	void interrupt(AudioMaster2IOManager *io);
-	
+
 private:
 	SoundResource *retrieveFromChain(const Common::String &resName);
 	void linkToChain(SoundResource *resource, SoundResource::Mode mode);
@@ -453,7 +453,7 @@ void SoundResource::loadName(Common::ReadStream *stream, uint32 size) {
 	stream->read(data, size);
 	data[size] = '\0';
 	_name = data;
-	
+
 	delete[] data;
 }
 
@@ -497,11 +497,8 @@ void SoundResource::interrupt(AudioMaster2IOManager *io) {
 	setupSoundEffect(unit, io->_sync, io->_tempo);
 }
 
-SoundResource8SVX::SoundResource8SVX(AudioMaster2ResourceManager *res) : SoundResource(res, 4) {
-	_numSamplesOnce = _numSamplesRepeat = _numSamplesPerCycle = _trackVolume = _dataSize = 0;
-	_rate = 0;
-	_numBlocks = _format = 0;
-	_data = 0;
+SoundResource8SVX::SoundResource8SVX(AudioMaster2ResourceManager *res) : SoundResource(res, 4),
+	_numSamplesOnce(0), _numSamplesRepeat(0), _numSamplesPerCycle(0), _trackVolume(0), _dataSize(0), _rate(0), _numBlocks(0), _format(0), _data(0) {
 }
 
 SoundResource8SVX::~SoundResource8SVX() {
@@ -539,9 +536,9 @@ void SoundResource8SVX::setupMusicNote(AudioMaster2IOManager::IOUnit *unit, uint
 	// The original code uses 3579546 here. But since the Paula code uses kPalPaulaClock I do the same.
 	uint32 rt = Audio::Paula::kPalPaulaClock;
 	uint32 offs = 0;
-	
+
 	if (_numSamplesRepeat && _numSamplesPerCycle) {
-		uint32 octave = _numBlocks;		
+		uint32 octave = _numBlocks;
 		rt = _periods[note] << 13;
 
 		for (rt /= _numSamplesPerCycle; rt >= 0x4000000 && octave > 1; octave--) {
@@ -650,7 +647,7 @@ void SoundResourceINST::loadSamples(Common::ReadStream *stream, uint32 size) {
 	char *data = new char[size + 1];
 	stream->read(data, size);
 	data[size] = '\0';
-	
+
 	if (_samplesResource)
 		_samplesResource->close();
 
@@ -709,7 +706,7 @@ void SoundResourceINST::setupEnvelopes(AudioMaster2IOManager::IOUnit *unit) {
 void SoundResourceINST::setupSoundEffect(AudioMaster2IOManager::IOUnit *unit, uint32 sync, uint32 rate) {
 	if (!unit)
 		return;
-	
+
 	if (_samplesResource)
 		_samplesResource->setupSoundEffect(unit, sync, rate);
 
@@ -726,7 +723,7 @@ SoundResourceSMUS::~SoundResourceSMUS() {
 void SoundResourceSMUS::loadHeader(Common::ReadStream *stream, uint32 size) {
 	if (size < 3)
 		error("SoundResourceSMUS:loadHeader(): Invalid data chunk size");
-	
+
 	_tempo = stream->readUint16BE() / 68;
 	_songVolume = stream->readByte();
 }
@@ -750,14 +747,14 @@ void SoundResourceSMUS::loadInstrument(Common::ReadStream *stream, uint32 size)
 		warning("SoundResourceSMUS::loadInstrument(): Samples resource '%s' not found for '%s'.", data, _name.c_str());
 	}
 
-	delete[] data;	
+	delete[] data;
 }
 
 void SoundResourceSMUS::loadTrack(Common::ReadStream *stream, uint32 size) {
 	Track *track = new Track();
 	uint8 *data = new uint8[size];
 	stream->read(data, size);
-	
+
 	track->_dataStart = data;
 	track->_dataEnd = data + size;
 	track->_volume = 128;
@@ -803,7 +800,7 @@ void SoundResourceSMUS::release() {
 
 bool SoundResourceSMUS::parse(AudioMaster2IOManager *io, Track *track) {
 	uint32 duration = 0;
-	
+
 	while (track->_sync <= io->_sync) {
 		if (track->_dataCur >= track->_dataEnd)
 			return false;
@@ -823,7 +820,7 @@ bool SoundResourceSMUS::parse(AudioMaster2IOManager *io, Track *track) {
 				AudioMaster2IOManager::IOUnit *unit = io->requestFreeUnit();
 				if (unit) {
 					unit->_startTick = track->_sync;
-					unit->_endTick = unit->_startTick + duration;					
+					unit->_endTick = unit->_startTick + duration;
 					track->_instrument->setupMusicNote(unit, cmd, _masterVolume * track->_volume);
 				}
 			}
@@ -961,7 +958,7 @@ void AudioMaster2ResourceManager::stopChain() {
 void AudioMaster2ResourceManager::flush() {
 	Common::StackLock lock(_mutex);
 
-	stopChain();	
+	stopChain();
 
 	while (_chainPlaying) {
 		SoundResource *res = _chainPlaying;
@@ -1240,7 +1237,7 @@ bool AudioMaster2Internal::init() {
 	_res = new AudioMaster2ResourceManager(this, _mutex);
 
 	startPaula();
-	
+
 	_mixer->playStream(Audio::Mixer::kPlainSoundType,
 		&_soundHandle, this, -1, Audio::Mixer::kMaxChannelVolume, 0, DisposeAfterUse::NO, true);
 
@@ -1361,11 +1358,11 @@ void AudioMaster2Internal::updateDevice() {
 		}
 
 		bool next = false;
-		
+
 		if (unit->_transposeData) {
 			unit->_period += unit->_transposePara;
 			const uint8 *data = unit->_transposeData;
-			
+
 			if (unit->_transposeDuration-- <= 1) {
 				for (bool loop = true; loop; ) {
 					uint8 para = *data++;
@@ -1443,7 +1440,7 @@ void AudioMaster2Internal::updateDevice() {
 						} else {
 							para2 = (unit->_volumeSetting * para2) >> 6;
 							if (para2 > 0x4000)
-								para2 = 0x4000;							
+								para2 = 0x4000;
 						}
 
 						if (!para) {
@@ -1483,7 +1480,7 @@ void AudioMaster2Internal::updateDevice() {
 				setChannelSampleStart(i, unit->_sampleDataRepeat);
 				setChannelSampleLen(i, unit->_lenRepeat);
 			}
-	
+
 		} else if (unit->_transposeData || unit->_levelAdjustData) {
 			setChannelPeriod(i, unit->_period);
 			setChannelVolume(i, unit->_outputVolume >> 8);
