@@ -80,6 +80,11 @@ AUDStream::AUDStream(Common::SeekableReadStream *stream) : _stream(stream), _end
 	_processedSize(0), _totalSize(0), _length(0, 1), _bytesLeft(0), _outBuffer(0),
 	_outBufferOffset(0), _outBufferSize(0), _inBuffer(0), _inBufferSize(0) {
 
+	if (_stream->size() < 8) {
+		warning("No AUD file: too short");
+		return;
+	}
+
 	_rate = _stream->readUint16LE();
 	_totalSize = _stream->readUint32LE();
 
