@@ -30,6 +30,7 @@
 
 #include "common/config-manager.h"
 #include "common/file.h"
+#include "common/translation.h"
 
 #include "gui/message.h"
 
@@ -121,7 +122,7 @@ void LabEngine::handleTrialWarning() {
 			// Wyrmkeep trial version
 			_extraGameFeatures = GF_WINDOWS_TRIAL;
 
-			GUI::MessageDialog trialMessage("This is a trial Windows version of the game. To play the full version, you will need to use the original interpreter and purchase a key from Wyrmkeep");
+			GUI::MessageDialog trialMessage(_("This is a trial Windows version of the game. To play the full version, you will need to use the original interpreter and purchase a key from Wyrmkeep"));
 			trialMessage.runModal();
 		}
 		else {
@@ -825,7 +826,7 @@ void LabEngine::processMainButton(uint16 &curInv, uint16 &lastInv, uint16 &oldDi
 				if (!intersect) {
 					if (_numCrumbs == MAX_CRUMBS) {
 						_numCrumbs = MAX_CRUMBS - 1;
-						memcpy(&_breadCrumbs[0], &_breadCrumbs[1], _numCrumbs * sizeof _breadCrumbs[0]);
+						memmove(&_breadCrumbs[0], &_breadCrumbs[1], _numCrumbs * sizeof _breadCrumbs[0]);
 					}
 
 					_breadCrumbs[_numCrumbs]._crumbRoomNum = _roomNum;
@@ -843,6 +844,9 @@ void LabEngine::processMainButton(uint16 &curInv, uint16 &lastInv, uint16 &oldDi
 
 		_interface->mayShowCrumbIndicator();
 		break;
+
+	default:
+		break;
 	}
 
 	_graphics->screenUpdate();
@@ -960,6 +964,9 @@ void LabEngine::processAltButton(uint16 &curInv, uint16 &lastInv, uint16 buttonI
 			}
 		}
 		break;
+
+	default:
+		break;
 	}
 
 	_graphics->screenUpdate();
@@ -1024,6 +1031,10 @@ void LabEngine::performAction(uint16 actionMode, Common::Point curPos, uint16 &c
 			else if (curPos.y < (_utils->vgaScaleY(149) + _utils->svgaCord(2)))
 				drawStaticMessage(kTextNothing);
 		}
+		break;
+
+	default:
+		break;
 	}
 }
 
