@@ -41,6 +41,7 @@
 #include "lab/console.h"
 #include "lab/image.h"
 #include "lab/labsets.h"
+#include "lab/detection.h"
 
 struct ADGameDescription;
 
@@ -74,11 +75,6 @@ struct SaveGameHeader {
 	uint16 _direction;
 };
 
-enum GameFeatures {
-	GF_LOWRES = 1 << 0,
-	GF_WINDOWS_TRIAL = 1 << 1
-};
-
 typedef Common::List<Button *> ButtonList;
 
 struct CrumbData {
