@@ -131,8 +131,8 @@ struct FrameInfo {
 class AnimFrame : public Drawable {
 public:
 	AnimFrame(Common::SeekableReadStream *in, const FrameInfo &f, bool ignoreSubtype = false);
-	~AnimFrame();
-	Common::Rect draw(Graphics::Surface *s);
+	~AnimFrame() override;
+	Common::Rect draw(Graphics::Surface *s) override;
 
 private:
 	void decomp3(Common::SeekableReadStream *in, const FrameInfo &f);
@@ -184,9 +184,9 @@ private:
 class SequenceFrame : public Drawable {
 public:
 	SequenceFrame(Sequence *sequence, uint16 frame = 0, bool dispose = false) : _sequence(sequence), _frame(frame), _dispose(dispose) {}
-	~SequenceFrame();
+	~SequenceFrame() override;
 
-	Common::Rect draw(Graphics::Surface *surface);
+	Common::Rect draw(Graphics::Surface *surface) override;
 
 	bool setFrame(uint16 frame);
 	uint32 getFrame() { return _frame; }
