@@ -55,13 +55,13 @@ class Subtitle;
 class SubtitleManager : public Drawable {
 public:
 	SubtitleManager(Font *font);
-	~SubtitleManager();
+	~SubtitleManager() override;
 
 	bool load(Common::SeekableReadStream *stream);
 	uint16 getMaxTime() const;
 	void setTime(uint16 time);
 	bool hasChanged() const;
-	Common::Rect draw(Graphics::Surface *surface);
+	Common::Rect draw(Graphics::Surface *surface) override;
 
 private:
 	Common::Array<Subtitle *> _subtitles;
