@@ -20,8 +20,8 @@
  *
  */
 
-#include "lastexpress/lastexpress.h"
 #include "engines/advancedDetector.h"
+#include "lastexpress/lastexpress.h"
 
 namespace LastExpress {
 
@@ -31,6 +31,19 @@ static const PlainGameDescriptor lastExpressGames[] = {
 	{0, 0}
 };
 
+static const DebugChannelDef debugFlagList[] = {
+	{LastExpress::kLastExpressDebugGraphics, "Graphics", "Debug graphics & animation/sequence playback"},
+	{LastExpress::kLastExpressDebugResource, "Resource", "Debug resource management"},
+	{LastExpress::kLastExpressDebugCursor, "Cursor", "Debug cursor handling"},
+	{LastExpress::kLastExpressDebugSound, "Sound", "Debug sound playback"},
+	{LastExpress::kLastExpressDebugSubtitle, "Subtitle", "Debug subtitles"},
+	{LastExpress::kLastExpressDebugSavegame, "Savegame", "Debug savegames"},
+	{LastExpress::kLastExpressDebugLogic, "Logic", "Debug logic"},
+	{LastExpress::kLastExpressDebugScenes, "Scenes", "Debug scenes & hotspots"},
+	{LastExpress::kLastExpressDebugUnknown, "Unknown", "Debug unknown data"},
+	DEBUG_CHANNEL_END
+};
+
 static const ADGameDescription gameDescriptions[] = {
 
 	// The Last Express (English) - US Broderbund Release
@@ -201,33 +214,20 @@ static const ADGameDescription gameDescriptions[] = {
 		GUIO2(GUIO_NOASPECT, GUIO_NOMIDI)
 	},
 
-	// The Last Express (GOG)
-	//   expressw.exe ???
-	//   express.exe  2010-12-14 13:49:04
-	{
-		"lastexpress",
-		"",
-		{
-			{"HD.HPF",  0, "ab940d5815008b176502f759ae753fb7", 30715904},   // 2000-03-01 17:03:58
-			{"CD1.HPF", 0, "cec8810125b050f41b7f34ab72371f81", 525522944},  // 2000-02-14 16:02:02
-			{"CD2.HPF", 0, "c648872b31e43d458680cf16bedc636c", 669581312},  // 1997-02-10 21:19:30
-			{"CD3.HPF", 0, "8cb3e68a6dca354e556c487ea24a6b10", 641128448},  // 1997-02-10 20:44:08
-			AD_LISTEND
-		},
-		Common::EN_ANY,
-		Common::kPlatformUnknown,
-		ADGF_UNSTABLE,
-		GUIO2(GUIO_NOASPECT, GUIO_NOMIDI)
-	},
-
 	AD_TABLE_END_MARKER
 };
 
+static const char *const directoryGlobs[] = {
+		"data", // GOG release
+		0
+};
 
-class LastExpressMetaEngine : public AdvancedMetaEngine {
+class LastExpressMetaEngineDetection : public AdvancedMetaEngineDetection {
 public:
-	LastExpressMetaEngine() : AdvancedMetaEngine(gameDescriptions, sizeof(ADGameDescription), lastExpressGames) {
+	LastExpressMetaEngineDetection() : AdvancedMetaEngineDetection(gameDescriptions, sizeof(ADGameDescription), lastExpressGames) {
 		_guiOptions = GUIO2(GUIO_NOSUBTITLES, GUIO_NOSFX);
+		_maxScanDepth = 2;
+		_directoryGlobs = directoryGlobs;
 	}
 
 	const char *getEngineId() const override {
@@ -242,25 +242,11 @@ public:
 		return "The Last Express (C) 1997 Smoking Car Productions";
 	}
 
-protected:
-	bool createInstance(OSystem *syst, Engine **engine, const ADGameDescription *gd) const override;
-};
-
-bool LastExpressMetaEngine::createInstance(OSystem *syst, Engine **engine, const ADGameDescription *gd) const {
-	if (gd) {
-		*engine = new LastExpressEngine(syst, (const ADGameDescription *)gd);
+	const DebugChannelDef *getDebugChannels() const override {
+		return debugFlagList;
 	}
-	return gd != 0;
-}
-
-bool LastExpressEngine::isDemo() const {
-	return (bool)(_gameDescription->flags & ADGF_DEMO);
-}
+};
 
 } // End of namespace LastExpress
 
-#if PLUGIN_ENABLED_DYNAMIC(LASTEXPRESS)
-	REGISTER_PLUGIN_DYNAMIC(LASTEXPRESS, PLUGIN_TYPE_ENGINE, LastExpress::LastExpressMetaEngine);
-#else
-	REGISTER_PLUGIN_STATIC(LASTEXPRESS, PLUGIN_TYPE_ENGINE, LastExpress::LastExpressMetaEngine);
-#endif
+REGISTER_PLUGIN_STATIC(LASTEXPRESS_DETECTION, PLUGIN_TYPE_ENGINE_DETECTION, LastExpress::LastExpressMetaEngineDetection);
