@@ -72,9 +72,9 @@
 namespace LastExpress {
 
 Chapters::Chapters(LastExpressEngine *engine) : Entity(engine, kEntityChapters) {
-	ADD_CALLBACK_FUNCTION(Chapters, savegame);
-	ADD_CALLBACK_FUNCTION(Chapters, enterStation);
-	ADD_CALLBACK_FUNCTION(Chapters, exitStation);
+	ADD_CALLBACK_FUNCTION_II(Chapters, savegame);
+	ADD_CALLBACK_FUNCTION_SI(Chapters, enterStation);
+	ADD_CALLBACK_FUNCTION_S(Chapters, exitStation);
 	ADD_CALLBACK_FUNCTION(Chapters, chapter1);
 	ADD_CALLBACK_FUNCTION(Chapters, resetMainEntities);
 	ADD_CALLBACK_FUNCTION(Chapters, firstDream);
@@ -92,8 +92,8 @@ Chapters::Chapters(LastExpressEngine *engine) : Entity(engine, kEntityChapters)
 	ADD_CALLBACK_FUNCTION(Chapters, chapter4Init);
 	ADD_CALLBACK_FUNCTION(Chapters, chapter4Handler);
 	ADD_CALLBACK_FUNCTION(Chapters, chapter5);
-	ADD_CALLBACK_FUNCTION(Chapters, chapter4Init);
-	ADD_CALLBACK_FUNCTION(Chapters, chapter4Handler);
+	ADD_CALLBACK_FUNCTION(Chapters, chapter5Init);
+	ADD_CALLBACK_FUNCTION(Chapters, chapter5Handler);
 }
 
 //////////////////////////////////////////////////////////////////////////
@@ -135,6 +135,7 @@ IMPLEMENT_FUNCTION(5, Chapters, resetMainEntities)
 	RESET_ENTITY_STATE(kEntityHadija, Hadija, setup_reset);
 	RESET_ENTITY_STATE(kEntityIvo, Ivo, setup_reset);
 	RESET_ENTITY_STATE(kEntityKahina, Kahina, setup_reset);
+	RESET_ENTITY_STATE(kEntityKronos, Kronos, setup_reset);
 	RESET_ENTITY_STATE(kEntityMmeBoutarel, MmeBoutarel, setup_reset);
 	RESET_ENTITY_STATE(kEntityMahmud, Mahmud, setup_reset);
 	RESET_ENTITY_STATE(kEntityMax, Max, setup_reset);
@@ -161,7 +162,7 @@ IMPLEMENT_FUNCTION(6, Chapters, firstDream)
 		break;
 
 	case kActionEndSound:
-		getSound()->playSound(kEntityChapters, "MUS0009", kFlagDefault);
+		getSound()->playSound(kEntityChapters, "MUS009", kVolumeFull);
 		break;
 
 	case kActionKnock:
@@ -172,9 +173,9 @@ IMPLEMENT_FUNCTION(6, Chapters, firstDream)
 	case kActionOpenDoor:
 		if (params->param1) {
 			getEntities()->clearSequences(kEntityChapters);
-			getSoundQueue()->processEntry(kEntityChapters);
+			getSoundQueue()->fade(kEntityChapters);
 			getSound()->playSound(kEntityPlayer, "LIB014");
-			getSoundQueue()->resetState();
+			getSoundQueue()->startAmbient();
 
 			ENTITY_PARAM(0, 4) = 7;
 
@@ -193,10 +194,10 @@ IMPLEMENT_FUNCTION(6, Chapters, firstDream)
 			callbackAction();
 		} else {
 			getSound()->playSound(kEntityPlayer, "LIB014");
-			getSound()->playSound(kEntityPlayer, "LIB015", kFlagDefault, 15);
+			getSound()->playSound(kEntityPlayer, "LIB015", kVolumeFull, 15);
 
 			if (!getSoundQueue()->isBuffered(kEntityChapters))
-				getSound()->playSound(kEntityChapters, "MUS009", kFlagDefault);
+				getSound()->playSound(kEntityChapters, "MUS009", kVolumeFull);
 
 			getScenes()->loadSceneFromPosition(kCarLocomotive, 38);
 
@@ -242,37 +243,34 @@ IMPLEMENT_FUNCTION(6, Chapters, firstDream)
 		RESET_ENTITY_STATE(kEntityHadija, Alouan, setup_function12);
 
 		if (ENTITY_PARAM(0, 2) || ENTITY_PARAM(0, 3)) {
-			getSoundQueue()->removeFromQueue(kEntityChapters);
+			getSoundQueue()->stop(kEntityChapters);
 
 			ENTITY_PARAM(0, 2) = 0;
 			ENTITY_PARAM(0, 3) = 0;
 		}
 
-		getSoundQueue()->processEntries();
+		getSoundQueue()->endAmbient();
 
 		if (getSoundQueue()->isBuffered("CON1505"))
-			getSoundQueue()->processEntry("CON1505");
+			getSoundQueue()->fade("CON1505");
 
 		if (getSoundQueue()->isBuffered("AUG1057"))
-			getSoundQueue()->processEntry("AUG1057");
+			getSoundQueue()->fade("AUG1057");
 
 		if (getSoundQueue()->isBuffered("ZFX1005"))
-			getSoundQueue()->processEntry("ZFX1005");
+			getSoundQueue()->fade("ZFX1005");
+		else if (getSoundQueue()->isBuffered("ZFX1006"))
+			getSoundQueue()->fade("ZFX1006");
+		else if (getSoundQueue()->isBuffered("ZFX1007"))
+			getSoundQueue()->fade("ZFX1007");
+		else if (getSoundQueue()->isBuffered("ZFX1007A"))
+			getSoundQueue()->fade("ZFX1007A");
+		else if (getSoundQueue()->isBuffered("ZFX1007B"))
+			getSoundQueue()->fade("ZFX1007B");
 
-		if (getSoundQueue()->isBuffered("ZFX1006"))
-			getSoundQueue()->processEntry("ZFX1006");
-
-		if (getSoundQueue()->isBuffered("ZFX1007"))
-			getSoundQueue()->processEntry("ZFX1007");
-
-		if (getSoundQueue()->isBuffered("ZFX1007A"))
-			getSoundQueue()->processEntry("ZFX1007A");
-
-		if (getSoundQueue()->isBuffered("ZFX1007B"))
-			getSoundQueue()->processEntry("ZFX1007B");
-
-		getSound()->playSound(kEntityPlayer, "MUS008", kFlagDefault);
+		getSound()->playSound(kEntityPlayer, "MUS008", kVolumeFull);
 		getInventory()->unselectItem();
+		// TODO: fade to black screen
 
 		// FIXME add event pump ?
 		while (getSoundQueue()->isBuffered("MUS008"))
@@ -305,7 +303,7 @@ IMPLEMENT_FUNCTION(6, Chapters, firstDream)
 				getSound()->playSound(kEntityPlayer, "LIB031");
 
 			if (params->param2 == 3) {
-				getData()->car = kCarGreenSleeping;
+				getData()->car = kCarLocomotive;
 				getEntities()->drawSequenceLeft(kEntityChapters, "JUGL");
 			}
 		}
@@ -319,9 +317,9 @@ IMPLEMENT_FUNCTION(7, Chapters, chapter1Init)
 		return;
 
 	getProgress().chapter = kChapter1;
-	getSoundQueue()->resetState();
+	getSoundQueue()->startAmbient();
 
-	getState()->time = kTimeChapter1;
+	getState()->time = kTimeStartGame;
 	getState()->timeDelta = 0;
 	getProgress().isTrainRunning = true;
 	getProgress().portrait = kPortraitOriginal;
@@ -376,8 +374,8 @@ IMPLEMENT_FUNCTION(7, Chapters, chapter1Init)
 	getObjects()->update(kObject65, kEntityPlayer, kObjectLocationNone, kCursorNormal, kCursorForward);
 	getObjects()->update(kObject69, kEntityPlayer, kObjectLocationNone, kCursorNormal, kCursorForward);
 	getObjects()->update(kObject98, kEntityPlayer, kObjectLocationNone, kCursorNormal, kCursorForward);
-	getObjects()->update(kObjectHandleOutsideLeft, kEntityPlayer, kObjectLocation1, kCursorNormal, kCursorHandKnock);
-	getObjects()->update(kObjectHandleOutsideRight, kEntityPlayer, kObjectLocation1, kCursorNormal, kCursorHandKnock);
+	getObjects()->update(kObjectHandleOutsideLeft, kEntityPlayer, kObjectLocation1, kCursorNormal, kCursorHand);
+	getObjects()->update(kObjectHandleOutsideRight, kEntityPlayer, kObjectLocation1, kCursorNormal, kCursorHand);
 	getObjects()->update(kObject101, kEntityPlayer, kObjectLocation1, kCursorHandKnock, kCursorHand);
 
 	setup_chapter1Handler();
@@ -414,7 +412,7 @@ label_processStations:
 
 label_enter_epernay:
 		// Entering Epernay station
-		if (timeCheckEnterStation(kTimeEnterEpernay, params->param8, 1, "Epernay", kCityEpernay))
+		if (timeCheckEnterStation(kTimeEnterEpernay, params->param8, 2, "Epernay", kCityEpernay))
 			break;
 
 label_exit_epernay:
@@ -586,7 +584,7 @@ label_chapter1_next:
 		}
 
 		if (ENTITY_PARAM(0, 3)) {
-			getSoundQueue()->resetState();
+			getSoundQueue()->startAmbient();
 			ENTITY_PARAM(0, 3) = 0;
 
 			if (params->param4) {
@@ -717,13 +715,14 @@ IMPLEMENT_FUNCTION(9, Chapters, chapter1Next)
 	if (savepoint.action == kActionDefault) {
 		// Reset sound cache
 		if (ENTITY_PARAM(0, 2) || ENTITY_PARAM(0, 3)) {
-			getSoundQueue()->removeFromQueue(kEntityChapters);
+			getSoundQueue()->stop(kEntityChapters);
 			ENTITY_PARAM(0, 2) = 0;
 			ENTITY_PARAM(0, 3) = 0;
 		}
 
-		getSound()->playSound(kEntityPlayer, "MUS008", kFlagDefault);
+		getSound()->playSound(kEntityPlayer, "MUS008", kVolumeFull);
 		getInventory()->unselectItem();
+		// TODO: fade to black screen
 
 		while (getSoundQueue()->isBuffered("MUS008"))
 			getSoundQueue()->updateQueue();
@@ -785,6 +784,8 @@ IMPLEMENT_FUNCTION(11, Chapters, chapter2Init)
 
 	// Setup inventory & items location
 	getInventory()->addItem(kItemGreenJacket);
+	getInventory()->get(kItemCorpse)->location = kObjectLocationNone;
+	getInventory()->get(kItemCorpse)->inPocket = false;
 
 	getObjects()->update(kObjectHandleOutsideLeft, kEntityPlayer, kObjectLocation1, kCursorNormal, kCursorHand);
 	getObjects()->update(kObjectHandleOutsideRight, kEntityPlayer, kObjectLocation1, kCursorNormal, kCursorHand);
@@ -813,7 +814,7 @@ IMPLEMENT_FUNCTION(11, Chapters, chapter2Init)
 
 	// Reset sound cache
 	if (ENTITY_PARAM(0, 2) || ENTITY_PARAM(0, 3)) {
-		getSoundQueue()->removeFromQueue(kEntityChapters);
+		getSoundQueue()->stop(kEntityChapters);
 		ENTITY_PARAM(0, 2) = 0;
 		ENTITY_PARAM(0, 3) = 0;
 	}
@@ -898,11 +899,13 @@ IMPLEMENT_FUNCTION(14, Chapters, chapter3Init)
 		getObjects()->update(kObject107, kEntityPlayer, kObjectLocation3, kCursorKeepValue, kCursorKeepValue);
 
 		if (ENTITY_PARAM(0, 2) || ENTITY_PARAM(0, 3)) {
-			getSoundQueue()->removeFromQueue(kEntityChapters);
+			getSoundQueue()->stop(kEntityChapters);
 			ENTITY_PARAM(0, 2) = 0;
 			ENTITY_PARAM(0, 3) = 0;
 		}
 
+		// TODO: fade to black screen
+
 		getScenes()->loadSceneFromPosition(kCarRestaurant, 60);
 		getInventory()->show();
 
@@ -972,7 +975,7 @@ label_callback_4:
 			break;
 
 label_callback_5:
-		if (timeCheckExitStation(kTimeEnterWels, CURRENT_PARAM(1, 3), 6, "Wels"))
+		if (timeCheckExitStation(kTimeExitWels, CURRENT_PARAM(1, 3), 6, "Wels"))
 			break;
 
 label_callback_6:
@@ -980,7 +983,7 @@ label_callback_6:
 			break;
 
 label_callback_7:
-		if (timeCheckExitStation(kTimeCityLinz, CURRENT_PARAM(1, 5), 8, "Linz"))
+		if (timeCheckExitStation(kTimeExitLinz, CURRENT_PARAM(1, 5), 8, "Linz"))
 			break;
 
 label_callback_8:
@@ -1020,18 +1023,18 @@ label_callback_8:
 				}
 			}
 
-			getSoundQueue()->resetState();
+			getSoundQueue()->startAmbient();
 			getSound()->playSteam((CityIndex)ENTITY_PARAM(0, 4));
 
 			ENTITY_PARAM(0, 2) = 0;
-			if (params->param1)
+			if (params->param3)
 				setup_viennaEvents();
 
 			break;
 		}
 
 		if (ENTITY_PARAM(0, 3)) {
-			getSoundQueue()->resetState();
+			getSoundQueue()->startAmbient();
 			ENTITY_PARAM(0, 3) = 0;
 		}
 		break;
@@ -1086,6 +1089,30 @@ IMPLEMENT_FUNCTION(16, Chapters, viennaEvents)
 		break;
 
 	case kActionDefault:
+		getEntityData(kEntityPlayer)->car = kCarLocomotive;
+		if (getSoundQueue()->isBuffered(kEntityAbbot))
+			getSoundQueue()->fade(kEntityAbbot);
+
+		if (!getEvent(kEventAugustBringBriefcase)) {
+			setCallback(1);
+			setup_savegame(kSavegameTypeEvent, kEventViennaAugustUnloadGuns);
+			break;
+		}
+
+		if (getInventory()->get(kItemFirebird)->location == kObjectLocation5) {
+			setCallback(2);
+			setup_savegame(kSavegameTypeEvent, kEventViennaKronosFirebird);
+			break;
+		}
+
+		if (ENTITY_PARAM(0, 1)) {
+			setCallback(3);
+			setup_savegame(kSavegameTypeEvent, kEventVergesAnnaDead);
+			break;
+		}
+
+		setCallback(4);
+		setup_savegame(kSavegameTypeEvent, kEventViennaContinueGame);
 		break;
 
 	case kActionCallback:
@@ -1108,10 +1135,7 @@ IMPLEMENT_FUNCTION(16, Chapters, viennaEvents)
 			if (getEvent(kEventKronosBringEggCeiling))
 				getLogic()->gameOver(kSavegameTypeEvent2, kEventKronosBringEggCeiling, kSceneGameOverVienna1, true);
 			else if (getEvent(kEventKronosBringEgg)) {
-				if (getEvent(kEventKronosBringEggCeiling))
-					getLogic()->gameOver(kSavegameTypeEvent2, kEventKronosBringEggCeiling, kSceneGameOverVienna1, true);
-				else
-					getLogic()->gameOver(kSavegameTypeTime, kTime2155500, kSceneGameOverVienna1, true);
+				getLogic()->gameOver(kSavegameTypeTime, kTime2155500, kSceneGameOverVienna1, true);
 			} else {
 				if (getProgress().field_C0) {
 					if (getEvent(kEventKronosReturnBriefcase))
@@ -1184,8 +1208,8 @@ IMPLEMENT_FUNCTION(18, Chapters, chapter4Init)
 	if (savepoint.action != kActionDefault)
 		return;
 
-	getSoundQueue()->processEntries();
-	getSoundQueue()->resetState();
+	getSoundQueue()->endAmbient();
+	getSoundQueue()->startAmbient();
 
 	getProgress().isTrainRunning = true;
 
@@ -1211,11 +1235,13 @@ IMPLEMENT_FUNCTION(18, Chapters, chapter4Init)
 	getObjects()->update(kObject107, kEntityPlayer, kObjectLocation3, kCursorKeepValue, kCursorKeepValue);
 
 	if (ENTITY_PARAM(0, 2) || ENTITY_PARAM(0, 3)) {
-		getSoundQueue()->removeFromQueue(kEntityChapters);
+		getSoundQueue()->stop(kEntityChapters);
 		ENTITY_PARAM(0, 2) = 0;
 		ENTITY_PARAM(0, 3) = 0;
 	}
 
+	// TODO: fade to black screen
+
 	if (getInventory()->hasItem(kItemFirebird))
 		getScenes()->loadSceneFromPosition(kCarGreenSleeping, 76);
 	else
@@ -1358,7 +1384,7 @@ label_callback_4:
 		}
 
 		if (ENTITY_PARAM(0, 3)) {
-			getSoundQueue()->resetState();
+			getSoundQueue()->startAmbient();
 			ENTITY_PARAM(0, 3) = 0;
 		} else if (!params->param2 && !params->param3) {
 			getSound()->playSound(kEntityChapters, "ZFX1001");
@@ -1396,16 +1422,16 @@ label_callback_4:
 
 		case 5:
 			if (getSoundQueue()->isBuffered(kEntityChapters))
-				getSoundQueue()->removeFromQueue(kEntityChapters);
+				getSoundQueue()->stop(kEntityChapters);
 
 			getAction()->playAnimation(kEventTrainExplosionBridge);
 			getLogic()->gameOver(kSavegameTypeIndex, 1, kSceneNone, true);
 			break;
 
 		case 6:
-			getSoundQueue()->processEntries();
+			getSoundQueue()->endAmbient();
 			getAction()->playAnimation(kEventTylerCastleDream);
-			getSoundQueue()->resetState();
+			getSoundQueue()->startAmbient();
 
 			getProgress().field_18 = 1;
 
@@ -1457,7 +1483,7 @@ label_callback_4:
 
 		case 11:
 			getScenes()->loadSceneFromPosition(kCarRedSleeping, 74);
-			getSound()->playSound(kEntityTrain, "ZFX4001", kFlagDefault);
+			getSound()->playSound(kEntityTrain, "ZFX4001", kVolumeFull);
 			getLogic()->gameOver(kSavegameTypeIndex, 1, kSceneNone, true);
 			break;
 		}
@@ -1504,15 +1530,20 @@ label_callback_4:
 		params->param1 = 1;
 
 		if (ENTITY_PARAM(0, 2) || ENTITY_PARAM(0, 3)) {
-			getSoundQueue()->removeFromQueue(kEntityChapters);
+			getSoundQueue()->stop(kEntityChapters);
 
 			ENTITY_PARAM(0, 2) = 0;
 			ENTITY_PARAM(0, 3) = 0;
 		}
 
-		getSound()->playSound(kEntityPlayer, "MUS008", kFlagDefault);
+		// BUG: the original game fades to black screen twice, before MUS008 starts playing
+		// (the second call just makes a delay)
+
+		getSound()->playSound(kEntityPlayer, "MUS008", kVolumeFull);
 		getInventory()->unselectItem();
 
+		// TODO: fade to black screen
+
 		while (getSoundQueue()->isBuffered("MUS008"))
 			getSoundQueue()->updateQueue();
 
@@ -1562,7 +1593,7 @@ label_callback_4:
 		getState()->time = kTime2520000;
 
 		if (getSoundQueue()->isBuffered(kEntityChapters))
-			getSoundQueue()->removeFromQueue(kEntityChapters);
+			getSoundQueue()->stop(kEntityChapters);
 
 		getEntities()->clearSequences(kEntityChapters);
 		getInventory()->removeItem(kItemTelegram);
@@ -1575,9 +1606,9 @@ label_callback_4:
 
 	case kAction201959744:
 		if (getSoundQueue()->isBuffered(kEntityChapters))
-			getSoundQueue()->removeFromQueue(kEntityChapters);
+			getSoundQueue()->stop(kEntityChapters);
 
-		getSound()->playSound(kEntityTrain, "ZFX4001", kFlagDefault);
+		getSound()->playSound(kEntityTrain, "ZFX4001", kVolumeFull);
 
 		getLogic()->gameOver(kSavegameTypeIndex, 0, kSceneNone, true);
 		break;
@@ -1683,11 +1714,13 @@ IMPLEMENT_FUNCTION(21, Chapters, chapter5Init)
 		getObjects()->updateModel(kObjectRestaurantCar, kObjectModel2);
 
 		if (ENTITY_PARAM(0, 2) || ENTITY_PARAM(0, 3)) {
-			getSoundQueue()->removeFromQueue(kEntityChapters);
+			getSoundQueue()->stop(kEntityChapters);
 			ENTITY_PARAM(0, 2) = 0;
 			ENTITY_PARAM(0, 3) = 0;
 		}
 
+		// TODO: fade to black screen
+
 		getScenes()->loadSceneFromPosition(kCarBaggageRear, 95);
 		getInventory()->show();
 
@@ -1713,8 +1746,8 @@ IMPLEMENT_FUNCTION(22, Chapters, chapter5Handler)
 			params->param2 = 1;
 
 			if (!getProgress().isNightTime) {
-				getSound()->playSound(kEntityChapters, "ARRIVE", kFlag8);
-				getSoundQueue()->processEntries();
+				getSound()->playSound(kEntityChapters, "ARRIVE", kVolume8);
+				getSoundQueue()->endAmbient();
 			}
 		}
 
@@ -1722,8 +1755,8 @@ IMPLEMENT_FUNCTION(22, Chapters, chapter5Handler)
 			params->param3 = 1;
 
 			if (!getEvent(kEventLocomotiveMilosDay) && !getEvent(kEventLocomotiveMilosNight)) {
-				getSound()->playSound(kEntityChapters, "ARRIVE", kFlag8);
-				getSoundQueue()->processEntries();
+				getSound()->playSound(kEntityChapters, "ARRIVE", kVolume8);
+				getSoundQueue()->endAmbient();
 			}
 		}
 		break;
@@ -1733,7 +1766,7 @@ IMPLEMENT_FUNCTION(22, Chapters, chapter5Handler)
 			setCallback(1);
 			setup_savegame(kSavegameTypeEvent, kEventTrainStopped);
 		} else {
-			getLogic()->gameOver(kSavegameTypeTime, kTimeTrainStopped2, kSceneGameOverTrainStopped, true);
+			getLogic()->gameOver(kSavegameTypeTime, kTime2934000, kSceneGameOverTrainStopped, true);
 		}
 		break;
 
@@ -1753,7 +1786,7 @@ IMPLEMENT_FUNCTION(22, Chapters, chapter5Handler)
 		getState()->time = kTime2916000;
 
 		if (getSoundQueue()->isBuffered(kEntityChapters))
-			getSoundQueue()->removeFromQueue(kEntityChapters);
+			getSoundQueue()->stop(kEntityChapters);
 		break;
 	}
 IMPLEMENT_FUNCTION_END
@@ -1768,7 +1801,7 @@ void Chapters::enterExitStation(const SavePoint &savepoint, bool isEnteringStati
 			return;
 		}
 
-		getSoundQueue()->removeFromQueue(kEntityChapters);
+		getSoundQueue()->stop(kEntityChapters);
 
 		if (!ENTITY_PARAM(0, 2)) {
 			if (ENTITY_PARAM(0, 3))
@@ -1835,8 +1868,8 @@ void Chapters::enterExitStation(const SavePoint &savepoint, bool isEnteringStati
 void Chapters::enterExitHelper(bool isEnteringStation) {
 	EXPOSE_PARAMS(EntityData::EntityParametersSIIS);
 
-	getSound()->playSound(kEntityChapters, isEnteringStation ? "ARRIVE" : "DEPART", kFlag8);
-	getSoundQueue()->processEntries();
+	getSound()->playSound(kEntityChapters, isEnteringStation ? "ARRIVE" : "DEPART", kVolume8);
+	getSoundQueue()->endAmbient();
 
 	getObjects()->update(kObjectHandleOutsideLeft, kEntityPlayer, kObjectLocation1, kCursorNormal, isEnteringStation ? kCursorNormal : kCursorHand);
 	getObjects()->update(kObjectHandleOutsideRight, kEntityPlayer, kObjectLocation1, kCursorNormal, isEnteringStation ? kCursorNormal : kCursorHand);
@@ -1855,7 +1888,7 @@ void Chapters::enterExitHelper(bool isEnteringStation) {
 }
 
 void Chapters::playSteam() const {
-	getSoundQueue()->resetState();
+	getSoundQueue()->startAmbient();
 	getSound()->playSteam((CityIndex)ENTITY_PARAM(0, 4));
 	ENTITY_PARAM(0, 2) = 0;
 }
