@@ -27,6 +27,7 @@
 #include "lilliput/script.h"
 #include "lilliput/sound.h"
 #include "lilliput/stream.h"
+#include "lilliput/detection.h"
 
 #include "common/file.h"
 #include "common/rect.h"
@@ -54,12 +55,6 @@ namespace Lilliput {
 
 static const int kSavegameVersion = 1;
 
-enum GameType {
-	kGameTypeNone  = 0,
-	kGameTypeRobin,
-	kGameTypeRome
-};
-
 enum LilliputDebugChannels {
 	kDebugEngine    = 1 << 0,
 	kDebugScript    = 1 << 1,
