@@ -31,10 +31,7 @@
 #include "lure/surface.h"
 #include "common/endian.h"
 #include "common/config-manager.h"
-
-#ifdef USE_TTS
 #include "common/text-to-speech.h"
-#endif
 
 namespace Lure {
 
@@ -472,21 +469,15 @@ Surface *Surface::newDialog(uint16 width, uint8 numLines, const char **lines, bo
 
 	Surface *s = new Surface(width, size.y);
 	s->createDialog();
-#ifdef USE_TTS
 	Common::String text;
-#endif
 
 	uint16 yP = Surface::textY();
 	for (uint8 ctr = 0; ctr < numLines; ++ctr) {
-#ifdef USE_TTS
 		text += lines[ctr];
-#endif
 		s->writeString(Surface::textX(), yP, lines[ctr], true, color, varLength);
 		yP += squashedLines ? FONT_HEIGHT - 1 : FONT_HEIGHT;
 	}
 
-
-#ifdef USE_TTS
 	if (ConfMan.getBool("tts_narrator")) {
 		Common::TextToSpeechManager *ttsMan = g_system->getTextToSpeechManager();
 		if (ttsMan != nullptr) {
@@ -494,7 +485,6 @@ Surface *Surface::newDialog(uint16 width, uint8 numLines, const char **lines, bo
 			ttsMan->say(text.c_str());
 		}
 	}
-#endif
 
 	return s;
 }
@@ -1146,7 +1136,7 @@ bool RestartRestoreDialog::show() {
 	LureEngine &engine = LureEngine::getReference();
 
 	Sound.killSounds();
-	Sound.musicInterface_Play(60, 0);
+	Sound.musicInterface_Play(188, true);
 	mouse.setCursorNum(CURSOR_ARROW);
 
 	// See if there are any savegames that can be restored
@@ -1435,4 +1425,56 @@ void CopyProtectionDialog::chooseCharacters() {
 	screen.update();
 }
 
+AudioInitIcon::AudioInitIcon() : _visible(false) {
+	if (LureEngine::getReference().isEGA()) {
+		// The icon is not shown on EGA
+		_iconSurface = 0;
+	} else {
+		// Load icon
+		_iconSurface = new Surface(Disk::getReference().getEntry(AUDIO_INIT_ICON_RESOURCE_ID), 14, 14);
+
+		Screen &screen = Screen::getReference();
+
+		// Add the colors needed for displaying the icon to the current palette
+		Palette combinedPalette;
+		Palette defaultPalette(GAME_PALETTE_RESOURCE_ID);
+		combinedPalette.palette()->copyFrom(screen.getPalette().palette(), 0, 0, 4 * 0xF8);
+		combinedPalette.palette()->copyFrom(defaultPalette.palette(), 4 * 0xF8, 4 * 0xF8, 4 * 6);
+		screen.setPalette(&combinedPalette);
+	}
+}
+
+AudioInitIcon::~AudioInitIcon() {
+	if (_iconSurface)
+		delete _iconSurface;
+}
+
+void AudioInitIcon::show() {
+	if (!LureEngine::getReference().isEGA()) {
+		Screen &screen = Screen::getReference();
+
+		_iconSurface->copyTo(&screen.screen(), 0, 185);
+		screen.update();
+		_visible = true;
+	}
+}
+
+void AudioInitIcon::hide() {
+	if (!LureEngine::getReference().isEGA()) {
+		Screen &screen = Screen::getReference();
+
+		screen.screen().fillRect(Common::Rect(0, 185, 14, 199), 0);
+		screen.update();
+		_visible = false;
+	}
+}
+
+void AudioInitIcon::toggleVisibility() {
+	if (_visible) {
+		hide();
+	} else {
+		show();
+	}
+}
+
 } // End of namespace Lure
