@@ -335,9 +335,13 @@ public:
 		composeSurface->clear(kColorGreen);
 
 		const Graphics::Font *font = &_gui->getCurrentFont();
-		uint y = target->h - font->getFontHeight();
+		int y = target->h - font->getFontHeight();
 		for (uint i = _scrollPos; i != 0; i--) {
 			font->drawString(target, _lines[i], textOffset, y, font->getStringWidth(_lines[i]), kColorBlack);
+
+			if (y < font->getFontHeight())	// Do not draw off-screen
+				break;
+
 			y -= font->getFontHeight();
 		}
 
