@@ -24,6 +24,7 @@
 #define MADE_MADE_H
 
 #include "made/sound.h"
+#include "made/detection.h"
 
 #include "engines/engine.h"
 
@@ -42,24 +43,8 @@
  */
 namespace Made {
 
-enum MadeGameID {
-	GID_RTZ		= 0,
-	GID_MANHOLE	= 1,
-	GID_LGOP2	= 2,
-	GID_RODNEY	= 3
-};
-
-enum MadeGameFeatures {
-	GF_DEMO				= 1 << 0,
-	GF_CD				= 1 << 1,
-	GF_CD_COMPRESSED	= 1 << 2,
-	GF_FLOPPY			= 1 << 3
-};
-
 const uint32 kTimerResolution = 40;
 
-struct MadeGameDescription;
-
 class ResourceReader;
 class PmvPlayer;
 class Screen;
