@@ -20,13 +20,12 @@
  *
  */
 
+#ifdef ENABLE_MADSV2
+
 #ifndef MADS_PHANTOM_SCENES5_H
 #define MADS_PHANTOM_SCENES5_H
 
-#include "common/scummsys.h"
 #include "common/serializer.h"
-#include "mads/game.h"
-#include "mads/scene.h"
 #include "mads/phantom/phantom_scenes.h"
 
 namespace MADS {
@@ -60,13 +59,13 @@ private:
 
 public:
 	Scene501(MADSEngine *vm);
-	virtual void synchronize(Common::Serializer &s);
+	void synchronize(Common::Serializer &s) override;
 
-	virtual void setup();
-	virtual void enter();
-	virtual void step();
-	virtual void preActions();
-	virtual void actions();
+	void setup() override;
+	void enter() override;
+	void step() override;
+	void preActions() override;
+	void actions() override;
 };
 
 class Scene502 : public Scene5xx {
@@ -103,15 +102,15 @@ private:
 
 public:
 	Scene502(MADSEngine *vm);
-	~Scene502();
+	~Scene502() override;
 
-	virtual void synchronize(Common::Serializer &s);
+	void synchronize(Common::Serializer &s) override;
 
-	virtual void setup();
-	virtual void enter();
-	virtual void step();
-	virtual void preActions();
-	virtual void actions();
+	void setup() override;
+	void enter() override;
+	void step() override;
+	void preActions() override;
+	void actions() override;
 };
 
 class Scene504 : public Scene5xx {
@@ -152,13 +151,13 @@ private:
 
 public:
 	Scene504(MADSEngine *vm);
-	virtual void synchronize(Common::Serializer &s);
+	void synchronize(Common::Serializer &s) override;
 
-	virtual void setup();
-	virtual void enter();
-	virtual void step();
-	virtual void preActions();
-	virtual void actions();
+	void setup() override;
+	void enter() override;
+	void step() override;
+	void preActions() override;
+	void actions() override;
 };
 
 class Scene505 : public Scene5xx {
@@ -187,13 +186,13 @@ private:
 
 public:
 	Scene505(MADSEngine *vm);
-	virtual void synchronize(Common::Serializer &s);
+	void synchronize(Common::Serializer &s) override;
 
-	virtual void setup();
-	virtual void enter();
-	virtual void step();
-	virtual void preActions();
-	virtual void actions();
+	void setup() override;
+	void enter() override;
+	void step() override;
+	void preActions() override;
+	void actions() override;
 };
 
 class Scene506 : public Scene5xx {
@@ -204,16 +203,18 @@ private:
 
 public:
 	Scene506(MADSEngine *vm);
-	virtual void synchronize(Common::Serializer &s);
+	void synchronize(Common::Serializer &s) override;
 
-	virtual void setup();
-	virtual void enter();
-	virtual void step();
-	virtual void preActions();
-	virtual void actions();
+	void setup() override;
+	void enter() override;
+	void step() override;
+	void preActions() override;
+	void actions() override;
 };
 
 } // End of namespace Phantom
 } // End of namespace MADS
 
 #endif /* MADS_PHANTOM_SCENES5_H */
+
+#endif
