@@ -190,8 +190,6 @@ private:
 	 * Draw a UI textual element
 	 */
 	void writeVocab(ScrCategory category, int id);
-
-	void updateRect(const Common::Rect &bounds);
 public:
 	MSurface _surface;
 	UISlots _uiSlots;
@@ -223,7 +221,7 @@ public:
 	/**
 	* Loads an interface from a specified resource
 	*/
-	virtual void load(const Common::String &resName);
+	void load(const Common::String &resName) override;
 
 	/**
 	* Set up the interface
@@ -240,7 +238,7 @@ public:
 	* @param destPos		Destination position to draw in current surface
 	* @param transparencyIndex	Transparency color
 	*/
-	void mergeFrom(MSurface *src, const Common::Rect &srcBounds, const Common::Point &destPos,
+	void mergeFrom(BaseSurface *src, const Common::Rect &srcBounds, const Common::Point &destPos,
 		int transparencyIndex = -1);
 
 	/**
