@@ -21,6 +21,7 @@
  */
 
 #include "mohawk/console.h"
+#include "mohawk/cursors.h"
 #include "mohawk/livingbooks.h"
 #include "mohawk/resource.h"
 #include "mohawk/sound.h"
@@ -327,7 +328,7 @@ bool MystConsole::Cmd_Resources(int argc, const char **argv) {
 }
 
 bool MystConsole::Cmd_QuickTest(int argc, const char **argv) {
-	_vm->pauseEngine(false);
+	_debugPauseToken.clear();
 
 	// Go through all the ages, all the views and click random stuff
 	for (uint i = 0; i < ARRAYSIZE(mystStackNames); i++) {
@@ -365,7 +366,7 @@ bool MystConsole::Cmd_QuickTest(int argc, const char **argv) {
 		}
 	}
 
-	_vm->pauseEngine(true);
+	_debugPauseToken = _vm->pauseEngine();
 	return true;
 }
 
@@ -689,7 +690,7 @@ bool RivenConsole::Cmd_SliderState(int argc, const char **argv) {
 }
 
 bool RivenConsole::Cmd_QuickTest(int argc, const char **argv) {
-	_vm->pauseEngine(false);
+	_debugPauseToken.clear();
 
 	// Go through all the stacks, all the cards and click random stuff
 	for (uint16 stackId = kStackFirst; stackId <= kStackLast; stackId++) {
@@ -743,7 +744,7 @@ bool RivenConsole::Cmd_QuickTest(int argc, const char **argv) {
 		}
 	}
 
-	_vm->pauseEngine(true);
+	_debugPauseToken = _vm->pauseEngine();
 	return true;
 }
 
@@ -754,6 +755,7 @@ LivingBooksConsole::LivingBooksConsole(MohawkEngine_LivingBooks *vm) : GUI::Debu
 	registerCmd("stopSound",			WRAP_METHOD(LivingBooksConsole, Cmd_StopSound));
 	registerCmd("drawImage",			WRAP_METHOD(LivingBooksConsole, Cmd_DrawImage));
 	registerCmd("changePage",			WRAP_METHOD(LivingBooksConsole, Cmd_ChangePage));
+	registerCmd("changeCursor",			WRAP_METHOD(LivingBooksConsole, Cmd_ChangeCursor));
 }
 
 LivingBooksConsole::~LivingBooksConsole() {
@@ -811,6 +813,16 @@ bool LivingBooksConsole::Cmd_ChangePage(int argc, const char **argv) {
 	return true;
 }
 
+bool LivingBooksConsole::Cmd_ChangeCursor(int argc, const char **argv) {
+	if (argc == 1) {
+		debugPrintf("Usage: changeCursor <value>\n");
+		return true;
+	}
+
+	_vm->_cursor->setCursor((uint16)atoi(argv[1]));
+	return true;
+}
+
 #ifdef ENABLE_CSTIME
 
 CSTimeConsole::CSTimeConsole(MohawkEngine_CSTime *vm) : GUI::Debugger(), _vm(vm) {
