@@ -338,6 +338,24 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
+	// Myst Masterpiece Edition
+	// Spanish Fan Translation 3.02c
+	// Bugreport #11927
+	{
+		{
+			"myst",
+			"Masterpiece Edition",
+			AD_ENTRY1s("myst.dat", "7552dd490861dc7e6307e1ede80220fd", 76640997),
+			Common::ES_ESP,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			GUI_OPTIONS_MYST_ME
+		},
+		GType_MYST,
+		GF_ME,
+		0,
+	},
+
 	// Myst Masterpiece Edition - 25th Anniversary
 	// Repacked by the ScummVM team
 	{
@@ -487,7 +505,6 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
-
 	// Riven: The Sequel to Myst
 	// Version 1.0J (5CD) - Japanese
 	// From sev
@@ -506,6 +523,24 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
+	// Riven: The Sequel to Myst
+	// Version 1.0 (5CD) - Brazilian
+	// from trembyle
+	{
+		{
+			"riven",
+			"",
+			AD_ENTRY1s("a_Data.MHK", "49fe3003d6da02b03c5c1f6028a7f719", 9892372),
+			Common::PT_BRA,
+			Common::kPlatformWindows,
+			ADGF_DROPPLATFORM,
+			GUI_OPTIONS_RIVEN
+		},
+		GType_RIVEN,
+		0,
+		0,
+	},
+
 	// Riven: The Sequel to Myst
 	// Version 1.? (DVD, From "Myst 10th Anniversary Edition")
 	// From Clone2727
@@ -724,7 +759,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"harryhh",
@@ -740,7 +775,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"harryhh",
@@ -756,7 +791,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"harryhh",
@@ -789,8 +824,25 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"HARRY.EXE"
 	},
 
+	// English / Spanish demo
+	// from einstein95, bug #12849
+	{
+		{
+			"harryhh",
+			"Demo English/Spanish",
+			AD_ENTRY1s("HARRY.512", "a0c97d80ab8957f61be1a41fdd74386e", 709),
+			Common::UNK_LANG,
+			Common::kPlatformWindows,
+			ADGF_DEMO,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV1,
+		0,
+		"HARRY.EXE"
+	},
+
 	// part of "Super Living Books" compilation
-	// from rgemini, bug #3309343
+	// from rgemini, bug #5726
 	{
 		{
 			"harryhh",
@@ -836,7 +888,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug #3309306
+	// From afholman in bug #5723
 	{
 		{
 			"lbsampler",
@@ -913,6 +965,21 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
+	{ // Version 2.0, has lots of additional livingbooks_code
+		{
+			"greeneggs",
+			_s("Missing game code"), // Reason for being unsupported
+			AD_ENTRY1s("Outline", "bca2320b800f616118c2be239628a964", 3022),
+			Common::EN_ANY,
+			Common::kPlatformMacintosh,
+			ADGF_UNSUPPORTED,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV4,
+		0,
+		0
+	},
+
 	{
 		{
 			"greeneggs",
@@ -989,6 +1056,36 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
+	{ // Version 1.0, built on unsupported LivingBooks version
+		{
+			"seussps",
+			_s("Missing game code"), // Reason for being unsupported
+			AD_ENTRY1s("SEUSS_PS.CFG", "627afcfa170460f0e2b7ed4fa734361c", 1439),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_UNSUPPORTED,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV2, // Most probably it is incorrect
+		0,
+		0
+	},
+
+	{ // Bugreport #11184, version 2.0
+		{
+			"seussps",
+			_s("Missing game code"), // Reason for being unsupported
+			AD_ENTRY1("SEUSS_PS.CFG", "a2fc5596e6f1511d17acbc687e27a4ac"),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_UNSUPPORTED,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV2, // Most probably it is incorrect
+		0,
+		0
+	},
+
 	{
 		{
 			"tortoise",
@@ -1005,7 +1102,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 	},
 
 	// part of "Super Living Books" compilation
-	// from rgemini, bug #3309343
+	// from rgemini, bug #5726
 	{
 		{
 			"tortoise",
@@ -1021,7 +1118,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"TORTOISE.EXE"
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"tortoise",
@@ -1037,7 +1134,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
-	// From Torsten in bug#3422652
+	// From Torsten in bug#5876
 	{
 		{
 			"tortoise",
@@ -1053,7 +1150,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
-	// Tortoise and the Hare Hebrew variant - From georgeqgreg on bug #3441928
+	// Tortoise and the Hare Hebrew variant - From georgeqgreg on bug #5904
 	{
 		{
 			"tortoise",
@@ -1069,7 +1166,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"tortoise",
@@ -1085,7 +1182,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
-	// From Torsten in bug#3422652
+	// From Torsten in bug#5876
 	{
 		{
 			"tortoise",
@@ -1101,7 +1198,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"tortoise",
@@ -1117,7 +1214,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
-	// From Torsten in bug#3422652
+	// From Torsten in bug#5876
 	{
 		{
 			"tortoise",
@@ -1133,6 +1230,22 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
+	// Macintosh version. Bugreport #12828
+	{
+		{
+			"tortoise",
+			"",
+			AD_ENTRY1s("BookOutline", "f4c162ca66197eedc3b676372bca3929", 2038),
+			Common::EN_ANY,
+			Common::kPlatformMacintosh,
+			ADGF_NO_FLAGS,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0
+	},
+
 	// From the Mac CD "La Tartaruga e la Lepre" (The Turtle and the Hare) [Italian, English]
 	{
 		{
@@ -1179,7 +1292,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"TORTOISE.EXE"
 	},
 
-	// From Scarlatti in bug #3275626
+	// From Scarlatti in bug #5636
 	{
 		{
 			"tortoise",
@@ -1226,7 +1339,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 	},
 
 	// part of "Super Living Books" compilation
-	// from rgemini, bug #3309343
+	// from rgemini, bug #5726
 	{
 		{
 			"arthur",
@@ -1242,7 +1355,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"ARTHUR.EXE"
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"arthur",
@@ -1258,7 +1371,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"Arthur's Teacher Trouble"
 	},
 
-	// From darthbo in bug#3301791
+	// From darthbo in bug#5699
 	{
 		{
 			"arthur",
@@ -1304,7 +1417,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"ARTHUR.EXE"
 	},
 
-	// From Scarlatti in bug #3275626
+	// From Scarlatti in bug #5636
 	{
 		{
 			"arthur",
@@ -1350,6 +1463,22 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"Living Books Player"
 	},
 
+	// English/Spanish demo. From einstein95, bugreport #12829
+	{
+		{
+			"arthur",
+			"Demo English/Spanish",
+			AD_ENTRY1s("Bookoutline", "3e6335865b4041be934d2e0c8ee75af2", 645),
+			Common::UNK_LANG,
+			Common::kPlatformMacintosh,
+			ADGF_DEMO,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV1,
+		GF_DEMO | GF_LB_10,
+		"Arthur's Teacher Trouble"
+	},
+
 	// Just Grandma and Me 2.0
 	// From pacifist
 	{
@@ -1385,7 +1514,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 	},
 
 	// Just Grandma and Me 2.0 Macintosh
-	// From aluff in bug #3461368
+	// From aluff in bug #5926
 	{
 		{
 			"grandma",
@@ -1435,7 +1564,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 	},
 
 	// Just Grandma and Me 1.1 Mac
-	// From eisnerguy1 in bug#3610725
+	// From eisnerguy1 in bug#6274
 	{
 		{
 			"grandma",
@@ -1451,7 +1580,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// from jjnryan in bug #3389857
+	// from jjnryan in bug #5827
 	{
 		{
 			"grandma",
@@ -1467,7 +1596,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"GRANDMA.EXE"
 	},
 
-	// From Torsten in bug#3422652
+	// From Torsten in bug#5876
 	{
 		{
 			"grandma",
@@ -1483,7 +1612,24 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
-	// From Torsten in bug#3422652
+	// From einstein95 in bug#12830
+	// English/Japanese/Spanish demo
+	{
+		{
+			"grandma",
+			"Demo v1.12 English/Japanese/Spanish",
+			AD_ENTRY1s("BookOutline", "577c2c6be1b76c38d83446e303664708", 804),
+			Common::UNK_LANG,
+			Common::kPlatformMacintosh,
+			ADGF_DEMO,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
+	// From Torsten in bug#5876
 	{
 		{
 			"grandma",
@@ -1499,7 +1645,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
-	// From Torsten in bug#3422652
+	// From Torsten in bug#5876
 	{
 		{
 			"grandma",
@@ -1545,7 +1691,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"GRANDMA.EXE"
 	},
 
-	// From Scarlatti in bug #3275626
+	// From Scarlatti in bug #5636
 	{
 		{
 			"grandma",
@@ -1561,6 +1707,22 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"GRANDMA.EXE"
 	},
 
+	// From ajshell1 in bug #11576
+	{
+		{
+			"grandma",
+			"Demo",
+			AD_ENTRY1s("GRANDMA.512", "1f2cb06795dddc20bedbd711fb57338e", 869),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_DEMO,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV1,
+		GF_DEMO,
+		"GRANDMA.EXE"
+	},
+
 	// From the Mac CD "La Tartaruga e la Lepre" (The Turtle and the Hare) [Italian, English]
 	{
 		{
@@ -1624,7 +1786,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"RUFF.EXE"
 	},
 
-	// From aluff in bug#3307785
+	// From aluff in bug#5715
 	{
 		{
 			"ruff",
@@ -1655,7 +1817,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"RUFF.EXE"
 	},
 
-	// From Scarlatti in bug #3275626
+	// From Scarlatti in bug #5636
 	{
 		{
 			"ruff",
@@ -1686,7 +1848,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"Living Books Player"
 	},
 
-	// From aluff in bug#3309981
+	// From aluff in bug#5731
 	{
 		{
 			"newkid",
@@ -1703,7 +1865,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 	},
 
 	// part of "Super Living Books" compilation
-	// from rgemini, bug #3309343
+	// from rgemini, bug #5726
 	{
 		{
 			"newkid",
@@ -1719,7 +1881,23 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"NEWKID.EXE"
 	},
 
-	// From aluff in bug#3309981
+	// Bugreport #11003
+	{
+		{
+			"newkid",
+			"",
+			AD_ENTRY1s("NEWKID.512", "5b643345af12a9ecee7b47768634d844", 3245),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV1,
+		0,
+		"NEWKID.EXE"
+	},
+
+	// From aluff in bug#5731
 	{
 		{
 			"newkid",
@@ -1765,7 +1943,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"NEWKID.EXE"
 	},
 
-	// From Scarlatti in bug #3275626
+	// From Scarlatti in bug #5636
 	{
 		{
 			"newkid",
@@ -1781,6 +1959,22 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"NEWKID.EXE"
 	},
 
+	// From ajshell1 in bug #11577
+	{
+		{
+			"newkid",
+			"Demo",
+			AD_ENTRY1s("NEWKID.512", "876a9f31527f4b3bb38d79a2e1206d21", 563),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_DEMO,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV1,
+		GF_DEMO,
+		"NEWKID.EXE"
+	},
+
 	{
 		{
 			"newkid",
@@ -1796,7 +1990,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"Living Books Player"
 	},
 
-	{
+	{ // November release
 		{
 			"arthurrace",
 			"",
@@ -1815,7 +2009,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 	{
 		{
 			"arthurrace",
-			"",
+			"32-bit",
 			AD_ENTRY1("RACE32.LB", "292a05bc48c1dd9583821a4181a02ef2"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
@@ -1827,6 +2021,37 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
+	{ // December release, marked as 1.0. Bugreport #11458
+		{
+			"arthurrace",
+			"",
+			AD_ENTRY1s("RACE.LB", "4d4347a010802c1e34e30a3d899546a7", 3155),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_UNSTABLE,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV3,
+		0,
+		0
+	},
+
+	// 32-bit version of the previous entry
+	{
+		{
+			"arthurrace",
+			"32-bit",
+			AD_ENTRY1s("RACE32.LB", "badea47f88f0ee96dfc55c9120db5751", 3153),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_UNSTABLE,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV3,
+		0,
+		0
+	},
+
 	{
 		{
 			"arthurrace",
@@ -1842,7 +2067,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From zerep in bug #3287894
+	// From zerep in bug #5647
 	{
 		{
 			"arthurbday",
@@ -1874,7 +2099,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"BIRTHDAY.EXE"
 	},
 
-	// From aluff in bug#3309936
+	// From aluff in bug#5729
 	{
 		{
 			"arthurbday",
@@ -1907,7 +2132,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
-	// From Torsten in bug#3422652
+	// From Torsten in bug#5876
 	{
 		{
 			"arthurbday",
@@ -1923,7 +2148,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
-	// From Torsten in bug#3422652
+	// From Torsten in bug#5876
 	{
 		{
 			"arthurbday",
@@ -1939,7 +2164,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
-	// From Torsten in bug#3422652
+	// From Torsten in bug#5876
 	{
 		{
 			"arthurbday",
@@ -1956,7 +2181,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 	},
 
 	// Arthur Birthday (English) Version 2.0 Windows(R) August 8, 1997
-	// From jacecen in bug #3413119
+	// From jacecen in bug #5847
 	{
 		{
 			"arthurbday",
@@ -1973,7 +2198,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 	},
 
 	// Arthur Birthday (English) Version 2.0 Macintosh
-	// From aluff in bug #3461368
+	// From aluff in bug #5926
 	{
 		{
 			"arthurbday",
@@ -2004,7 +2229,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"BIRTHDAY.EXE"
 	},
 
-	// From Scarlatti in bug #3275626
+	// From Scarlatti in bug #5636
 	{
 		{
 			"arthurbday",
@@ -2065,7 +2290,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"Little Monster at School"
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"lilmonster",
@@ -2081,7 +2306,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"lilmonster",
@@ -2097,7 +2322,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"lilmonster",
@@ -2113,7 +2338,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"lilmonster",
@@ -2145,7 +2370,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"lilmonster",
@@ -2161,7 +2386,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"lilmonster",
@@ -2177,7 +2402,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From Scarlatti in bug #3275626
+	// From Scarlatti in bug #5636
 	{
 		{
 			"lilmonster",
@@ -2287,6 +2512,24 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
+	// Rugrats Adventure Game
+	// Spanish Windows
+	// Reported in #12389
+	{
+		{
+			"rugrats",
+			"",
+			AD_ENTRY1s("outline", "a8f4ec8e88b028c2452c1aa84b1a9c51", 6546),
+			Common::ES_ESP,
+			Common::kPlatformWindows,
+			ADGF_UNSTABLE,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV4,
+		0,
+		0
+	},
+
 	// Rugrats Adventure Game
 	// English Windows Demo
 	// From GeorgeQGreg (Rugrats Movie Soundtrack)
@@ -2412,7 +2655,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 	},
 
 	// The Berenstain Bears Get in a Fight (English and Spanish) Version 1.0 1995
-	// From jacecen in bug #3413119
+	// From jacecen in bug #5847
 	{
 		{
 			"bearfight",
@@ -2443,7 +2686,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"Bears Get in a Fight"
 	},
 
-	// From bkennimer in bug #3284930
+	// From bkennimer in bug #5645
 	{
 		{
 			"beardark",
@@ -2459,7 +2702,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From bkennimer in bug #3284930
+	// From bkennimer in bug #5645
 	// 32-bit version of the previous entry
 	{
 		{
@@ -2476,7 +2719,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From bkennimer in bug #3284930
+	// From bkennimer in bug #5645
 	{
 		{
 			"beardark",
@@ -2492,7 +2735,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From aluff in bug #3461368
+	// From aluff in bug #5926
 	{
 		{
 			"beardark",
@@ -2572,7 +2815,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From aluff in bug#3306722
+	// From aluff in bug#5711
 	{
 		{
 			"stellaluna",
@@ -2588,7 +2831,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From aluff in bug#3306722
+	// From aluff in bug#5711
 	{
 		{
 			"stellaluna",
@@ -2621,7 +2864,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From aluff in bug#3309934
+	// From aluff in bug#5728
 	{
 		{
 			"sheila",
@@ -2637,7 +2880,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"sheila",
@@ -2653,7 +2896,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"sheila",
@@ -2669,7 +2912,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"sheila",
@@ -2685,7 +2928,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"sheila",
@@ -2701,7 +2944,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"sheila",
@@ -2717,7 +2960,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
-	// From afholman in bug#3309308
+	// From afholman in bug#5724
 	{
 		{
 			"sheila",
@@ -2751,6 +2994,70 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
+	// From sev
+	{
+		{
+			"create",
+			"",
+			AD_ENTRY1s("CREATE.LB", "8a94e13093dd3e2f58c220a1f265a7be", 1217),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
+	// From sev
+	{
+		{
+			"create",
+			"Demo",
+			AD_ENTRY1s("CREATED.LB", "86165d80189815ada2abd67e55258486", 826),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_DEMO,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
+	// From sev
+	{
+		{
+			"daniel",
+			"",
+			AD_ENTRY1s("DANIEL.LB", "cdea21d55f0ead70c7990d2f1cfbc160", 1300),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
+	// From sev
+	{
+		{
+			"daniel",
+			"Demo",
+			AD_ENTRY1s("DANIELD.LB", "4220631d9f677f694fa9d59a7c242dbe", 651),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_DEMO,
+			GUIO1(GUIO_NOASPECT)
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
 	{ AD_TABLE_END_MARKER, 0, 0, 0 }
 };
 
