@@ -25,6 +25,7 @@
 
 #include "mohawk/console.h"
 #include "mohawk/mohawk.h"
+#include "mohawk/myst_actions.h"
 #include "mohawk/resource_cache.h"
 #include "mohawk/video.h"
 
@@ -41,7 +42,8 @@ class MystGraphics;
 class MystScriptParser;
 class MystConsole;
 class MystGameState;
-class MystOptionsDialog;
+struct MystLanguage;
+class MystOptionsWidget;
 class MystSound;
 class MystArea;
 class MystAreaImageSwitch;
@@ -145,6 +147,7 @@ public:
 	uint16 getMainCursor() { return _mainCursor; }
 	void refreshCursor();
 	bool wait(uint32 duration, bool skippable = false);
+	bool addCdRomDelay;
 
 	/** Update the game state according to events and update the screen */
 	void doFrame();
@@ -178,44 +181,51 @@ public:
 
 	void playSoundBlocking(uint16 id);
 
-	GUI::Debugger *getDebugger() override { return _console; }
-
 	/**
 	 * Is the game currently interactive
 	 *
 	 * When the game is interactive, the user can interact with the game world
 	 * and perform other operations such as loading saved games, ...
 	 */
-	bool isInteractive();
+	bool isInteractive() const;
+	bool isGameStarted() const;
 	bool canLoadGameStateCurrently() override;
 	bool canSaveGameStateCurrently() override;
 	Common::Error loadGameState(int slot) override;
-	Common::Error saveGameState(int slot, const Common::String &desc) override;
-	void tryAutoSaving();
+	Common::Error saveGameState(int slot, const Common::String &desc, bool isAutosave = false) override;
+	Common::String getSaveStateName(int slot) const override {
+		return Common::String::format("myst-%03d.mys", slot);
+	}
+
 	bool hasFeature(EngineFeature f) const override;
 
+	void applyGameSettings() override;
+	static Common::Array<Common::Keymap *> initKeymaps(const char *target);
+
 	void resumeFromMainMenu();
 
-	void runLoadDialog();
-	void runSaveDialog();
 	void runOptionsDialog();
+	void runCredits();
+
+	bool canDoAction(MystEventAction action);
+	void doAction(MystEventAction action);
+	void scheduleAction(MystEventAction action);
+
+	static const MystLanguage *getLanguageDesc(Common::Language language);
+	Common::Language getLanguage() const override;
 
 private:
-	MystConsole *_console;
-	MystOptionsDialog *_optionsDialog;
 	ResourceCache _cache;
 
 	MystScriptParserPtr _prevStack;
 
 	MystCardPtr _card;
 	MystCardPtr _prevCard;
-	uint32 _lastSaveTime;
 
 	bool hasGameSaveSupport() const;
 	void pauseEngineIntern(bool pause) override;
 
 	void goToMainMenu();
-	bool isGameStarted() const;
 
 	void dropPage();
 
@@ -232,6 +242,9 @@ private:
 
 	uint16 _currentCursor;
 	uint16 _mainCursor; // Also defines the current page being held (white, blue, red, or none)
+
+	Common::Language _currentLanguage;
+	MystEventAction _scheduledAction;
 };
 
 } // End of namespace Mohawk
