@@ -44,6 +44,7 @@
 #include "mortevielle/saveload.h"
 #include "mortevielle/sound.h"
 #include "mortevielle/outtext.h"
+#include "mortevielle/detection.h"
 
 namespace Mortevielle {
 
@@ -61,11 +62,6 @@ enum {
 	MORTDAT_LANG_GERMAN = 2
 };
 
-enum {
-	kUseOriginalData = 0,
-	kUseEngineDataFile = 1
-};
-
 // Static string list
 enum {
 	S_YES_NO = 0, S_GO_TO = 1, S_SOMEONE_ENTERS = 2, S_COOL = 3, S_LOURDE = 4,
@@ -158,8 +154,6 @@ struct Hint {
 	byte _point;
 };
 
-struct MortevielleGameDescription;
-
 class MortevielleEngine : public Engine {
 private:
 	const MortevielleGameDescription *_gameDescription;
