@@ -76,6 +76,8 @@ void Module1000::createScene(int sceneNum, int which) {
 		_vm->_soundMan->startMusic(_musicFileHash, 0, 0);
 		_childObject = new Scene1005(_vm, this, which);
 		break;
+	default:
+		break;
 	}
 	SetUpdateHandler(&Module1000::updateScene);
 	_childObject->handleUpdate();
@@ -94,7 +96,7 @@ void Module1000::updateScene() {
 			if (_moduleResult == 1)
 				leaveModule(0);
 			else if (_moduleResult == 2) {
-				if (_vm->isDemo())
+				if (_vm->isDemo() && !_vm->isBigDemo())
 					// Demo version returns to the same scene
 					createScene(1, 2);
 				else
@@ -115,6 +117,8 @@ void Module1000::updateScene() {
 			_vm->_soundMan->stopMusic(_musicFileHash, 0, 1);
 			createScene(3, 1);
 			break;
+		default:
+			break;
 		}
 	}
 }
@@ -223,6 +227,8 @@ uint32 Scene1001::handleMessage(int messageNum, const MessageParam &param, Entit
 	case NM_KLAYMEN_LOWER_LEVER:
 		sendMessage(_asHammer, 0x2000, 0);
 		break;
+	default:
+		break;
 	}
 	return messageResult;
 }
@@ -454,6 +460,8 @@ uint32 Scene1002::handleMessage(int messageNum, const MessageParam &param, Entit
 		setSpriteSurfacePriority(_ssCeiling, 1015);
 		setSpriteSurfacePriority(_ssLadderArch, 1015);
 		break;
+	default:
+		break;
 	}
 	return messageResult;
 }
@@ -536,6 +544,8 @@ uint32 Scene1004::handleMessage(int messageNum, const MessageParam &param, Entit
 	case NM_POSITION_CHANGE:
 		sendMessage(_asTrashCan, NM_POSITION_CHANGE, 0);
 		break;
+	default:
+		break;
 	}
 	return messageResult;
 }
@@ -585,6 +595,8 @@ uint32 Scene1005::handleMessage(int messageNum, const MessageParam &param, Entit
 		if (param.asPoint().x <= 20 || param.asPoint().x >= 620)
 			leaveScene(0);
 		break;
+	default:
+		break;
 	}
 	return 0;
 }
