@@ -327,7 +327,7 @@ void Parallaction_ns::_c_endComment(void *param) {
 		button. If the input is reconciled with the main
 		loop then the command sequence must be suspended
 		to avoid executing QUIT before this actual
-		routine gets a chance to be run. See bug #2619824
+		routine gets a chance to be run. See bug #4184
 		for a similar situation.
 	*/
 
@@ -377,7 +377,7 @@ void Parallaction_ns::_c_finito(void *parm) {
 
 	_saveLoad->setPartComplete(_char.getBaseName());
 
-	cleanInventory();
+	cleanInventory(true);
 	cleanupGame();
 
 	_gfx->setPalette(_gfx->_palette);
@@ -454,7 +454,7 @@ void Parallaction_ns::_c_endIntro(void *parm) {
 		// NOTE: suspend command execution queue, to
 		// avoid running the QUIT command before
 		// credits are displayed. This solves bug
-		// #2619824.
+		// #4184.
 		// Execution of the command list will resume
 		// as soon as runGameFrame is run.
 		_cmdExec->suspend();
