@@ -49,16 +49,6 @@ Parallaction::Parallaction(OSystem *syst, const PARALLACTIONGameDescription *gam
 	syncSoundSettings();
 
 	g_vm = this;
-	DebugMan.addDebugChannel(kDebugDialogue, "dialogue", "Dialogues debug level");
-	DebugMan.addDebugChannel(kDebugParser, "parser", "Parser debug level");
-	DebugMan.addDebugChannel(kDebugDisk, "disk", "Disk debug level");
-	DebugMan.addDebugChannel(kDebugWalk, "walk", "Walk debug level");
-	DebugMan.addDebugChannel(kDebugGraphics, "gfx", "Gfx debug level");
-	DebugMan.addDebugChannel(kDebugExec, "exec", "Execution debug level");
-	DebugMan.addDebugChannel(kDebugInput, "input", "Input debug level");
-	DebugMan.addDebugChannel(kDebugAudio, "audio", "Audio debug level");
-	DebugMan.addDebugChannel(kDebugMenu, "menu", "Menu debug level");
-	DebugMan.addDebugChannel(kDebugInventory, "inventory", "Inventory debug level");
 
 	_screenWidth = 0;
 	_screenHeight = 0;
@@ -665,7 +655,7 @@ bool Parallaction::checkSpecialZoneBox(ZonePtr z, uint32 type, uint x, uint y) {
 	if (((ACTIONTYPE(z) == kZoneMerge) && (((x == z->u._mergeObj1) && (y == z->u._mergeObj2)) || ((x == z->u._mergeObj2) && (y == z->u._mergeObj1)))) ||
 		((ACTIONTYPE(z) == kZoneGet) && ((x == z->u._getIcon) || (y == z->u._getIcon)))) {
 
-		// WORKAROUND for bug 2070751: special zones are only used in NS, to allow the
+		// WORKAROUND for bug #3897: special zones are only used in NS, to allow the
 		// the EXAMINE/USE action to be applied on some particular item in the inventory.
 		// The usage a verb requires at least an item match, so type can't be 0, as it
 		// was in the original code. This bug has been here since the beginning, and was
