@@ -46,6 +46,7 @@ InputDeviceManager::InputDeviceManager() {
 
 	g_system->getEventManager()->getEventDispatcher()->registerObserver(this, 2, false);
 	_lastRawBits = kAllUpBits;
+	_AKeyWasDown = false;
 }
 
 InputDeviceManager::~InputDeviceManager() {
@@ -53,17 +54,19 @@ InputDeviceManager::~InputDeviceManager() {
 }
 
 void InputDeviceManager::getInput(Input &input, const InputBits filter) {
-	// Poll for events, but ignore them!
-	// We'll pick them up in notifyEvent()
+	// Poll for events, but ignore most of them!
+	// We'll pick the rest up in notifyEvent()
 	// We do that so that any pollEvent() call can update the variables
 	// (ie. if one uses enter to access the restore menu, we never receive
 	// the key up event, which leads to bad things)
 	// This is to closely emulate what the GetKeys() function did on Mac OS
-	pumpEvents();
-
-	// Now create the bitfield
 	InputBits currentBits = 0;
 
+	Common::Event event;
+	while (g_system->getEventManager()->pollEvent(event))
+		;
+
+	// Now fill in the rest of the bitfield
 	if (_keysDown[kPegasusActionUp])
 		currentBits |= (kRawButtonDown << kUpButtonShift);
 
@@ -94,6 +97,21 @@ void InputDeviceManager::getInput(Input &input, const InputBits filter) {
 	if (_keysDown[kPegasusActionShowBiochip])
 		currentBits |= (kRawButtonDown << kRightFireButtonShift);
 
+	if (((PegasusEngine *)g_engine)->isDVD()) {
+		if (_keysDown[kPegasusActionToggleChattyAI] && !_AKeyWasDown) {
+			((PegasusEngine *)g_engine)->requestToggle();
+			_AKeyWasDown = true;
+		} else if (!_keysDown[kPegasusActionToggleChattyAI])
+			_AKeyWasDown = false;
+	}
+
+	// Update mouse button state
+	// Note that we don't use EVENT_LBUTTONUP/EVENT_LBUTTONDOWN because
+	// they do not show if the button is being held down. We're treating
+	// both mouse buttons as the same for ease of use.
+	if (g_system->getEventManager()->getButtonState() != 0)
+		currentBits |= (kRawButtonDown << kTwoButtonShift);
+
 	// Update the mouse position too
 	input.setInputLocation(g_system->getEventManager()->getMousePos());
 
