@@ -34,7 +34,7 @@ namespace Pegasus {
 class PegasusChip : public BiochipItem {
 public:
 	PegasusChip(const ItemID, const NeighborhoodID, const RoomID, const DirectionConstant);
-	virtual ~PegasusChip();
+	~PegasusChip() override;
 
 	void select() override;
 
