@@ -25,6 +25,7 @@
 
 #include "pegasus/gamestate.h"
 #include "pegasus/pegasus.h"
+#include "pegasus/items/biochips/arthurchip.h"
 #include "pegasus/neighborhood/caldoria/caldoria.h"
 #include "pegasus/neighborhood/caldoria/caldoriabomb.h"
 
@@ -48,7 +49,9 @@ static const uint32 kOnTime3 = kOffTime2 + kFlashOnTime;
 static const uint32 kOffTime3 = kOnTime3 + kFlashOffTime;
 static const uint32 kOnTime4 = kOffTime3 + kFlashOnTime;
 
-static const HotSpotID kVertextHotSpotBaseID = 10000;
+// Bomb hotspots start at 20000 since the extra Caldoria hotspots start at 10000.
+// Assigning these vice versa causes a hotspot in level 4 to never activate for some reason.
+static const HotSpotID kVertextHotSpotBaseID = 20000;
 
 static const CoordType kVertextHotSpotWidth = 24;
 static const CoordType kVertextHotSpotHeight = 24;
@@ -1248,6 +1251,12 @@ void CaldoriaBomb::receiveNotification(Notification *notification, const Notific
 			_lastVertex = -1;
 			_owner->_navMovie.setVolume(((PegasusEngine *)g_engine)->getAmbienceLevel());
 			startBombAmbient("Sounds/Caldoria/BmbLoop1.22K.AIFF");
+			if (g_arthurChip) {
+				if (((PegasusEngine *)g_engine)->getRandomBit())
+					g_arthurChip->playArthurMovieForEvent("Images/AI/Globals/XGLOBA14", kArthurCaldoriaSeeRoofBomb);
+				else
+					g_arthurChip->playArthurMovieForEvent("Images/AI/Globals/XGLOBB28", kArthurCaldoriaSeeRoofBomb);
+			}
 			break;
 		case kCaldoria56BombStage2:
 		case kCaldoria56BombStage3:
@@ -1429,6 +1438,8 @@ void CaldoriaBomb::handleInput(const Input &input, const Hotspot *hotspot) {
 				_timer.hide();
 				_owner->_navMovie.setVolume(((PegasusEngine *)g_engine)->getSoundFXLevel());
 				_owner->startExtraSequence(kCaldoria56BombStage7, kExtraCompletedFlag, kFilterNoInput);
+				if (g_arthurChip)
+					g_arthurChip->playArthurMovieForEvent("Images/AI/Globals/XGLOBA02", kArthurCaldoriaDisarmedNuke);
 				break;
 			default:
 				break;
