@@ -32,6 +32,12 @@ namespace Pegasus {
 
 // Element Coordinates
 
+static const CoordType kPodScreenLeft = kNavAreaLeft + 88;
+static const CoordType kPodScreenTop = kNavAreaTop + 204;
+
+static const CoordType kPodSteerLeft = kNavAreaLeft + 212;
+static const CoordType kPodSteerTop = kNavAreaTop + 232;
+
 static const CoordType kUndoHiliteLeft = kNavAreaLeft + 140;
 static const CoordType kUndoHiliteTop = kNavAreaTop + 36;
 
@@ -99,6 +105,9 @@ static const CoordType kShuttleEnergyTop = 60;
 static const CoordType kShuttleEnergyWidth = 252;
 static const CoordType kShuttleEnergyHeight = 22;
 
+static const CoordType kShuttleSteerLeft = kShuttleWindowLeft + 136;
+static const CoordType kShuttleSteerTop = kShuttleWindowTop + 196;
+
 static const CoordType kPlanetStartLeft = kShuttleWindowLeft;
 static const CoordType kPlanetStartTop = kShuttleWindowTop + kShuttleWindowHeight;
 
@@ -130,11 +139,21 @@ static const TimeValue kShuttleSwingStart = 0;
 static const TimeValue kShuttleSwingStop = 5 * 600;
 
 static const TimeValue kCanyonChaseStart = kShuttleSwingStop;
-static const TimeValue kCanyonChaseStop = 60 * 600 + 43 * 600 + 14 * 40;
+static const TimeValue kCanyonChaseCDStop = 60 * 600 + 43 * 600 + 14 * 40;
+static const TimeValue kCanyonChaseDVDStop = 60 * 600 + 50 * 600 + 12 * 40;
 
-static const TimeValue kLaunchTubeReachedTime = 60 * 600 + 38 * 600 - kCanyonChaseStart;
-static const TimeValue kCanyonChaseFinishedTime = kCanyonChaseStop - kCanyonChaseStart -
-											kLaunchTubeReachedTime;
+static const TimeValue kCanyonChaseExitedTime = 60 * 600 + 40 * 600 + 13 * 40 - kCanyonChaseStart;
+static const TimeValue kCanyonChaseFadedTime = 60 * 600 + 43 * 600 + 6 * 40 - kCanyonChaseStart -
+											kCanyonChaseExitedTime;
+
+static const TimeValue kLaunchTubeCDReachedTime = 60 * 600 + 38 * 600 - kCanyonChaseStart;
+static const TimeValue kLaunchTubeDVDReachedTime = 60 * 600 + 45 * 600 - kCanyonChaseStart -
+											kCanyonChaseExitedTime - kCanyonChaseFadedTime;
+static const TimeValue kCanyonChaseCDFinishedTime = kCanyonChaseCDStop - kCanyonChaseStart -
+											kLaunchTubeCDReachedTime;
+static const TimeValue kCanyonChaseDVDFinishedTime = kCanyonChaseDVDStop - kCanyonChaseStart -
+											kCanyonChaseExitedTime - kCanyonChaseFadedTime -
+											kLaunchTubeDVDReachedTime;
 
 // Left shuttle.
 
@@ -183,6 +202,8 @@ static const TimeValue kShuttleLowerLeftTubeTime = 40;
 
 static const TimeValue kShuttleLowerLeftAutopilotTime = 80;
 
+static const TimeValue kShuttleLowerLeftKeypadHintTime = 120;
+
 // Lower Right shuttle.
 
 static const TimeValue kShuttleLowerRightOffTime = 0;
@@ -929,6 +950,11 @@ static const ExtraID kMarsMaze184WestLoop = 109;
 static const ExtraID kMarsMaze184WestDeath = 110;
 static const ExtraID kMars200DeathInBucket = 111;
 
+// Mars interactions.
+
+static const InteractionID kMarsTunnelPodInteractionID = 0;
+static const InteractionID kMarsCanyonChaseInteractionID = 1;
+
 static const ResIDType kReactorUndoHilitePICTID = 900;
 
 static const int16 kMars52Compass = 90;
