@@ -33,9 +33,9 @@ namespace Pegasus {
 class EnergyBeam : public ShuttleWeapon {
 public:
 	EnergyBeam();
-	virtual ~EnergyBeam() {}
+	~EnergyBeam() override {}
 
-	void draw(const Common::Rect &);
+	void draw(const Common::Rect &) override;
 };
 
 } // End of namespace Pegasus
