@@ -23,19 +23,27 @@
  *
  */
 
+#include "pegasus/cursor.h"
 #include "pegasus/energymonitor.h"
 #include "pegasus/gamestate.h"
+#include "pegasus/interface.h"
 #include "pegasus/pegasus.h"
 #include "pegasus/ai/ai_area.h"
+#include "pegasus/items/biochips/arthurchip.h"
 #include "pegasus/items/inventory/airmask.h"
 #include "pegasus/neighborhood/norad/constants.h"
 #include "pegasus/neighborhood/norad/subcontrolroom.h"
 #include "pegasus/neighborhood/norad/alpha/ecrmonitor.h"
 #include "pegasus/neighborhood/norad/alpha/fillingstation.h"
 #include "pegasus/neighborhood/norad/alpha/noradalpha.h"
+#include "pegasus/neighborhood/norad/alpha/subchase.h"
 
 namespace Pegasus {
 
+static const ExtraID kShowThermalScan = 1000;
+
+static const HotSpotID kThermalScanHotSpotID = 10000;
+
 const uint32 NoradAlpha::_noradAlphaClawExtras[22] = {
 	kN22ClawFromAToB,
 	kN22ClawALoop,
@@ -61,7 +69,9 @@ const uint32 NoradAlpha::_noradAlphaClawExtras[22] = {
 	kN22ClawDClockwise
 };
 
-NoradAlpha::NoradAlpha(InputHandler *nextHandler, PegasusEngine *owner) : Norad(nextHandler, owner, "Norad Alpha", kNoradAlphaID) {
+NoradAlpha::NoradAlpha(InputHandler *nextHandler, PegasusEngine *owner)
+	: Norad(nextHandler, owner, "Norad Alpha", kNoradAlphaID),
+	_thermalScanSpot(kThermalScanHotSpotID), _extraMovie(kNoDisplayElement) {
 	_elevatorUpRoomID = kNorad11South;
 	_elevatorDownRoomID = kNorad12South;
 	_elevatorUpSpotID = kNorad12ElevatorUpSpotID;
@@ -82,10 +92,10 @@ NoradAlpha::NoradAlpha(InputHandler *nextHandler, PegasusEngine *owner) : Norad(
 	_lowerPressureDoorDownSpotID = kAlphaLowerPressureDoorDownSpotID;
 	_lowerPressureDoorAbortSpotID = kNorad21WestOutSpotID;
 
-	_pressureSoundIn = kPressureDoorIntro1In;
-	_pressureSoundOut = kPressureDoorIntro1Out;
-	_equalizeSoundIn = kPressureDoorIntro2In;
-	_equalizeSoundOut = kPressureDoorIntro2Out;
+	_pressureSoundIn = kAlphaPressureDoorIntro1In;
+	_pressureSoundOut = kAlphaPressureDoorIntro1Out;
+	_equalizeSoundIn = kAlphaPressureDoorIntro2In;
+	_equalizeSoundOut = kAlphaPressureDoorIntro2Out;
 	_accessDeniedIn = kAlphaAccessDeniedIn;
 	_accessDeniedOut = kAlphaAccessDeniedOut;
 
@@ -98,9 +108,22 @@ NoradAlpha::NoradAlpha(InputHandler *nextHandler, PegasusEngine *owner) : Norad(
 	setIsItemTaken(kGasCanister);
 }
 
+NoradAlpha::~NoradAlpha() {
+	if (_vm->isDVD())
+		_vm->getAllHotspots().remove(&_thermalScanSpot);
+}
+
 void NoradAlpha::init() {
 	Norad::init();
 
+	_extraMovieCallBack.setNotification(&_neighborhoodNotification);
+
+	if (_vm->isDVD()) {
+		_thermalScanSpot.setArea(Common::Rect(216, 112, 336, 312));
+		_thermalScanSpot.setHotspotFlags(kNeighborhoodSpotFlag | kClickSpotFlag);
+		_vm->getAllHotspots().push_back(&_thermalScanSpot);
+	}
+
 	Hotspot *hotspot = _vm->getAllHotspots().findHotspotByID(kN01GasCanisterSpotID);
 	hotspot->setMaskedHotspotFlags(kPickUpItemSpotFlag, kPickUpItemSpotFlag);
 	HotspotInfoTable::Entry *hotspotEntry = findHotspotEntry(kN01GasCanisterSpotID);
@@ -209,7 +232,7 @@ void NoradAlpha::getExtraCompassMove(const ExtraTable::Entry &entry, FaderMoveSp
 }
 
 void NoradAlpha::playClawMonitorIntro() {
-	playSpotSoundSync(kLoadClawIntroIn, kLoadClawIntroOut);
+	playSpotSoundSync(kAlphaLoadClawIntroIn, kAlphaLoadClawIntroOut);
 }
 
 GameInteraction *NoradAlpha::makeInteraction(const InteractionID interactionID) {
@@ -218,6 +241,8 @@ GameInteraction *NoradAlpha::makeInteraction(const InteractionID interactionID)
 		return new NoradAlphaECRMonitor(this);
 	case kNoradFillingStationInteractionID:
 		return new NoradAlphaFillingStation(this);
+	case kNoradSubChaseInteractionID:
+		return new SubChase(this);
 	default:
 		break;
 	}
@@ -250,17 +275,27 @@ void NoradAlpha::loadAmbientLoops() {
 				play unmanned loop
 */
 
-	if (!GameState.getNoradSeenTimeStream())
+	if (!GameState.getNoradSeenTimeStream() || !g_interface || _vm->getEnergyDeathReason() == kDeathSubDestroyed)
 		return;
 
 	RoomID room = GameState.getCurrentRoom();
 	if (GameState.getNoradGassed()) {
-		if (room >= kNorad11 && room <= kNorad19West)
-			loadLoopSound1("Sounds/Norad/NEW SUB AMB.22K.AIFF", kNoradWarningVolume * 3);
-		else if (room >= kNorad21 && room <= kNorad22West)
-			loadLoopSound1("Sounds/Norad/SUB CONTRL LOOP.22K.AIFF", kNoradWarningVolume * 3);
-		else
-			loadLoopSound1("Sounds/Norad/WARNING LOOP.22K.AIFF", kNoradWarningVolume);
+		if (room >= kNorad11 && room <= kNorad19West) {
+			if (_vm->isDVD())
+				loadLoopSound1("Sounds/Norad/NEW SUB AMB.44K.AIFF", kNoradWarningVolume * 3);
+			else
+				loadLoopSound1("Sounds/Norad/NEW SUB AMB.22K.AIFF", kNoradWarningVolume * 3);
+		} else if (room >= kNorad21 && room <= kNorad22West) {
+			if (_vm->isDVD())
+				loadLoopSound1("Sounds/Norad/SUB CONTRL LOOP.32K.AIFF", kNoradWarningVolume * 3);
+			else
+				loadLoopSound1("Sounds/Norad/SUB CONTRL LOOP.22K.AIFF", kNoradWarningVolume * 3);
+		} else {
+			if (_vm->isDVD())
+				loadLoopSound1("Sounds/Norad/WARNING LOOP.32K.AIFF", kNoradWarningVolume);
+			else
+				loadLoopSound1("Sounds/Norad/WARNING LOOP.22K.AIFF", kNoradWarningVolume);
+		}
 	} else {
 		loadLoopSound1("");
 	}
@@ -322,8 +357,14 @@ void NoradAlpha::arriveAt(const RoomID room, const DirectionConstant direction)
 	case kNorad04:
 		arriveAtNorad04();
 		break;
+	case kNorad07:
+		if (_vm->isDVD() && GameState.getLastRoom() == kNorad06)
+			startExtraSequence(kShowThermalScan, kExtraCompletedFlag, kFilterNoInput);
+		break;
 	case kNorad07North:
 		GameState.setScoringSawUnconsciousOperator(true);
+		if (g_arthurChip)
+			g_arthurChip->playArthurMovieForEvent("Images/AI/Globals/XGLOBA70", kArthurNoradSawUnconsciousOperator);
 		break;
 	case kNorad11:
 		GameState.setScoringWentThroughPressureDoor(true);
@@ -337,11 +378,30 @@ void NoradAlpha::arriveAt(const RoomID room, const DirectionConstant direction)
 }
 
 void NoradAlpha::arriveAtNorad01() {
-	if (!GameState.getNoradSeenTimeStream() && GameState.getCurrentDirection() == kSouth) {
-		GameState.setNoradN22MessagePlayed(false);
-		requestExtraSequence(kNoradArriveFromTSA, kExtraCompletedFlag, kFilterNoInput);
-		// You are no match for me, human.
-		requestExtraSequence(kNorad01RobotTaunt, kExtraCompletedFlag, kFilterNoInput);
+	Item *argonCanister, *nitrogenCanister;
+
+	switch (GameState.getCurrentDirection()) {
+	case kSouth:
+		if (!GameState.getNoradSeenTimeStream()) {
+			GameState.setNoradN22MessagePlayed(false);
+			requestExtraSequence(kNoradArriveFromTSA, kExtraCompletedFlag, kFilterNoInput);
+			// You are no match for me, human.
+			requestExtraSequence(kNorad01RobotTaunt, kExtraCompletedFlag, kFilterNoInput);
+		}
+		break;
+	case kEast:
+		if (g_arthurChip)
+			g_arthurChip->playArthurMovieForEvent("Images/AI/Globals/XGLOBA33", kArthurNoradAtSecurityMonitor);
+		break;
+	case kWest:
+		if (GameState.getLastRoom() == kNorad01West) {
+			argonCanister = g_allItems.findItemByID(kArgonCanister);
+			nitrogenCanister = g_allItems.findItemByID(kNitrogenCanister);
+			if (((GameState.isTakenItemID(kArgonCanister) && argonCanister->getItemState() != kArgonFull) ||
+				(GameState.isTakenItemID(kNitrogenCanister) && nitrogenCanister->getItemState() != kNitrogenFull)) && g_arthurChip)
+				g_arthurChip->playArthurMovieForEvent("Images/AI/Globals/XGLOBA34", kArthurNoradDidntFillCanisters);
+		}
+		break;
 	}
 }
 
@@ -366,20 +426,103 @@ void NoradAlpha::arriveAtNorad22() {
 	}
 }
 
+void NoradAlpha::turnTo(const DirectionConstant direction) {
+	Norad::turnTo(direction);
+	if (GameState.getCurrentRoomAndView() == MakeRoomView(kNorad01, kEast) && g_arthurChip)
+		g_arthurChip->playArthurMovieForEvent("Images/AI/Globals/XGLOBA33", kArthurNoradAtSecurityMonitor);
+}
+
 void NoradAlpha::bumpIntoWall() {
 	requestSpotSound(kAlphaBumpIntoWallIn, kAlphaBumpIntoWallOut, kFilterNoInput, 0);
 	Neighborhood::bumpIntoWall();
 }
 
+void NoradAlpha::startExtraSequence(const ExtraID extraID, const NotificationFlags flags, const InputBits interruptionFilter) {
+	TimeValue segmentStart = 0, segmentStop = 0;
+	bool loopSequence = false;
+	Common::Rect pushBounds;
+	NotificationFlags extraFlags;
+
+	switch (extraID) {
+	case kShowThermalScan:
+		_turnPush.getBounds(pushBounds);
+
+		switch (extraID) {
+		case kShowThermalScan:
+			_extraMovie.initFromMovieFile("Images/Norad Alpha/N07NS.movie");
+			segmentStart = 0;
+			segmentStop = _extraMovie.getDuration();
+			loopSequence = false;
+			break;
+		default:
+			break;
+		}
+
+		_lastExtra = extraID;
+		_turnPush.hide();
+
+		if (!loopSequence && g_AIArea)
+			g_AIArea->lockAIOut();
+
+		extraFlags = flags;
+		_interruptionFilter = interruptionFilter;
+		// Stop the nav movie before doing anything else
+		_navMovie.stop();
+		_navMovie.stopDisplaying();
+
+		_extraMovie.setVolume(_vm->getSoundFXLevel());
+		_extraMovie.moveElementTo(pushBounds.left, pushBounds.top);
+		_extraMovie.setDisplayOrder(kNavMovieOrder + 1);
+		_extraMovie.startDisplaying();
+		_extraMovie.show();
+		_extraMovie.setFlags(0);
+		_extraMovie.setSegment(segmentStart, segmentStop);
+		_extraMovie.setTime(segmentStart);
+		if (loopSequence)
+			_extraMovie.setFlags(kLoopTimeBase);
+		else
+			extraFlags |= kNeighborhoodMovieCompletedFlag;
+		_extraMovieCallBack.cancelCallBack();
+		_extraMovieCallBack.initCallBack(&_extraMovie, kCallBackAtExtremes);
+		if (extraFlags != 0) {
+			_extraMovieCallBack.setCallBackFlag(extraFlags);
+			_extraMovieCallBack.scheduleCallBack(kTriggerAtStop, 0, 0);
+		}
+		_extraMovie.start();
+		break;
+	default:
+		Neighborhood::startExtraSequence(extraID, flags, interruptionFilter);
+		break;
+	}
+}
+
 void NoradAlpha::receiveNotification(Notification *notification, const NotificationFlags flags) {
 	if ((flags & kExtraCompletedFlag) != 0) {
 		switch (_lastExtra) {
+		case kShowThermalScan:
+			_interruptionFilter = kFilterAllInput;
+			_extraMovie.stopDisplaying();
+			_extraMovie.releaseMovie();
+			_navMovie.startDisplaying();
+			break;
+		case kNorad19ExitToSub:
+			if (_vm->isDVD()) {
+				_interruptionFilter = kFilterAllInput;
+				_vm->_cursor->hide();
+				setNextHandler(_vm);
+				throwAwayInterface();
+				loadLoopSound1("");
+				newInteraction(kNoradSubChaseInteractionID);
+				GameState.setScoringEnteredSub(true);
+			}
+			break;
 		case kNoradArriveFromTSA:
 			GameState.setNoradSeenTimeStream(true);
 			loadAmbientLoops();
 			break;
 		case kNorad01RobotTaunt:
-			g_AIArea->playAIMovie(kRightAreaSignature, "Images/AI/Norad/XN01SB", false, kWarningInterruption);
+			if (_vm->isChattyAI())
+				g_AIArea->playAIMovie(kRightAreaSignature, "Images/AI/Norad/XN01SB", false, kWarningInterruption);
 			_interruptionFilter = kFilterAllInput;
 			makeContinuePoint();
 			break;
@@ -398,11 +541,38 @@ void NoradAlpha::receiveNotification(Notification *notification, const Notificat
 			startExtraSequence(kNorad22SouthFinish, kExtraCompletedFlag, kFilterNoInput);
 			break;
 		case kNorad22SouthFinish:
+			if (g_arthurChip)
+				g_arthurChip->playArthurMovieForEvent("Images/AI/Globals/XGLOBB29", kArthurNoradSawSubMessage);
 			_interruptionFilter = kFilterAllInput;
 			// Force ArriveAt to do its thing...
 			GameState.setCurrentRoom(kNorad21);
 			arriveAt(kNorad22, kSouth);
 			break;
+		case kN22ClawFromAToB:
+		case kN22ClawAPinch:
+		case kN22ClawACounterclockwise:
+		case kN22ClawAClockwise:
+		case kN22ClawFromBToA:
+		case kN22ClawFromBToC:
+		case kN22ClawFromBToD:
+		case kN22ClawBPinch:
+		case kN22ClawBCounterclockwise:
+		case kN22ClawBClockwise:
+		case kN22ClawFromCToB:
+		case kN22ClawCPinch:
+		case kN22ClawCCounterclockwise:
+		case kN22ClawCClockwise:
+		case kN22ClawFromDToB:
+		case kN22ClawDPinch:
+		case kN22ClawDCounterclockwise:
+		case kN22ClawDClockwise:
+			if (g_arthurChip) {
+				if (_vm->getRandomBit())
+					g_arthurChip->playArthurMovieForEvent("Images/AI/Globals/XGLOBA64", kArthurNoradPlayedWithClaw);
+				else
+					g_arthurChip->playArthurMovieForEvent("Images/AI/Globals/XGLOBA66", kArthurNoradPlayedWithClaw);
+			}
+			break;
 		default:
 			break;
 		}
@@ -501,10 +671,19 @@ TimeValue NoradAlpha::getViewTime(const RoomID room, const DirectionConstant dir
 	return Norad::getViewTime(room, direction);
 }
 
+void NoradAlpha::setSoundFXLevel(const uint16 level) {
+	Neighborhood::setSoundFXLevel(level);
+
+	if (_extraMovie.isMovieValid())
+		_extraMovie.setVolume(level);
+}
+
 void NoradAlpha::turnOnFillingStation() {
 	if (GameState.getCurrentRoom() == kNorad01West && !GameState.getNoradFillingStationOn()) {
 		GameState.setNoradFillingStationOn(true);
 		updateViewFrame();
+		if (g_arthurChip)
+			g_arthurChip->playArthurMovieForEvent("Images/AI/Globals/XGLOBA72", kArthurNoradSawFillingStation);
 	}
 }
 
@@ -556,6 +735,10 @@ void NoradAlpha::activateHotspots() {
 			}
 		}
 		break;
+	case MakeRoomView(kNorad07, kNorth):
+		if (_vm->isDVD())
+			_vm->getAllHotspots().activateOneHotspot(kThermalScanHotSpotID);
+		break;
 	case MakeRoomView(kNorad10, kEast):
 		if (GameState.isCurrentDoorOpen())
 			_vm->getAllHotspots().deactivateOneHotspot(kNorad10DoorSpotID);
@@ -581,6 +764,9 @@ void NoradAlpha::clickInHotspot(const Input &input, const Hotspot *cursorSpot) {
 				hotspotEntry->hotspotItem = item->getObjectID();
 			}
 		}
+	} else if (GameState.getCurrentRoomAndView() == MakeRoomView(kNorad07, kNorth) &&
+				cursorSpot->getObjectID() == kThermalScanHotSpotID) {
+		startExtraSequence(kShowThermalScan, kExtraCompletedFlag, kFilterNoInput);
 	}
 }
 
