@@ -92,10 +92,10 @@ void Surface::getImageFromPICTFile(const Common::String &fileName) {
 void Surface::getImageFromPICTResource(Common::MacResManager *resFork, uint16 id) {
 	Common::SeekableReadStream *res = resFork->getResource(MKTAG('P', 'I', 'C', 'T'), id);
 	if (!res)
-		error("Could not open PICT resource %d from '%s'", id, resFork->getBaseFileName().c_str());
+		error("Could not open PICT resource %d from '%s'", id, resFork->getBaseFileName().toString().c_str());
 
 	if (!getImageFromPICTStream(res))
-		error("Failed to load PICT resource %d from '%s'", id, resFork->getBaseFileName().c_str());
+		error("Failed to load PICT resource %d from '%s'", id, resFork->getBaseFileName().toString().c_str());
 
 	delete res;
 }
