@@ -177,12 +177,12 @@ private:
 class IdlerTimeBase : public Idler, public TimeBase {
 public:
 	IdlerTimeBase();
-	virtual ~IdlerTimeBase() { stopIdling(); }
+	~IdlerTimeBase() override { stopIdling(); }
 
 	TimeValue getLastTime() const { return _lastTime; }
 
 protected:
-	virtual void useIdleTime();
+	void useIdleTime() override;
 	virtual void timeChanged(const TimeValue) {}
 
 	TimeValue _lastTime;
@@ -192,7 +192,7 @@ protected:
 class NotificationCallBack : public TimeBaseCallBack {
 public:
 	NotificationCallBack();
-	virtual ~NotificationCallBack() {}
+	~NotificationCallBack() override {}
 
 	void setNotification(Notification *notifier) { _notifier = notifier; }
 
@@ -200,7 +200,7 @@ public:
 	NotificationFlags getCallBackFlag() const { return _callBackFlag; }
 
 protected:
-	void callBack();
+	void callBack() override;
 
 	Notification *_notifier;
 	NotificationFlags _callBackFlag;
@@ -214,7 +214,7 @@ public:
 class Fuse : private NotificationReceiver {
 public:
 	Fuse();
-	virtual ~Fuse() {}
+	~Fuse() override {}
 
 	void primeFuse(const TimeValue, const TimeScale = 1); // An appropriately named function :P
 	void lightFuse();
@@ -229,7 +229,7 @@ public:
 	bool isFusePaused() { return _fuseTimer.isPaused(); }
 
 protected:
-	virtual void receiveNotification(Notification *, const NotificationFlags);
+	void receiveNotification(Notification *, const NotificationFlags) override;
 	virtual void invokeAction() {}
 
 	TimeBase _fuseTimer;
@@ -240,11 +240,11 @@ protected:
 class FuseFunction : public Fuse {
 public:
 	FuseFunction() : _functor(0) {}
-	virtual ~FuseFunction() { delete _functor; }
+	~FuseFunction() override { delete _functor; }
 
 	void setFunctor(Common::Functor0<void> *functor) { delete _functor; _functor = functor; }
 protected:
-	virtual void invokeAction() { if (_functor && _functor->isValid()) (*_functor)(); }
+	void invokeAction() override { if (_functor && _functor->isValid()) (*_functor)(); }
 
 	Common::Functor0<void> *_functor;
 };
