@@ -34,7 +34,7 @@ public:
 	SeqTimer();
 
 	void deserialize(Archive &archive) override;
-	void toConsole() override;
+	void toConsole() const override;
 
 	void update();
 
