@@ -45,12 +45,6 @@ PinkEngine::PinkEngine(OSystem *system, const ADGameDescription *desc)
 	_desc(desc), _bro(nullptr), _menu(nullptr), _actor(nullptr),
 	_module(nullptr), _director(nullptr), _pdaMgr(this) {
 
-	DebugMan.addDebugChannel(kPinkDebugGeneral, "general", "General issues");
-	DebugMan.addDebugChannel(kPinkDebugLoadingResources, "loading_resources", "Loading resources data");
-	DebugMan.addDebugChannel(kPinkDebugLoadingObjects, "loading_objects", "Serializing objects from Orb");
-	DebugMan.addDebugChannel(kPinkDebugScripts, "scripts", "Sequences");
-	DebugMan.addDebugChannel(kPinkDebugActions, "actions", "Actions");
-
 	const Common::FSNode gameDataDir(ConfMan.get("path"));
 	SearchMan.addSubDirectoryMatching(gameDataDir, "install");
 }
@@ -66,7 +60,6 @@ PinkEngine::~PinkEngine() {
 		delete _cursors[j];
 	}
 	delete _director;
-	DebugMan.clearAllDebugChannels();
 }
 
 Common::Error PinkEngine::init() {
@@ -80,7 +73,7 @@ Common::Error PinkEngine::init() {
 	}
 
 	setDebugger(new Console(this));
-	_director = new Director();
+	_director = new Director(this);
 
 	initMenu();
 
@@ -101,7 +94,7 @@ Common::Error PinkEngine::init() {
 			return Common::kNoGameDataFoundError;
 		if (_orb.getTimestamp() != _bro->getTimestamp()) {
 			warning("ORB and BRO timestamp mismatch. %x != %x", _orb.getTimestamp(), _bro->getTimestamp());
-			return Common::kNoGameDataFoundError;
+			//return Common::kNoGameDataFoundError;
 		}
 	}
 
