@@ -530,8 +530,15 @@ void PrinceEngine::checkOptions() {
 			case Common::EN_ANY:
 				optText = optionsTextEN[i];
 				break;
+			case Common::ES_ESP:
+				optText = optionsTextES[i];
+				break;
 			case Common::RU_RUS:
-				optText = optionsTextRU[i];
+				if (getFeatures() & GF_RUSPROJEDITION) {
+					optText = optionsTextRU2[i];
+				} else {
+					optText = optionsTextRU[i];
+				}
 				break;
 			default:
 				break;
@@ -582,8 +589,15 @@ void PrinceEngine::checkInvOptions() {
 			case Common::EN_ANY:
 				invText = invOptionsTextEN[i];
 				break;
+			case Common::ES_ESP:
+				invText = invOptionsTextES[i];
+				break;
 			case Common::RU_RUS:
-				invText = invOptionsTextRU[i];
+				if (getFeatures() & GF_RUSPROJEDITION) {
+					invText = invOptionsTextRU2[i];
+				} else {
+					invText = invOptionsTextRU[i];
+				}
 				break;
 			default:
 				error("Unknown game language %d", getLanguage());
