@@ -144,9 +144,9 @@ bool PrinceEngine::canLoadGameStateCurrently() {
 	return false;
 }
 
-Common::Error PrinceEngine::saveGameState(int slot, const Common::String &desc) {
+Common::Error PrinceEngine::saveGameState(int slot, const Common::String &desc, bool isAutosave) {
 	// Set up the serializer
-	Common::String slotName = generateSaveName(slot);
+	Common::String slotName = getSaveStateName(slot);
 	Common::OutSaveFile *saveFile = g_system->getSavefileManager()->openForSaving(slotName);
 
 	// Write out the ScummVM savegame header
@@ -165,10 +165,6 @@ Common::Error PrinceEngine::saveGameState(int slot, const Common::String &desc)
 	return Common::kNoError;
 }
 
-Common::String PrinceEngine::generateSaveName(int slot) {
-	return Common::String::format("%s.%03d", _targetName.c_str(), slot);
-}
-
 void PrinceEngine::writeSavegameHeader(Common::OutSaveFile *out, SavegameHeader &header) {
 	// Write out a savegame header
 	out->write(kSavegameStr, kSavegameStrSize + 1);
@@ -435,9 +431,12 @@ bool PrinceEngine::loadGame(int slotNumber) {
 	Common::MemoryReadStream *readStream;
 
 	// Open up the savegame file
-	Common::String slotName = generateSaveName(slotNumber);
+	Common::String slotName = getSaveStateName(slotNumber);
 	Common::InSaveFile *saveFile = g_system->getSavefileManager()->openForLoading(slotName);
 
+	if (!saveFile)
+		return false;
+
 	// Read the data into a data buffer
 	int size = saveFile->size();
 	byte *dataBuffer = (byte *)malloc(size);
