@@ -85,7 +85,7 @@ bool PrinceEngine::loadSample(uint32 sampleSlot, const Common::String &streamNam
 		delete sampleStream;
 		error("Can't load sample %s to slot %d", normalizedPath.c_str(), sampleSlot);
 	}
-	_audioStream[sampleSlot] = Audio::makeWAVStream(sampleStream, DisposeAfterUse::NO);
+	_audioStream[sampleSlot] = Audio::makeWAVStream(sampleStream->readStream(sampleStream->size()), DisposeAfterUse::YES);
 	delete sampleStream;
 	return true;
 }
@@ -141,7 +141,7 @@ bool PrinceEngine::loadVoice(uint32 slot, uint32 sampleSlot, const Common::Strin
 
 	debugEngine("SetVoice slot %d time %04x", slot, id);
 	sampleStream->seek(SEEK_SET);
-	_audioStream[sampleSlot] = Audio::makeWAVStream(sampleStream, DisposeAfterUse::NO);
+	_audioStream[sampleSlot] = Audio::makeWAVStream(sampleStream->readStream(sampleStream->size()), DisposeAfterUse::YES);
 	delete sampleStream;
 	return true;
 }
@@ -157,7 +157,11 @@ void PrinceEngine::setVoice(uint16 slot, uint32 sampleSlot, uint16 flag) {
 		sampleName = Common::String::format("inv%02d-01.WAV", currentString - 70000);
 	} else if (currentString >= 60000) {
 		sampleName = Common::String::format("M%04d-%02d.WAV", currentString - 60000, flag);
-	} else if (currentString >= 2000) {
+	// String 316.
+	// Fixes PRINCE: conversation with the priest bug #11771
+	// When Galador starts conversation with the priest with any gesture,
+	// the priest sits down to his place and conversation cannot be continued.
+	} else if (currentString == 316 || currentString >= 2000) {
 		return;
 	} else if (flag >= 100) {
 		sampleName = Common::String::format("%03d-%03d.WAV", currentString, flag);
