@@ -180,8 +180,8 @@ enum DragonMoveTypes {
 
 struct PathDirectionData {
 	int8 direction;
-	int16 x;
-	int16 y;
+	int32 x;
+	int32 y;
 };
 
 struct ActorFrameRange {
@@ -269,16 +269,6 @@ struct Location {
 		y = stream.readUint16LE();
 		z = stream.readUint16LE();
 	}
-
-#if 0
-	// Obsolete function, throws warnings in older versions of GCC
-	// (warning: int format, int32 arg)
-	// Keeping it around for debug purposes
-	void debugPrint(int debuglevel = 0, const char *loc = "Loc:") const {
-		debug(debuglevel, "%s %d, %d, %d", loc, x, y, z);
-	}
-#endif
-
 };
 
 class CommonObjectData {
@@ -437,7 +427,25 @@ struct SpeechData {
 	int playingTime;
 
 	SpeechData() {
-		memset(this, 0, sizeof(*this));
+		for (uint i = 0; i < ACTOR_SPEECH_ACTORS_MAX; i++) {
+			speechColor[i] = 0;
+			outlineColor[i] = 0;
+		}
+		speechFlags = 0;
+		for (uint i = 0; i < ACTOR_SPEECH_ACTORS_MAX; i++) {
+			strings[i] = nullptr;
+		}
+		// speechBox is initialized by Rect constructor
+		// drawRect is initialized by Rect constructor
+		stringsCount = 0;
+		slowModeCharIndex = 0;
+		for (uint i = 0; i < ACTOR_SPEECH_ACTORS_MAX; i++) {
+			actorIds[i] = 0;
+		}
+		actorsCount = 0;
+		sampleResourceId = 0;
+		playing = false;
+		playingTime = 0;
 	}
 
 	FontEffectFlags getFontFlags(int i) {
