@@ -8,12 +8,12 @@
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
@@ -185,7 +185,7 @@ int Anim::playCutaway(int cut, bool fade) {
 		event.time = (40 / 3) * 1000 / _cutawayList[cut].frameRate;
 
 		if (fade)
-			eventColumns = _vm->_events->chain(eventColumns, event);
+			_vm->_events->chain(eventColumns, event);
 		else
 			_vm->_events->queue(event);
 	}
@@ -501,7 +501,7 @@ void Anim::play(uint16 animId, int vectorTime, bool playing) {
 	}
 
 	anim = getAnimation(animId);
-	displayBuffer = (byte *)_vm->_render->getBackGroundSurface()->pixels;
+	displayBuffer = (byte *)_vm->_render->getBackGroundSurface()->getPixels();
 
 	if (playing) {
 		anim->state = ANIM_PLAYING;
@@ -914,14 +914,14 @@ void Anim::animInfo() {
 
 	animCount = getAnimationCount();
 
-	_vm->_console->DebugPrintf("There are %d animations loaded:\n", animCount);
+	_vm->_console->debugPrintf("There are %d animations loaded:\n", animCount);
 
 	for (i = 0; i < MAX_ANIMATIONS; i++) {
 		if (_animations[i] == NULL) {
 			continue;
 		}
 
-		_vm->_console->DebugPrintf("%02d: Frames: %u Flags: %u\n", i, _animations[i]->maxFrame, _animations[i]->flags);
+		_vm->_console->debugPrintf("%02d: Frames: %u Flags: %u\n", i, _animations[i]->maxFrame, _animations[i]->flags);
 	}
 }
 
@@ -929,10 +929,10 @@ void Anim::animInfo() {
 void Anim::cutawayInfo() {
 	uint16 i;
 
-	_vm->_console->DebugPrintf("There are %d cutaways loaded:\n", _cutawayList.size());
+	_vm->_console->debugPrintf("There are %d cutaways loaded:\n", _cutawayList.size());
 
 	for (i = 0; i < _cutawayList.size(); i++) {
-		_vm->_console->DebugPrintf("%02d: Bg res: %u Anim res: %u Cycles: %u Framerate: %u\n", i,
+		_vm->_console->debugPrintf("%02d: Bg res: %u Anim res: %u Cycles: %u Framerate: %u\n", i,
 			_cutawayList[i].backgroundResourceId, _cutawayList[i].animResourceId,
 			_cutawayList[i].cycles, _cutawayList[i].frameRate);
 	}
