@@ -115,12 +115,22 @@ struct Surface : Graphics::Surface {
 			fillRect(rect, color);
 		}
 	}
+
+	void clearRect2x(Common::Rect r) {
+	// This clears a 2x scaled rect (used for Japanese font removal).
+	// The pixels buffer only gets allocated for game versions that actually require it.
+		if (!pixels)
+			return;
+		fillRect(Common::Rect(r.left << 1, r.top << 1, r.right << 1, r.bottom << 1), 0);
+	}
 };
 
 #define PAL_ENTRIES 256
 
 #define CURSOR_W 7
 #define CURSOR_H 7
+#define CURSOR_PC98_W 16
+#define CURSOR_PC98_H 16
 
 #define CURSOR_ORIGIN_X 4
 #define CURSOR_ORIGIN_Y 4
@@ -174,6 +184,8 @@ public:
 	// to add the corresponding dirty rectangle itself
 	void hLine(int x, int y, int x2, uint32 color) {
 		_backBuffer.hLine(x, y, x2, color);
+		// Clear corresponding area of the sjis text layer (if the pixels buffer was actually created)
+		_sjisBackBuffer.clearRect2x(Common::Rect(x, y, x2, y + 1));
 	}
 
 	// WARNING: This method does not add a dirty rectangle automatically.
@@ -181,6 +193,8 @@ public:
 	// to add the corresponding dirty rectangle itself
 	void vLine(int x, int y, int y2, uint32 color) {
 		_backBuffer.vLine(x, y, y2, color);
+		// Clear corresponding area of the sjis text layer (if the pixels buffer was actually created)
+		_sjisBackBuffer.clearRect2x(Common::Rect(x, y, x + 1, y2));
 	}
 
 	// WARNING: This method does not add a dirty rectangle automatically.
@@ -188,6 +202,11 @@ public:
 	// to add the corresponding dirty rectangle itself
 	void setPixelColor(int x, int y, byte color) {
 		((byte *)_backBuffer.getBasePtr(x, y))[0] = color;
+		// Clear corresponding area of the sjis text layer (if the pixels buffer was actually created)
+		if (_sjisBackBuffer.getPixels()) {
+			*((uint16 *)_sjisBackBuffer.getBasePtr(x << 1, y << 1)) = 0;
+			*((uint16 *)_sjisBackBuffer.getBasePtr(x << 1, (y << 1) + 1)) = 0;
+		}
 	}
 
 	// WARNING: This method does not add a dirty rectangle automatically.
@@ -204,24 +223,49 @@ public:
 		return (byte *)_backBuffer.getPixels();
 	}
 
+	// Same as getBackBufferPixels(), but for the hires sjis buffer
+	byte *getSJISBackBufferPixels() {
+		return (byte *)_sjisBackBuffer.getPixels();
+	}
+
+	// Expose the sjis buffer directly. One of the two implementations of Graphics::FontSJIS::drawChar()
+	// allows a Common::Surface as a parameter which makes the rendering a bit nicer compared to using
+	// the raw pixel buffer.
+	Surface &getSJISBackBuffer() {
+		return _sjisBackBuffer;
+	}
+
 	uint16 getBackBufferWidth() {
 		return _backBuffer.w;
 	}
 
+	uint16 getSJISBackBufferWidth() {
+		return _sjisBackBuffer.w;
+	}
+
 	uint16 getBackBufferHeight() {
 		return _backBuffer.h;
 	}
 
+	uint16 getSJISBackBufferHeight() {
+		return _sjisBackBuffer.h;
+	}
+
 	uint16 getBackBufferPitch() {
 		return _backBuffer.pitch;
 	}
 
+	uint16 getSJISBackBufferPitch() {
+		return _sjisBackBuffer.pitch;
+	}
+
 	void getBackBufferRect(Common::Rect &rect) {
 		_backBuffer.getRect(rect);
 	}
 
 private:
 	Surface _backBuffer;
+	Surface _sjisBackBuffer;
 	byte _currentPal[PAL_ENTRIES * 3];
 	OSystem *_system;
 	SagaEngine *_vm;
