@@ -101,6 +101,7 @@ enum {
 	kITECreditsPCCD         = (1 << 1),
 	kITECreditsMac          = (1 << 2),
 	kITECreditsWyrmKeep     = (1 << 3),
+	kITECreditsPC98		    = (1 << 4),
 	kITECreditsAny          = 0xffff,
 	kITECreditsNotWyrmKeep  = kITECreditsAny & ~kITECreditsWyrmKeep
 };
@@ -137,11 +138,12 @@ extern const IntroDialogue introDialogueCave2[][3];
 extern const IntroDialogue introDialogueCave3[][3];
 extern const IntroDialogue introDialogueCave4[][4];
 
-extern const IntroCredit creditsValley[16];
-extern const IntroCredit creditsTreeHouse1[17];
-extern const IntroCredit creditsTreeHouse2[23];
-extern const IntroCredit creditsFairePath1[20];
-extern const IntroCredit creditsFairePath2[7];
+extern const IntroCredit creditsValley[37];
+extern const IntroCredit creditsTreeHouse1[31];
+extern const IntroCredit creditsTreeHouse2[45];
+extern const IntroCredit creditsFairePath1[38];
+extern const IntroCredit creditsFairePath2[16];
+extern const IntroCredit creditsTent[6];
 
 } // End of namespace Saga
 
