@@ -26,9 +26,13 @@
 #define SAGA_MUSIC_H
 
 #include "audio/mididrv.h"
-#include "audio/midiplayer.h"
+#include "audio/mididrv_ms.h"
+#include "audio/mt32gm.h"
 #include "audio/midiparser.h"
 #include "audio/mixer.h"
+#include "audio/softsynth/fmtowns_pc98/towns_pc98_driver.h"
+
+class TownsPC98_AudioDriver;
 
 namespace Saga {
 
@@ -37,35 +41,15 @@ enum MusicFlags {
 	MUSIC_LOOP = 0x0001
 };
 
-class MusicDriver : public Audio::MidiPlayer {
-public:
-	MusicDriver();
-
-	void play(SagaEngine *vm, ByteArray *buffer, bool loop);
-	void playQuickTime(const Common::String &musicName, bool loop);
-	virtual void pause();
-	virtual void resume();
-
-	bool isAdlib() const { return _driverType == MT_ADLIB; }
-
-	// FIXME
-	bool isPlaying() const { return _parser && _parser->isPlaying(); }
-
-	// MidiDriver_BASE interface implementation
-	virtual void send(uint32 b);
-	virtual void metaEvent(byte type, byte *data, uint16 length);
-
-protected:
-	MusicType _driverType;
-	bool _isGM;
-	bool _milesAudioMode;
-};
-
 class Music {
-public:
+private:
+	static const uint8 MUSIC_SUNSPOT = 26;
+	static const uint8 MT32_GOODBYE_MSG[MidiDriver_MT32GM::MT32_DISPLAY_NUM_CHARS];
 
+public:
 	Music(SagaEngine *vm, Audio::Mixer *mixer);
 	~Music();
+	void close();
 	bool isPlaying();
 	bool hasDigitalMusic() { return _digitalMusic; }
 
@@ -76,8 +60,12 @@ public:
 
 	void setVolume(int volume, int time = 1);
 	int getVolume() { return _currentVolume; }
+	void resetVolume();
+	bool isFading();
 
-	bool isAdlib() const { return _player->isAdlib(); }
+	bool isAdlib() const { return  _driverType == MT_ADLIB; }
+
+	void syncSoundSettings();
 
 	Common::Array<int32> _songTable;
 
@@ -85,21 +73,31 @@ private:
 	SagaEngine *_vm;
 	Audio::Mixer *_mixer;
 
-	MusicDriver *_player;
+	MidiParser *_parser;
+	MidiDriver_Multisource *_driver;
+	TownsPC98_AudioDriver *_driverPC98;
 	Audio::SoundHandle _musicHandle;
 	uint32 _trackNumber;
 
+	int _userVolume;
+	bool _userMute;
 	int _targetVolume;
 	int _currentVolume;
 	int _currentVolumePercent;
 	bool _digitalMusic;
+	MusicType _musicType;
+	MusicType _driverType;
 
 	ResourceContext *_musicContext;
 	ResourceContext *_digitalMusicContext;
 
 
 	static void musicVolumeGaugeCallback(void *refCon);
-	static void onTimer(void *refCon);
+	static void timerCallback(void *refCon);
+	void onTimer();
+	bool playDigital(uint32 resourceId, MusicFlags flags);
+	void playQuickTime(uint32 resourceId, MusicFlags flags);
+	void playMidi(uint32 resourceId, MusicFlags flags);
 	void musicVolumeGauge();
 	ByteArray *_currentMusicBuffer;
 	ByteArray _musicBuffer[2];
