@@ -25,6 +25,7 @@
 #include "common/config-manager.h"
 #include "common/system.h"
 #include "common/events.h"
+#include "common/translation.h"
 
 #include "audio/mixer.h"
 
@@ -64,7 +65,6 @@ SagaEngine::SagaEngine(OSystem *syst, const SAGAGameDescription *gameDesc)
 	_spiritualBarometer = 0;
 
 	_soundVolume = 0;
-	_musicVolume = 0;
 	_speechVolume = 0;
 	_subtitlesEnabled = false;
 	_voicesEnabled = false;
@@ -127,12 +127,6 @@ SagaEngine::SagaEngine(OSystem *syst, const SAGAGameDescription *gameDesc)
 	// Mac CD Wyrmkeep
 	SearchMan.addSubDirectoryMatching(gameDataDir, "patch");
 
-	// Dinotopia
-	SearchMan.addSubDirectoryMatching(gameDataDir, "smack");
-
-	// FTA2
-	SearchMan.addSubDirectoryMatching(gameDataDir, "video");
-
 	_displayClip.left = _displayClip.top = 0;
 }
 
@@ -157,13 +151,11 @@ SagaEngine::~SagaEngine() {
 	delete _events;
 	_events = NULL;
 
-	if (!isSaga2()) {
-		delete _font;
-		_font = NULL;
+	delete _font;
+	_font = NULL;
 
-		delete _sprite;
-		_sprite = NULL;
-	}
+	delete _sprite;
+	_sprite = NULL;
 
 	delete _anim;
 	_anim = NULL;
@@ -171,10 +163,8 @@ SagaEngine::~SagaEngine() {
 	delete _script;
 	_script = NULL;
 
-	if (!isSaga2()) {
-		delete _interface;
-		_interface = NULL;
-	}
+	delete _interface;
+	_interface = NULL;
 
 	delete _actor;
 	_actor = NULL;
@@ -211,7 +201,6 @@ Common::Error SagaEngine::run() {
 	ConfMan.registerDefault("talkspeed", "255");
 	ConfMan.registerDefault("subtitles", "true");
 
-	_musicVolume = ConfMan.getInt("music_volume");
 	_subtitlesEnabled = ConfMan.getBool("subtitles");
 	_readingSpeed = getTalkspeed();
 	_copyProtection = ConfMan.getBool("copy_protection");
@@ -230,12 +219,6 @@ Common::Error SagaEngine::run() {
 		case GID_IHNM:
 			_resource = new Resource_RES(this);
 			break;
-#endif
-#ifdef ENABLE_SAGA2
-		case GID_DINO:
-		case GID_FTA2:
-			_resource = new Resource_HRS(this);
-			break;
 #endif
 		default:
 			break;
@@ -243,22 +226,20 @@ Common::Error SagaEngine::run() {
 
 	// Detect game and open resource files
 	if (!initGame()) {
-		GUIErrorMessage("Error loading game resources.");
+		GUIErrorMessage(_("Error loading game resources."));
 		return Common::kUnknownError;
 	}
 
 	// Initialize engine modules
-	// TODO: implement differences for SAGA2
 	_sndRes = new SndRes(this);
 	_events = new Events(this);
 
-	if (!isSaga2()) {
-		_font = new Font(this);
-		_sprite = new Sprite(this);
-		_script = new SAGA1Script(this);
-	} else {
-		_script = new SAGA2Script(this);
-	}
+	if (getLanguage() == Common::JA_JPN)
+		_font = new SJISFont(this);
+	else
+		_font = new DefaultFont(this);
+	_sprite = new Sprite(this);
+	_script = new SAGA1Script(this);
 
 	_anim = new Anim(this);
 	_interface = new Interface(this); // requires script module
@@ -292,16 +273,12 @@ Common::Error SagaEngine::run() {
 	// Initialize system specific sound
 	_sound = new Sound(this, _mixer);
 
-	if (!isSaga2()) {
-		_interface->converseClear();
-		_script->setVerb(_script->getVerbType(kVerbWalkTo));
-	}
+	_interface->converseClear();
+	_script->setVerb(_script->getVerbType(kVerbWalkTo));
 
-	_music->setVolume(_musicVolume, 1);
+	_music->resetVolume();
 
-	if (!isSaga2()) {
-		_gfx->initPalette();
-	}
+	_gfx->initPalette();
 
 	if (_voiceFilesExist) {
 		if (getGameId() == GID_IHNM) {
@@ -389,6 +366,8 @@ Common::Error SagaEngine::run() {
 		_system->delayMillis(10);
 	}
 
+	_music->close();
+
 	return Common::kNoError;
 }
 
@@ -416,7 +395,7 @@ void SagaEngine::loadStrings(StringsTable &stringsTable, const ByteArray &string
 		// In some rooms in IHNM, string offsets can be greater than the maximum value than a 16-bit integer can hold
 		// We detect this by checking the previous offset, and if it was bigger than the current one, an overflow
 		// occurred (since the string offsets are sequential), so we're adding the missing part of the number
-		// Fixes bug #1895205 - "IHNM: end game text/caption error"
+		// Fixes bug #3629 - "IHNM: end game text/caption error"
 		if (prevOffset > offset)
 			offset += 65536;
 		prevOffset = offset;
@@ -520,6 +499,13 @@ const char *SagaEngine::getTextString(int textStringId) {
 			break;
 	}
 
+	if (getLanguage() == Common::RU_RUS && textStringId == 43) {
+		if (getGameId() == GID_ITE)
+			return "\xCF\xF0\xE8\xEC\xE5\xED\xE8\xF2\xFC -> %s -> %s"; // "Применить -> %s -> %s"
+		else
+			return "\xC8\xF1\xEF\xEE\xEB\xFC\xE7\xEE\xE2\xE0\xF2\xFC %s >> %s"; // "Использовать %s >> %s"
+	}
+
 	string = ITEinterfaceTextStrings[lang][textStringId];
 	if (!string)
 		string = ITEinterfaceTextStrings[0][textStringId];
@@ -572,6 +558,9 @@ ColorId SagaEngine::KnownColor2ColorId(KnownColor knownColor) {
 		case (kKnownColorSubtitleTextColor):
 			colorId = (ColorId)255;
 			break;
+		case (kKnownColorSubtitleEffectColorPC98):
+			colorId = (ColorId)210;
+			break;
 		case (kKnownColorVerbText):
 			colorId = kITEColorBlue;
 			break;
@@ -588,7 +577,7 @@ ColorId SagaEngine::KnownColor2ColorId(KnownColor knownColor) {
 #ifdef ENABLE_IHNM
 	} else if (getGameId() == GID_IHNM) {
 		// The default colors in the Spanish, version of IHNM are shifted by one
-		// Fixes bug #1848016 - "IHNM: Wrong Subtitles Color (Spanish)". This
+		// Fixes bug #3498 - "IHNM: Wrong Subtitles Color (Spanish)". This
 		// also applies to the German and French versions (bug #7064 - "IHNM:
 		// text mistake in german version").
 		int offset = (getFeatures() & GF_IHNM_COLOR_FIX) ? 1 : 0;
@@ -641,9 +630,7 @@ void SagaEngine::syncSoundSettings() {
 	if (_readingSpeed > 3)
 		_readingSpeed = 0;
 
-	_musicVolume = ConfMan.getInt("music_volume");
-	_music->setVolume(_musicVolume, 1);
-	_sound->setVolume();
+	_music->syncSoundSettings();
 }
 
 void SagaEngine::pauseEngineIntern(bool pause) {
