@@ -45,6 +45,7 @@ GameFeatures::GameFeatures(SegManager *segMan, Kernel *kernel) : _segMan(segMan)
 	if (!ConfMan.getBool("use_cdaudio"))
 		_usesCdTrack = false;
 	_forceDOSTracks = false;
+	_useWindowsCursors = ConfMan.getBool("windows_cursors");
 	_pseudoMouseAbility = kPseudoMouseAbilityUninitialized;
 }
 
@@ -215,7 +216,14 @@ SciVersion GameFeatures::detectSetCursorType() {
 			// kSetCursor semantics, otherwise it uses the SCI0 early kSetCursor
 			// semantics.
 			if (number == 0)
-				_setCursorType = SCI_VERSION_1_1;
+				// KQ5 CD's DOS interpreter contained the new kSetCusor API while
+				// the Windows interpreter contained the old. The scripts tested
+				// the platform to see which version to call.
+				if (g_sci->getGameId() == GID_KQ5 && _useWindowsCursors) {
+					_setCursorType = SCI_VERSION_0_EARLY;
+				} else {
+					_setCursorType = SCI_VERSION_1_1;
+				}
 			else
 				_setCursorType = SCI_VERSION_0_EARLY;
 		}
@@ -636,7 +644,7 @@ int GameFeatures::detectPlaneIdBase() {
 	else
 		return 20000;
 }
-	
+
 bool GameFeatures::autoDetectMoveCountType() {
 	// Look up the script address
 	reg_t addr = getDetectionAddr("Motion", SELECTOR(doit));
@@ -723,7 +731,7 @@ bool GameFeatures::generalMidiOnly() {
 		return (sound.exists() && sound.getTrackByType(/* AdLib */ 0) == nullptr);
 	}
 	default:
-		 if (g_sci->getPlatform() == Common::kPlatformMacintosh && 
+		 if (g_sci->getPlatform() == Common::kPlatformMacintosh &&
 			 getSciVersion() >= SCI_VERSION_2_1_MIDDLE) {
 			 return true;
 		 }
@@ -830,4 +838,16 @@ bool GameFeatures::useEarlyGetLongestTextCalculations() const {
 	}
 }
 
+bool GameFeatures::hasScriptObjectNames() const {
+	switch (g_sci->getGameId()) {
+	case GID_HOYLE4:
+	case GID_LSL6:
+	case GID_QFG1VGA:
+		return (g_sci->getPlatform() != Common::kPlatformMacintosh);
+	
+	default:
+		return true;
+	}
+}
+
 } // End of namespace Sci
