@@ -22,7 +22,7 @@
 
 /* String and parser handling */
 
-#include "sci/resource.h"
+#include "sci/resource/resource.h"
 #include "sci/engine/state.h"
 #include "sci/engine/selector.h"
 #include "sci/engine/message.h"
