@@ -319,18 +319,18 @@ static void draw_line(EngineState *s, Common::Point p1, Common::Point p2, int ty
 	// Red : Barred access
 	// Yellow: Contained access
 	int poly_colors[4] = { 0, 0, 0, 0 };
-	
+
 	if (getSciVersion() <= SCI_VERSION_1_1) {
-		poly_colors[0] = g_sci->_gfxPalette16->kernelFindColor(0, 255, 0);		// green
-		poly_colors[1] = g_sci->_gfxPalette16->kernelFindColor(0, 0, 255);		// blue
-		poly_colors[2] = g_sci->_gfxPalette16->kernelFindColor(255, 0, 0);		// red
-		poly_colors[3] = g_sci->_gfxPalette16->kernelFindColor(255, 255, 0);	// yellow
+		poly_colors[0] = g_sci->_gfxPalette16->kernelFindColor(0, 255, 0, true);   // green
+		poly_colors[1] = g_sci->_gfxPalette16->kernelFindColor(0, 0, 255, true);   // blue
+		poly_colors[2] = g_sci->_gfxPalette16->kernelFindColor(255, 0, 0, true);   // red
+		poly_colors[3] = g_sci->_gfxPalette16->kernelFindColor(255, 255, 0, true); // yellow
 #ifdef ENABLE_SCI32
 	} else {
 		poly_colors[0] = g_sci->_gfxPalette32->matchColor(0, 255, 0);			// green
 		poly_colors[1] = g_sci->_gfxPalette32->matchColor(0, 0, 255);			// blue
 		poly_colors[2] = g_sci->_gfxPalette32->matchColor(255, 0, 0);			// red
-		poly_colors[3] = g_sci->_gfxPalette32->matchColor(255, 255, 0);			// yellow	
+		poly_colors[3] = g_sci->_gfxPalette32->matchColor(255, 255, 0);			// yellow
 #endif
 	}
 
@@ -360,8 +360,8 @@ static void draw_point(EngineState *s, Common::Point p, int start, int width, in
 	int point_colors[2] = { 0, 0 };
 
 	if (getSciVersion() <= SCI_VERSION_1_1) {
-		point_colors[0] = g_sci->_gfxPalette16->kernelFindColor(0, 255, 0);	// green
-		point_colors[1] = g_sci->_gfxPalette16->kernelFindColor(0, 0, 255);	// blue
+		point_colors[0] = g_sci->_gfxPalette16->kernelFindColor(0, 255, 0, true); // green
+		point_colors[1] = g_sci->_gfxPalette16->kernelFindColor(0, 0, 255, true); // blue
 #ifdef ENABLE_SCI32
 	} else {
 		point_colors[0] = g_sci->_gfxPalette32->matchColor(0, 255, 0);		// green
@@ -401,7 +401,7 @@ static void draw_polygon(EngineState *s, reg_t polygon, int width, int height) {
 #endif
 
 	int size = readSelectorValue(segMan, polygon, SELECTOR(size));
-	int type = readSelectorValue(segMan, polygon, SELECTOR(type));
+	int type = readSelectorValue(segMan, polygon, SELECTOR(type)) & ~0x10; // ignore kMergePoly flag
 	Common::Point first, prev;
 	int i;
 
@@ -1005,7 +1005,25 @@ static Common::Point *fixup_start_point(PathfindingState *s, const Common::Point
 					// We need to break in this case, otherwise we'll end in an infinite
 					// loop.
 					warning("AvoidPath: start point is contained in multiple polygons");
-					break;
+
+					// WORKAROUND: LB2 room 530 has two barred access polygons obstacles with
+					// the second completely contained in the first. To walk down the stairs,
+					// the script places ego within the inner polygon to walk along a path
+					// that's also contained by both polygons. Our algorithm fixes up the
+					// start point against the first polygon that contains it, and so the
+					// staircase polygon is ignored. Instead ego's start position is set just
+					// outside the first (outer) polygon. The destination is then unreachable
+					// and so the script proceeds without ego ever walking down the stairs.
+					// The workaround is to ignore the fixup against the first polygon.
+					bool ignoreEarlierPolygon = g_sci->getGameId() == GID_LAURABOW2 &&
+												g_sci->getEngineState()->currentRoomNumber() == 530 &&
+												(*it)->vertices.size() == 14;
+					if (ignoreEarlierPolygon) {
+						delete s->_prependPoint;
+						s->_prependPoint = NULL;
+					} else {
+						break;
+					}
 				}
 
 				if (s->findNearPoint(start, (*it), new_start) != PF_OK) {
@@ -1064,7 +1082,7 @@ static Common::Point *fixup_end_point(PathfindingState *s, const Common::Point &
 					// We shouldn't get here twice.
 					// Happens in LB2CD, inside the speakeasy when walking from the
 					// speakeasy (room 310) into the bathroom (room 320), after having
-					// consulted the notebook (bug #3036299).
+					// consulted the notebook (bug #5029).
 					// We need to break in this case, otherwise we'll end in an infinite
 					// loop.
 					warning("AvoidPath: end point is contained in multiple polygons");
@@ -1169,7 +1187,7 @@ static Polygon *convert_polygon(EngineState *s, reg_t polygon) {
 	SegmentRef pointList = segMan->dereference(points);
 	// Check if the target polygon is still valid. It may have been released
 	// in the meantime (e.g. in LSL6, room 700, when using the elevator).
-	// Refer to bug #3034501.
+	// Refer to bug #4946.
 	if (!pointList.isValid() || pointList.skipByte) {
 		warning("convert_polygon: Polygon data pointer is invalid, skipping polygon");
 		return NULL;
@@ -1254,7 +1272,7 @@ static PathfindingState *convert_polygon_set(EngineState *s, reg_t poly_list, Co
 
 		while (node) {
 			// The node value might be null, in which case there's no polygon to parse.
-			// Happens in LB2 floppy - refer to bug #3041232
+			// Happens in LB2 floppy - refer to bug #5195
 			polygon = !node->value.isNull() ? convert_polygon(s, node->value) : NULL;
 
 			if (polygon) {
@@ -1880,7 +1898,7 @@ reg_t kIntersections(EngineState *s, int argc, reg_t *argv) {
 
 // Compute square of the distance of p to the segment a-b.
 static float pointSegDistance(const Common::Point &a, const Common::Point &b,
-                              const Common::Point &p) {
+							  const Common::Point &p) {
 	FloatPoint ba(b-a);
 	FloatPoint pa(p-a);
 	FloatPoint bp(b-p);
