@@ -21,7 +21,7 @@
  */
 
 #include "sci/sci.h"
-#include "sci/resource.h"
+#include "sci/resource/resource.h"
 #include "sci/engine/seg_manager.h"
 #include "sci/engine/script.h"
 #include "sci/engine/state.h"
@@ -287,17 +287,6 @@ reg_t kScriptID(EngineState *s, int argc, reg_t *argv) {
 		return NULL_REG;
 
 	const uint32 address = scr->validateExportFunc(index, true) + scr->getHeapOffset();
-
-	// WORKAROUND: Bugfix for the intro speed in PQ2 version 1.002.011.
-	// This is taken from the patch by NewRisingSun(NRS) / Belzorash. Global 3
-	// is used for timing during the intro, and in the problematic version it's
-	// initialized to 0, whereas it's 6 in other versions. Thus, we assign it
-	// to 6 here, fixing the speed of the introduction. Refer to bug #3102071.
-	if (g_sci->getGameId() == GID_PQ2 && script == 200 &&
-		s->variables[VAR_GLOBAL][kGlobalVarSpeed].isNull()) {
-		s->variables[VAR_GLOBAL][kGlobalVarSpeed] = make_reg(0, 6);
-	}
-
 	return make_reg32(scriptSeg, address);
 }
 
