@@ -37,6 +37,13 @@ struct EngineState;
  *
  * Version - new/changed feature
  * =============================
+ *      45 - Sync stopAfterFading
+ *      44 - GK2+SCI3 audio resource locks
+ *      43 - stop saving SCI3 mustSetViewVisible array
+ *      42 - SCI3 robots and VM objects
+ *      41 - palette support for newer SCI2.1 games; stable SCI2/2.1 save games
+ *      40 - always store palvary variables
+ *      39 - Accurate SCI32 arrays/strings, score metadata, avatar metadata
  *      38 - SCI32 cursor
  *      37 - Segment entry data changed to pointers
  *      36 - SCI32 bitmap segment
@@ -63,8 +70,12 @@ struct EngineState;
  */
 
 enum {
-	CURRENT_SAVEGAME_VERSION = 38,
+	CURRENT_SAVEGAME_VERSION = 45,
 	MINIMUM_SAVEGAME_VERSION = 14
+#ifdef ENABLE_SCI32
+	,
+	MINIMUM_SCI32_SAVEGAME_VERSION = 41
+#endif
 };
 
 // Savegame metadata
@@ -77,35 +88,63 @@ struct SavegameMetadata {
 	uint32 playTime;
 	uint16 gameObjectOffset;
 	uint16 script0Size;
+
+	// Used by Shivers 1
+	uint16 lowScore;
+	uint16 highScore;
+
+	// Used by MGDX
+	uint8 avatarId;
 };
 
+/**
+* Saves a game state to the hard disk in a portable way.
+* @param s			The state to save
+* @param saveId		The id of the savegame
+* @param savename	The description of the savegame
+* @param version	The version string of the game
+* @return true on success, false otherwise
+*/
+bool gamestate_save(EngineState *s, int saveId, const Common::String &savename, const Common::String &version);
+
 /**
  * Saves a game state to the hard disk in a portable way.
  * @param s			The state to save
  * @param save		The stream to save to
  * @param savename	The description of the savegame
- * @return 0 on success, 1 otherwise
+ * @param version	The version string of the game
+ * @return true on success, false otherwise
  */
 bool gamestate_save(EngineState *s, Common::WriteStream *save, const Common::String &savename, const Common::String &version);
 
-// does a delayed saved game restore, used by ScummVM game menu - see detection.cpp / SciEngine::loadGameState()
-void gamestate_delayedrestore(EngineState *s);
-
 // does a few fixups right after restoring a saved game
 void gamestate_afterRestoreFixUp(EngineState *s, int savegameId);
 
+/**
+* Restores a game state from a directory.
+* @param s			An older state from the same game
+* @param saveId		The id of the savegame to restore from
+* @return true on success, false otherwise
+*/
+bool gamestate_restore(EngineState *s, int saveId);
+
 /**
  * Restores a game state from a directory.
  * @param s			An older state from the same game
- * @param dirname	The subdirectory to restore from
+ * @param save		The stream to restore from
  */
 void gamestate_restore(EngineState *s, Common::SeekableReadStream *save);
 
 /**
  * Read the header from a savegame.
  */
-bool get_savegame_metadata(Common::SeekableReadStream* stream, SavegameMetadata* meta);
+bool get_savegame_metadata(Common::SeekableReadStream *stream, SavegameMetadata &meta);
 
+/**
+ * Write the header to a savegame.
+ */
+void set_savegame_metadata(Common::Serializer &ser, Common::WriteStream *fh, const Common::String &savename, const Common::String &version);
+void set_savegame_metadata(Common::WriteStream *fh, const Common::String &savename, const Common::String &version);
 
 } // End of namespace Sci
 
