@@ -23,6 +23,7 @@
 
 #include "sci/sci.h"	// for INCLUDE_OLDGFX
 #include "sci/debug.h"	// for g_debug_sleeptime_factor
+#include "sci/engine/features.h"
 #include "sci/engine/file.h"
 #include "sci/engine/guest_additions.h"
 #include "sci/engine/kernel.h"
@@ -107,6 +108,7 @@ void EngineState::reset(bool isRestoring) {
 #ifdef ENABLE_SCI32
 	_eventCounter = 0;
 #endif
+	_paletteSetIntensityCounter = 0;
 	_throttleLastTime = 0;
 	_throttleTrigger = false;
 	_gameIsBenchmarking = false;
@@ -168,6 +170,13 @@ void EngineState::initGlobals() {
 	variablesSegment[VAR_GLOBAL] = script_000->getLocalsSegment();
 	variablesBase[VAR_GLOBAL] = variables[VAR_GLOBAL] = script_000->getLocalsBegin();
 	variablesMax[VAR_GLOBAL] = script_000->getLocalsCount();
+
+	// The KQ5 CD Windows interpreter set global 400 to tell the scripts that the
+	//  platform was Windows. The global determines which cursors the scripts use,
+	//  so we only set this if the user has chosen to use Windows cursors.
+	if (g_sci->getGameId() == GID_KQ5 && g_sci->isCD()) {
+		variables[VAR_GLOBAL][400].setOffset(g_sci->_features->useWindowsCursors());
+	}
 }
 
 uint16 EngineState::currentRoomNumber() const {
@@ -212,6 +221,9 @@ static kLanguage charToLanguage(const char c) {
 Common::String SciEngine::getSciLanguageString(const Common::String &str, kLanguage requestedLanguage, kLanguage *secondaryLanguage, uint16 *languageSplitter) const {
 	kLanguage foundLanguage = K_LANG_NONE;
 	const byte *textPtr = (const byte *)str.c_str();
+	if (secondaryLanguage) {
+		*secondaryLanguage = K_LANG_NONE;
+	}
 	byte curChar = 0;
 	byte curChar2 = 0;
 
@@ -252,24 +264,6 @@ Common::String SciEngine::getSciLanguageString(const Common::String &str, kLangu
 				switch (curChar) {
 				case 0: // Terminator NUL
 					return fullWidth;
-				case '\\':
-					// "\n", "\N", "\r" and "\R" were overwritten with SPACE + 0x0D in PC-9801 SSCI
-					//  inside GetLongest() (text16). We do it here, because it's much cleaner and
-					//  we have to process the text here anyway.
-					//  Occurs for example in Police Quest 2 intro
-					curChar2 = *(textPtr + 1);
-					switch (curChar2) {
-					case 'n':
-					case 'N':
-					case 'r':
-					case 'R':
-						fullWidth += ' ';
-						fullWidth += 0x0D; // CR
-						textPtr += 2;
-						continue;
-					default:
-						break;
-					}
 				default:
 					break;
 				}
@@ -325,6 +319,13 @@ kLanguage SciEngine::getSciLanguage() {
 			switch (getLanguage()) {
 			case Common::FR_FRA:
 				lang = K_LANG_FRENCH;
+				// WORKAROUND: The French version of LSL1VGA is a fan patch that's based
+				// on the official Spanish version, with the Spanish content replaced
+				// with French content. The game scripts require printLang to be Spanish
+				// in order to use the French text and load the correct views.
+				if (g_sci->getGameId() == GID_LSL1) {
+					lang = K_LANG_SPANISH;
+				}
 				break;
 			case Common::ES_ESP:
 				lang = K_LANG_SPANISH;
