@@ -179,51 +179,15 @@ static inline reg_t make_reg(SegmentId segment, uint16 offset) {
 	return r;
 }
 
-#define PRINT_REG(r) (kSegmentMask) & (unsigned) (r).getSegment(), (unsigned) (r).getOffset()
-
-// A true 32-bit reg_t
-struct reg32_t {
-	// Segment and offset. These should never be accessed directly
-	SegmentId _segment;
-	uint32 _offset;
-
-	inline SegmentId getSegment() const {
-		return _segment;
-	}
-
-	inline void setSegment(SegmentId segment) {
-		_segment = segment;
-	}
-
-	inline uint32 getOffset() const {
-		return _offset;
-	}
-
-	inline void setOffset(uint32 offset) {
-		_offset = offset;
-	}
-
-	inline void incOffset(int32 offset) {
-		setOffset(getOffset() + offset);
-	}
-
-	// Comparison operators
-	bool operator==(const reg32_t &x) const {
-		return (getOffset() == x.getOffset()) && (getSegment() == x.getSegment());
-	}
-
-	bool operator!=(const reg32_t &x) const {
-		return (getOffset() != x.getOffset()) || (getSegment() != x.getSegment());
-	}
-};
-
-static inline reg32_t make_reg32(SegmentId segment, uint32 offset) {
-	reg32_t r;
+static inline reg_t make_reg32(SegmentId segment, uint32 offset) {
+	reg_t r;
 	r.setSegment(segment);
 	r.setOffset(offset);
 	return r;
 }
 
+#define PRINT_REG(r) (kSegmentMask) & (unsigned) (r).getSegment(), (unsigned) (r).getOffset()
+
 // Stack pointer type
 typedef reg_t *StackPtr;
 
