@@ -30,6 +30,7 @@
 #include "sci/graphics/cache.h"
 #include "sci/graphics/scifont.h"
 #include "sci/graphics/fontsjis.h"
+#include "sci/graphics/fontkorean.h"
 #include "sci/graphics/view.h"
 
 namespace Sci {
@@ -66,8 +67,11 @@ GfxFont *GfxCache::getFont(GuiResourceId fontId) {
 		purgeFontCache();
 
 	if (!_cachedFonts.contains(fontId)) {
+		// Create special Korean font in korean games, when font 1001 is selected
+		if ((fontId == 1001) && (g_sci->getLanguage() == Common::KO_KOR))
+			_cachedFonts[fontId] = new GfxFontKorean(_screen, fontId);
 		// Create special SJIS font in japanese games, when font 900 is selected
-		if ((fontId == 900) && (g_sci->getLanguage() == Common::JA_JPN))
+		else if ((fontId == 900) && (g_sci->getLanguage() == Common::JA_JPN))
 			_cachedFonts[fontId] = new GfxFontSjis(_screen, fontId);
 		else
 			_cachedFonts[fontId] = new GfxFontFromResource(_resMan, _screen, fontId);
