@@ -33,7 +33,7 @@
 #include "sci/graphics/paint16.h"
 #include "sci/graphics/animate.h"
 #include "sci/graphics/cursor.h"
-#include "sci/graphics/font.h"
+#include "sci/graphics/scifont.h"
 #include "sci/graphics/text16.h"
 #include "sci/graphics/screen.h"
 #include "sci/graphics/menu.h"
@@ -138,6 +138,8 @@ void GfxMenu::kernelAddEntry(Common::String title, Common::String content, reg_t
 					functionPos = curPos;
 				}
 				break;
+			default:
+				break;
 			}
 			curPos++;
 		}
@@ -205,6 +207,9 @@ void GfxMenu::kernelAddEntry(Common::String title, Common::String content, reg_t
 				// Some multilingual sci01 games use e.g. '--!%G--!' (which doesn't really make sense)
 				separatorCount += 2;
 				curPos++;
+				break;
+			default:
+				break;
 			}
 			curPos++;
 		}
@@ -283,7 +288,7 @@ void GfxMenu::kernelSetAttribute(uint16 menuId, uint16 itemId, uint16 attributeI
 	GuiMenuItemEntry *itemEntry = findItem(menuId, itemId);
 
 	if (!itemEntry) {
-		// PQ2 demo calls this, for example, but has no menus (bug report #3034507). Some SCI
+		// PQ2 demo calls this, for example, but has no menus (bug report #4948). Some SCI
 		// fan games (Al Pond 2, Aquarius) call this too on non-existent menu items. The
 		// original interpreter ignored these as well.
 		debugC(kDebugLevelGraphics, "Tried to setAttribute() on non-existent menu-item %d:%d", menuId, itemId);
@@ -350,12 +355,24 @@ void GfxMenu::drawBar() {
 	_paint16->fillRect(_ports->_menuBarRect, 1, _screen->getColorWhite());
 	_paint16->fillRect(_ports->_menuLine, 1, 0);
 	_ports->penColor(0);
-	_ports->moveTo(8, 1);
+	if (!g_sci->isLanguageRTL())
+		_ports->moveTo(8, 1);
+	else
+		_ports->moveTo(_screen->getWidth() - 8, 1);
 
 	listIterator = _list.begin();
 	while (listIterator != listEnd) {
 		listEntry = *listIterator;
+		int16 textWidth;
+		int16 textHeight;
+		if (g_sci->isLanguageRTL()) {
+			_text16->StringWidth(listEntry->textSplit.c_str(), _text16->GetFontId(), textWidth, textHeight);
+			_ports->_curPort->curLeft -= textWidth;
+		}
+		int16 origCurLeft = _ports->_curPort->curLeft;
 		_text16->DrawString(listEntry->textSplit.c_str());
+		if (g_sci->isLanguageRTL())
+			_ports->_curPort->curLeft = origCurLeft;
 
 		listIterator++;
 	}
@@ -492,6 +509,9 @@ reg_t GfxMenu::kernelSelect(reg_t eventObject, bool pauseSound) {
 			forceClaimed = true;
 		}
 		} break;
+
+	default:
+		break;
 	}
 
 	if (!_menuSaveHandle.isNull()) {
@@ -576,19 +596,30 @@ void GfxMenu::drawMenu(uint16 oldMenuId, uint16 newMenuId) {
 	_menuRect.top = _ports->_menuBarRect.bottom;
 	menuTextRect.top = _ports->_menuBarRect.top;
 	menuTextRect.bottom = _ports->_menuBarRect.bottom;
-	menuTextRect.left = menuTextRect.right = 7;
+	if (!g_sci->isLanguageRTL())
+		menuTextRect.left = menuTextRect.right = 7;
+	else
+		menuTextRect.left = menuTextRect.right = _ports->_menuBarRect.right - 7;
 	listIterator = _list.begin();
 	while (listIterator != listEnd) {
 		listEntry = *listIterator;
 		listNr++;
-		menuTextRect.left = menuTextRect.right;
-		menuTextRect.right += listEntry->textWidth;
-		if (listNr == newMenuId)
-			_menuRect.left = menuTextRect.left;
+		if (!g_sci->isLanguageRTL()) {
+			menuTextRect.left = menuTextRect.right;
+			menuTextRect.right += listEntry->textWidth;
+			if (listNr == newMenuId)
+				_menuRect.left = menuTextRect.left;
+		} else {
+			menuTextRect.right = menuTextRect.left;
+			menuTextRect.left -= listEntry->textWidth;
+			if (listNr == newMenuId)
+				_menuRect.right = menuTextRect.right;
+		}
 		if ((listNr == newMenuId) || (listNr == oldMenuId)) {
-			menuTextRect.translate(1, 0);
+			int multiplier = !g_sci->isLanguageRTL() ? 1 : -1;
+			menuTextRect.translate(1 * multiplier, 0);
 			_paint16->invertRect(menuTextRect);
-			menuTextRect.translate(-1, 0);
+			menuTextRect.translate(-1 * multiplier, 0);
 		}
 
 		listIterator++;
@@ -606,16 +637,26 @@ void GfxMenu::drawMenu(uint16 oldMenuId, uint16 newMenuId) {
 		}
 		listItemIterator++;
 	}
-	_menuRect.right = _menuRect.left + 16 + 4 + 2;
-	_menuRect.right += maxTextWidth + maxTextRightAlignedWidth;
-	if (!maxTextRightAlignedWidth)
-		_menuRect.right -= 5;
+	if (!g_sci->isLanguageRTL()) {
+		_menuRect.right = _menuRect.left + 16 + 4 + 2;
+		_menuRect.right += maxTextWidth + maxTextRightAlignedWidth;
+		if (!maxTextRightAlignedWidth)
+			_menuRect.right -= 5;
+	} else {
+		_menuRect.left = _menuRect.right - (16 + 4 + 2);
+		_menuRect.left -= (maxTextWidth + maxTextRightAlignedWidth);
+		if (!maxTextRightAlignedWidth)
+			_menuRect.left += 5;
+	}
 
 	// If part of menu window is outside the screen, move it into the screen
 	// (this happens in multilingual sq3 and lsl3).
 	if (_menuRect.right > _screen->getWidth()) {
 		_menuRect.translate(-(_menuRect.right - _screen->getWidth()), 0);
 	}
+	if (_menuRect.left < 0) {
+		warning("GfxMenu::drawMenu: _menuRect.left < 0");
+	}
 
 	// Save background
 	_menuSaveHandle = _paint16->bitsSave(_menuRect, GFX_SCREEN_MASK_VISUAL);
@@ -625,7 +666,10 @@ void GfxMenu::drawMenu(uint16 oldMenuId, uint16 newMenuId) {
 	_menuRect.left++; _menuRect.right--; _menuRect.bottom--;
 	_paint16->fillRect(_menuRect, GFX_SCREEN_MASK_VISUAL, _screen->getColorWhite());
 
-	_menuRect.left += 8;
+	if (!g_sci->isLanguageRTL())
+		_menuRect.left += 8;
+	else
+		_menuRect.right -= 8;
 	topPos = _menuRect.top + 1;
 	listItemIterator = _itemList.begin();
 	while (listItemIterator != listItemEnd) {
@@ -633,10 +677,17 @@ void GfxMenu::drawMenu(uint16 oldMenuId, uint16 newMenuId) {
 		if (listItemEntry->menuId == newMenuId) {
 			if (!listItemEntry->separatorLine) {
 				_ports->textGreyedOutput(!listItemEntry->enabled);
-				_ports->moveTo(_menuRect.left, topPos);
-				_text16->DrawString(listItemEntry->textSplit.c_str());
-				_ports->moveTo(_menuRect.right - listItemEntry->textRightAlignedWidth - 5, topPos);
-				_text16->DrawString(listItemEntry->textRightAligned.c_str());
+				if (!g_sci->isLanguageRTL()) {
+					_ports->moveTo(_menuRect.left, topPos);
+					_text16->DrawString(listItemEntry->textSplit.c_str());
+					_ports->moveTo(_menuRect.right - listItemEntry->textRightAlignedWidth - 5, topPos);
+					_text16->DrawString(listItemEntry->textRightAligned.c_str());
+				} else {
+					_ports->moveTo(_menuRect.left + 5, topPos);
+					_text16->DrawString(listItemEntry->textRightAligned.c_str());
+					_ports->moveTo(_menuRect.right - listItemEntry->textWidth, topPos);
+					_text16->DrawString(listItemEntry->textSplit.c_str());
+				}
 			} else {
 				// We dont 100% follow sierra here, we draw the line from left to right. Looks better
 				// BTW. SCI1.1 seems to put 2 pixels and then skip one, we don't do this at all (lsl6)
@@ -656,8 +707,16 @@ void GfxMenu::drawMenu(uint16 oldMenuId, uint16 newMenuId) {
 	// Draw the black line again
 	_paint16->fillRect(_ports->_menuLine, 1, 0);
 
-	_menuRect.left -= 8;
-	_menuRect.left--; _menuRect.right++; _menuRect.bottom++;
+	if (!g_sci->isLanguageRTL()) {
+		_menuRect.left -= 8;
+		_menuRect.left--;
+		_menuRect.right++;
+	} else {
+		_menuRect.right += 8;
+		_menuRect.right--;
+		_menuRect.left++;
+	}
+	_menuRect.bottom++;
 	_paint16->bitsShow(_menuRect);
 }
 
@@ -693,15 +752,26 @@ uint16 GfxMenu::mouseFindMenuSelection(Common::Point mousePosition) {
 	GuiMenuEntry *listEntry;
 	GuiMenuList::iterator listIterator;
 	GuiMenuList::iterator listEnd = _list.end();
-	uint16 curXstart = 8;
+	uint16 curXstart;
+	if (!g_sci->isLanguageRTL())
+		curXstart = 8;
+	else
+		curXstart = _screen->getWidth() - 8;
 
 	listIterator = _list.begin();
 	while (listIterator != listEnd) {
 		listEntry = *listIterator;
-		if (mousePosition.x >= curXstart && mousePosition.x < curXstart + listEntry->textWidth) {
-			return listEntry->id;
+		if (!g_sci->isLanguageRTL()) {
+			if (mousePosition.x >= curXstart && mousePosition.x < curXstart + listEntry->textWidth) {
+				return listEntry->id;
+			}
+			curXstart += listEntry->textWidth;
+		} else {
+			if (mousePosition.x <= curXstart && mousePosition.x > curXstart - listEntry->textWidth) {
+				return listEntry->id;
+			}
+			curXstart -= listEntry->textWidth;
 		}
-		curXstart += listEntry->textWidth;
 		listIterator++;
 	}
 	return 0;
@@ -759,6 +829,8 @@ GuiMenuItemEntry *GfxMenu::interactiveWithKeyboard() {
 	_paint16->bitsShow(_ports->_menuRect);
 	_paint16->bitsShow(_menuRect);
 
+	int multiplier = !g_sci->isLanguageRTL() ? 1 : -1;
+
 	while (true) {
 		curEvent = _event->getSciEvent(kSciEventAny);
 
@@ -779,10 +851,12 @@ GuiMenuItemEntry *GfxMenu::interactiveWithKeyboard() {
 					}
 					break;
 				case kSciKeyLeft:
-					newMenuId--; newItemId = 1;
+					newMenuId -= 1 * multiplier;
+					newItemId = 1;
 					break;
 				case kSciKeyRight:
-					newMenuId++; newItemId = 1;
+					newMenuId += 1 * multiplier;
+					newItemId = 1;
 					break;
 				case kSciKeyUp:
 					newItemId--;
@@ -790,6 +864,8 @@ GuiMenuItemEntry *GfxMenu::interactiveWithKeyboard() {
 				case kSciKeyDown:
 					newItemId++;
 					break;
+				default:
+					break;
 				}
 				if ((newMenuId != curItemEntry->menuId) || (newItemId != curItemEntry->id)) {
 					// Selection changed, fix up new selection if required
@@ -801,6 +877,9 @@ GuiMenuItemEntry *GfxMenu::interactiveWithKeyboard() {
 					case kSciKeyLeft:
 					case kSciKeyRight:
 						curEvent.character = kSciKeyDown;
+						break;
+					default:
+						break;
 					}
 				}
 			} while (newItemEntry->separatorLine);
@@ -855,6 +934,9 @@ GuiMenuItemEntry *GfxMenu::interactiveWithKeyboard() {
 			g_sci->sleep(2500 / 1000);
 			break;
 
+		case kSciEventQuit:
+			return NULL;
+
 		default:
 			break;
 		}
@@ -939,7 +1021,14 @@ void GfxMenu::kernelDrawStatus(const char *text, int16 colorPen, int16 colorBack
 
 	_paint16->fillRect(_ports->_menuBarRect, 1, colorBack);
 	_ports->penColor(colorPen);
-	_ports->moveTo(0, 1);
+	if (!g_sci->isLanguageRTL()) {
+		_ports->moveTo(0, 1);
+	} else {
+		int16 textWidth;
+		int16 textHeight;
+		_text16->StringWidth(text, _text16->GetFontId(), textWidth, textHeight);
+		_ports->moveTo(_screen->getWidth() - textWidth, 1);
+	}
 	_text16->DrawStatus(text);
 	_paint16->bitsShow(_ports->_menuBarRect);
 	// Also draw the line under the status bar. Normally, this is never drawn,
