@@ -144,7 +144,7 @@ void GfxPicture::drawCelData(const SciSpan<const byte> &inbuffer, int headerPos,
 	const SciSpan<const byte> headerPtr = inbuffer.subspan(headerPos);
 	const SciSpan<const byte> rlePtr = inbuffer.subspan(rlePos);
 	// displaceX, displaceY fields are ignored, and may contain garbage
-	// (e.g. pic 261 in Dr. Brain 1 Spanish - bug #3614914)
+	// (e.g. pic 261 in Dr. Brain 1 Spanish - bug #6388)
 	//int16 displaceX, displaceY;
 	byte priority = _priority;
 	byte clearColor;
@@ -562,7 +562,7 @@ void GfxPicture::drawVectorData(const SciSpan<const byte> &data) {
 					case 35:
 					case 381:
 					case 376:
-					//case 390:	// in the blacklisted NRS patch 1.2 (bug #3615060)
+					case 390: // NRS SQ4 Update patch
 						return;
 					default:
 						break;
