@@ -44,6 +44,8 @@ GfxText16::GfxText16(GfxCache *cache, GfxPorts *ports, GfxPaint16 *paint16, GfxS
 }
 
 GfxText16::~GfxText16() {
+	delete[] _codeFonts;
+	delete[] _codeColors;
 }
 
 void GfxText16::init() {
@@ -200,6 +202,7 @@ int16 GfxText16::GetLongest(const char *&textPtr, int16 maxWidth, GuiResourceId
 	uint16 curWidth = 0, tempWidth = 0;
 	GuiResourceId previousFontId = GetFontId();
 	int16 previousPenColor = _ports->_curPort->penClr;
+	bool escapedNewLine = false;
 
 	GetFont();
 	if (!_font)
@@ -210,6 +213,14 @@ int16 GfxText16::GetLongest(const char *&textPtr, int16 maxWidth, GuiResourceId
 		if (_font->isDoubleByte(curChar)) {
 			curChar |= (*(const byte *)(textPtr + 1)) << 8;
 		}
+		if (escapedNewLine) {
+			escapedNewLine = false;
+			curChar = 0x0D;
+		} else if (isJapaneseNewLine(curChar, *(textPtr + 1))) {
+			escapedNewLine = true;
+			curChar = ' ';
+		}
+
 		switch (curChar) {
 		case 0x7C:
 			if (getSciVersion() >= SCI_VERSION_1_1) {
@@ -288,6 +299,7 @@ int16 GfxText16::GetLongest(const char *&textPtr, int16 maxWidth, GuiResourceId
 
 	} else {
 		// Break without spaces found, we split the very first word - may also be Kanji/Japanese
+
 		if (curChar > 0xFF) {
 			// current character is Japanese
 
@@ -370,6 +382,7 @@ void GfxText16::Width(const char *text, int16 from, int16 len, GuiResourceId org
 	int16 previousPenColor = _ports->_curPort->penClr;
 
 	textWidth = 0; textHeight = 0;
+	bool escapedNewLine = false;
 
 	GetFont();
 	if (_font) {
@@ -380,6 +393,14 @@ void GfxText16::Width(const char *text, int16 from, int16 len, GuiResourceId org
 				curChar |= (*(const byte *)text++) << 8;
 				len--;
 			}
+			if (escapedNewLine) {
+				escapedNewLine = false;
+				curChar = 0x0D;
+			} else if (isJapaneseNewLine(curChar, *text)) {
+				escapedNewLine = true;
+				curChar = ' ';
+			}
+
 			switch (curChar) {
 			case 0x0A:
 			case 0x0D:
@@ -435,6 +456,8 @@ int16 GfxText16::Size(Common::Rect &rect, const char *text, uint16 languageSplit
 	rect.top = rect.left = 0;
 
 	if (maxWidth < 0) { // force output as single line
+		if (g_sci->getLanguage() == Common::KO_KOR)
+			SwitchToFont1001OnKorean(text, languageSplitter);
 		if (g_sci->getLanguage() == Common::JA_JPN)
 			SwitchToFont900OnSjis(text, languageSplitter);
 
@@ -447,6 +470,11 @@ int16 GfxText16::Size(Common::Rect &rect, const char *text, uint16 languageSplit
 		rect.right = (maxWidth ? maxWidth : 192);
 		const char *curTextPos = text; // in work position for GetLongest()
 		const char *curTextLine = text; // starting point of current line
+
+		// Check for Korean text
+		if (g_sci->getLanguage() == Common::KO_KOR)
+			SwitchToFont1001OnKorean(curTextPos, languageSplitter);
+
 		while (*curTextPos) {
 			// We need to check for Shift-JIS every line
 			if (g_sci->getLanguage() == Common::JA_JPN)
@@ -480,12 +508,21 @@ void GfxText16::Draw(const char *text, int16 from, int16 len, GuiResourceId orgF
 	rect.top = _ports->_curPort->curTop;
 	rect.bottom = rect.top + _ports->_curPort->fontHeight;
 	text += from;
+	bool escapedNewLine = false;
 	while (len--) {
 		curChar = (*(const byte *)text++);
 		if (_font->isDoubleByte(curChar)) {
 			curChar |= (*(const byte *)text++) << 8;
 			len--;
 		}
+		if (escapedNewLine) {
+			escapedNewLine = false;
+			curChar = 0x0D;
+		} else if (isJapaneseNewLine(curChar, *text)) {
+			escapedNewLine = true;
+			curChar = ' ';
+		}
+
 		switch (curChar) {
 		case 0x0A:
 		case 0x0D:
@@ -542,6 +579,14 @@ void GfxText16::Box(const char *text, uint16 languageSplitter, bool show, const
 	else
 		fontId = previousFontId;
 
+	// Check for Korean text
+	if (g_sci->getLanguage() == Common::KO_KOR) {
+		if (SwitchToFont1001OnKorean(curTextPos, languageSplitter)) {
+			doubleByteMode = true;
+			fontId = 1001;
+		}
+	}
+
 	// Reset reference code rects
 	_codeRefRects.clear();
 	_codeRefTempRect.left = _codeRefTempRect.top = -1;
@@ -682,6 +727,28 @@ void GfxText16::DrawStatus(const Common::String &strOrig) {
 	}
 }
 
+// Check for Korean strings, and use font 1001 to render them
+bool GfxText16::SwitchToFont1001OnKorean(const char *text, uint16 languageSplitter) {
+	const byte* ptr = (const byte *)text;
+	if (languageSplitter != 0x6b23) { // #k prefix as language splitter
+		// Check if the text contains at least one Korean character
+		while (*ptr) {
+			byte ch = *ptr++;
+			if (ch >= 0xB0 && ch <= 0xC8) {
+				ch = *ptr++;
+				if (!ch)
+					return false;
+
+				if (ch >= 0xA1 && ch <= 0xFE) {
+					SetFont(1001);
+					return true;
+				}
+			}
+		}
+	}
+	return false;
+}
+
 // Sierra did this in their PC98 interpreter only, they identify a text as being
 // sjis and then switch to font 900
 bool GfxText16::SwitchToFont900OnSjis(const char *text, uint16 languageSplitter) {
@@ -695,6 +762,17 @@ bool GfxText16::SwitchToFont900OnSjis(const char *text, uint16 languageSplitter)
 	return false;
 }
 
+// In PC-9801 SSCI, "\n", "\N", "\r" and "\R" were overwritten with SPACE + 0x0D
+// inside GetLongest() (text16). This was a bit of a hack since it meant this
+// version altered the input that it's normally only supposed to be measuring.
+// Instead, we detect the newline sequences during string processing loops and
+// apply the substitute characters on the fly. PQ2 is the only game known to use
+// this feature. "\n" appears in most of its Japanese strings.
+bool GfxText16::isJapaneseNewLine(int16 curChar, int16 nextChar) {
+	return g_sci->getLanguage() == Common::JA_JPN &&
+		curChar == '\\' && (nextChar == 'n' || nextChar == 'N' || nextChar == 'r' || nextChar == 'R');
+}
+
 reg_t GfxText16::allocAndFillReferenceRectArray() {
 	uint rectCount = _codeRefRects.size();
 	if (rectCount) {
@@ -730,7 +808,7 @@ void GfxText16::kernelTextSize(const char *text, uint16 languageSplitter, int16
 void GfxText16::kernelTextFonts(int argc, reg_t *argv) {
 	int i;
 
-	delete _codeFonts;
+	delete[] _codeFonts;
 	_codeFontsCount = argc;
 	_codeFonts = new GuiResourceId[argc];
 	for (i = 0; i < argc; i++) {
@@ -742,7 +820,7 @@ void GfxText16::kernelTextFonts(int argc, reg_t *argv) {
 void GfxText16::kernelTextColors(int argc, reg_t *argv) {
 	int i;
 
-	delete _codeColors;
+	delete[] _codeColors;
 	_codeColorsCount = argc;
 	_codeColors = new uint16[argc];
 	for (i = 0; i < argc; i++) {
