@@ -29,6 +29,7 @@
 #include "common/random.h"
 #include "sci/engine/vm_types.h"	// for Selector
 #include "sci/debug.h"	// for DebugState
+#include "sci/detection.h" // Shared code between detection and engine
 
 struct ADGameDescription;
 
@@ -45,22 +46,6 @@ struct ADGameDescription;
  */
 namespace Sci {
 
-// GUI-options, primarily used by detection_tables.h
-#define GAMEOPTION_PREFER_DIGITAL_SFX       GUIO_GAMEOPTIONS1
-#define GAMEOPTION_ORIGINAL_SAVELOAD        GUIO_GAMEOPTIONS2
-#define GAMEOPTION_MIDI_MODE                GUIO_GAMEOPTIONS3
-#define GAMEOPTION_JONES_CDAUDIO            GUIO_GAMEOPTIONS4
-#define GAMEOPTION_KQ6_WINDOWS_CURSORS      GUIO_GAMEOPTIONS5
-#define GAMEOPTION_SQ4_SILVER_CURSORS       GUIO_GAMEOPTIONS6
-#define GAMEOPTION_EGA_UNDITHER             GUIO_GAMEOPTIONS7
-// HIGH_RESOLUTION_GRAPHICS availability is checked for in SciEngine::run()
-#define GAMEOPTION_HIGH_RESOLUTION_GRAPHICS GUIO_GAMEOPTIONS8
-#define GAMEOPTION_ENABLE_BLACK_LINED_VIDEO GUIO_GAMEOPTIONS9
-#define GAMEOPTION_HQ_VIDEO                 GUIO_GAMEOPTIONS10
-#define GAMEOPTION_ENABLE_CENSORING         GUIO_GAMEOPTIONS11
-#define GAMEOPTION_LARRYSCALE               GUIO_GAMEOPTIONS12
-#define GAMEOPTION_UPSCALE_VIDEOS           GUIO_GAMEOPTIONS13
-
 struct EngineState;
 class Vocabulary;
 class ResourceManager;
@@ -134,106 +119,6 @@ enum kDebugLevels {
 	kDebugLevelGame          = 1 << 25
 };
 
-enum SciGameId {
-	GID_ASTROCHICKEN,
-	GID_CAMELOT,
-	GID_CASTLEBRAIN,
-	GID_CHEST,
-	GID_CHRISTMAS1988,
-	GID_CHRISTMAS1990,
-	GID_CHRISTMAS1992,
-	GID_CNICK_KQ,
-	GID_CNICK_LAURABOW,
-	GID_CNICK_LONGBOW,
-	GID_CNICK_LSL,
-	GID_CNICK_SQ,
-	GID_ECOQUEST,
-	GID_ECOQUEST2,
-	GID_FAIRYTALES,
-	GID_FREDDYPHARKAS,
-	GID_FUNSEEKER,
-	GID_GK1DEMO,	// We have a separate ID for GK1 demo, because it's actually a completely different game (SCI1.1 vs SCI2/SCI2.1)
-	GID_GK1,
-	GID_GK2,
-	GID_HOYLE1,
-	GID_HOYLE2,
-	GID_HOYLE3,
-	GID_HOYLE4,
-	GID_HOYLE5,
-	GID_ICEMAN,
-	GID_INNDEMO,
-	GID_ISLANDBRAIN,
-	GID_JONES,
-	GID_KQ1,
-	GID_KQ4,
-	GID_KQ5,
-	GID_KQ6,
-	GID_KQ7,
-	GID_KQUESTIONS,
-	GID_LAURABOW,
-	GID_LAURABOW2,
-	GID_LIGHTHOUSE,
-	GID_LONGBOW,
-	GID_LSL1,
-	GID_LSL2,
-	GID_LSL3,
-	GID_LSL5,
-	GID_LSL6,
-	GID_LSL6HIRES, // We have a separate ID for LSL6 SCI32, because it's actually a completely different game
-	GID_LSL7,
-	GID_MOTHERGOOSE, // this one is the SCI0 version
-	GID_MOTHERGOOSE256, // this one handles SCI1 and SCI1.1 variants, at least those 2 share a bit in common
-	GID_MOTHERGOOSEHIRES, // this one is the SCI2.1 hires version, completely different from the other ones
-	GID_MSASTROCHICKEN,
-	GID_PEPPER,
-	GID_PHANTASMAGORIA,
-	GID_PHANTASMAGORIA2,
-	GID_PQ1,
-	GID_PQ2,
-	GID_PQ3,
-	GID_PQ4,
-	GID_PQ4DEMO,	// We have a separate ID for PQ4 demo, because it's actually a completely different game (SCI1.1 vs SCI2/SCI2.1)
-	GID_PQSWAT,
-	GID_QFG1,
-	GID_QFG1VGA,
-	GID_QFG2,
-	GID_QFG3,
-	GID_QFG4,
-	GID_QFG4DEMO,	// We have a separate ID for QFG4 demo, because it's actually a completely different game (SCI1.1 vs SCI2/SCI2.1)
-	GID_RAMA,
-	GID_SHIVERS,
-	//GID_SHIVERS2,	// Not SCI
-	GID_SLATER,
-	GID_SQ1,
-	GID_SQ3,
-	GID_SQ4,
-	GID_SQ5,
-	GID_SQ6,
-	GID_TORIN,
-	GID_FANMADE
-};
-
-/**
- * SCI versions
- * For more information, check here:
- * https://wiki.scummvm.org/index.php/Sierra_Game_Versions#SCI_Games
- */
-enum SciVersion {
-	SCI_VERSION_NONE,
-	SCI_VERSION_0_EARLY, // KQ4 early, LSL2 early, XMAS card 1988
-	SCI_VERSION_0_LATE, // KQ4, LSL2, LSL3, SQ3 etc
-	SCI_VERSION_01, // KQ1 and multilingual games (S.old.*)
-	SCI_VERSION_1_EGA_ONLY, // SCI 1 EGA with parser (i.e. QFG2 only)
-	SCI_VERSION_1_EARLY, // KQ5 floppy, SQ4 floppy, XMAS card 1990, Fairy tales, Jones floppy
-	SCI_VERSION_1_MIDDLE, // LSL1, Jones CD, LSL3 & SQ3 multilingual Amiga
-	SCI_VERSION_1_LATE, // Dr. Brain 1, EcoQuest 1, Longbow, PQ3, SQ1, LSL5, KQ5 CD
-	SCI_VERSION_1_1, // Dr. Brain 2, EcoQuest 1 CD, EcoQuest 2, KQ6, QFG3, SQ4CD, XMAS 1992 and many more
-	SCI_VERSION_2, // GK1, PQ4 floppy, QFG4 floppy
-	SCI_VERSION_2_1_EARLY, // GK2 demo, KQ7 1.4/1.51, LSL6 hires, PQ4CD, QFG4CD
-	SCI_VERSION_2_1_MIDDLE, // GK2, Hoyle 5, KQ7 2.00b, MUMG Deluxe, Phantasmagoria 1, PQ:SWAT, Shivers 1, SQ6, Torin
-	SCI_VERSION_2_1_LATE, // demos and Mac versions of LSL7, Lighthouse, RAMA
-	SCI_VERSION_3 // LSL7, Lighthouse, RAMA, Phantasmagoria 2
-};
 
 /** Supported languages */
 enum kLanguage {
@@ -247,13 +132,6 @@ enum kLanguage {
 	K_LANG_PORTUGUESE = 351
 };
 
-/** MIDI devices */
-enum kMidiMode {
-	kMidiModeStandard,
-	kMidiModeFB01,
-	kMidiModeD110
-};
-
 class SciEngine : public Engine {
 	friend class Console;
 public:
@@ -350,7 +228,7 @@ public:
 	void setSciLanguage(kLanguage lang);
 	void setSciLanguage();
 
-	Common::String getSciLanguageString(const Common::String &str, kLanguage lang, kLanguage *lang2 = NULL, uint16 *languageSplitter = NULL) const;
+	Common::String getSciLanguageString(const Common::String &str, kLanguage requestedLanguage, kLanguage *secondaryLanguage = nullptr, uint16 *languageSplitter = nullptr) const;
 
 	// Check if vocabulary needs to get switched (in multilingual parser games)
 	void checkVocabularySwitch();
@@ -367,24 +245,25 @@ public:
 	GfxCache *_gfxCache;
 	GfxCompare *_gfxCompare;
 	GfxControls16 *_gfxControls16; // Controls for 16-bit gfx
-	GfxControls32 *_gfxControls32; // Controls for 32-bit gfx
 	GfxCoordAdjuster16 *_gfxCoordAdjuster;
 	GfxCursor *_gfxCursor;
 	GfxMenu *_gfxMenu; // Menu for 16-bit gfx
 	GfxPalette *_gfxPalette16;
-	GfxPalette32 *_gfxPalette32; // Palette for 32-bit gfx
 	GfxRemap *_gfxRemap16;	// Remapping for the QFG4 demo
-	GfxRemap32 *_gfxRemap32; // Remapping for 32-bit gfx
 	GfxPaint16 *_gfxPaint16; // Painting in 16-bit gfx
-	GfxPaint32 *_gfxPaint32; // Painting in 32-bit gfx
-	GfxPorts *_gfxPorts; // Port managment for 16-bit gfx
+	GfxPorts *_gfxPorts; // Port management for 16-bit gfx
 	GfxScreen *_gfxScreen;
 	GfxText16 *_gfxText16;
-	GfxText32 *_gfxText32;
 	GfxTransitions *_gfxTransitions; // transitions between screens for 16-bit gfx
 	GfxMacIconBar *_gfxMacIconBar; // Mac Icon Bar manager
 
 #ifdef ENABLE_SCI32
+	GfxControls32 *_gfxControls32; // Controls for 32-bit gfx
+	GfxPalette32 *_gfxPalette32; // Palette for 32-bit gfx
+	GfxRemap32 *_gfxRemap32; // Remapping for 32-bit gfx
+	GfxPaint32 *_gfxPaint32; // Painting in 32-bit gfx
+	GfxText32 *_gfxText32;
+
 	Audio32 *_audio32;
 	Video32 *_video32;
 	GfxFrameout *_gfxFrameout; // kFrameout and the like for 32-bit gfx
