@@ -378,7 +378,7 @@ end:
 	*outData++ = 0x00;
 
 	// This occurs in the music tracks of LB1 Amiga, when using the MT-32
-	// driver (bug #3297881)
+	// driver (bug #5692)
 	if (!containsMidiData)
 		warning("MIDI parser: the requested SCI0 sound has no MIDI note data for the currently selected sound driver");
 }
@@ -399,12 +399,16 @@ void MidiParser_SCI::resetStateTracking() {
 }
 
 void MidiParser_SCI::initTrack() {
-	if (_soundVersion > SCI_VERSION_0_LATE)
+	if (_soundVersion > SCI_VERSION_0_LATE || !_pSnd || !_track || !_track->header.byteSize())
 		return;
 	// Send header data to SCI0 sound drivers. The driver function which parses the header (opcode 3)
 	// seems to be implemented at least in all SCI0_LATE drivers. The things that the individual drivers
 	// do in that init function varies.
-	if (_track->header.byteSize())
+	// Unlike the original (which doesn't need that due to the way it is implemented) we need to have a
+	// thread safe way to call this to avoid glitches (like permanently hanging notes in some situations).
+	if (_mainThreadCalled)
+		_music->putTrackInitCommandInQueue(_pSnd);
+	else
 		static_cast<MidiPlayer*>(_driver)->initTrack(_track->header);
 }
 
@@ -440,8 +444,13 @@ void MidiParser_SCI::unloadMusic() {
 	if (_pSnd) {
 		resetTracking();
 		allNotesOff();
+		// Pending track init commands have to be removed from the queue,
+		// since the sound thread will otherwise continue to try executing these.
+		_music->removeTrackInitCommandsFromQueue(_pSnd);
 	}
 	_numTracks = 0;
+	_pSnd = 0;
+	_track = 0;
 	_activeTrack = 255;
 	_resetOnPause = false;
 	_mixedData.clear();
@@ -686,7 +695,7 @@ bool MidiParser_SCI::processEvent(const EventInfo &info, bool fireEvents) {
 				// SCI1 and newer games. Signalling is done differently in SCI0
 				// though, so ignoring these signals in SCI0 games will result
 				// in glitches (e.g. the intro of LB1 Amiga gets stuck - bug
-				// #3297883). Refer to MusicEntry::setSignal() in sound/music.cpp.
+				// #5693). Refer to MusicEntry::setSignal() in sound/music.cpp.
 				// FIXME: SSCI doesn't start playing at the very beginning
 				// of the stream, but at a fixed location a few commands later.
 				// That is probably why this signal isn't triggered
@@ -823,7 +832,7 @@ bool MidiParser_SCI::processEvent(const EventInfo &info, bool fireEvents) {
 			// QFG3 abuses the hold flag. Its scripts call kDoSoundSetHold,
 			// but sometimes there's no hold marker in the associated songs
 			// (e.g. song 110, during the intro). The original interpreter
-			// treats this case as an infinite loop (bug #3311911).
+			// treats this case as an infinite loop (bug #5744).
 			if (_pSnd->loop || _pSnd->hold > 0) {
 				jumpToTick(_loopTick);
 
@@ -831,7 +840,6 @@ bool MidiParser_SCI::processEvent(const EventInfo &info, bool fireEvents) {
 				return true;
 
 			} else {
-				_pSnd->status = kSoundStopped;
 				_pSnd->setSignal(SIGNAL_OFFSET);
 
 				debugC(4, kDebugLevelSound, "signal EOT");
@@ -897,7 +905,7 @@ void MidiParser_SCI::allNotesOff() {
 	for (i = 0; i < 16; ++i) {
 		if (_channelRemap[i] != -1) {
 			sendToDriver(0xB0 | i, 0x7b, 0); // All notes off
-			sendToDriver(0xB0 | i, 0x40, 0); // Also send a sustain off event (bug #3116608)
+			sendToDriver(0xB0 | i, 0x40, 0); // Also send a sustain off event (bug #5524)
 		}
 	}
 
