@@ -25,6 +25,7 @@
 
 #include "common/scummsys.h"
 #include "common/rect.h"
+#include "graphics/fonts/macfont.h"
 #include "graphics/sjis.h"
 #include "scumm/scumm.h"
 #include "scumm/gfx.h"
@@ -35,12 +36,33 @@ class ScummEngine;
 class NutRenderer;
 struct VirtScreen;
 
+static inline bool checkKSCode(byte hi, byte lo) {
+	//hi : xx
+	//lo : yy
+	if ((0xA1 > lo) || (0xFE < lo)) {
+		return false;
+	}
+	if ((hi >= 0xB0) && (hi <= 0xC8)) {
+		return true;
+	}
+	return false;
+}
+
 static inline bool checkSJISCode(byte c) {
 	if ((c >= 0x80 && c <= 0x9f) || (c >= 0xe0 && c <= 0xfd))
 		return true;
 	return false;
 }
 
+static inline bool is2ByteCharacter(Common::Language lang, byte c) {
+	if (lang == Common::JA_JPN)
+		return (c >= 0x80 && c <= 0x9F) || (c >= 0xE0 && c <= 0xFD);
+	else if (lang == Common::KO_KOR)
+		return (c >= 0xB0 && c <= 0xD0);
+	else if (lang == Common::ZH_TWN || lang == Common::ZH_CNA)
+		return (c >= 0x80);
+	return false;
+}
 
 class CharsetRenderer {
 public:
@@ -75,7 +97,7 @@ public:
 	virtual void printChar(int chr, bool ignoreCharsetMask) = 0;
 	virtual void drawChar(int chr, Graphics::Surface &s, int x, int y) {}
 
-	int getStringWidth(int a, const byte *str);
+	virtual int getStringWidth(int arg, const byte *text, uint strLenMax = 100000);
 	void addLinebreaks(int a, byte *str, int pos, int maxwidth);
 	void translateColor();
 
@@ -104,9 +126,9 @@ protected:
 public:
 	CharsetRendererCommon(ScummEngine *vm);
 
-	void setCurID(int32 id);
+	void setCurID(int32 id) override;
 
-	virtual int getFontHeight();
+	int getFontHeight() override;
 };
 
 class CharsetRendererPC : public CharsetRendererCommon {
@@ -121,6 +143,7 @@ class CharsetRendererPC : public CharsetRendererCommon {
 protected:
 	virtual void enableShadow(bool enable);
 	virtual void drawBits1(Graphics::Surface &dest, int x, int y, const byte *src, int drawTop, int width, int height);
+	void drawBits1Kor(Graphics::Surface &dest, int x1, int y1, const byte *src, int drawTop, int width, int height);
 
 public:
 	CharsetRendererPC(ScummEngine *vm) : CharsetRendererCommon(vm), _shadowType(kNoShadowType) { }
@@ -142,10 +165,10 @@ protected:
 public:
 	CharsetRendererClassic(ScummEngine *vm) : CharsetRendererPC(vm) {}
 
-	void printChar(int chr, bool ignoreCharsetMask);
-	void drawChar(int chr, Graphics::Surface &s, int x, int y);
+	void printChar(int chr, bool ignoreCharsetMask) override;
+	void drawChar(int chr, Graphics::Surface &s, int x, int y) override;
 
-	int getCharWidth(uint16 chr);
+	int getCharWidth(uint16 chr) override;
 };
 
 #ifdef USE_RGB_COLOR
@@ -154,12 +177,12 @@ class CharsetRendererTownsClassic : public CharsetRendererClassic {
 public:
 	CharsetRendererTownsClassic(ScummEngine *vm);
 
-	int getCharWidth(uint16 chr);
-	int getFontHeight();
+	int getCharWidth(uint16 chr) override;
+	int getFontHeight() override;
 
 private:
-	void drawBitsN(const Graphics::Surface &s, byte *dst, const byte *src, byte bpp, int drawTop, int width, int height);
-	bool prepareDraw(uint16 chr);
+	void drawBitsN(const Graphics::Surface &s, byte *dst, const byte *src, byte bpp, int drawTop, int width, int height) override;
+	bool prepareDraw(uint16 chr) override;
 	void setupShadowMode();
 	bool useFontRomCharacter(uint16 chr);
 	void processCharsetColors();
@@ -178,12 +201,12 @@ protected:
 public:
 	CharsetRendererNES(ScummEngine *vm) : CharsetRendererCommon(vm) {}
 
-	void setCurID(int32 id) {}
-	void printChar(int chr, bool ignoreCharsetMask);
-	void drawChar(int chr, Graphics::Surface &s, int x, int y);
+	void setCurID(int32 id) override {}
+	void printChar(int chr, bool ignoreCharsetMask) override;
+	void drawChar(int chr, Graphics::Surface &s, int x, int y) override;
 
-	int getFontHeight() { return 8; }
-	int getCharWidth(uint16 chr) { return 8; }
+	int getFontHeight() override { return 8; }
+	int getCharWidth(uint16 chr) override { return 8; }
 };
 
 class CharsetRendererV3 : public CharsetRendererPC {
@@ -197,27 +220,27 @@ protected:
 public:
 	CharsetRendererV3(ScummEngine *vm) : CharsetRendererPC(vm) {}
 
-	void printChar(int chr, bool ignoreCharsetMask);
-	void drawChar(int chr, Graphics::Surface &s, int x, int y);
-	void setCurID(int32 id);
-	void setColor(byte color);
-	virtual int getCharWidth(uint16 chr);
+	void printChar(int chr, bool ignoreCharsetMask) override;
+	void drawChar(int chr, Graphics::Surface &s, int x, int y) override;
+	void setCurID(int32 id) override;
+	void setColor(byte color) override;
+	int getCharWidth(uint16 chr) override;
 };
 
 class CharsetRendererTownsV3 : public CharsetRendererV3 {
 public:
 	CharsetRendererTownsV3(ScummEngine *vm);
 
-	int getCharWidth(uint16 chr);
-	int getFontHeight();
+	int getCharWidth(uint16 chr) override;
+	int getFontHeight() override;
 
 private:
-	void enableShadow(bool enable);
-	void drawBits1(Graphics::Surface &dest, int x, int y, const byte *src, int drawTop, int width, int height);
+	void enableShadow(bool enable) override;
+	void drawBits1(Graphics::Surface &dest, int x, int y, const byte *src, int drawTop, int width, int height) override;
 #ifndef DISABLE_TOWNS_DUAL_LAYER_MODE
-	int getDrawWidthIntern(uint16 chr);
-	int getDrawHeightIntern(uint16 chr);
-	void setDrawCharIntern(uint16 chr);
+	int getDrawWidthIntern(uint16 chr) override;
+	int getDrawHeightIntern(uint16 chr) override;
+	void setDrawCharIntern(uint16 chr) override;
 #endif
 	uint16 _sjisCurChar;
 };
@@ -225,18 +248,18 @@ private:
 #ifdef USE_RGB_COLOR
 class CharsetRendererPCE : public CharsetRendererV3 {
 private:
-	void drawBits1(Graphics::Surface &dest, int x, int y, const byte *src, int drawTop, int width, int height);
+	void drawBits1(Graphics::Surface &dest, int x, int y, const byte *src, int drawTop, int width, int height) override;
 
-	int getDrawWidthIntern(uint16 chr);
-	int getDrawHeightIntern(uint16 chr);
-	void setDrawCharIntern(uint16 chr);
+	int getDrawWidthIntern(uint16 chr) override;
+	int getDrawHeightIntern(uint16 chr) override;
+	void setDrawCharIntern(uint16 chr) override;
 
 	uint16 _sjisCurChar;
 
 public:
 	CharsetRendererPCE(ScummEngine *vm) : CharsetRendererV3(vm), _sjisCurChar(0) {}
 
-	void setColor(byte color);
+	void setColor(byte color) override;
 };
 #endif
 
@@ -246,10 +269,42 @@ protected:
 
 public:
 	CharsetRendererV2(ScummEngine *vm, Common::Language language);
-	~CharsetRendererV2();
+	~CharsetRendererV2() override;
 
-	void setCurID(int32 id) {}
-	int getCharWidth(uint16 chr) { return 8; }
+	void setCurID(int32 id) override {}
+	int getCharWidth(uint16 chr) override { return 8; }
+};
+
+class CharsetRendererMac : public CharsetRendererCommon {
+protected:
+	Graphics::MacFONTFont _macFonts[2];
+	bool _correctFontSpacing;
+	bool _pad;
+	int _lastTop;
+
+
+	int getDrawWidthIntern(uint16 chr);
+
+	void printCharInternal(int chr, int color, bool shadow, int x, int y);
+	void printCharToTextBox(int chr, int color, int x, int y);
+
+	byte getTextColor();
+	byte getTextShadowColor();
+
+	Graphics::Surface *_glyphSurface;
+
+public:
+	CharsetRendererMac(ScummEngine *vm, const Common::String &fontFile, bool correctFontSpacing);
+	~CharsetRendererMac() override;
+
+	void setCurID(int32 id) override;
+
+	int getStringWidth(int arg, const byte *text, uint strLenMax = 100000) override;
+	int getFontHeight() override;
+	int getCharWidth(uint16 chr) override;
+	void printChar(int chr, bool ignoreCharsetMask) override;
+	void drawChar(int chr, Graphics::Surface &s, int x, int y) override;
+	void setColor(byte color) override;
 };
 
 #ifdef ENABLE_SCUMM_7_8
@@ -260,15 +315,16 @@ protected:
 
 public:
 	CharsetRendererNut(ScummEngine *vm);
-	~CharsetRendererNut();
+	~CharsetRendererNut() override;
 
-	void printChar(int chr, bool ignoreCharsetMask);
+	void printChar(int chr, bool ignoreCharsetMask) override;
 
-	void setCurID(int32 id);
+	void setCurID(int32 id) override;
 
-	int getFontHeight();
-	int getCharHeight(byte chr);
-	int getCharWidth(uint16 chr);
+	int getStringWidth(int arg, const byte *text, uint strLenMax = 1000000) override;
+	int getFontHeight() override;
+	int getCharHeight(byte chr) override;
+	int getCharWidth(uint16 chr) override;
 };
 #endif
 
