@@ -597,8 +597,6 @@ void ScummEngine_v5::resetCursors() {
 }
 
 void ScummEngine_v5::setBuiltinCursor(int idx) {
-	// TODO: This function gets called over and over. For the Mac cursors,
-	//       it should be enough to just call it once.
 	if (!_macCursorFile.empty()) {
 		Common::MacResManager resource;
 		if (resource.open(_macCursorFile)) {
@@ -606,6 +604,7 @@ void ScummEngine_v5::setBuiltinCursor(int idx) {
 			Common::SeekableReadStream *curs = resource.getResource(MKTAG('C', 'U', 'R', 'S'), resArray[0]);
 			Graphics::MacCursor macCursor;
 			if (macCursor.readFromStream(*curs)) {
+				_cursor.animate = 0;
 				CursorMan.replaceCursor(&macCursor);
 				delete curs;
 				return;
@@ -633,6 +632,7 @@ void ScummEngine_v5::setBuiltinCursor(int idx) {
 			0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x0F, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF
 		};
 
+		_cursor.animate = 0;
 		CursorMan.replaceCursor(buf, 15, 15, 7, 7, 0xFF);
 		return;
 	}
