@@ -156,6 +156,17 @@ struct VirtScreen : Graphics::Surface {
 	 */
 	uint16 bdirty[80 + 1];
 
+	void clear() {
+		// FIXME: Call Graphics::Surface clear / constructor?
+		number = kMainVirtScreen;
+		topline = 0;
+		xstart = 0;
+		hasTwoBuffers = false;
+		backBuf = nullptr;
+		for (uint i = 0; i < ARRAYSIZE(tdirty); i++) tdirty[i] = 0;
+		for (uint i = 0; i < ARRAYSIZE(bdirty); i++) bdirty[i] = 0;
+	}
+
 	/**
 	 * Convenience method to set the whole tdirty and bdirty arrays to one
 	 * specific value each. This is mostly used to mark every as dirty in
@@ -456,57 +467,66 @@ public:
 #endif
 
 #ifndef DISABLE_TOWNS_DUAL_LAYER_MODE
-// Helper class for FM-Towns output (required for specific hardware effects like
-// switching graphics layers on and off).
+// Helper class for FM-Towns output (required for specific hardware effects like switching graphics layers on and off).
 class TownsScreen {
 public:
-	TownsScreen(OSystem *system, int width, int height, Graphics::PixelFormat &format);
+	enum {
+		kDirtyRectsMax = 20,
+		kFullRedraw = (kDirtyRectsMax + 1)
+	};
+public:
+	TownsScreen(OSystem *system);
 	~TownsScreen();
 
-	void setupLayer(int layer, int width, int height, int numCol, void *srcPal = 0);
+	void setupLayer(int layer, int width, int height, int scaleW, int scaleH, int numCol, void *srcPal = 0);
 	void clearLayer(int layer);
 	void fillLayerRect(int layer, int x, int y, int w, int h, int col);
-	//void copyRectToLayer(int layer, int x, int y, int w, int h, const uint8 *src);
-
-	uint8 *getLayerPixels(int layer, int x, int y);
-	int getLayerPitch(int layer);
-	int getLayerHeight(int layer);
-	int getLayerBpp(int layer);
-	int getLayerScaleW(int layer);
-	int getLayerScaleH(int layer);
-
 	void addDirtyRect(int x, int y, int w, int h);
-	void toggleLayers(int flag);
+	void toggleLayers(int flags);
+	void scrollLayers(int flags, int offset);
 	void update();
+	bool isScrolling(int direction, int threshold = 0) const { return (direction == 0) ? _scrollRemainder != threshold : (direction == 1 ? _scrollRemainder > threshold : _scrollRemainder < threshold); }
+
+	uint8 *getLayerPixels(int layer, int x, int y) const;
+	int getLayerPitch(int layer) const { return (layer >= 0 && layer < 2) ? _layers[layer].pitch : 0; }
+	int getLayerWidth(int layer) const { return (layer >= 0 && layer < 2) ? _layers[layer].width : 0; }
+	int getLayerHeight(int layer) const { return (layer >= 0 && layer < 2) ? _layers[layer].height : 0; }
+	int getLayerBpp(int layer) const { return (layer >= 0 && layer < 2) ? _layers[layer].bpp : 0; }
+	int getLayerScaleW(int layer) const { return (layer >= 0 && layer < 2) ? _layers[layer].scaleW : 0; }
+	int getLayerScaleH(int layer) const { return (layer >= 0 && layer < 2) ? _layers[layer].scaleH : 0; }
 
 private:
-	void updateOutputBuffer();
-	void outputToScreen();
-	uint16 calc16BitColor(const uint8 *palEntry);
-
 	struct TownsScreenLayer {
 		uint8 *pixels;
 		uint8 *palette;
 		int pitch;
+		int width;
 		int height;
 		int bpp;
 		int numCol;
+		int hScroll;
 		uint8 scaleW;
 		uint8 scaleH;
 		bool onBottom;
 		bool enabled;
 		bool ready;
 
-		uint16 *bltInternX;
-		uint8 **bltInternY;
 		uint16 *bltTmpPal;
 	} _layers[2];
 
-	uint8 *_outBuffer;
+	template<typename dstPixelType, typename srcPixelType, int scaleW, int scaleH, bool col4bit> void transferRect(uint8 *dst, TownsScreenLayer *l, int x, int y, int w, int h);
+	template<typename dstPixelType> void updateScreenBuffer();
+
+#ifdef USE_RGB_COLOR
+	void update16BitPalette();
+	uint16 calc16BitColor(const uint8 *palEntry);
+#endif
 
 	int _height;
 	int _width;
 	int _pitch;
+	uint16 _scrollOffset;
+	int _scrollRemainder;
 	Graphics::PixelFormat _pixelFormat;
 
 	int _numDirtyRects;
