@@ -32,6 +32,13 @@ struct FloodFillParameters {
 	int32 x;
 	int32 y;
 	int32 flags;
+
+	void reset() {
+		box.top = box.left = box.bottom = box.right = 0;
+		x = 0;
+		y = 0;
+		flags = 0;
+	}
 };
 
 struct FloodFillLine {
