@@ -33,8 +33,8 @@ class LogicHEbaseball2001 : public LogicHE {
 public:
 	LogicHEbaseball2001(ScummEngine_v90he *vm) : LogicHE(vm) {}
 
-	int versionID();
-	int32 dispatch(int op, int numArgs, int32 *args);
+	int versionID() override;
+	int32 dispatch(int op, int numArgs, int32 *args) override;
 };
 
 int LogicHEbaseball2001::versionID() {
