@@ -24,7 +24,10 @@
 #define SCUMM_HE_RESOURCE_HE_H
 
 #include "common/macresman.h"
-#include "common/winexe_pe.h"
+
+namespace Common {
+class PEResources;
+}
 
 namespace Scumm {
 
@@ -68,23 +71,23 @@ private:
 class Win32ResExtractor : public ResExtractor {
 public:
 	Win32ResExtractor(ScummEngine_v70he *scumm);
-	~Win32ResExtractor() {}
+	~Win32ResExtractor() override;
 
 private:
-	Common::PEResources _exe;
+	Common::PEResources *_exe;
 
-	bool extractResource(int id, CachedCursor *cc);
+	bool extractResource(int id, CachedCursor *cc) override;
 };
 
 class MacResExtractor : public ResExtractor {
 public:
 	MacResExtractor(ScummEngine_v70he *scumm);
-	~MacResExtractor() {}
+	~MacResExtractor() override {}
 
 private:
 	Common::MacResManager *_resMgr;
 
-	bool extractResource(int id, CachedCursor *cc);
+	bool extractResource(int id, CachedCursor *cc) override;
 };
 
 } // End of namespace Scumm
