@@ -24,6 +24,7 @@
 #define SCUMM_IMUSE_H
 
 #include "common/scummsys.h"
+#include "common/serializer.h"
 #include "common/mutex.h"
 #include "scumm/music.h"
 
@@ -35,7 +36,6 @@ namespace Scumm {
 class IMuseInternal;
 class Player;
 class ScummEngine;
-class Serializer;
 
 typedef void (*sysexfunc)(Player *, const byte *, uint16);
 
@@ -53,6 +53,7 @@ public:
 		PROP_TEMPO_BASE,
 		PROP_NATIVE_MT32,
 		PROP_GS,
+		PROP_AMIGA,
 		PROP_LIMIT_PLAYERS,
 		PROP_RECYCLE_PLAYERS,
 		PROP_GAME_ID,
@@ -62,7 +63,7 @@ public:
 public:
 	virtual void on_timer(MidiDriver *midi) = 0;
 	virtual void pause(bool paused) = 0;
-	virtual int save_or_load(Serializer *ser, ScummEngine *scumm, bool fixAfterLoad = true) = 0;
+	virtual void saveLoadIMuse(Common::Serializer &ser, ScummEngine *scumm, bool fixAfterLoad = true) = 0;
 	virtual bool get_sound_active(int sound) const = 0;
 	virtual int32 doCommand(int numargs, int args[]) = 0;
 	virtual int clear_queue() = 0;
