@@ -88,12 +88,13 @@ private:
 	int32 _curMusicCue;		// current cue for current music. used in FT
 	int _stopingSequence;
 	bool _radioChatterSFX;
+	bool _speechIsPlaying;
 
 	static void timer_handler(void *refConf);
 	void callback();
 	void switchToNextRegion(Track *track);
 	int allocSlot(int priority);
-	void startSound(int soundId, const char *soundName, int soundType, int volGroupId, Audio::AudioStream *input, int hookId, int volume, int priority, Track *otherTrack);
+	int startSound(int soundId, const char *soundName, int soundType, int volGroupId, Audio::AudioStream *input, int hookId, int volume, int priority, Track *otherTrack);
 	void selectVolumeGroup(int soundId, int volGroupId);
 
 	int32 getPosInMs(int soundId);
@@ -105,6 +106,9 @@ private:
 	void setTrigger(TriggerParams *trigger);
 	void setHookIdForMusic(int hookId);
 	Track *cloneToFadeOutTrack(Track *track, int fadeDelay);
+	Track *handleFadeOut(Track *track, int fadeDelay);
+	int transformVolumeLinearToEqualPow(int volume, int mode);
+	int transformVolumeEqualPowToLinear(int volume, int mode);
 
 	void setFtMusicState(int stateId);
 	void setFtMusicSequence(int seqId);
@@ -113,7 +117,9 @@ private:
 
 	void setComiMusicState(int stateId);
 	void setComiMusicSequence(int seqId);
+	void setComiDemoMusicState(int stateId);
 	void playComiMusic(const char *songName, const imuseComiTable *table, int attribPos, bool sequence);
+	void playComiDemoMusic(const char *songName, const imuseComiTable *table, int attribPos);
 
 	void setDigMusicState(int stateId);
 	void setDigMusicSequence(int seqId);
@@ -127,12 +133,12 @@ public:
 
 	void setAudioNames(int32 num, char *names);
 
-	void startVoice(int soundId, Audio::AudioStream *input);
-	void startVoice(int soundId, const char *soundName);
-	void startMusic(int soundId, int volume);
-	void startMusic(const char *soundName, int soundId, int hookId, int volume);
-	void startMusicWithOtherPos(const char *soundName, int soundId, int hookId, int volume, Track *otherTrack);
-	void startSfx(int soundId, int priority);
+	int startVoice(int soundId, Audio::AudioStream *input);
+	int startVoice(int soundId, const char *soundName);
+	int startMusic(int soundId, int volume);
+	int startMusic(const char *soundName, int soundId, int hookId, int volume);
+	int startMusicWithOtherPos(const char *soundName, int soundId, int hookId, int volume, Track *otherTrack);
+	int startSfx(int soundId, int priority);
 	void startSound(int sound) override
 		{ error("IMuseDigital::startSound(int) should be never called"); }
 
