@@ -29,6 +29,7 @@
 #include "scumm/imuse_digi/dimuse.h"
 #include "scumm/imuse_digi/dimuse_bndmgr.h"
 #include "scumm/imuse_digi/dimuse_track.h"
+#include "scumm/imuse_digi/dimuse_tables.h"
 
 #include "audio/audiostream.h"
 #include "audio/mixer.h"
@@ -79,14 +80,47 @@ int IMuseDigital::allocSlot(int priority) {
 	return trackId;
 }
 
-void IMuseDigital::startSound(int soundId, const char *soundName, int soundType, int volGroupId, Audio::AudioStream *input, int hookId, int volume, int priority, Track *otherTrack) {
+int IMuseDigital::startSound(int soundId, const char *soundName, int soundType, int volGroupId, Audio::AudioStream *input, int hookId, int volume, int priority, Track *otherTrack) {
 	Common::StackLock lock(_mutex, "IMuseDigital::startSound()");
 	debug(5, "IMuseDigital::startSound(%d) - begin func", soundId);
 
+	bool forceFadeIn = false;
+	if (_vm->_game.id == GID_FT && volGroupId == IMUSE_VOLGRP_MUSIC) {
+		// First of all we check if there's another track playing the target soundId
+		int alreadyPlayingTrackId = -1;
+		for (int l = 0; l < MAX_DIGITAL_TRACKS; l++) {
+			if (_track[l]->volGroupId == IMUSE_VOLGRP_MUSIC && _track[l]->used) {
+				forceFadeIn = true;
+				if (_track[l]->soundId == soundId) {
+					alreadyPlayingTrackId = l;
+					break;
+				}
+			}
+		}
+		// If the current music state corresponds to the same soundId
+		// we're trying to play, we just adjust its volume to the new one.
+		// Otherwise... just flush the old track and start the new one
+		if (alreadyPlayingTrackId != -1) {
+			if (getSoundIdByName(_ftStateMusicTable[_curMusicState].audioName) == soundId) {
+				Track *alreadyPlayingTrack = _track[alreadyPlayingTrackId];
+				alreadyPlayingTrack->volFadeDelay = 60;
+				alreadyPlayingTrack->volFadeDest = volume * 1000;
+				alreadyPlayingTrack->volFadeStep = (alreadyPlayingTrack->volFadeDest - alreadyPlayingTrack->vol) * 60 * (1000 / _callbackFps) / (1000 * alreadyPlayingTrack->volFadeDelay);
+				alreadyPlayingTrack->volFadeUsed = true;
+				alreadyPlayingTrack->toBeRemoved = false;
+				return alreadyPlayingTrackId;
+			} else {
+				flushTrack(_track[alreadyPlayingTrackId]);
+			}
+		}
+	} else if (_vm->_game.id == GID_CMI) {
+		forceFadeIn = true;
+	}
+
 	int l = allocSlot(priority);
 	if (l == -1) {
 		warning("IMuseDigital::startSound() Can't start sound - no free slots");
-		return;
+		return -1;
 	}
 	debug(5, "IMuseDigital::startSound(%d, trackId:%d)", soundId, l);
 
@@ -105,12 +139,24 @@ void IMuseDigital::startSound(int soundId, const char *soundName, int soundType,
 	track->soundType = soundType;
 	track->trackId = l;
 
+	if (_vm->_game.id == GID_FT) {
+		// Tweak the default gain reduction to about 2 dB
+		track->gainRedFadeDest = 127 * 180;
+	} else if (_vm->_game.id == GID_CMI) {
+		// Tweak the default gain reduction to about 4 dB
+		track->gainRedFadeDest = 127 * 290;
+	}
+
 	int bits = 0, freq = 0, channels = 0;
 
 	track->souStreamUsed = (input != 0);
 
 	if (track->souStreamUsed) {
-		_mixer->playStream(track->getType(), &track->mixChanHandle, input, -1, track->getVol(), track->getPan());
+		int effVol = track->getVol();
+		if (_vm->_game.id == GID_FT) {
+			effVol = int(round(effVol * 1.3));
+		}
+		_mixer->playStream(track->getType(), &track->mixChanHandle, input, -1, effVol, track->getPan());
 	} else {
 		strcpy(track->soundName, soundName);
 		track->soundDesc = _sound->openSound(soundId, soundName, soundType, volGroupId, -1);
@@ -120,7 +166,7 @@ void IMuseDigital::startSound(int soundId, const char *soundName, int soundType,
 			track->soundDesc = _sound->openSound(soundId, soundName, soundType, volGroupId, 2);
 
 		if (!track->soundDesc)
-			return;
+			return -1;
 
 		track->sndDataExtComp = _sound->isSndDataExtComp(track->soundDesc);
 
@@ -132,8 +178,23 @@ void IMuseDigital::startSound(int soundId, const char *soundName, int soundType,
 			if (_vm->_actorToPrintStrFor != 0xFF && _vm->_actorToPrintStrFor != 0) {
 				Actor *a = _vm->derefActor(_vm->_actorToPrintStrFor, "IMuseDigital::startSound");
 				freq = (freq * a->_talkFrequency) / 256;
-				track->pan = a->_talkPan;
-				track->vol = a->_talkVolume * 1000;
+
+				if (a->_talkPan <= 127)
+					track->pan = a->_talkPan;
+				else
+					track->pan = 64;
+
+				if (a->_talkVolume <= 127)
+					track->vol = a->_talkVolume * 1000;
+				else
+					track->vol = 127 * 1000;
+
+				// Keep track of the current actor in COMI:
+				// This is necessary since pan and volume settings for actors
+				// are often changed AFTER the speech sound is started,
+				// so this is a way to keep track of the changes in real time.
+				if (_vm->_game.id == GID_CMI)
+					track->speakingActor = a;
 			}
 
 			// The volume is set to zero, when using subtitles only setting in COMI
@@ -158,11 +219,28 @@ void IMuseDigital::startSound(int soundId, const char *soundName, int soundType,
 		} else
 			error("IMuseDigital::startSound(): Can't handle %d bit samples", bits);
 
+		track->littleEndian = track->soundDesc->littleEndian;
+
+		int fadeDelay = 30; // Default fade value if not found anywhere else
+
 		if (otherTrack && otherTrack->used && !otherTrack->toBeRemoved) {
 			track->curRegion = otherTrack->curRegion;
 			track->dataOffset = otherTrack->dataOffset;
 			track->regionOffset = otherTrack->regionOffset;
 			track->dataMod12Bit = otherTrack->dataMod12Bit;
+
+			if (_vm->_game.id == GID_CMI) {
+				fadeDelay = otherTrack->volFadeDelay != 0 ? otherTrack->volFadeDelay : fadeDelay;
+				track->regionOffset -= track->regionOffset >= (track->feedSize / _callbackFps) ? (track->feedSize / _callbackFps) : 0;
+			}
+		}
+		if (_vm->_game.id != GID_DIG && (track->volGroupId == IMUSE_VOLGRP_MUSIC) && forceFadeIn) {
+			// Fade in the new track
+			track->vol = 0;
+			track->volFadeDelay = fadeDelay;
+			track->volFadeDest = volume * 1000;
+			track->volFadeStep = (track->volFadeDest - track->vol) * 60 * (1000 / _callbackFps) / (1000 * fadeDelay);
+			track->volFadeUsed = true;
 		}
 
 		track->stream = Audio::makeQueuingAudioStream(freq, track->mixerFlags & kFlagStereo);
@@ -170,6 +248,8 @@ void IMuseDigital::startSound(int soundId, const char *soundName, int soundType,
 	}
 
 	track->used = true;
+
+	return track->trackId;
 }
 
 void IMuseDigital::setPriority(int soundId, int priority) {
@@ -279,9 +359,18 @@ void IMuseDigital::fadeOutMusicAndStartNew(int fadeDelay, const char *filename,
 		Track *track = _track[l];
 		if (track->used && !track->toBeRemoved && (track->volGroupId == IMUSE_VOLGRP_MUSIC)) {
 			debug(5, "IMuseDigital::fadeOutMusicAndStartNew(sound:%d) - starting", soundId);
-			startMusicWithOtherPos(filename, soundId, 0, 127, track);
-			cloneToFadeOutTrack(track, fadeDelay);
-			flushTrack(track);
+
+			// Store the fadeDelay in the track: startMusicWithOtherPos will use it to
+			// fade in the new track; this will match fade in and fade out speeds.
+			if (_vm->_game.id == GID_CMI) {
+				track->volFadeDelay = fadeDelay;
+				startMusicWithOtherPos(filename, soundId, 0, 127, track);
+				handleFadeOut(track, fadeDelay);
+			} else {
+				startMusicWithOtherPos(filename, soundId, 0, 127, track);
+				cloneToFadeOutTrack(track, fadeDelay);
+				flushTrack(track);
+			}
 			break;
 		}
 	}
@@ -295,8 +384,12 @@ void IMuseDigital::fadeOutMusic(int fadeDelay) {
 		Track *track = _track[l];
 		if (track->used && !track->toBeRemoved && (track->volGroupId == IMUSE_VOLGRP_MUSIC)) {
 			debug(5, "IMuseDigital::fadeOutMusic(fade:%d, sound:%d)", fadeDelay, track->soundId);
-			cloneToFadeOutTrack(track, fadeDelay);
-			flushTrack(track);
+			if (_vm->_game.id == GID_CMI || _vm->_game.id == GID_FT) {
+				handleFadeOut(track, fadeDelay);
+			} else {
+				cloneToFadeOutTrack(track, fadeDelay);
+				flushTrack(track);
+			}
 			break;
 		}
 	}
@@ -324,6 +417,16 @@ void IMuseDigital::setTrigger(TriggerParams *trigger) {
 	_triggerUsed = true;
 }
 
+Track *IMuseDigital::handleFadeOut(Track *track, int fadeDelay) {
+	track->volFadeDelay = fadeDelay != 0 ? fadeDelay : 60;
+	track->volFadeDest = 0;
+	track->volFadeStep = (track->volFadeDest - track->vol) * 60 * (1000 / _callbackFps) / (1000 * track->volFadeDelay);
+	track->volFadeUsed = true;
+	track->toBeRemoved = true;
+	return track;
+}
+
+
 Track *IMuseDigital::cloneToFadeOutTrack(Track *track, int fadeDelay) {
 	assert(track);
 	Track *fadeTrack;
@@ -337,7 +440,6 @@ Track *IMuseDigital::cloneToFadeOutTrack(Track *track, int fadeDelay) {
 
 	assert(track->trackId < MAX_DIGITAL_TRACKS);
 	fadeTrack = _track[track->trackId + MAX_DIGITAL_TRACKS];
-
 	if (fadeTrack->used) {
 		debug(5, "cloneToFadeOutTrack: No free fade track, force flush fade soundId:%d", fadeTrack->soundId);
 		flushTrack(fadeTrack);
@@ -349,7 +451,7 @@ Track *IMuseDigital::cloneToFadeOutTrack(Track *track, int fadeDelay) {
 	fadeTrack->trackId = track->trackId + MAX_DIGITAL_TRACKS;
 
 	// Clone the sound.
-	// leaving bug number for now #1635361
+	// leaving bug number for now #3005
 	ImuseDigiSndMgr::SoundDesc *soundDesc = _sound->cloneSound(track->soundDesc);
 	if (!soundDesc) {
 		// it fail load open old song after switch to different CDs
@@ -368,10 +470,99 @@ Track *IMuseDigital::cloneToFadeOutTrack(Track *track, int fadeDelay) {
 	fadeTrack->stream = Audio::makeQueuingAudioStream(_sound->getFreq(fadeTrack->soundDesc), track->mixerFlags & kFlagStereo);
 	_mixer->playStream(track->getType(), &fadeTrack->mixChanHandle, fadeTrack->stream, -1, fadeTrack->getVol(), fadeTrack->getPan());
 	fadeTrack->used = true;
-
 	debug(5, "cloneToFadeOutTrack() - end of func, soundId %d, fade soundId %d", track->soundId, fadeTrack->soundId);
 
 	return fadeTrack;
 }
 
+int IMuseDigital::transformVolumeLinearToEqualPow(int volume, int mode) {
+	if (volume == 0 || volume == 127000)
+		return volume;
+
+	int result = volume;
+	if (!(volume < 0 || volume > 127000)) {
+		// Change range of values from 0-127*1000 to 0.0-1.0
+		double mappedValue = (((volume - 0) * (1.0 - 0.0)) / (127000 - 0)) + 0;
+		double eqPowValue;
+
+		switch (mode) {
+		case 0:  // Sqrt curve
+			eqPowValue = sqrt(mappedValue);
+			break;
+		case 1:  // Quarter sine curve
+			eqPowValue = sin(mappedValue * M_PI / 2.0);
+			break;
+		case 2:  // Parabola
+			eqPowValue = (1 - (1 - mappedValue) * (1 - mappedValue));
+			break;
+		case 3:  // Logarithmic 1
+			eqPowValue = 1 + 0.2 * log10(mappedValue);
+			break;
+		case 4:  // Logarithmic 2
+			eqPowValue = 1 + 0.5 * log10(mappedValue);
+			break;
+		case 5:  // Logarithmic 3
+			eqPowValue = 1 + 0.7 * log10(mappedValue);
+			break;
+		case 6:  // Quadratic
+			eqPowValue = mappedValue * mappedValue;
+			break;
+		default: // Fallback to linear
+			eqPowValue = mappedValue;
+			break;
+		}
+
+		// Change range again, this time round the result
+		result = (((eqPowValue - 0.0) * (127000 - 0)) / (1.0 - 0.0)) + 0.0;
+		result = (int)round(result);
+	}
+
+	return result;
+}
+
+int IMuseDigital::transformVolumeEqualPowToLinear(int volume, int mode) {
+	if (volume == 0 || volume == 127000)
+		return volume;
+
+	int result = volume;
+	if (!(volume < 0 || volume > 127000)) {
+		// Change range of values from 0-127*1000 to 0.0-1.0
+		double mappedValue = (((volume - 0) * (1.0 - 0.0)) / (127000 - 0)) + 0;
+		double linearValue;
+
+		switch (mode) {
+		case 0:  // Sqrt curve
+			linearValue = mappedValue * mappedValue;
+			break;
+		case 1:  // Quarter sine curve
+			linearValue = 0.63662 * asin(mappedValue);
+			break;
+		case 2:  // Parabola
+			linearValue = 1 - sqrt(1 - mappedValue);
+			break;
+		case 3:  // Logarithmic 1
+			linearValue = 0.00001 * pow(M_E, 11.5129 * mappedValue);
+			break;
+		case 4:  // Logarithmic 2
+			linearValue = 0.01 * pow(M_E, 4.60517 * mappedValue);
+			break;
+		case 5:  // Logarithmic 3
+			linearValue = 0.0372759 * pow(M_E, 3.28941 * mappedValue);
+			break;
+		case 6:  // Quadratic
+			linearValue = sqrt(mappedValue);
+			break;
+		default: // Fallback to linear
+			linearValue = mappedValue;
+			break;
+		}
+
+		// Change range again, this time round the result
+		result = (((linearValue - 0.0) * (127000 - 0)) / (1.0 - 0.0)) + 0.0;
+		result = (int)round(result);
+	}
+
+	return result;
+}
+
 } // End of namespace Scumm
