@@ -45,47 +45,57 @@ enum {
 };
 
 struct Track {
-	int trackId;		// used to identify track by value (0-15)
-
-	int8 pan;			// panning value of sound
-	int32 vol;			// volume level (values 0-127 * 1000)
-	int32 volFadeDest;	// volume level which fading target (values 0-127 * 1000)
-	int32 volFadeStep;	// delta of step while changing volume at each imuse callback
-	int32 volFadeDelay;	// time in ms how long fading volume must be
-	bool volFadeUsed;	// flag if fading is in progress
-
-	int32 soundId;		// sound id used by scumm script
-	char soundName[15]; // sound name but also filename of sound in bundle data
-	bool used;			// flag mean that track is used
-	bool toBeRemoved;   // flag mean that track need to be free
-	bool souStreamUsed;	// flag mean that track use stream from sou file
-	bool sndDataExtComp;// flag mean that sound data is compressed by scummvm tools
-	int32 soundPriority;// priority level of played sound (0-127)
-	int32 regionOffset; // offset to sound data relative to begining of current region
-	int32 dataOffset;	// offset to sound data relative to begining of 'DATA' chunk
-	int32 curRegion;	// id of current used region
-	int32 curHookId;	// id of current used hook id
-	int32 volGroupId;	// id of volume group (IMUSE_VOLGRP_VOICE, IMUSE_VOLGRP_SFX, IMUSE_VOLGRP_MUSIC)
-	int32 soundType;	// type of sound data (IMUSE_BUNDLE, IMUSE_RESOURCE)
-	int32 feedSize;		// size of sound data needed to be filled at each callback iteration
-	int32 dataMod12Bit;	// value used between all callback to align 12 bit source of data
-	int32 mixerFlags;	// flags for sound mixer's channel (kFlagStereo, kFlag16Bits, kFlagUnsigned)
+	int trackId;		     // used to identify track by value (0-15)
 
+	int8 pan;			     // panning value of sound
+	int32 vol;			     // volume level (values 0-127 * 1000)
+	int32 volFadeDest;	     // volume level which fading target (values 0-127 * 1000)
+	int32 volFadeStep;	     // delta of step while changing volume at each imuse callback
+	int32 volFadeDelay;	     // time in ms how long fading volume must be
+	bool volFadeUsed;	     // flag if fading is in progress
+	int32 gainReduction;     // amount of volume to subtract
+	int32 gainRedFadeDest;   // target of fade for gain reduction
+	bool gainRedFadeUsed;    // flag if fading is in progress
+	bool alreadyCrossfading; // used by COMI to check if this track is already running a crossfade
+	int loopShiftType;       // currently used by COMI to check if the loop point for this track has to be shifted
+	int32 soundId;		     // sound id used by scumm script
+	char soundName[15];      // sound name but also filename of sound in bundle data
+	bool used;			     // flag mean that track is used
+	bool toBeRemoved;        // flag mean that track need to be free
+	bool souStreamUsed;	     // flag mean that track use stream from sou file
+	bool sndDataExtComp;     // flag mean that sound data is compressed by scummvm tools
+	int32 soundPriority;     // priority level of played sound (0-127)
+	int32 regionOffset;      // offset to sound data relative to begining of current region
+	int32 dataOffset;	     // offset to sound data relative to begining of 'DATA' chunk
+	int32 curRegion;	     // id of current used region
+	int32 curHookId;	     // id of current used hook id
+	int32 volGroupId;	     // id of volume group (IMUSE_VOLGRP_VOICE, IMUSE_VOLGRP_SFX, IMUSE_VOLGRP_MUSIC)
+	int32 soundType;	     // type of sound data (IMUSE_BUNDLE, IMUSE_RESOURCE)
+	int32 feedSize;		     // size of sound data needed to be filled at each callback iteration
+	int32 dataMod12Bit;	     // value used between all callback to align 12 bit source of data
+	int32 mixerFlags;	     // flags for sound mixer's channel (kFlagStereo, kFlag16Bits, kFlagUnsigned)
+	bool littleEndian;       // Endianness: default is big for original files and native for recompressed ones
 	ImuseDigiSndMgr::SoundDesc *soundDesc;	// sound handle used by iMuse sound manager
-	Audio::SoundHandle mixChanHandle;					// sound mixer's channel handle
+	Audio::SoundHandle mixChanHandle;		// sound mixer's channel handle
 	Audio::QueuingAudioStream *stream;		// sound mixer's audio stream handle for *.la1 and *.bun
+	Actor *speakingActor;					// actor reference for CMI speech
 
 	Track() : soundId(-1), used(false), stream(nullptr) {
 	}
 
 	void reset() {
 		trackId = 0;
-		pan = 0;
+		pan = 64;
 		vol = 0;
 		volFadeDest = 0;
 		volFadeStep = 0;
 		volFadeDelay = 0;
 		volFadeUsed = false;
+		gainReduction = 0;
+		gainRedFadeDest = 0;
+		gainRedFadeUsed = false;
+		alreadyCrossfading = false;
+		loopShiftType = 0;
 		soundId = 0;
 		memset(soundName, 0, sizeof(soundName));
 		used = false;
@@ -103,6 +113,8 @@ struct Track {
 		mixerFlags = 0;
 		soundDesc = nullptr;
 		stream = nullptr;
+		speakingActor = nullptr;
+		littleEndian = false;
 	}
 
 	int getPan() const { return (pan != 64) ? 2 * pan - 127 : 0; }
