@@ -161,7 +161,7 @@ void ScummEngine::parseEvent(Common::Event event) {
 			// On most (all?) keyboards it is safe to assume that
 			// both upper and lower letters are unpressed on keyup event
 			//
-			// Fixes bug #1709430: "FT: CAPSLOCK + V enables cheating for all fights"
+			// Fixes bug #3173: "FT: CAPSLOCK + V enables cheating for all fights"
 			//
 			// Fingolfin remarks: This wouldn't be a problem if we used keycodes.
 			_keyDownMap[toupper(event.kbd.ascii)] = false;
@@ -185,7 +185,7 @@ void ScummEngine::parseEvent(Common::Event event) {
 			_mouse.x -= (kHercWidth - _screenWidth * 2) / 2;
 			_mouse.x >>= 1;
 			_mouse.y = _mouse.y * 4 / 7;
-		} else if (_useCJKMode && _textSurfaceMultiplier == 2) {
+		} else if (_macScreen || (_useCJKMode && _textSurfaceMultiplier == 2)) {
 			_mouse.x >>= 1;
 			_mouse.y >>= 1;
 		}
@@ -200,7 +200,7 @@ void ScummEngine::parseEvent(Common::Event event) {
 
 	// The following two cases enable dialog choices to be scrolled
 	// through in the SegaCD version of MI. Values are taken from script-14.
-	// See bug report #1193185 for details.
+	// See bug report #2013 for details.
 	case Common::EVENT_WHEELDOWN:
 		if (_game.id == GID_MONKEY && _game.platform == Common::kPlatformSegaCD)
 			_keyPressed = Common::KeyState(Common::KEYCODE_7, 55);	// '7'
@@ -391,7 +391,19 @@ void ScummEngine_v7::processKeyboard(Common::KeyState lastKeyHit) {
 				_insane->escapeKeyHandler();
 			else
 				_smushVideoShouldFinish = true;
-			_skipVideo = true;
+
+			// WORKAROUND bug #12022: For some reason, skipping the cutscene in which Ben fires up
+			// his bike (after retrieving the keys from the bartender), will outright skip the first
+			// bike fight sequence. Because of this, the script which handles playing ambient and wind SFX
+			// outside the bar is never stopped, so those SFX are unintentionally played throughout the
+			// rest of the game.
+			// This fix produces the intended behaviour from the original interpreter.
+			if (_game.id == GID_FT && _currentRoom == 6
+				&& (vm.slot[_currentScript].number == 65 || vm.slot[_currentScript].number == 64)) {
+				_skipVideo = false;
+			} else {
+				_skipVideo = true;
+			}
 		} else {
 			abortCutscene();
 		}
@@ -607,6 +619,16 @@ void ScummEngine::processKeyboard(Common::KeyState lastKeyHit) {
 		    lastKeyHit.keycode <= Common::KEYCODE_F9) {
 			_mouseAndKeyboardStat = lastKeyHit.keycode - Common::KEYCODE_F1 + 315;
 
+		} else if (lastKeyHit.flags & Common::KBD_CTRL && _game.version >= 3 && _game.version <= 7 &&
+				   (lastKeyHit.keycode >= Common::KEYCODE_a && lastKeyHit.keycode <= Common::KEYCODE_z)) {
+			// Some games (at least their DOS variants)
+			// expect Ctrl+A, B, C, etc. to generate codes 1, 2, 3, etc.
+			//
+			// This is used for several settings in the "ultimate talkie" versions of
+			// Monkey Island 1 and 2. Monkey Island 1 also uses it for Ctrl+W to immediately
+			// win the game. On other games, Ctrl+I shows the inventory, Ctrl+V shows version
+			// information. On The Dig Ctrl+B makes Boston display his muscles.
+			_mouseAndKeyboardStat = lastKeyHit.keycode & 0x1f;
 		} else if (_game.id == GID_MONKEY2 && (lastKeyHit.flags & Common::KBD_ALT)) {
 			// Handle KBD_ALT combos in MI2. We know that the result must be 273 for Alt-W
 			// because that's what MI2 looks for in its "instant win" cheat.
@@ -616,7 +638,7 @@ void ScummEngine::processKeyboard(Common::KeyState lastKeyHit) {
 		          lastKeyHit.keycode <= Common::KEYCODE_LEFT) {
 			if (_game.id == GID_MONKEY && _game.platform == Common::kPlatformSegaCD) {
 				// Map arrow keys to number keys in the SEGA version of MI to support
-				// scrolling to conversation choices. See bug report #1193185 for details.
+				// scrolling to conversation choices. See bug report #2013 for details.
 				_mouseAndKeyboardStat = lastKeyHit.keycode - Common::KEYCODE_UP + 54;
 			} else if (_game.id == GID_LOOM && _game.platform == Common::kPlatformPCEngine) {
 				// Map arrow keys to number keys in the PCEngine version of Loom to support
