@@ -22,9 +22,7 @@
 
 
 #include "audio/midiparser.h"
-#include "audio/mididrv.h"
 #include "common/textconsole.h"
-#include "common/util.h"
 
 namespace Scumm {
 
@@ -41,11 +39,11 @@ protected:
 
 protected:
 	void compressToType0();
-	void parseNextEvent (EventInfo &info);
+	void parseNextEvent (EventInfo &info) override;
 
 public:
-	bool loadMusic (byte *data, uint32 size);
-	uint32 getTick() { return (uint32) _markerCount * _ppqn / 2; }
+	bool loadMusic (byte *data, uint32 size) override;
+	uint32 getTick() override { return (uint32) _markerCount * _ppqn / 2; }
 };
 
 
@@ -75,7 +73,7 @@ void MidiParser_RO::parseNextEvent (EventInfo &info) {
 				// to determine, only used in one single song
 				// in EGA Loom. It seems to be meant for adding
 				// values greater than 255 to info.delta. See
-				// bug #1498785.
+				// bug #2650.
 				info.delta += 256;
 			}
 			continue;
@@ -121,6 +119,9 @@ void MidiParser_RO::parseNextEvent (EventInfo &info) {
 		}
 		info.event = 0xFF;
 		break;
+
+	default:
+		break;
 	}
 }
 
