@@ -42,9 +42,8 @@ class ScummEngine;
  */
 class Player_V3M : public Player_Mac {
 public:
-	Player_V3M(ScummEngine *scumm, Audio::Mixer *mixer);
+	Player_V3M(ScummEngine *scumm, Audio::Mixer *mixer, bool lowQuality);
 
-	bool checkMusicAvailable() override;
 	bool loadMusic(const byte *ptr) override;
 	bool getNextNote(int ch, uint32 &samples, int &pitchModifier, byte &velocity) override;
 };
