@@ -44,9 +44,8 @@ class Player_V5M : public Player_Mac {
 public:
 	Player_V5M(ScummEngine *scumm, Audio::Mixer *mixer);
 
-	virtual bool checkMusicAvailable();
-	virtual bool loadMusic(const byte *ptr);
-	virtual bool getNextNote(int ch, uint32 &samples, int &pitchModifier, byte &velocity);
+	bool loadMusic(const byte *ptr) override;
+	bool getNextNote(int ch, uint32 &samples, int &pitchModifier, byte &velocity) override;
 
 private:
 	uint32 _lastNoteSamples[3];
