@@ -68,7 +68,7 @@ struct SaveInfoSection {
 
 #define SaveInfoSectionSize (4+4+4 + 4+4 + 4+2)
 
-#define CURRENT_VER 99
+#define CURRENT_VER 102
 #define INFOSECTION_VERSION 2
 
 #pragma mark -
@@ -85,7 +85,7 @@ bool ScummEngine::canLoadGameStateCurrently() {
 	// aware of *any* spots where loading is not supported?
 
 	// HE games are limited to original load and save interface only,
-	// due to numerous glitches (see bug #1726909) that can occur.
+	// due to numerous glitches (see bug #3210) that can occur.
 	//
 	// Except the earliest HE Games (3DO and initial DOS version of
 	// puttputt), which didn't offer scripted load/save screens.
@@ -119,19 +119,24 @@ bool ScummEngine::canSaveGameStateCurrently() {
 	// original EXE allowed this.
 
 	// HE games are limited to original load and save interface only,
-	// due to numerous glitches (see bug #1726909) that can occur.
+	// due to numerous glitches (see bug #3210) that can occur.
 	//
 	// Except the earliest HE Games (3DO and initial DOS version of
 	// puttputt), which didn't offer scripted load/save screens.
 	if (_game.heversion >= 62)
 		return false;
 
+#ifdef ENABLE_SCUMM_7_8
 	// COMI always disables saving/loading (to tell the truth:
 	// the main menu) via its scripts, thus we need to make an
 	// exception here. This the same forced overwriting of the
 	// script decisions as in ScummEngine::processKeyboard.
+	// Also, disable saving when a SAN video is playing.
+	if (_game.version >= 7 && ((ScummEngine_v7 *)this)->isSmushActive())
+		return false;
 	if (_game.id == GID_CMI)
 		return true;
+#endif
 
 	// SCUMM v4+ doesn't allow saving in room 0 or if
 	// VAR(VAR_MAINMENU_KEY) to set to zero.
@@ -399,7 +404,7 @@ bool ScummEngine::loadState(int slot, bool compat, Common::String &filename) {
 	// Thus, we should probably not stop music when restoring from one of
 	// these saves. This change stops the Mole Man theme from going quiet in
 	// Sam & Max when Doug tells you about the Ball of Twine, as mentioned in
-	// patch #886058.
+	// patch #8316.
 	//
 	// If we don't have iMUSE at all we may as well stop the sounds. The previous
 	// default behavior here was to stopAllSounds on all state restores.
@@ -465,7 +470,7 @@ bool ScummEngine::loadState(int slot, bool compat, Common::String &filename) {
 	if (_screenTop < 0)
 		_screenTop = 0;
 
-	// WORKAROUND bug #795214: For unknown reasons, object 819 sometimes is in
+	// WORKAROUND bug #1191: For unknown reasons, object 819 sometimes is in
 	// state 1 in old save games, implying it should be drawn. This in turn
 	// results in a crash when entering the church, as object 819 is part of the
 	// exitof the church and there are no graphics assigned to it.
@@ -555,6 +560,8 @@ bool ScummEngine::loadState(int slot, bool compat, Common::String &filename) {
 
 	// Reset charset mask
 	_charset->_hasMask = false;
+	if (_macScreen)
+		_macScreen->fillRect(Common::Rect(_macScreen->w, _macScreen->h), 0);
 	clearTextSurface();
 
 	_lastCodePtr = NULL;
@@ -580,7 +587,7 @@ bool ScummEngine::loadState(int slot, bool compat, Common::String &filename) {
 	// after game load, and o2_loadRoomWithEgo() does as well
 	// this script starts character-dependent music
 	//
-	// Fixes bug #1766072: MANIACNES: Music Doesn't Start On Load Game
+	// Fixes bug #3362: MANIACNES: Music Doesn't Start On Load Game
 	if (_game.platform == Common::kPlatformNES) {
 		runScript(5, 0, 0, 0);
 
@@ -814,8 +821,8 @@ static void syncWithSerializer(Common::Serializer &s, ObjectData &od) {
 	s.syncAsByte(od.flags, VER(46));
 }
 
-static void syncWithSerializer(Common::Serializer &s, VerbSlot &vs) {
-	s.syncAsSint16LE(vs.curRect.left, VER(8));
+static void syncWithSerializer(Common::Serializer &s, VerbSlot &vs, bool isISR) {
+	s.syncAsSint16LE(!isISR ? vs.curRect.left : vs.origLeft, VER(8));
 	s.syncAsSint16LE(vs.curRect.top, VER(8));
 	s.syncAsSint16LE(vs.curRect.right, VER(8));
 	s.syncAsSint16LE(vs.curRect.bottom, VER(8));
@@ -837,6 +844,16 @@ static void syncWithSerializer(Common::Serializer &s, VerbSlot &vs) {
 	s.syncAsByte(vs.center, VER(8));
 	s.syncAsByte(vs.prep, VER(8));
 	s.syncAsUint16LE(vs.imgindex, VER(8));
+	if (isISR && s.isLoading() && s.getVersion() >= 8)
+		vs.curRect.left = vs.origLeft;
+}
+
+static void syncWithSerializerNonISR(Common::Serializer &s, VerbSlot &vs) {
+	syncWithSerializer(s, vs, false);
+}
+
+static void syncWithSerializerISR(Common::Serializer &s, VerbSlot &vs) {
+	syncWithSerializer(s, vs, true);
 }
 
 static void syncWithSerializer(Common::Serializer &s, ScriptSlot &ss) {
@@ -1007,6 +1024,10 @@ void ScummEngine::saveLoadWithSerializer(Common::Serializer &s) {
 	s.syncAsSint16LE(camera._dest.y, VER(8));
 	s.syncAsSint16LE(camera._cur.x, VER(8));
 	s.syncAsSint16LE(camera._cur.y, VER(8));
+	if (_game.platform == Common::kPlatformFMTowns)
+		// WORKAROUND: FM-TOWNS original _screenHeight is 240. if we use trim_fmtowns_to_200_pixels, it's reduced to 200
+		// camera's y is always half of the screen. in order to share save games between the two modes, we need to update the y
+		camera._cur.y = _screenHeight / 2;
 	s.syncAsSint16LE(camera._last.x, VER(8));
 	s.syncAsSint16LE(camera._last.y, VER(8));
 	s.syncAsSint16LE(camera._accel.x, VER(8));
@@ -1218,7 +1239,7 @@ void ScummEngine::saveLoadWithSerializer(Common::Serializer &s) {
 	//
 	// Save/load misc stuff
 	//
-	s.syncArray(_verbs, _numVerbs, syncWithSerializer);
+	s.syncArray(_verbs, _numVerbs, _language != Common::HE_ISR ? syncWithSerializerNonISR : syncWithSerializerISR);
 	s.syncArray(vm.nest, 16, syncWithSerializer);
 	s.syncArray(_sentence, 6, syncWithSerializer);
 	s.syncArray(_string, 6, syncWithSerializer);
@@ -1258,6 +1279,7 @@ void ScummEngine::saveLoadWithSerializer(Common::Serializer &s) {
 				while (s.syncAsUint16LE(idx), idx != 0xFFFF) {
 					assert(idx < _res->_types[type].size());
 					loadResource(s, type, idx);
+					applyWorkaroundIfNeeded(type, idx);
 				}
 			}
 		}
@@ -1318,7 +1340,6 @@ void ScummEngine::saveLoadWithSerializer(Common::Serializer &s) {
 
 	if (hasTownsData) {
 		s.syncBytes(_textPalette, 48);
-		// TODO: This seems wrong, there are 16 _cyclRects
 		s.syncArray(_cyclRects, 10, syncWithSerializer, VER(82));
 		if (s.getVersion() >= VER(82))
 			syncWithSerializer(s, _curStringRect);
@@ -1416,6 +1437,25 @@ void ScummEngine::saveLoadWithSerializer(Common::Serializer &s) {
 	s.syncBytes(_bitVars, _numBitVariables / 8);
 
 
+	// WORKAROUND: FM-TOWNS Zak used the extra 40 pixels at the bottom to increase the inventory to 10 items
+	// if we trim to 200 pixels, we can show only 6 items
+	// therefore we need to make sure that the inventory is now display correctly, regardless of the mode that the game was saved with
+	if (s.isLoading() && _game.platform == Common::kPlatformFMTowns && _game.id == GID_ZAK) {
+		if (ConfMan.getBool("trim_fmtowns_to_200_pixels"))
+			_verbs[getVerbSlot(116, 0)].curRect.top = 208 - 18;		// make down arrow higher
+		else
+			_verbs[getVerbSlot(116, 0)].curRect.top = 208;			// return down arrow to its original location
+
+		if (ConfMan.getBool("trim_fmtowns_to_200_pixels"))
+			// VAR(102) to VAR(111) originally keep the 10 displayed inventory items; clean the last 4 ones
+			for (int v = 102 + 6; v <= 111; v++)
+				VAR(v) = 0;
+
+		// make sure the appropriate verbs and arrows are displayed
+		runInventoryScript(0);
+	}
+
+
 	//
 	// Save/load a list of the locked objects
 	//
@@ -1449,7 +1489,7 @@ void ScummEngine::saveLoadWithSerializer(Common::Serializer &s) {
 		syncWithSerializer(s, info);
 		// If we are loading, and the music being loaded was supposed to loop
 		// forever, then resume playing it. This helps a lot when the audio CD
-		// is used to provide ambient music (see bug #788195).
+		// is used to provide ambient music (see bug #1150).
 		if (s.isLoading() && info.playing && info.numLoops < 0)
 			_sound->playCDTrackInternal(info.track, info.numLoops, info.start, info.duration);
 	}
@@ -1483,7 +1523,7 @@ void ScummEngine::saveLoadWithSerializer(Common::Serializer &s) {
 			_charset->setCurID(curId);
 		} else {
 			// Before V72, the charset id wasn't saved. This used to cause issues such
-			// as the one described in the bug report #1722153. For these savegames,
+			// as the one described in the bug report #3194. For these savegames,
 			// we reinitialize the id using a, hopefully, sane value.
 			_charset->setCurID(_string[0]._default.charset);
 		}
@@ -1572,7 +1612,7 @@ void ScummEngine_v7::saveLoadWithSerializer(Common::Serializer &s) {
 	s.syncAsSint32LE(_verbLineSpacing, VER(68));
 
 	if (s.getVersion() <= VER(68) && s.isLoading()) {
-		// WORKAROUND bug #1846049: Reset the default charset color to a sane value.
+		// WORKAROUND bug #3483: Reset the default charset color to a sane value.
 		_string[0]._default.charset = 1;
 	}
 }
@@ -1680,7 +1720,7 @@ void ScummEngine::loadResourceOLD(Common::Serializer &ser, ResType type, ResId i
 			}
 			if (type == rtObjectName && ser.getVersion() >= VER(25)) {
 				// Paranoia: We increased the possible number of new names
-				// to fix bugs #933610 and #936323. The savegame format
+				// to fix bugs #1591 and #1600. The savegame format
 				// didn't change, but at least during the transition
 				// period there is a slight chance that we try to load
 				// more names than we have allocated space for. If so,
