@@ -24,6 +24,7 @@
 #include "common/file.h"
 #include "common/system.h"
 #include "common/util.h"
+#include "common/rect.h"
 
 #include "audio/mixer.h"
 
@@ -274,7 +275,7 @@ void SmushPlayer::init(int32 speed) {
 	_dst = vs->getPixels(0, 0);
 
 	// HACK HACK HACK: This is an *evil* trick, beware!
-	// We do this to fix bug #1037052. A proper solution would change all the
+	// We do this to fix bug #1792. A proper solution would change all the
 	// drawing code to use the pitch value specified by the virtual screen.
 	// However, since a lot of the SMUSH code currently assumes the screen
 	// width and pitch to be equal, this will require lots of changes. So
@@ -513,8 +514,8 @@ void SmushPlayer::handleTextResource(uint32 subType, int32 subSize, Common::Seek
 	int flags = b.readSint16LE();
 	int left = b.readSint16LE();
 	int top = b.readSint16LE();
-	int right = b.readSint16LE();
-	/*int32 height =*/ b.readSint16LE();
+	int width = b.readSint16LE();
+	int height = b.readSint16LE();
 	/*int32 unk2 =*/ b.readUint16LE();
 
 	const char *str;
@@ -534,12 +535,14 @@ void SmushPlayer::handleTextResource(uint32 subType, int32 subSize, Common::Seek
 	//
 	// Query ConfMan here. However it may be slower, but
 	// player may want to switch the subtitles on or off during the
-	// playback. This fixes bug #1550974
+	// playback. This fixes bug #2812
 	if ((!ConfMan.getBool("subtitles")) && ((flags & 8) == 8))
 		return;
 
-	SmushFont *sf = getFont(0);
+	bool isCJKComi = (_vm->_game.id == GID_CMI && _vm->_useCJKMode);
 	int color = 15;
+	int fontId = isCJKComi ? 1 : 0;
+
 	while (*str == '/') {
 		str++; // For Full Throttle text resources
 	}
@@ -561,24 +564,33 @@ void SmushPlayer::handleTextResource(uint32 subType, int32 subSize, Common::Seek
 	while (str[0] == '^') {
 		switch (str[1]) {
 		case 'f':
-			{
-				int id = str[3] - '0';
-				str += 4;
-				sf = getFont(id);
-			}
-			break;
+		{
+			fontId = str[3] - '0';
+			str += 4;
+		}
+		break;
 		case 'c':
-			{
-				color = str[4] - '0' + 10 *(str[3] - '0');
-				str += 5;
-			}
-			break;
+		{
+			color = str[4] - '0' + 10 *(str[3] - '0');
+			str += 5;
+		}
+		break;
 		default:
 			error("invalid escape code in text string");
 		}
 	}
 
-	// HACK. This is to prevent bug #1310846. In updated Win95 dig
+	// This is a hack from the original COMI CJK interpreter. Its purpose is to avoid
+	// ugly combinations of two byte characters (rendered with the respective special
+	// font) and standard one byte (NUT font) characters (see bug #11947).
+	if (isCJKComi && !(fontId == 0 && color == 1)) {
+		fontId = 1;
+		color = 255;
+	}
+
+	SmushFont *sf = getFont(fontId);
+
+	// HACK. This is to prevent bug #2220. In updated Win95 dig
 	// there is such line:
 	//
 	// ^f01^c001LEAD TESTER
@@ -613,6 +625,8 @@ void SmushPlayer::handleTextResource(uint32 subType, int32 subSize, Common::Seek
 					error("invalid escape code in text string");
 				}
 			} else {
+				if (SmushFont::is2ByteCharacter(_vm->_language, *sptr))
+					*sptr2++ = *sptr++;
 				*sptr2++ = *sptr++;
 			}
 		}
@@ -628,36 +642,33 @@ void SmushPlayer::handleTextResource(uint32 subType, int32 subSize, Common::Seek
 	}
 
 	// flags:
-	// bit 0 - center       1
-	// bit 1 - not used     2
-	// bit 2 - ???          4
-	// bit 3 - wrap around  8
-	switch (flags & 9) {
-	case 0:
-		sf->drawString(str, _dst, _width, _height, pos_x, pos_y, false);
-		break;
-	case 1:
-		sf->drawString(str, _dst, _width, _height, pos_x, MAX(pos_y, top), true);
-		break;
-	case 8:
-		// FIXME: Is 'right' the maximum line width here, just
-		// as it is in the next case? It's used several times
-		// in The Dig's intro, where 'left' and 'right' are
-		// always 0 and 321 respectively, and apparently we
-		// handle that correctly.
-		sf->drawStringWrap(str, _dst, _width, _height, pos_x, MAX(pos_y, top), left, right, false);
-		break;
-	case 9:
-		// In this case, the 'right' parameter is actually the
-		// maximum line width. This explains why it's sometimes
-		// smaller than 'left'.
-		//
-		// Note that in The Dig's "Spacetime Six" movie it's
-		// 621. I have no idea what that means.
-		sf->drawStringWrap(str, _dst, _width, _height, pos_x, MAX(pos_y, top), left, MIN(left + right, _width), true);
-		break;
-	default:
-		error("SmushPlayer::handleTextResource. Not handled flags: %d", flags);
+	// bit 0 - center                  0x01
+	// bit 1 - not used (align right)  0x02
+	// bit 2 - word wrap               0x04
+	// bit 3 - switchable              0x08
+	// bit 4 - fill background         0x10
+	// bit 5 - outline/shadow          0x20        (apparently only set by the text renderer itself, not from the smush data)
+	// bit 6 - vertical fix (COMI)     0x40        (COMI handles this in the printing method, but I haven't seen a case where it is used)
+	// bit 7 - skip ^ codes (COMI)     0x80        (should be irrelevant for Smush, we strip these commands anyway)
+	// bit 8 - no vertical fix (COMI)  0x100       (COMI handles this in the printing method, but I haven't seen a case where it is used)
+
+	if ((flags & 4) || _vm->_language == Common::HE_ISR) {
+		// COMI has to do it all a bit different, of course. SCUMM7 games immediately render the text from here and actually use the clipping data
+		// provided by the text resource. COMI does not render directly, but enqueues a blast string (which is then drawn through the usual main
+		// loop routines). During that process the rect data will get dumped and replaced with the following default values. It's hard to tell
+		// whether this is on purpose or not (the text looks not necessarily better or worse, just different), so we follow the original...
+		if (_vm->_game.id == GID_CMI) {
+			left = top = 10;
+			width = _width - 20;
+			height = _height - 20;
+		}
+		Common::Rect clipRect(MAX<int>(0, left), MAX<int>(0, top), MIN<int>(left + width, _width), MIN<int>(top + height, _height));
+		sf->drawStringWrap(str, _dst, clipRect, pos_x, pos_y, flags & 1);
+	} else {
+		// Similiar to the wrapped text, COMI will pass on rect coords here, which will later be lost. Unlike with the wrapped text, it will
+		// finally use the full screen dimenstions. SCUMM7 renders directly from here (see comment above), but also with the full screen.
+		Common::Rect clipRect(0, 0, _width, _height);
+		sf->drawString(str, _dst, clipRect, pos_x, pos_y, flags & 1);
 	}
 
 	free(string);
@@ -1249,7 +1260,7 @@ void SmushPlayer::play(const char *filename, int32 speed, int32 offset, int32 st
 			skipped = 0;
 		if (_updateNeeded) {
 			if (!skipFrame) {
-				// Workaround for bug #1386333: "FT DEMO: assertion triggered
+				// Workaround for bug #2415: "FT DEMO: assertion triggered
 				// when playing movie". Some frames there are 384 x 224
 				int w = MIN(_width, _vm->_screenWidth);
 				int h = MIN(_height, _vm->_screenHeight);
