@@ -44,7 +44,7 @@ enum ScalpelSequences {
 class ScalpelPerson : public Person {
 public:
 	ScalpelPerson() : Person() {}
-	virtual ~ScalpelPerson() {}
+	~ScalpelPerson() override {}
 
 	/**
 	 * Synchronize the data for a savegame
@@ -54,34 +54,34 @@ public:
 	/**
 	* This adjusts the sprites position, as well as its animation sequence:
 	*/
-	virtual void adjustSprite();
+	void adjustSprite() override;
 
 	/**
 	 * Bring a moving character to a standing position
 	 */
-	virtual void gotoStand();
+	void gotoStand() override;
 
 	/**
 	 * Set the variables for moving a character from one poisition to another
 	 * in a straight line
 	 */
-	virtual void setWalking();
+	void setWalking() override;
 
 	/**
 	 * Walk to the co-ordinates passed, and then face the given direction
 	 */
-	virtual void walkToCoords(const Point32 &destPos, int destDir);
+	void walkToCoords(const Point32 &destPos, int destDir) override;
 
 	/**
 	 * Get the source position for a character potentially affected by scaling
 	 */
-	virtual Common::Point getSourcePoint() const;
+	Common::Point getSourcePoint() const override;
 };
 
 class ScalpelPeople : public People {
 public:
 	ScalpelPeople(SherlockEngine *vm);
-	virtual ~ScalpelPeople() {}
+	~ScalpelPeople() override {}
 
 	ScalpelPerson &operator[](PeopleId id) { return *(ScalpelPerson  *)_data[id]; }
 	ScalpelPerson  &operator[](int idx) { return *(ScalpelPerson  *)_data[idx]; }
@@ -94,22 +94,22 @@ public:
 	/**
 	 * Synchronize the data for a savegame
 	 */
-	virtual void synchronize(Serializer &s);
+	void synchronize(Serializer &s) override;
 
 	/**
 	 * Change the sequence of the scene background object associated with the specified speaker.
 	 */
-	virtual void setTalkSequence(int speaker, int sequenceNum = 1);
+	void setTalkSequence(int speaker, int sequenceNum = 1) override;
 
 	/**
 	 * Restrict passed point to zone using Sherlock's positioning rules
 	 */
-	virtual const Common::Point restrictToZone(int zoneId, const Common::Point &destPos);
+	const Common::Point restrictToZone(int zoneId, const Common::Point &destPos) override;
 
 	/**
 	 * Load the walking images for Sherlock
 	 */
-	virtual bool loadWalk();
+	bool loadWalk() override;
 
 	/**
 	 * If the specified speaker is a background object, it will set it so that it uses
@@ -120,7 +120,7 @@ public:
 	 * @param speaker		Who is speaking
 	 * @param sequenceNum	Which listen sequence to use
 	 */
-	virtual void setListenSequence(int speaker, int sequenceNum = 1);
+	void setListenSequence(int speaker, int sequenceNum = 1) override;
 };
 
 } // End of namespace Scalpel
