@@ -514,7 +514,7 @@ void ScalpelUserInterface::clearInfo() {
 void ScalpelUserInterface::clearWindow() {
 	if (_windowOpen) {
 		_vm->_screen->vgaBar(Common::Rect(3, CONTROLS_Y + 11, SHERLOCK_SCREEN_WIDTH - 2,
-			SHERLOCK_SCREEN_HEIGHT - 2), INV_BACKGROUND);
+			SHERLOCK_SCREEN_HEIGHT - 1), INV_BACKGROUND);
 	}
 }
 
@@ -1266,12 +1266,13 @@ void ScalpelUserInterface::doLookControl() {
 	_keyboardInput = (_keyPress != '\0');
 
 	if (events._released || events._rightReleased || _keyboardInput) {
+		// Is there any remaining text to display?
+		if (!_descStr.empty()) {
+			printObjectDesc(_descStr, false);
+		}
 		// Is an inventory object being looked at?
-		if (!_invLookFlag) {
-			// Is there any remaining text to display?
-			if (!_descStr.empty()) {
-				printObjectDesc(_descStr, false);
-			} else if (!_lookHelp) {
+		else if (!_invLookFlag) {
+			if (!_lookHelp) {
 				// Need to close the window and depress the Look button
 				Common::Point pt(MENU_POINTS[0][0], MENU_POINTS[0][1]);
 				offsetButton3DO(pt, 0);
@@ -1990,7 +1991,7 @@ void ScalpelUserInterface::printObjectDesc(const Common::String &str, bool first
 
 	// Clear background
 	bb.fillRect(Common::Rect(2, CONTROLS_Y + 10, SHERLOCK_SCREEN_WIDTH - 2,
-		SHERLOCK_SCREEN_HEIGHT - 2), INV_BACKGROUND);
+		SHERLOCK_SCREEN_HEIGHT - 1), INV_BACKGROUND);
 
 	_windowBounds.top = CONTROLS_Y;
 	events.clearEvents();
@@ -2105,6 +2106,8 @@ void ScalpelUserInterface::summonWindow(const Surface &bgSurface, bool slideUp)
 		}
 	}
 
+	events.clearEvents();
+
 	// Final display of the entire window
 	screen.getBackBuffer()->SHblitFrom(bgSurface, Common::Point(0, SHERLOCK_SCREEN_HEIGHT - bgSurface.height()),
 		Common::Rect(0, 0, bgSurface.width(), bgSurface.height()));
@@ -2188,6 +2191,8 @@ void ScalpelUserInterface::banishWindow(bool slideUp) {
 			screen.slamRect(Common::Rect(0, CONTROLS_Y1, SHERLOCK_SCREEN_WIDTH, SHERLOCK_SCREEN_HEIGHT));
 		}
 
+		events.clearEvents();
+
 		_infoFlag = false;
 		_windowOpen = false;
 	}
