@@ -27,6 +27,7 @@
 #include "sherlock/scalpel/scalpel_people.h"
 #include "sherlock/scalpel/scalpel_scene.h"
 #include "sherlock/scalpel/scalpel_screen.h"
+#include "sherlock/scalpel/3do/scalpel_3do_screen.h"
 #include "sherlock/tattoo/tattoo.h"
 #include "sherlock/tattoo/tattoo_scene.h"
 #include "sherlock/tattoo/tattoo_user_interface.h"
@@ -356,7 +357,7 @@ bool Scene::loadScene(const Common::String &filename) {
 			if (IS_ROSE_TATTOO) {
 				// Resize the screen if necessary
 				int fullWidth = SHERLOCK_SCREEN_WIDTH + bgHeader._scrollSize;
-				if (screen._backBuffer1.w() != fullWidth) {
+				if (screen._backBuffer1.width() != fullWidth) {
 					screen._backBuffer1.create(fullWidth, SHERLOCK_SCREEN_HEIGHT);
 					screen._backBuffer2.create(fullWidth, SHERLOCK_SCREEN_HEIGHT);
 				}
@@ -373,7 +374,7 @@ bool Scene::loadScene(const Common::String &filename) {
 				} else {
 					rrmStream->read(screen._backBuffer1.getPixels(), fullWidth * SHERLOCK_SCREEN_HEIGHT);
 				}
-			} 
+			}
 
 			// Read in the shapes header info
 			Common::Array<BgFileHeaderInfo> bgInfo;
@@ -527,7 +528,7 @@ bool Scene::loadScene(const Common::String &filename) {
 				delete[] cAnimOffsetTablePtr;
 			}
 
-			
+
 
 			// Read in the room bounding areas
 			int size = rrmStream->readUint16LE();
@@ -626,7 +627,7 @@ bool Scene::loadScene(const Common::String &filename) {
 			if (IS_ROSE_TATTOO) {
 				// Load the object sound list
 				char buffer[27];
-			
+
 				_objSoundList.resize(rrmStream->readUint16LE());
 				for (uint idx = 0; idx < _objSoundList.size(); ++idx) {
 					rrmStream->read(buffer, 27);
@@ -649,7 +650,7 @@ bool Scene::loadScene(const Common::String &filename) {
 			}
 
 			// Backup the image and set the palette
-			screen._backBuffer2.blitFrom(screen._backBuffer1);
+			screen._backBuffer2.SHblitFrom(screen._backBuffer1);
 			screen.setPalette(screen._cMap);
 
 			delete rrmStream;
@@ -996,12 +997,12 @@ bool Scene::loadScene(const Common::String &filename) {
 
 #if 0
 		// code to show the background
-		screen.blitFrom(screen._backBuffer1);
+		screen.SHblitFrom(screen._backBuffer1);
 		_vm->_events->wait(10000);
 #endif
 
 		// Backup the image
-		screen._backBuffer2.blitFrom(screen._backBuffer1);
+		screen._backBuffer2.SHblitFrom(screen._backBuffer1);
 	}
 
 	// Handle drawing any on-screen interface
@@ -1204,9 +1205,9 @@ void Scene::transitionToScene() {
 		if (hSavedFacing < 8 && !saves._justLoaded) {
 			if (IS_ROSE_TATTOO)
 				hSavedFacing = Tattoo::FS_TRANS[hSavedFacing];
-			else			
+			else
 				hSavedFacing = Scalpel::FS_TRANS[hSavedFacing];
-			
+
 			hSavedPos.x *= FIXED_INT_MULTIPLIER;
 			hSavedPos.y *= FIXED_INT_MULTIPLIER;
 		}
@@ -1234,9 +1235,9 @@ void Scene::transitionToScene() {
 		people[HOLMES]._position = Common::Point(0, 0);
 	}
 
-	// If the scene is capable of scrolling, set the current scroll so that whoever has control 
+	// If the scene is capable of scrolling, set the current scroll so that whoever has control
 	// of the scroll code is in the middle of the screen
-	if (screen._backBuffer1.w() > SHERLOCK_SCREEN_WIDTH)
+	if (screen._backBuffer1.width() > SHERLOCK_SCREEN_WIDTH)
 		people[people._walkControl].centerScreenOnPerson();
 
 	for (uint objIdx = 0; objIdx < _bgShapes.size(); ++objIdx) {
@@ -1255,7 +1256,7 @@ void Scene::transitionToScene() {
 			}
 
 			if (Common::Rect(topLeft.x, topLeft.y, bottomRight.x, bottomRight.y).contains(
-					Common::Point(people[HOLMES]._position.x / FIXED_INT_MULTIPLIER, 
+					Common::Point(people[HOLMES]._position.x / FIXED_INT_MULTIPLIER,
 					people[HOLMES]._position.y / FIXED_INT_MULTIPLIER))) {
 				// Current point is already inside box - impact occurred on
 				// a previous call. So simply do nothing except talk until the
