@@ -30,11 +30,6 @@ namespace Sherlock {
 
 SherlockEngine::SherlockEngine(OSystem *syst, const SherlockGameDescription *gameDesc) :
 		Engine(syst), _gameDescription(gameDesc), _randomSource("Sherlock") {
-	DebugMan.addDebugChannel(kDebugLevelScript,      "scripts", "Script debug level");
-	DebugMan.addDebugChannel(kDebugLevelAdLibDriver, "AdLib",   "AdLib driver debugging");
-	DebugMan.addDebugChannel(kDebugLevelMT32Driver,  "MT32",    "MT32 driver debugging");
-	DebugMan.addDebugChannel(kDebugLevelMusic,       "Music",   "Music debugging");
-
 	_animation = nullptr;
 	_debugger = nullptr;
 	_events = nullptr;
