@@ -31,7 +31,9 @@
 #include "common/random.h"
 #include "common/savefile.h"
 #include "common/util.h"
+
 #include "engines/engine.h"
+
 #include "sherlock/animation.h"
 #include "sherlock/debugger.h"
 #include "sherlock/events.h"
@@ -48,6 +50,7 @@
 #include "sherlock/sound.h"
 #include "sherlock/talk.h"
 #include "sherlock/user_interface.h"
+#include "sherlock/detection.h"
 
 namespace Sherlock {
 
@@ -58,11 +61,6 @@ enum {
 	kDebugLevelMusic       = 4 << 0
 };
 
-enum GameType {
-	GType_SerratedScalpel = 0,
-	GType_RoseTattoo = 1
-};
-
 #define SHERLOCK_SCREEN_WIDTH _vm->_screen->width()
 #define SHERLOCK_SCREEN_HEIGHT _vm->_screen->height()
 #define SHERLOCK_SCENE_WIDTH _vm->_screen->_backBuffer1.width()
@@ -74,8 +72,6 @@ enum GameType {
 #define COL_PEN_COLOR (IS_SERRATED_SCALPEL ? (byte)Scalpel::PEN_COLOR : (byte)Tattoo::PEN_COLOR)
 #define COL_PEN_HIGHLIGHT (IS_SERRATED_SCALPEL ? 15 : 129)
 
-struct SherlockGameDescription;
-
 class Resource;
 
 class SherlockEngine : public Engine {
