@@ -125,11 +125,11 @@ void WidgetBase::drawBackground() {
 	TattooUserInterface &ui = *(TattooUserInterface *)_vm->_ui;
 
 	Common::Rect bounds = _bounds;
+	bounds.grow(-3);
 
 	if (vm._transparentMenus) {
 		ui.makeBGArea(bounds);
 	} else {
-		bounds.grow(-3);
 		screen._backBuffer1.fillRect(bounds, MENU_BACKGROUND);
 	}
 }
@@ -195,7 +195,7 @@ void WidgetBase::makeInfoArea(Surface &s) {
 	s.SHtransBlitFrom(images[0], Common::Point(0, 0));
 	s.SHtransBlitFrom(images[1], Common::Point(s.width() - images[1]._width, 0));
 	s.SHtransBlitFrom(images[2], Common::Point(0, s.height() - images[2]._height));
-	s.SHtransBlitFrom(images[3], Common::Point(s.width() - images[3]._width, s.height()));
+	s.SHtransBlitFrom(images[3], Common::Point(s.width() - images[3]._width, s.height() - images[3]._height));
 
 	// Draw the top of the Info Box
 	s.hLine(images[0]._width, 0, s.width() - images[1]._width, INFO_TOP);
@@ -269,7 +269,7 @@ void WidgetBase::drawScrollBar(int index, int pageSize, int count) {
 	int barY = (count <= pageSize) ? r.top + BUTTON_SIZE : r.top + BUTTON_SIZE +
 		(r.height() - BUTTON_SIZE * 2 - barHeight) * index / (count - pageSize);
 
-	_surface.fillRect(Common::Rect(r.left + 2, barY + 2, r.right - 2, barY + barHeight - 3), INFO_MIDDLE);
+	_surface.fillRect(Common::Rect(r.left + 2, barY + 2, r.right - 2, barY + barHeight - 2), INFO_MIDDLE);
 	ui.drawDialogRect(_surface, Common::Rect(r.left, barY, r.right, barY + barHeight), true);
 }
 
