@@ -298,27 +298,9 @@ void WidgetOptions::render(OptionRenderMode mode) {
 				str = Common::String::format("%s %s", FIXED(Music), OFF_ON[music._musicOn]);
 				break;
 
-			case 3: {
-				int num = (_surface.fontHeight() + 4) & 0xfe;
-				int sliderY = yp + num / 2 - 8;
-
-				_surface.fillRect(Common::Rect(4, sliderY - (num - 6) / 2, _surface.width() - 5,
-					sliderY - (num - 6) / 2 + num - 1), TRANSPARENCY);
-				_surface.fillRect(Common::Rect(_surface.widestChar(), sliderY + 2,
-					_surface.width() - _surface.widestChar() - 1, sliderY + 3), INFO_MIDDLE);
-				drawDialogRect(Common::Rect(_surface.widestChar(), sliderY, _surface.width() - _surface.widestChar(), sliderY + 6));
-
-				_surface.fillRect(Common::Rect(_midiSliderX - 1, sliderY - (num - 6) / 2 + 2,
-					_midiSliderX + 1, sliderY - (num - 6) / 2 + num - 3), INFO_MIDDLE);
-				drawDialogRect(Common::Rect(_midiSliderX - 3, sliderY - (num - 6) / 2,
-					_midiSliderX + 4, sliderY - (num - 6) / 2 + num));
-
-				if (_midiSliderX - 4 > _surface.widestChar())
-					_surface.fillRect(Common::Rect(_midiSliderX - 4, sliderY, _midiSliderX - 4, sliderY + 4), INFO_BOTTOM);
-				if (_midiSliderX + 4 < _surface.width() - _surface.widestChar())
-					_surface.fillRect(Common::Rect(_midiSliderX + 4, sliderY, _midiSliderX + 4, sliderY + 4), INFO_BOTTOM);
+			case 3:
+				drawSlider(yp, _midiSliderX);
 				break;
-			}
 
 			case 4:
 				str = Common::String::format("%s %s", FIXED(SoundEffects), OFF_ON[sound._digitized]);
@@ -328,25 +310,9 @@ void WidgetOptions::render(OptionRenderMode mode) {
 				str = Common::String::format("%s %s", FIXED(Voices), OFF_ON[sound._speechOn]);
 				break;
 
-			case 6: {
-				int num = (_surface.fontHeight() + 4) & 0xfe;
-				int sliderY = yp + num / 2 - 8;
-
-				_surface.fillRect(Common::Rect(4, sliderY - (num - 6) / 2, _surface.width() - 5,
-					sliderY - (num - 6) / 2 + num - 1), TRANSPARENCY);
-				_surface.fillRect(Common::Rect(_surface.widestChar(), sliderY + 2, _surface.width() - _surface.widestChar() - 1,
-					sliderY + 3), INFO_MIDDLE);
-				drawDialogRect(Common::Rect(_surface.widestChar(), sliderY, _surface.width() - _surface.widestChar(), sliderY + 6));
-				_surface.fillRect(Common::Rect(_digiSliderX - 1, sliderY - (num - 6) / 2 + 2, _digiSliderX + 1,
-					sliderY - (num - 6) / 2 + num - 3), INFO_MIDDLE);
-				drawDialogRect(Common::Rect(_digiSliderX - 3, sliderY - (num - 6) / 2, _digiSliderX + 4,
-					sliderY - (num - 6) / 2 + num));
-				if (_digiSliderX - 4 > _surface.widestChar())
-					_surface.fillRect(Common::Rect(_digiSliderX - 4, sliderY, _digiSliderX - 4, sliderY + 4), INFO_BOTTOM);
-				if (_digiSliderX + 4 < _surface.width() - _surface.widestChar())
-					_surface.fillRect(Common::Rect(_digiSliderX + 4, sliderY, _digiSliderX + 4, sliderY + 4), INFO_BOTTOM);
+			case 6:
+				drawSlider(yp, _digiSliderX);
 				break;
-			}
 
 			case 7:
 				if (!sound._voices) {
@@ -382,6 +348,27 @@ void WidgetOptions::render(OptionRenderMode mode) {
 	}
 }
 
+void WidgetOptions::drawSlider(int yp, int sliderX) {
+	int num = (_surface.fontHeight() + 4) & 0xfe;
+	int sliderY = yp + num / 2 - 8;
+
+	_surface.fillRect(Common::Rect(4, sliderY - (num - 6) / 2, _surface.width() - 5,
+		sliderY - (num - 6) / 2 + num - 1), TRANSPARENCY);
+	_surface.fillRect(Common::Rect(_surface.widestChar(), sliderY + 2,
+		_surface.width() - _surface.widestChar() - 1, sliderY + 4), INFO_MIDDLE);
+	drawDialogRect(Common::Rect(_surface.widestChar(), sliderY, _surface.width() - _surface.widestChar(), sliderY + 6));
+
+	_surface.fillRect(Common::Rect(sliderX - 1, sliderY - (num - 6) / 2 + 2,
+		sliderX + 2, sliderY - (num - 6) / 2 + num - 2), INFO_MIDDLE);
+	drawDialogRect(Common::Rect(sliderX - 3, sliderY - (num - 6) / 2,
+		sliderX + 4, sliderY - (num - 6) / 2 + num));
+
+	if (sliderX - 4 > _surface.widestChar())
+		_surface.fillRect(Common::Rect(sliderX - 4, sliderY, sliderX - 3, sliderY + 4), INFO_BOTTOM);
+	if (sliderX + 4 < _surface.width() - _surface.widestChar())
+		_surface.fillRect(Common::Rect(sliderX + 4, sliderY, sliderX + 5, sliderY + 4), INFO_BOTTOM);
+}
+
 } // End of namespace Tattoo
 
 } // End of namespace Sherlock
