@@ -21,6 +21,8 @@
  */
 
 
+#include "backends/keymapper/keymap.h"
+
 #include "common/endian.h"
 #include "common/config-manager.h"
 #include "common/events.h"
@@ -194,7 +196,8 @@ void ControlStatus::drawToScreen() {
 	_statusText->drawToScreen(WITH_MASK);
 }
 
-Control::Control(Common::SaveFileManager *saveFileMan, Screen *screen, Disk *disk, Mouse *mouse, Text *text, MusicBase *music, Logic *logic, Sound *sound, SkyCompact *skyCompact, OSystem *system) {
+Control::Control(SkyEngine *vm, Common::SaveFileManager *saveFileMan, Screen *screen, Disk *disk, Mouse *mouse, Text *text, MusicBase *music, Logic *logic, Sound *sound, SkyCompact *skyCompact, OSystem *system, Common::Keymap *shortcutsKeymap) {
+	_vm = vm;
 	_saveFileMan = saveFileMan;
 
 	_skyScreen = screen;
@@ -206,7 +209,9 @@ Control::Control(Common::SaveFileManager *saveFileMan, Screen *screen, Disk *dis
 	_skySound = sound;
 	_skyCompact = skyCompact;
 	_system = system;
+	_shortcutsKeymap = shortcutsKeymap;
 	_controlPanel = NULL;
+	_action = kSkyActionNone;
 }
 
 ConResource *Control::createResource(void *pSpData, uint32 pNSprites, uint32 pCurSprite, int16 pX, int16 pY, uint32 pText, uint8 pOnClick, uint8 panelType) {
@@ -222,25 +227,48 @@ ConResource *Control::createResource(void *pSpData, uint32 pNSprites, uint32 pCu
 }
 
 void Control::removePanel() {
+	//
+	// We sync sound settings when exiting the Panel
+	// TODO: There's still an edge case not addressed here
+	//       for when the player opens the native menu (F5)
+	//       and the ScummVM in-game menu on top of it.
+	//       In that case, the eventual music volume
+	//       will be the one set in the ScummVM UI
+	//
+	// Setting the music volume from native menu affects only music volume
+	// even though the native menu has no setting for SFX and Speech volume
+	// TODO: Was this the behavior in the original (DOS version)?
+	//
+	// SkyEngine native sound volume range is [0, 127]
+	// However, via ScummVM UI, the volume range can be set within [0, 256]
+	// so we "translate" between them
+	uint8 volume = _skyMusic->giveVolume();
+	if (volume == 127) { // ensure mapping of max values
+		ConfMan.setInt("music_volume", 256);
+	} else {
+		ConfMan.setInt("music_volume", CLIP(volume << 1, 0, 256));
+	}
+	_vm->syncSoundSettings();
+
 	free(_screenBuf);
-	free(_sprites.controlPanel);	free(_sprites.button);
-	free(_sprites.buttonDown);		free(_sprites.savePanel);
-	free(_sprites.yesNo);			free(_sprites.slide);
-	free(_sprites.slide2);			free(_sprites.slode);
-	free(_sprites.slode2);			free(_sprites.musicBodge);
-	delete _controlPanel;			delete _exitButton;
+	free(_sprites.controlPanel); free(_sprites.button);
+	free(_sprites.buttonDown);   free(_sprites.savePanel);
+	free(_sprites.yesNo);        free(_sprites.slide);
+	free(_sprites.slide2);       free(_sprites.slode);
+	free(_sprites.slode2);       free(_sprites.musicBodge);
+	delete _controlPanel;        delete _exitButton;
 	_controlPanel = NULL;
-	delete _slide;				delete _slide2;
-	delete _slode;				delete _restorePanButton;
-	delete _savePanel;			delete _saveButton;
-	delete _downFastButton;			delete _downSlowButton;
-	delete _upFastButton;			delete _upSlowButton;
-	delete _quitButton;			delete _autoSaveButton;
-	delete _savePanButton;			delete _dosPanButton;
-	delete _restartPanButton;		delete _fxPanButton;
-	delete _musicPanButton;			delete _bodge;
-	delete _yesNo;				delete _text;
-	delete _statusBar;			delete _restoreButton;
+	delete _slide;               delete _slide2;
+	delete _slode;               delete _restorePanButton;
+	delete _savePanel;           delete _saveButton;
+	delete _downFastButton;      delete _downSlowButton;
+	delete _upFastButton;        delete _upSlowButton;
+	delete _quitButton;          delete _autoSaveButton;
+	delete _savePanButton;       delete _dosPanButton;
+	delete _restartPanButton;    delete _fxPanButton;
+	delete _musicPanButton;      delete _bodge;
+	delete _yesNo;               delete _text;
+	delete _statusBar;           delete _restoreButton;
 
 	if (_textSprite) {
 		free(_textSprite);
@@ -253,7 +281,7 @@ void Control::initPanel() {
 	memset(_screenBuf, 0, GAME_SCREEN_WIDTH * FULL_SCREEN_HEIGHT);
 
 	uint16 volY = (127 - _skyMusic->giveVolume()) / 4 + 59 - MPNL_Y; // volume slider's Y coordinate
-	uint16 spdY = (SkyEngine::_systemVars.gameSpeed - 2) / SPEED_MULTIPLY;
+	uint16 spdY = (SkyEngine::_systemVars->gameSpeed - 2) / SPEED_MULTIPLY;
 	spdY += MPNL_Y + 83; // speed slider's initial position
 
 	_sprites.controlPanel	= _skyDisk->loadFile(60500);
@@ -265,7 +293,7 @@ void Control::initPanel() {
 	_sprites.slode			= _skyDisk->loadFile(60506);
 	_sprites.slode2			= _skyDisk->loadFile(60507);
 	_sprites.slide2			= _skyDisk->loadFile(60508);
-	if (SkyEngine::_systemVars.gameVersion < 368)
+	if (SkyEngine::_systemVars->gameVersion < 368)
 		_sprites.musicBodge = NULL;
 	else
 		_sprites.musicBodge = _skyDisk->loadFile(60509);
@@ -419,7 +447,7 @@ void Control::drawMainPanel() {
 	_slide2->drawToScreen(WITH_MASK);
 	_bodge->drawToScreen(WITH_MASK);
 	if (SkyEngine::isCDVersion())
-		drawTextCross(SkyEngine::_systemVars.systemFlags & TEXT_FLAG_MASK);
+		drawTextCross(SkyEngine::_systemVars->systemFlags & TEXT_FLAG_MASK);
 	_statusBar->drawToScreen();
 }
 
@@ -428,7 +456,7 @@ void Control::doLoadSavePanel() {
 		return; // I don't think this can even happen
 	initPanel();
 	_skyScreen->clearScreen();
-	if (SkyEngine::_systemVars.gameVersion < 331)
+	if (SkyEngine::_systemVars->gameVersion < 331)
 		_skyScreen->setPalette(60509);
 	else
 		_skyScreen->setPalette(60510);
@@ -446,7 +474,7 @@ void Control::doLoadSavePanel() {
 	_system->copyRectToScreen(_screenBuf, GAME_SCREEN_WIDTH, 0, 0, GAME_SCREEN_WIDTH, FULL_SCREEN_HEIGHT);
 	_system->updateScreen();
 	_skyScreen->forceRefresh();
-	_skyScreen->setPaletteEndian((uint8 *)_skyCompact->fetchCpt(SkyEngine::_systemVars.currentPalette));
+	_skyScreen->setPaletteEndian((uint8 *)_skyCompact->fetchCpt(SkyEngine::_systemVars->currentPalette));
 	removePanel();
 	_skyMouse->spriteMouse(_savedMouse, 0, 0);
 	_skyText->fnSetFont(_savedCharSet);
@@ -463,19 +491,19 @@ void Control::doControlPanel() {
 	_skyText->fnSetFont(2);
 
 	_skyScreen->clearScreen();
-	if (SkyEngine::_systemVars.gameVersion < 331)
+	if (SkyEngine::_systemVars->gameVersion < 331)
 		_skyScreen->setPalette(60509);
 	else
 		_skyScreen->setPalette(60510);
 
 	// Set initial button lights
 	_fxPanButton->_curSprite =
-		(SkyEngine::_systemVars.systemFlags & SF_FX_OFF ? 0 : 2);
+		(SkyEngine::_systemVars->systemFlags & SF_FX_OFF ? 0 : 2);
 
 	// music button only available in floppy version
 	if (!SkyEngine::isCDVersion())
 		_musicPanButton->_curSprite =
-			(SkyEngine::_systemVars.systemFlags & SF_MUS_OFF ? 0 : 2);
+			(SkyEngine::_systemVars->systemFlags & SF_MUS_OFF ? 0 : 2);
 
 	drawMainPanel();
 
@@ -494,7 +522,7 @@ void Control::doControlPanel() {
 		delay(ANIM_DELAY);
 		if (!_controlPanel)
 			return;
-		if (_keyPressed.keycode == Common::KEYCODE_ESCAPE) { // escape pressed
+		if (_action == kSkyActionSkip) { // escape pressed
 			_mouseClicked = false;
 			quitPanel = true;
 		}
@@ -526,7 +554,7 @@ void Control::doControlPanel() {
 	if (!Engine::shouldQuit())
 		_system->updateScreen();
 	_skyScreen->forceRefresh();
-	_skyScreen->setPaletteEndian((uint8 *)_skyCompact->fetchCpt(SkyEngine::_systemVars.currentPalette));
+	_skyScreen->setPaletteEndian((uint8 *)_skyCompact->fetchCpt(SkyEngine::_systemVars->currentPalette));
 	removePanel();
 	_skyMouse->spriteMouse(_savedMouse, 0, 0);
 	_skyText->fnSetFont(_savedCharSet);
@@ -691,6 +719,8 @@ uint16 Control::doMusicSlide() {
 			if (volume >= 128) volume = 0;
 			else volume = 127 - volume;
 			_skyMusic->setVolume(volume);
+			// we don't sync here with ConfMan to avoid numerous redundant I/O.
+			// we sync in removePanel()
 		}
 		buttonControl(_slide2);
 		_text->drawToScreen(WITH_MASK);
@@ -727,13 +757,13 @@ uint16 Control::doSpeedSlide() {
 		_text->drawToScreen(WITH_MASK);
 		_system->updateScreen();
 	}
-	SkyEngine::_systemVars.gameSpeed = speedDelay;
+	SkyEngine::_systemVars->gameSpeed = speedDelay;
 	return SPEED_CHANGED;
 }
 
 void Control::toggleFx(ConResource *pButton) {
-	SkyEngine::_systemVars.systemFlags ^= SF_FX_OFF;
-	if (SkyEngine::_systemVars.systemFlags & SF_FX_OFF) {
+	SkyEngine::_systemVars->systemFlags ^= SF_FX_OFF;
+	if (SkyEngine::_systemVars->systemFlags & SF_FX_OFF) {
 		pButton->_curSprite = 0;
 		_statusBar->setToText(0x7000 + 87);
 	} else {
@@ -741,15 +771,15 @@ void Control::toggleFx(ConResource *pButton) {
 		_statusBar->setToText(0x7000 + 86);
 	}
 
-	ConfMan.setBool("sfx_mute", (SkyEngine::_systemVars.systemFlags & SF_FX_OFF) != 0);
+	ConfMan.setBool("sfx_mute", (SkyEngine::_systemVars->systemFlags & SF_FX_OFF) != 0);
 
 	pButton->drawToScreen(WITH_MASK);
 	_system->updateScreen();
 }
 
 uint16 Control::toggleText() {
-	uint32 flags = SkyEngine::_systemVars.systemFlags & TEXT_FLAG_MASK;
-	SkyEngine::_systemVars.systemFlags &= ~TEXT_FLAG_MASK;
+	uint32 flags = SkyEngine::_systemVars->systemFlags & TEXT_FLAG_MASK;
+	SkyEngine::_systemVars->systemFlags &= ~TEXT_FLAG_MASK;
 
 	if (flags == SF_ALLOW_TEXT) {
 		flags = SF_ALLOW_SPEECH;
@@ -765,7 +795,7 @@ uint16 Control::toggleText() {
 	ConfMan.setBool("subtitles", (flags & SF_ALLOW_TEXT) != 0);
 	ConfMan.setBool("speech_mute", (flags & SF_ALLOW_SPEECH) == 0);
 
-	SkyEngine::_systemVars.systemFlags |= flags;
+	SkyEngine::_systemVars->systemFlags |= flags;
 
 	drawTextCross(flags);
 
@@ -774,18 +804,18 @@ uint16 Control::toggleText() {
 }
 
 void Control::toggleMusic(ConResource *pButton) {
-	SkyEngine::_systemVars.systemFlags ^= SF_MUS_OFF;
-	if (SkyEngine::_systemVars.systemFlags & SF_MUS_OFF) {
+	SkyEngine::_systemVars->systemFlags ^= SF_MUS_OFF;
+	if (SkyEngine::_systemVars->systemFlags & SF_MUS_OFF) {
 		_skyMusic->startMusic(0);
 		pButton->_curSprite = 0;
 		_statusBar->setToText(0x7000 + 89);
 	} else {
-		_skyMusic->startMusic(SkyEngine::_systemVars.currentMusic);
+		_skyMusic->startMusic(SkyEngine::_systemVars->currentMusic);
 		pButton->_curSprite = 2;
 		_statusBar->setToText(0x7000 + 88);
 	}
 
-	ConfMan.setBool("music_mute", (SkyEngine::_systemVars.systemFlags & SF_MUS_OFF) != 0);
+	ConfMan.setBool("music_mute", (SkyEngine::_systemVars->systemFlags & SF_MUS_OFF) != 0);
 
 	pButton->drawToScreen(WITH_MASK);
 	_system->updateScreen();
@@ -827,14 +857,8 @@ uint16 Control::shiftUp(uint8 speed) {
 
 bool Control::autoSaveExists() {
 	bool test = false;
-	Common::InSaveFile *f;
-	char fName[20];
-	if (SkyEngine::isCDVersion())
-		strcpy(fName, "SKY-VM-CD.ASD");
-	else
-		sprintf(fName, "SKY-VM%03d.ASD", SkyEngine::_systemVars.gameVersion);
-
-	f = _saveFileMan->openForLoading(fName);
+	Common::InSaveFile *f = _saveFileMan->openForLoading(
+		g_engine->getSaveStateName(g_engine->getAutosaveSlot()));
 	if (f != NULL) {
 		test = true;
 		delete f;
@@ -844,6 +868,7 @@ bool Control::autoSaveExists() {
 
 uint16 Control::saveRestorePanel(bool allowSave) {
 	_keyPressed.reset();
+	_action = kSkyActionNone;
 	_mouseWheel = 0;
 	buttonControl(NULL);
 	_text->drawToScreen(WITH_MASK); // flush text restore buffer
@@ -855,6 +880,9 @@ uint16 Control::saveRestorePanel(bool allowSave) {
 		lookList = _savePanLookList;
 		lookListLen = 6;
 		_system->setFeatureState(OSystem::kFeatureVirtualKeyboard, true);
+
+		 // Disable the shortcuts keymap during text input to prevent letters from being mapped to action events
+		_shortcutsKeymap->setEnabled(false);
 	} else {
 		lookList = _restorePanLookList;
 		if (autoSaveExists())
@@ -902,11 +930,11 @@ uint16 Control::saveRestorePanel(bool allowSave) {
 		delay(ANIM_DELAY);
 		if (!_controlPanel)
 			return clickRes;
-		if (_keyPressed.keycode == Common::KEYCODE_ESCAPE) { // escape pressed
+		if (_action == kSkyActionSkip) { // escape pressed
 			_mouseClicked = false;
 			clickRes = CANCEL_PRESSED;
 			quitPanel = true;
-		} else if ((_keyPressed.keycode == Common::KEYCODE_RETURN) || (_keyPressed.keycode == Common::KEYCODE_KP_ENTER)) {
+		} else if (_action == kSkyActionConfirm) { // enter pressed
 			clickRes = handleClick(lookList[0]);
 			if (!_controlPanel) //game state was destroyed
 				return clickRes;
@@ -916,7 +944,7 @@ uint16 Control::saveRestorePanel(bool allowSave) {
 				displayMessage(0, "Could not save the game. (%s)", _saveFileMan->popErrorDesc().c_str());
 			quitPanel = true;
 			_mouseClicked = false;
-			_keyPressed.reset();
+			_action = kSkyActionNone;
 		} if (allowSave && _keyPressed.keycode) {
 			handleKeyPress(_keyPressed, saveGameTexts[_selectedGame]);
 			refreshNames = true;
@@ -985,6 +1013,7 @@ uint16 Control::saveRestorePanel(bool allowSave) {
 		free(textSprites[cnt]);
 
 	if (allowSave) {
+		_shortcutsKeymap->setEnabled(true);
 		_system->setFeatureState(OSystem::kFeatureVirtualKeyboard, false);
 	}
 
@@ -1080,7 +1109,7 @@ void Control::loadDescriptions(Common::StringArray &savenames) {
 }
 
 bool Control::loadSaveAllowed() {
-	if (SkyEngine::_systemVars.systemFlags & SF_CHOOSING)
+	if (SkyEngine::_systemVars->systemFlags & SF_CHOOSING)
 		return false; // texts get lost during load/save, so don't allow it during choosing
 	if (Logic::_scriptVariables[SCREEN] >= 101)
 		return false; // same problem with LINC terminals
@@ -1111,7 +1140,7 @@ void Control::saveDescriptions(const Common::StringArray &list) {
 
 	outf = _saveFileMan->openForSaving("SKY-VM.SAV");
 	bool ioFailed = true;
-	if (outf) {
+	if (outf != nullptr) {
 		for (uint16 cnt = 0; cnt < MAX_SAVE_GAMES; cnt++) {
 			outf->write(list[cnt].c_str(), list[cnt].size() + 1);
 		}
@@ -1124,30 +1153,16 @@ void Control::saveDescriptions(const Common::StringArray &list) {
 		displayMessage(NULL, "Unable to store Savegame names to file SKY-VM.SAV. (%s)", _saveFileMan->popErrorDesc().c_str());
 }
 
-void Control::doAutoSave() {
-	char fName[20];
-	if (SkyEngine::isCDVersion())
-		strcpy(fName, "SKY-VM-CD.ASD");
-	else
-		sprintf(fName, "SKY-VM%03d.ASD", SkyEngine::_systemVars.gameVersion);
-
-	uint16 res = saveGameToFile(false, fName);
-
-	if (res != GAME_SAVED)
-		displayMessage(0, "Unable to perform autosave to '%s'. (%s)", fName, _saveFileMan->popErrorDesc().c_str());
-
-}
-
-uint16 Control::saveGameToFile(bool fromControlPanel, const char *filename) {
+uint16 Control::saveGameToFile(bool fromControlPanel, const char *filename, bool isAutosave) {
 	char fName[20];
 	if (!filename) {
-		sprintf(fName,"SKY-VM.%03d", _selectedGame);
+		sprintf(fName,"SKY-VM.%03d", isAutosave ? 0 : _selectedGame + 1);
 		filename = fName;
 	}
 
 	Common::OutSaveFile *outf;
 	outf = _saveFileMan->openForSaving(filename);
-	if (outf == NULL)
+	if (outf == nullptr)
 		return NO_DISK_SPACE;
 
 	if (!fromControlPanel) {
@@ -1178,7 +1193,7 @@ uint32 Control::prepareSaveData(uint8 *destBuf) {
 	memset(destBuf, 0, 4); // space for data size
 	uint8 *destPos = destBuf + 4;
 	STOSD(destPos, SAVE_FILE_REVISION);
-	STOSD(destPos, SkyEngine::_systemVars.gameVersion);
+	STOSD(destPos, SkyEngine::_systemVars->gameVersion);
 
 	STOSW(destPos, _skySound->_saveSounds[0]);
 	STOSW(destPos, _skySound->_saveSounds[1]);
@@ -1186,7 +1201,7 @@ uint32 Control::prepareSaveData(uint8 *destBuf) {
 	STOSD(destPos, _skyMusic->giveCurrentMusic());
 	STOSD(destPos, _savedCharSet);
 	STOSD(destPos, _savedMouse);
-	STOSD(destPos, SkyEngine::_systemVars.currentPalette);
+	STOSD(destPos, SkyEngine::_systemVars->currentPalette);
 	for (cnt = 0; cnt < 838; cnt++)
 		STOSD(destPos, Logic::_scriptVariables[cnt]);
 	uint32 *loadedFilesList = _skyDisk->giveLoadedFilesList();
@@ -1345,16 +1360,16 @@ uint16 Control::parseSaveData(uint8 *srcBuf) {
 		return RESTORE_FAILED;
 	}
 	LODSD(srcPos, gameVersion);
-	if (gameVersion != SkyEngine::_systemVars.gameVersion) {
+	if (gameVersion != SkyEngine::_systemVars->gameVersion) {
 		if ((!SkyEngine::isCDVersion()) || (gameVersion < 365)) { // cd versions are compatible
 			displayMessage(NULL, "This saved game was created by\n"
 				"Beneath a Steel Sky v0.0%03d\n"
 				"It cannot be loaded by this version (v0.0%3d)",
-				gameVersion, SkyEngine::_systemVars.gameVersion);
+				gameVersion, SkyEngine::_systemVars->gameVersion);
 			return RESTORE_FAILED;
 		}
 	}
-	SkyEngine::_systemVars.systemFlags |= SF_GAME_RESTORED;
+	SkyEngine::_systemVars->systemFlags |= SF_GAME_RESTORED;
 
 	LODSW(srcPos, _skySound->_saveSounds[0]);
 	LODSW(srcPos, _skySound->_saveSounds[1]);
@@ -1409,28 +1424,22 @@ uint16 Control::parseSaveData(uint8 *srcBuf) {
 		error("Restore failed! Savegame data = %lu bytes. Expected size: %d", (long)(srcPos-srcBuf), size);
 
 	_skyDisk->refreshFilesList(reloadList);
-	SkyEngine::_systemVars.currentMusic = (uint16)music;
-	if (!(SkyEngine::_systemVars.systemFlags & SF_MUS_OFF))
+	SkyEngine::_systemVars->currentMusic = (uint16)music;
+	if (!(SkyEngine::_systemVars->systemFlags & SF_MUS_OFF))
 		_skyMusic->startMusic((uint16)music);
 	_savedMouse = (uint16)mouseType;
-	SkyEngine::_systemVars.currentPalette = palette; // will be set when doControlPanel ends
+	SkyEngine::_systemVars->currentPalette = palette; // will be set when doControlPanel ends
 
 	return GAME_RESTORED;
 }
 
 
 uint16 Control::restoreGameFromFile(bool autoSave) {
-	char fName[20];
-	if (autoSave) {
-		if (SkyEngine::isCDVersion())
-			strcpy(fName, "SKY-VM-CD.ASD");
-		else
-			sprintf(fName, "SKY-VM%03d.ASD", SkyEngine::_systemVars.gameVersion);
-	} else
-		sprintf(fName,"SKY-VM.%03d", _selectedGame);
+	int slot = autoSave ? g_engine->getAutosaveSlot() : _selectedGame + 1;
+	Common::String filename = g_engine->getSaveStateName(slot);
 
 	Common::InSaveFile *inf;
-	inf = _saveFileMan->openForLoading(fName);
+	inf = _saveFileMan->openForLoading(filename);
 	if (inf == NULL) {
 		return RESTORE_FAILED;
 	}
@@ -1441,19 +1450,23 @@ uint16 Control::restoreGameFromFile(bool autoSave) {
 	*(uint32 *)saveData = TO_LE_32(infSize);
 
 	if (inf->read(saveData+4, infSize-4) != infSize-4) {
-		displayMessage(NULL, "Can't read from file '%s'", fName);
+		displayMessage(NULL, "Can't read from file '%s'", filename.c_str());
 		free(saveData);
 		delete inf;
 		return RESTORE_FAILED;
 	}
 
 	uint16 res = parseSaveData(saveData);
-	SkyEngine::_systemVars.pastIntro = true;
+	SkyEngine::_systemVars->pastIntro = true;
 	delete inf;
 	free(saveData);
 	return res;
 }
 
+/**
+* @param slot The slot index in the ScummVM Save file manager. "0" is the auto-save slot.
+* @return The result of the restore attempt. A value from "onClick return codes" eg GAME_RESTORED, RESTORE_FAILED etc
+*/
 uint16 Control::quickXRestore(uint16 slot) {
 	uint16 result;
 	if (!_controlPanel)
@@ -1466,7 +1479,7 @@ uint16 Control::quickXRestore(uint16 slot) {
 	_system->copyRectToScreen(_screenBuf, GAME_SCREEN_WIDTH, 0, 0, FULL_SCREEN_WIDTH, FULL_SCREEN_HEIGHT);
 	_system->updateScreen();
 
-	if (SkyEngine::_systemVars.gameVersion < 331)
+	if (SkyEngine::_systemVars->gameVersion < 331)
 		_skyScreen->setPalette(60509);
 	else
 		_skyScreen->setPalette(60510);
@@ -1484,7 +1497,7 @@ uint16 Control::quickXRestore(uint16 slot) {
 		memset(_skyScreen->giveCurrent(), 0, GAME_SCREEN_WIDTH * GAME_SCREEN_HEIGHT);
 		_skyScreen->showScreen(_skyScreen->giveCurrent());
 		_skyScreen->forceRefresh();
-		_skyScreen->setPaletteEndian((uint8 *)_skyCompact->fetchCpt(SkyEngine::_systemVars.currentPalette));
+		_skyScreen->setPaletteEndian((uint8 *)_skyCompact->fetchCpt(SkyEngine::_systemVars->currentPalette));
 	} else {
 		memset(_screenBuf, 0, FULL_SCREEN_WIDTH * FULL_SCREEN_HEIGHT);
 		_system->copyRectToScreen(_screenBuf, GAME_SCREEN_WIDTH, 0, 0, GAME_SCREEN_WIDTH, FULL_SCREEN_HEIGHT);
@@ -1499,20 +1512,25 @@ uint16 Control::quickXRestore(uint16 slot) {
 	return result;
 }
 
+/**
+ * Restarts the game (skipping intro) and places Foster (the player)
+ * already on the top level of the factory.
+ *
+*/
 void Control::restartGame() {
-	if (SkyEngine::_systemVars.gameVersion <= 267)
+	if (SkyEngine::_systemVars->gameVersion <= 267)
 		return; // no restart for floppy demo
 
-	uint8 *resetData = _skyCompact->createResetData((uint16)SkyEngine::_systemVars.gameVersion);
+	uint8 *resetData = _skyCompact->createResetData((uint16)SkyEngine::_systemVars->gameVersion);
 	parseSaveData((uint8 *)resetData);
 	free(resetData);
 	_skyScreen->forceRefresh();
 
 	memset(_skyScreen->giveCurrent(), 0, GAME_SCREEN_WIDTH * FULL_SCREEN_HEIGHT);
 	_skyScreen->showScreen(_skyScreen->giveCurrent());
-	_skyScreen->setPaletteEndian((uint8 *)_skyCompact->fetchCpt(SkyEngine::_systemVars.currentPalette));
+	_skyScreen->setPaletteEndian((uint8 *)_skyCompact->fetchCpt(SkyEngine::_systemVars->currentPalette));
 	_skyMouse->spriteMouse(_savedMouse, 0, 0);
-	SkyEngine::_systemVars.pastIntro = true;
+	SkyEngine::_systemVars->pastIntro = true;
 }
 
 void Control::delay(unsigned int amount) {
@@ -1521,16 +1539,20 @@ void Control::delay(unsigned int amount) {
 	uint32 start = _system->getMillis();
 	uint32 cur = start;
 	_keyPressed.reset();
+	_action = kSkyActionNone;
 
 	do {
 		Common::EventManager *eventMan = _system->getEventManager();
 		while (eventMan->pollEvent(event)) {
 			switch (event.type) {
+			case Common::EVENT_CUSTOM_ENGINE_ACTION_START:
+				_action = event.customType;
+				break;
 			case Common::EVENT_KEYDOWN:
 				_keyPressed = event.kbd;
 				break;
 			case Common::EVENT_MOUSEMOVE:
-				if (!(SkyEngine::_systemVars.systemFlags & SF_MOUSE_LOCKED))
+				if (!(SkyEngine::_systemVars->systemFlags & SF_MOUSE_LOCKED))
 					_skyMouse->mouseMoved(event.mouse.x, event.mouse.y);
 				break;
 			case Common::EVENT_LBUTTONDOWN:
@@ -1553,9 +1575,6 @@ void Control::delay(unsigned int amount) {
 		}
 
 		uint this_delay = 20; // 1?
-#ifdef _WIN32_WCE
-		this_delay = 10;
-#endif
 		if (this_delay > amount)
 			this_delay = amount;
 
@@ -1579,8 +1598,8 @@ void Control::showGameQuitMsg() {
 		_skyText->displayText(_quitTexts[8 * 2 + 0], textBuf1, true, 320, 255);
 		_skyText->displayText(_quitTexts[8 * 2 + 1], textBuf2, true, 320, 255);
 	} else {
-		_skyText->displayText(_quitTexts[SkyEngine::_systemVars.language * 2 + 0], textBuf1, true, 320, 255);
-		_skyText->displayText(_quitTexts[SkyEngine::_systemVars.language * 2 + 1], textBuf2, true, 320, 255);
+		_skyText->displayText(_quitTexts[SkyEngine::_systemVars->language * 2 + 0], textBuf1, true, 320, 255);
+		_skyText->displayText(_quitTexts[SkyEngine::_systemVars->language * 2 + 1], textBuf2, true, 320, 255);
 	}
 	uint8 *curLine1 = textBuf1 + sizeof(DataFileHeader);
 	uint8 *curLine2 = textBuf2 + sizeof(DataFileHeader);
