@@ -1258,6 +1258,8 @@ bool Debugger::Cmd_LogicCommand(int argc, const char **argv) {
 		case  3:
 			arg1 = atoi(argv[2]);
 			// fall through
+		default:
+			break;
 	}
 
 	for (int i = 0; i < numMCodes; ++i) {
@@ -1273,9 +1275,9 @@ bool Debugger::Cmd_LogicCommand(int argc, const char **argv) {
 }
 
 bool Debugger::Cmd_Info(int argc, const char **argv) {
-	debugPrintf("Beneath a Steel Sky version: 0.0%d\n", SkyEngine::_systemVars.gameVersion);
-	debugPrintf("Speech: %s\n", (SkyEngine::_systemVars.systemFlags & SF_ALLOW_SPEECH) ? "on" : "off");
-	debugPrintf("Text  : %s\n", (SkyEngine::_systemVars.systemFlags & SF_ALLOW_TEXT) ? "on" : "off");
+	debugPrintf("Beneath a Steel Sky version: 0.0%d\n", SkyEngine::_systemVars->gameVersion);
+	debugPrintf("Speech: %s\n", (SkyEngine::_systemVars->systemFlags & SF_ALLOW_SPEECH) ? "on" : "off");
+	debugPrintf("Text  : %s\n", (SkyEngine::_systemVars->systemFlags & SF_ALLOW_TEXT) ? "on" : "off");
 	return true;
 }
 
