@@ -32,20 +32,20 @@ namespace Sky {
 class MT32Music : public MusicBase {
 public:
 	MT32Music(MidiDriver *pMidiDrv, Audio::Mixer *pMixer, Disk *pDisk);
-	~MT32Music();
+	~MT32Music() override;
 private:
 	static void passTimerFunc(void *param);
 	void timerCall();
 	bool processPatchSysEx(uint8 *sysExData);
-	virtual void setVolume(uint16 volume);
+	void setVolume(uint16 volume) override;
 
 	uint32 _timerCount;
 	uint8 *_sysExSequence;
 	MidiDriver *_midiDrv;
 
-	virtual void setupPointers();
-	virtual void setupChannels(uint8 *channelData);
-	virtual void startDriver();
+	void setupPointers() override;
+	void setupChannels(uint8 *channelData) override;
+	void startDriver() override;
 };
 
 } // End of namespace Sky
