@@ -23,7 +23,10 @@
 #ifndef SLUDGE_EVENT_H
 #define SLUDGE_EVENT_H
 
-#include "common/stream.h"
+namespace Common {
+class SeekableReadStream;
+class WriteStream;
+}
 
 namespace Sludge {
 
