@@ -20,13 +20,9 @@
  *
  */
 
-#include "graphics/surface.h"
-
-#include "sludge/allfiles.h"
 #include "sludge/fileset.h"
 #include "sludge/floor.h"
 #include "sludge/graphics.h"
-#include "sludge/moreio.h"
 #include "sludge/newfatal.h"
 #include "sludge/people.h"
 #include "sludge/sludge.h"
@@ -145,6 +141,8 @@ bool FloorManager::setFloor(int fileNum) {
 	if (!g_sludge->_resMan->openFileFromNum(fileNum))
 		return false;
 
+	g_sludge->_resMan->dumpFile(fileNum, "floor%04d.flo.comp");
+
 	// Find out how many polygons there are and reserve memory
 
 	_currentFloor->originalNum = fileNum;
@@ -156,16 +154,13 @@ bool FloorManager::setFloor(int fileNum) {
 	// Read in each polygon
 
 	for (i = 0; i < _currentFloor->numPolygons; i++) {
-
 		// Find out how many vertex IDs there are and reserve memory
-
 		_currentFloor->polygon[i].numVertices = g_sludge->_resMan->getData()->readByte();
 		_currentFloor->polygon[i].vertexID = new int[_currentFloor->polygon[i].numVertices];
 		if (!checkNew(_currentFloor->polygon[i].vertexID))
 			return false;
 
 		// Read in each vertex ID
-
 		for (j = 0; j < _currentFloor->polygon[i].numVertices; j++) {
 			_currentFloor->polygon[i].vertexID[j] = g_sludge->_resMan->getData()->readUint16BE();
 		}
@@ -179,13 +174,14 @@ bool FloorManager::setFloor(int fileNum) {
 		return false;
 
 	for (j = 0; j < i; j++) {
-
 		_currentFloor->vertex[j].x = g_sludge->_resMan->getData()->readUint16BE();
 		_currentFloor->vertex[j].y = g_sludge->_resMan->getData()->readUint16BE();
 	}
 
 	g_sludge->_resMan->finishAccess();
 
+	dumpFloor(fileNum);
+
 	// Now build the movement martix
 
 	_currentFloor->matrix = new int *[_currentFloor->numPolygons];
@@ -256,6 +252,29 @@ bool FloorManager::setFloor(int fileNum) {
 	return true;
 }
 
+void FloorManager::dumpFloor(int fileNum) {
+	if (!g_sludge->_dumpScripts)
+		return;
+
+	Common::DumpFile dumpFile;
+	dumpFile.open(Common::String::format("dumps/floor%04d.flo", fileNum));
+
+	for (int i = 0; i < _currentFloor->numPolygons; i++) {
+		int nV = _currentFloor->polygon[i].numVertices;
+		if (nV > 1) {
+			int vert = _currentFloor->polygon[i].vertexID[0];
+			dumpFile.writeString(Common::String::format("* %d, %d", _currentFloor->vertex[vert].x, _currentFloor->vertex[vert].y));
+			for (int j = 1; j < nV; j++) {
+				vert = _currentFloor->polygon[i].vertexID[j];
+				dumpFile.writeString(Common::String::format("; %d, %d", _currentFloor->vertex[vert].x, _currentFloor->vertex[vert].y));
+			}
+			dumpFile.writeString("\n");
+		}
+	}
+
+	dumpFile.close();
+}
+
 void FloorManager::drawFloor() {
 	int i, j, nV;
 	for (i = 0; i < _currentFloor->numPolygons; i++) {
