@@ -20,22 +20,16 @@
  *
  */
 
-#include "sludge/allfiles.h"
-#include "sludge/backdrop.h"
 #include "sludge/cursors.h"
 #include "sludge/event.h"
-#include "sludge/fonttext.h"
-#include "sludge/freeze.h"
 #include "sludge/graphics.h"
+#include "sludge/freeze.h"
 #include "sludge/newfatal.h"
-#include "sludge/objtypes.h"
 #include "sludge/people.h"
 #include "sludge/region.h"
 #include "sludge/sludge.h"
 #include "sludge/sludger.h"
 #include "sludge/speech.h"
-#include "sludge/sprites.h"
-#include "sludge/sprbanks.h"
 #include "sludge/statusba.h"
 #include "sludge/zbuffer.h"
 
@@ -69,8 +63,9 @@ bool GraphicsManager::freeze() {
 	newFreezer->lightMapSurface.copyFrom(_lightMap);
 	newFreezer->lightMapNumber = _lightMapNumber;
 
-	newFreezer->parallaxStuff = _parallaxStuff;
-	_parallaxStuff = NULL;
+	newFreezer->parallaxLayers = _parallaxLayers;
+	_parallaxLayers = NULL;
+
 	newFreezer->zBufferSprites = _zBuffer->sprites;
 	newFreezer->zBufferNumber = _zBuffer->originalNum;
 	newFreezer->zPanels = _zBuffer->numPanels;
@@ -88,7 +83,7 @@ bool GraphicsManager::freeze() {
 	StatusStuff *newStatusStuff = new StatusStuff;
 	if (!checkNew(newStatusStuff))
 		return false;
-	newFreezer->frozenStatus = copyStatusBarStuff(newStatusStuff);
+	newFreezer->frozenStatus = _vm->_statusBar->copyStatusBarStuff(newStatusStuff);
 
 	_vm->_regionMan->freeze(newFreezer);
 	_vm->_cursorMan->freeze(newFreezer);
@@ -153,9 +148,10 @@ void GraphicsManager::unfreeze(bool killImage) {
 	}
 
 	killParallax();
-	_parallaxStuff = _frozenStuff->parallaxStuff;
+	_parallaxLayers = _frozenStuff->parallaxLayers;
+
 	_vm->_cursorMan->resotre(_frozenStuff);
-	restoreBarStuff(_frozenStuff->frozenStatus);
+	_vm->_statusBar->restoreBarStuff(_frozenStuff->frozenStatus);
 	_vm->_evtMan->restore(_frozenStuff);
 	_vm->_speechMan->restore(_frozenStuff);
 
