@@ -23,13 +23,13 @@
 #ifndef SLUDGE_GRAPHICS_H
 #define SLUDGE_GRAPHICS_H
 
-#include "common/stream.h"
-
-#include "graphics/surface.h"
-#include "graphics/transparent_surface.h"
-
 #include "sludge/sprbanks.h"
 
+namespace Common {
+class SeekableReadStream;
+class WriteStream;
+}
+
 namespace Sludge {
 
 class Parallax;
@@ -43,6 +43,7 @@ struct OnScreenPerson;
 struct SpriteBank;
 struct Sprite;
 struct SpriteLayers;
+struct VariableStack;
 struct ZBufferData;
 
 enum ELightMapMode {
@@ -52,6 +53,16 @@ enum ELightMapMode {
 	LIGHTMAPMODE_NUM
 };
 
+// Parallax
+struct ParallaxLayer {
+	Graphics::Surface surface;
+	int speedX, speedY;
+	bool wrapS, wrapT;
+	uint16 fileNum, fractionX, fractionY;
+	int cameraX, cameraY;
+};
+typedef Common::List<ParallaxLayer *> ParallaxLayers;
+
 class GraphicsManager {
 public:
 	GraphicsManager(SludgeEngine *vm);
@@ -84,8 +95,8 @@ public:
 	void blankAllScreen();
 	void darkScreen();
 	void saveHSI(Common::WriteStream *stream);
-	bool loadHSI(Common::SeekableReadStream *stream, int, int, bool);
-	bool mixHSI(Common::SeekableReadStream *stream, int x = 0, int y = 0);
+	bool loadHSI(int num, Common::SeekableReadStream *stream, int, int, bool);
+	bool mixHSI(int num, Common::SeekableReadStream *stream, int x = 0, int y = 0);
 	void drawLine(uint, uint, uint, uint);
 	void drawHorizontalLine(uint, uint, uint);
 	void drawVerticalLine(uint, uint, uint);
@@ -140,7 +151,7 @@ public:
 	void burnSpriteToBackDrop(int x1, int y1, Sprite &single, const SpritePalette &fontPal);
 
 	void resetSpriteLayers(ZBufferData *ptrZBuffer, int x, int y, bool upsidedown);
-	void addSpriteDepth(Graphics::Surface *ptr, int depth, int x, int y, Graphics::FLIP_FLAGS flip, int width = -1, int height = -1, bool disposeAfterUse = false);
+	void addSpriteDepth(Graphics::Surface *ptr, int depth, int x, int y, Graphics::FLIP_FLAGS flip, int width = -1, int height = -1, bool disposeAfterUse = false, byte trans = 255);
 	void displaySpriteLayers();
 	void killSpriteLayers();
 
@@ -175,6 +186,20 @@ public:
 	void setFadeMode(int fadeMode) { _fadeMode = fadeMode; };
 	void fixBrightness();
 	void resetRandW();
+	void reserveTransitionTexture();
+
+	void transitionFader();
+	void transitionDisolve();
+	void transitionTV();
+	void transitionBlinds();
+	void transitionSnapshotBox();
+	void transitionCrossFader();
+
+	// BG effects
+	bool blurScreen();
+	void blur_saveSettings(Common::WriteStream *stream);
+	void blur_loadSettings(Common::SeekableReadStream *stream);
+	bool blur_createSettings(int numParams, VariableStack *&stack);
 
 private:
 	SludgeEngine *_vm;
@@ -191,9 +216,6 @@ private:
 	int _lightMapNumber;
 	Graphics::Surface _lightMap;
 
-	// Parallax
-	Parallax *_parallaxStuff;
-
 	// Camera
 	float _cameraZoom;
 	int _cameraX, _cameraY;
@@ -234,6 +256,19 @@ private:
 	// Transition
 	byte _brightnessLevel;
 	byte _fadeMode;
+
+#define RANDKK 17
+
+	uint32 _randbuffer[RANDKK][2];
+	int _randp1, _randp2;
+	Graphics::TransparentSurface *_transitionTexture;
+
+	// Parallax
+	ParallaxLayers *_parallaxLayers;
+
+	inline int sortOutPCamera(int cX, int fX, int sceneMax, int boxMax) {
+		return (fX == 65535) ? (sceneMax ? ((cX * boxMax) / sceneMax) : 0) : ((cX * fX) / 100);
+	}
 };
 
 } // End of namespace Sludge
