@@ -20,13 +20,11 @@
  *
  */
 
-#include "sludge/allfiles.h"
 #include "sludge/fileset.h"
 #include "sludge/moreio.h"
 #include "sludge/newfatal.h"
 #include "sludge/objtypes.h"
 #include "sludge/sludge.h"
-#include "sludge/variable.h"
 #include "sludge/version.h"
 
 namespace Sludge {
