@@ -20,22 +20,17 @@
  *
  */
 
-#include "common/debug.h"
-#include "common/file.h"
-#include "common/list.h"
-#include "common/memstream.h"
-
 #include "audio/audiostream.h"
 #include "audio/decoders/wave.h"
 #include "audio/decoders/vorbis.h"
 #include "audio/mods/mod_xm_s3m.h"
 
-#include "sludge/allfiles.h"
+#include "sludge/errors.h"
 #include "sludge/fileset.h"
-#include "sludge/moreio.h"
 #include "sludge/newfatal.h"
 #include "sludge/sludge.h"
 #include "sludge/sound.h"
+#include "sludge/variable.h"
 
 namespace Sludge {
 
@@ -220,28 +215,24 @@ bool SoundManager::playMOD(int f, int a, int fromTrack) {
 		return false;
 	}
 
+	g_sludge->_resMan->dumpFile(f, "music%04d.xm");
+
 	// make audio stream
 	Common::SeekableReadStream *readStream = g_sludge->_resMan->getData();
 	Common::SeekableReadStream *memImage = readStream->readStream(length);
 
-// debug output
-#if 0
-	Common::DumpFile *dump = new Common::DumpFile();
-	Common::String name = Common::String::format("mod_sound_%i", f);
-	dump->open(name);
-	byte *soundData = new byte[length];
-	memImage->read(soundData, length);
-	dump->write(soundData, length);
-	dump->finalize();
-	delete []soundData;
-	delete dump;
-	memImage->seek(0, SEEK_SET);
-#endif
-
 	if (memImage->size() != (int)length || readStream->err()) {
 		return fatal("Sound reading failed");
 	}
-	Audio::AudioStream *stream = Audio::makeModXmS3mStream(memImage, DisposeAfterUse::NO);
+	Audio::RewindableAudioStream *mod = Audio::makeModXmS3mStream(memImage, DisposeAfterUse::NO, fromTrack);
+
+	if (!mod) {
+		warning("Could not load MOD file");
+		g_sludge->_resMan->finishAccess();
+		return false;
+	}
+
+	Audio::LoopingAudioStream *stream = new Audio::LoopingAudioStream(mod, 0, DisposeAfterUse::YES, false);
 
 	if (stream) {
 		// play sound
@@ -321,6 +312,8 @@ int SoundManager::makeSoundAudioStream(int f, Audio::AudioStream *&audiostream,
 	if (!length)
 		return -1;
 
+	g_sludge->_resMan->dumpFile(f, "sound%04d.ogg");
+
 	Common::SeekableReadStream *readStream = g_sludge->_resMan->getData();
 	uint curr_ptr = readStream->pos();
 	Audio::RewindableAudioStream *stream = Audio::makeWAVStream(readStream->readStream(length), DisposeAfterUse::NO);
