@@ -24,6 +24,7 @@
 #include "common/memstream.h"
 
 #include "startrek/iwfile.h"
+#include "startrek/resource.h"
 #include "startrek/room.h"
 #include "startrek/startrek.h"
 
@@ -48,22 +49,33 @@ int StarTrekEngine::loadActorAnim(int actorIndex, const Common::String &animName
 	debugC(6, kDebugGraphics, "Load animation '%s' on actor %d", animName.c_str(), actorIndex);
 
 	if (actorIndex == -1) {
-		// TODO
-		warning("loadActorAnim: actor == -1");
-	} else {
-		Actor *actor = &_actorList[actorIndex];
+		bool foundSlot = false;
 
-		if (actor->spriteDrawn) {
-			releaseAnim(actor);
-			drawActorToScreen(actor, animName, x, y, scale, false);
-		} else {
-			drawActorToScreen(actor, animName, x, y, scale, true);
+		for (int i = 8; i < NUM_ACTORS; i++) {
+			if (_actorList[i].spriteDrawn == 0) {
+				actorIndex = i;
+				foundSlot = true;
+				break;
+			}
 		}
 
-		actor->triggerActionWhenAnimFinished = false;
-		actor->finishedAnimActionParam = 0;
+		if (!foundSlot) {
+			error("All animations are in use");
+		}
 	}
 
+	Actor *actor = &_actorList[actorIndex];
+
+	if (actor->spriteDrawn) {
+		releaseAnim(actor);
+		drawActorToScreen(actor, animName, x, y, scale, false);
+	} else {
+		drawActorToScreen(actor, animName, x, y, scale, true);
+	}
+
+	actor->triggerActionWhenAnimFinished = false;
+	actor->finishedAnimActionParam = 0;
+
 	return actorIndex;
 }
 
@@ -71,7 +83,7 @@ void StarTrekEngine::loadBanFile(const Common::String &name) {
 	debugC(kDebugGeneral, 7, "Load BAN file: %s.ban", name.c_str());
 	for (int i = 0; i < MAX_BAN_FILES; i++) {
 		if (!_banFiles[i]) {
-			_banFiles[i] = loadFile(name + ".ban");
+			_banFiles[i] = _resource->loadFile(name + ".ban");
 			_banFileOffsets[i] = 0;
 			return;
 		}
@@ -168,9 +180,12 @@ void StarTrekEngine::updateActorAnimations() {
 					actor->animFile->seek(actor->animFrame * 22, SEEK_SET);
 					char animFrameFilename[16];
 					actor->animFile->read(animFrameFilename, 16);
-					sprite->setBitmap(loadAnimationFrame(animFrameFilename, actor->scale));
-
 					actor->bitmapFilename = animFrameFilename;
+					actor->bitmapFilename.trim();
+					if (actor->bitmapFilename.contains(' '))
+						actor->bitmapFilename = actor->bitmapFilename.substr(0, actor->bitmapFilename.find(' '));
+
+					sprite->setBitmap(loadAnimationFrame(actor->bitmapFilename, actor->scale));
 
 					actor->animFile->seek(10 + actor->animFrame * 22, SEEK_SET);
 					uint16 xOffset = actor->animFile->readUint16();
@@ -206,7 +221,8 @@ void StarTrekEngine::updateActorAnimations() {
 					Fixed16 newX = actor->granularPosX + actor->speedX;
 					Fixed16 newY = actor->granularPosY + actor->speedY;
 					if ((actor->field90 & 3) == 0) {
-						sprite->bitmap.reset();
+						delete sprite->bitmap;
+						sprite->bitmap = nullptr;
 						updateActorPositionWhileWalking(actor, (newX + 0.5).toInt(), (newY + 0.5).toInt());
 						actor->field92++;
 					}
@@ -222,7 +238,8 @@ void StarTrekEngine::updateActorAnimations() {
 						addAction(ACTION_FINISHED_WALKING, actor->finishedAnimActionParam & 0xff, 0, 0);
 					}
 
-					actor->sprite.bitmap.reset();
+					delete actor->sprite.bitmap;
+					actor->sprite.bitmap = nullptr;
 					updateActorPositionWhileWalking(actor, (actor->granularPosX + 0.5).toInt(), (actor->granularPosY + 0.5).toInt());
 					initStandAnim(i);
 				} else { // actor->iwSrcPosition != -1
@@ -426,7 +443,7 @@ void StarTrekEngine::removeActorFromScreen(int actorIndex) {
 	releaseAnim(actor);
 }
 
-void StarTrekEngine::actorFunc1() {
+void StarTrekEngine::removeDrawnActorsFromScreen() {
 	for (int i = 0; i < NUM_ACTORS; i++) {
 		if (_actorList[i].spriteDrawn == 1) {
 			removeActorFromScreen(i);
@@ -446,7 +463,7 @@ void StarTrekEngine::drawActorToScreen(Actor *actor, const Common::String &_anim
 
 	actor->animFilename = _animName;
 	actor->animType = 2;
-	actor->animFile = SharedPtr<Common::MemoryReadStreamEndian>(loadFile(animFilename + ".anm"));
+	actor->animFile = SharedPtr<Common::MemoryReadStreamEndian>(_resource->loadFile(animFilename + ".anm"));
 	actor->numAnimFrames = actor->animFile->size() / 22;
 	actor->animFrame = 0;
 	actor->pos.x = x;
@@ -466,8 +483,9 @@ void StarTrekEngine::drawActorToScreen(Actor *actor, const Common::String &_anim
 	if (addSprite)
 		_gfx->addSprite(sprite);
 
-	sprite->setBitmap(loadAnimationFrame(firstFrameFilename, scale));
 	actor->bitmapFilename = firstFrameFilename;
+	actor->bitmapFilename.trim();
+	sprite->setBitmap(loadAnimationFrame(actor->bitmapFilename, scale));
 	actor->scale = scale;
 	actor->animFile->seek(10, SEEK_SET);
 
@@ -487,11 +505,11 @@ void StarTrekEngine::releaseAnim(Actor *actor) {
 	switch (actor->animType) {
 	case 0:
 	case 2:
-		actor->sprite.bitmap.reset();
 		actor->animFile.reset();
-		break;
+		// Fall through
 	case 1:
-		actor->sprite.bitmap.reset();
+		delete actor->sprite.bitmap;
+		actor->sprite.bitmap = nullptr;
 		break;
 	default:
 		error("Invalid anim type");
@@ -707,17 +725,20 @@ int StarTrekEngine::findObjectAt(int x, int y) {
 
 Bitmap *StarTrekEngine::loadAnimationFrame(const Common::String &filename, Fixed8 scale) {
 	Bitmap *bitmapToReturn = nullptr;
+	bool isDemo = getFeatures() & GF_DEMO;
 
 	char basename[5];
 	strncpy(basename, filename.c_str() + 1, 4);
 	basename[4] = '\0';
 
+	char mcCoyChar = !isDemo ? 'm' : 'b';
+
 	char c = filename[0];
 	if ((strcmp(basename, "stnd") == 0 || strcmp(basename, "tele") == 0)
-	        && (c == 'm' || c == 's' || c == 'k' || c == 'r')) {
-		if (c == 'm') {
+	        && (c == mcCoyChar || c == 's' || c == 'k' || c == 'r')) {
+		if (c == mcCoyChar) {
 			// Mccoy has the "base" animations for all crewmen
-			bitmapToReturn = new Bitmap(loadBitmapFile(filename));
+			bitmapToReturn = new Bitmap(_resource->loadBitmapFile(filename));
 		} else {
 			// All crewman other than mccoy copy the animation frames from mccoy, change
 			// the colors of the uniforms, and load an "xor" file to redraw the face.
@@ -728,8 +749,10 @@ Bitmap *StarTrekEngine::loadAnimationFrame(const Common::String &filename, Fixed
 
 			if (bitmapToReturn == nullptr) {
 				Common::String mccoyFilename = filename;
-				mccoyFilename.setChar('m', 0);
-				Bitmap *bitmap = new Bitmap(loadBitmapFile(mccoyFilename));
+				mccoyFilename.setChar(mcCoyChar, 0);
+				if (isDemo && mccoyFilename.hasPrefix("bstnds"))
+					mccoyFilename.setChar('m', 0);
+				Bitmap *bitmap = new Bitmap(_resource->loadBitmapFile(mccoyFilename));
 
 				uint16 width = bitmap->width;
 				uint16 height = bitmap->height;
@@ -751,6 +774,7 @@ Bitmap *StarTrekEngine::loadAnimationFrame(const Common::String &filename, Fixed
 					colorShift = 0;
 					break;
 				case 'm': // McCoy
+				case 'b': // McCoy (demo)
 					colorShift = 0;
 					break;
 				default:
@@ -774,29 +798,33 @@ Bitmap *StarTrekEngine::loadAnimationFrame(const Common::String &filename, Fixed
 					}
 				}
 
-				// Redraw face with xor file
-				Common::MemoryReadStreamEndian *xorFile = loadFile(filename + ".xor");
-				xorFile->seek(0, SEEK_SET);
-				uint16 xoffset = bitmap->xoffset - xorFile->readUint16();
-				uint16 yoffset = bitmap->yoffset - xorFile->readUint16();
-				uint16 xorWidth = xorFile->readUint16();
-				uint16 xorHeight = xorFile->readUint16();
+				// Redraw face with XOR file
+				if (!isDemo) {
+					Common::MemoryReadStreamEndian *xorFile = _resource->loadFile(filename + ".xor");
+					xorFile->seek(0, SEEK_SET);
+					uint16 xoffset = bitmap->xoffset - xorFile->readUint16();
+					uint16 yoffset = bitmap->yoffset - xorFile->readUint16();
+					uint16 xorWidth = xorFile->readUint16();
+					uint16 xorHeight = xorFile->readUint16();
 
-				byte *dest = bitmapToReturn->pixels + yoffset * bitmap->width + xoffset;
+					byte *dest = bitmapToReturn->pixels + yoffset * bitmap->width + xoffset;
 
-				for (int i = 0; i < xorHeight; i++) {
-					for (int j = 0; j < xorWidth; j++)
-						*dest++ ^= xorFile->readByte();
-					dest += (bitmap->width - xorWidth);
+					for (int i = 0; i < xorHeight; i++) {
+						for (int j = 0; j < xorWidth; j++)
+							*dest++ ^= xorFile->readByte();
+						dest += (bitmap->width - xorWidth);
+					}
+
+					delete xorFile;
 				}
 
-				delete xorFile;
+				delete bitmap;
 			}
 		}
 	} else {
 		// TODO: when loading a bitmap, it passes a different argument than is standard to
 		// the "file loading with cache" function...
-		bitmapToReturn = new Bitmap(loadBitmapFile(filename));
+		bitmapToReturn = new Bitmap(_resource->loadBitmapFile(filename));
 	}
 
 	if (scale != 1.0) {
@@ -898,7 +926,8 @@ int StarTrekEngine::selectObjectForUseAction() {
 }
 
 Common::String StarTrekEngine::getCrewmanAnimFilename(int actorIndex, const Common::String &basename) {
-	const char *crewmanChars = "ksmr";
+	bool isDemo = getFeatures() & GF_DEMO;
+	const char *crewmanChars = !isDemo ? "ksmr" : "ksbr";	// Kirk, Spock, McCoy (Bones), RedShirt
 	assert(actorIndex >= 0 && actorIndex < 4);
 	return crewmanChars[actorIndex] + basename;
 }
@@ -972,7 +1001,7 @@ bool StarTrekEngine::walkActiveObjectToHotspot() {
 	else {
 		// If this action has code defined for it in this room, buffer the action to be
 		// done after the object finished walking there.
-		Action action = {_awayMission.activeAction, _awayMission.activeObject, 0, 0};
+		Action action = {static_cast<int8>(_awayMission.activeAction), _awayMission.activeObject, 0, 0};
 		if (_awayMission.activeAction == ACTION_USE)
 			action.b2 = _awayMission.passiveObject;
 
@@ -1035,7 +1064,7 @@ void StarTrekEngine::showInventoryIcons(bool showItem) {
 		_itemIconSprite.pos.y = 10;
 		_itemIconSprite.drawPriority = 15;
 		_itemIconSprite.drawPriority2 = 8;
-		_itemIconSprite.setBitmap(loadBitmapFile(itemFilename));
+		_itemIconSprite.setBitmap(_resource->loadBitmapFile(itemFilename));
 
 		_inventoryIconSprite.pos.x = 46;
 	}
@@ -1046,7 +1075,7 @@ void StarTrekEngine::showInventoryIcons(bool showItem) {
 	_inventoryIconSprite.drawMode = 2;
 	_inventoryIconSprite.drawPriority = 15;
 	_inventoryIconSprite.drawPriority2 = 8;
-	_inventoryIconSprite.setBitmap(loadBitmapFile("inv00"));
+	_inventoryIconSprite.setBitmap(_resource->loadBitmapFile("inv00"));
 }
 
 bool StarTrekEngine::isObjectUnusable(int object, int action) {
@@ -1075,13 +1104,15 @@ void StarTrekEngine::hideInventoryIcons() {
 	if (_itemIconSprite.drawMode == 2) {
 		_gfx->delSprite(&_itemIconSprite);
 		_itemIconSprite.drawMode = 0;
-		_itemIconSprite.bitmap.reset();
+		delete _itemIconSprite.bitmap;
+		_itemIconSprite.bitmap = nullptr;
 	}
 
 	if (_inventoryIconSprite.drawMode == 2) {
 		_gfx->delSprite(&_inventoryIconSprite);
 		_inventoryIconSprite.drawMode = 0;
-		_inventoryIconSprite.bitmap.reset();
+		delete _inventoryIconSprite.bitmap;
+		_inventoryIconSprite.bitmap = nullptr;
 	}
 }
 
@@ -1163,7 +1194,7 @@ int StarTrekEngine::showInventoryMenu(int x, int y, bool restoreMouse) {
 		itemSprites[i].pos.y = itemPositions[i].y;
 		itemSprites[i].drawPriority = 15;
 		itemSprites[i].drawPriority2 = 8;
-		itemSprites[i].setBitmap(loadBitmapFile(itemNames[i]));
+		itemSprites[i].setBitmap(_resource->loadBitmapFile(itemNames[i]));
 	}
 
 	chooseMousePositionFromSprites(itemSprites, numItems, -1, 4);
@@ -1183,11 +1214,11 @@ int StarTrekEngine::showInventoryMenu(int x, int y, bool restoreMouse) {
 			itemIndex = getMenuButtonAt(itemSprites, numItems, mousePos.x, mousePos.y);
 			if (itemIndex != lastItemIndex) {
 				if (lastItemIndex != -1) {
-					drawMenuButtonOutline(itemSprites[lastItemIndex].bitmap.get(), 0);
+					drawMenuButtonOutline(itemSprites[lastItemIndex].bitmap, 0);
 					itemSprites[lastItemIndex].bitmapChanged = true;
 				}
 				if (itemIndex != -1) {
-					drawMenuButtonOutline(itemSprites[itemIndex].bitmap.get(), 15);
+					drawMenuButtonOutline(itemSprites[itemIndex].bitmap, 15);
 					itemSprites[itemIndex].bitmapChanged = true;
 				}
 				lastItemIndex = itemIndex;
@@ -1197,12 +1228,10 @@ int StarTrekEngine::showInventoryMenu(int x, int y, bool restoreMouse) {
 		}
 
 		case TREKEVENT_LBUTTONDOWN:
-exitWithSelection:
 			displayMenu = false;
 			break;
 
 		case TREKEVENT_RBUTTONDOWN:
-exitWithoutSelection:
 			displayMenu = false;
 			lastItemIndex = -1;
 			break;
@@ -1211,12 +1240,15 @@ exitWithoutSelection:
 			switch (event.kbd.keycode) {
 			case Common::KEYCODE_ESCAPE:
 			case Common::KEYCODE_F2:
-				goto exitWithoutSelection;
+				displayMenu = false;
+				lastItemIndex = -1;
+				break;
 
 			case Common::KEYCODE_RETURN:
 			case Common::KEYCODE_KP_ENTER:
 			case Common::KEYCODE_F1:
-				goto exitWithSelection;
+				displayMenu = false;
+				break;
 
 			case Common::KEYCODE_HOME:
 			case Common::KEYCODE_KP7:
@@ -1266,7 +1298,7 @@ exitWithoutSelection:
 
 	_sound->playSoundEffectIndex(0x10);
 	if (lastItemIndex >= 0)
-		drawMenuButtonOutline(itemSprites[lastItemIndex].bitmap.get(), 0);
+		drawMenuButtonOutline(itemSprites[lastItemIndex].bitmap, 0);
 
 	for (int i = 0; i < numItems; i++)
 		itemSprites[i].dontDrawNextFrame();
@@ -1274,7 +1306,8 @@ exitWithoutSelection:
 	_gfx->drawAllSprites();
 
 	for (int i = 0; i < numItems; i++) {
-		itemSprites[i].bitmap.reset();
+		delete itemSprites[i].bitmap;
+		itemSprites[i].bitmap = nullptr;
 		_gfx->delSprite(&itemSprites[i]);
 	}
 
