@@ -40,9 +40,16 @@ private:
 	bool Cmd_Room(int argc, const char **argv);
 	bool Cmd_Actions(int argc, const char **argv);
 	bool Cmd_Text(int argc, const char **argv);
+	bool Cmd_Bg(int argc, const char **argv);
+	bool Cmd_DumpFile(int argc, const char **argv);
+	bool Cmd_SearchFile(int argc, const char **argv);
+	bool Cmd_Score(int argc, const char **argv);
+	bool Cmd_BridgeSequence(int argc, const char **argv);
+	bool Cmd_DumpText(int argc, const char **argv);
 
 	Common::String EventToString(uint32 action);
 	Common::String ItemToString(byte index);
+	void dumpFile(Common::String fileName);
 };
 
 } // End of namespace StarTrek
