@@ -102,19 +102,19 @@ public:
 	 * Check if a particular action is defined for this room.
 	 */
 	bool actionHasCode(const Action &action);
-	bool actionHasCode(byte type, byte b1, byte b2, byte b3);
+	bool actionHasCode(int8 type, byte b1, byte b2, byte b3);
 
 	/**
 	 * Execute a particular action for this room, if defined.
 	 */
 	bool handleAction(const Action &action);
-	bool handleAction(byte type, byte b1, byte b2, byte b3);
+	bool handleAction(int8 type, byte b1, byte b2, byte b3);
 
 	/**
 	 * Same as above, but if any byte in the action is -1 (0xff), it matches any value.
 	 */
 	bool handleActionWithBitmask(const Action &action);
-	bool handleActionWithBitmask(byte type, byte b1, byte b2, byte b3);
+	bool handleActionWithBitmask(int8 type, byte b1, byte b2, byte b3);
 
 	uint16 getFirstHotspot() {
 		return readRdfWord(0x12);
@@ -163,22 +163,26 @@ public:
 	byte *_rdfData;
 
 private:
-	uint16 _rdfSize;
+	//uint16 _rdfSize;
 
 	StarTrekEngine *_vm;
 	AwayMission *_awayMission;
 
 	const RoomAction *_roomActionList;
-	int _numRoomActions;
-
-	Common::HashMap<int, Common::String> _lookMessages;
-	Common::HashMap<int, Common::String> _lookWithTalkerMessages;
-	Common::HashMap<int, Common::String> _talkMessages;
+	const RoomTextOffsets *_roomTextList;
+	const RoomTextOffsets *_roomCommonTextList;
+	const RoomText *_roomStaticTextList;
+	Common::String _commonTextRdf;
+	byte *_commonRdfData;
 
+	byte *loadRoomRDF(Common::String fileName);
 	void loadRoomMessages();
 	void loadOtherRoomMessages();
 	void loadRoomMessage(const char *text);
-	Common::String patchRoomMessage(const char *text);
+	const char *getText(uint16 textId);
+
+	Common::MemoryReadStreamEndian *loadBitmapFile(Common::String baseName);
+	Common::MemoryReadStreamEndian *loadFileWithParams(Common::String filename, bool unk1, bool unk2, bool unk3);
 
 	int findFunctionPointer(int action, void (Room::*funcPtr)());
 
@@ -205,9 +209,9 @@ private:
 	 * Cmd 0x03
 	 */
 	int showRoomSpecificText(const char **textAddr);
-	int showMultipleTexts(const TextRef *text, bool fromRDF = false, bool lookWithTalker = false);
-	int showDescription(TextRef text, bool fromRDF = false, bool lookWithTalker = false);
-	int showText(TextRef speaker, TextRef text, bool fromRDF = false, bool lookWithTalker = false);
+	int showMultipleTexts(const TextRef *text);
+	int showDescription(TextRef text);
+	int showText(TextRef speaker, TextRef text);
 
 	/**
 	 * Cmd 0x04
@@ -299,8 +303,8 @@ private:
 	 * If "changeDirection" is true, they remain facing that direction even after their
 	 * animation is finished. The game is inconsistent about doing this.
 	 */
-	void spockScan(int direction, TextRef text, bool changeDirection = false, bool fromRDF = false);
-	void mccoyScan(int direction, TextRef text, bool changeDirection = false, bool fromRDF = false);
+	void spockScan(int direction, TextRef speaker, TextRef text, bool changeDirection = false);
+	void mccoyScan(int direction, TextRef speaker, TextRef text, bool changeDirection = false);
 
 	// Room-specific code
 public:
@@ -2605,6 +2609,7 @@ public:
 	void veng2UseImpulseConsole();
 	void veng2SpockReachedImpulseConsole();
 	void veng2SpockUsedImpulseConsole();
+	void veng2PowerWeapons();
 	void veng2UseMainComputer();
 	void veng2UseSTricorderOnMainComputer();
 	void veng2SpockReachedMainComputerToPutTricorder();
