@@ -25,6 +25,168 @@
 
 namespace StarTrek {
 
+extern const RoomAction demon4ActionList[] = {
+	{ {ACTION_TICK, 1, 0, 0}, &Room::demon4Tick1 },
+	{ {ACTION_FINISHED_ANIMATION, 1, 0, 0}, &Room::demon4FinishedAnimation1 },
+	{ {ACTION_FINISHED_ANIMATION, 2, 0, 0}, &Room::demon4FinishedAnimation2 },
+	{ {ACTION_FINISHED_ANIMATION, 3, 0, 0}, &Room::demon4FinishedAnimation3 },
+	{ {ACTION_TIMER_EXPIRED, 0, 0, 0}, &Room::demon4Timer0Expired },
+	{ {ACTION_TIMER_EXPIRED, 1, 0, 0}, &Room::demon4Timer1Expired },
+	{ {ACTION_FINISHED_WALKING, 4, 0, 0}, &Room::demon4CrewmanReachedBeamoutPosition },
+	{ {ACTION_TIMER_EXPIRED, 2, 0, 0}, &Room::demon4Timer2Expired },
+	{ {ACTION_TIMER_EXPIRED, 3, 0, 0}, &Room::demon4Timer3Expired },
+	{ {ACTION_TIMER_EXPIRED, 4, 0, 0}, &Room::demon4Timer4Expired },
+	{ {ACTION_TIMER_EXPIRED, 5, 0, 0}, &Room::demon4Timer5Expired },
+	{ {ACTION_TIMER_EXPIRED, 6, 0, 0}, &Room::demon4Timer6Expired },
+
+	{ {ACTION_USE, OBJECT_IPHASERK, 8, 0}, &Room::demon4UsePhaserOnNauian },
+	{ {ACTION_USE, OBJECT_IPHASERS, 8, 0}, &Room::demon4UsePhaserOnNauian },
+	{ {ACTION_USE, OBJECT_IMETAL, 0x22, 0}, &Room::demon4UseMetalOnSecurityEquipment },
+	{ {ACTION_FINISHED_WALKING, 5, 0, 0}, &Room::demon4KirkReachedSecurityEquipment },
+	{ {ACTION_FINISHED_ANIMATION, 4, 0, 0}, &Room::demon4KirkFinishedUsingSecurityEquipment },
+	{ {ACTION_USE, OBJECT_IMETAL, 8, 0}, &Room::demon4UseMetalOnNauian },
+	{ {ACTION_FINISHED_WALKING, 1, 0, 0}, &Room::demon4KirkReachedNauian },
+	{ {ACTION_USE, OBJECT_ISKULL, 8, 0}, &Room::demon4UseSkullOnNauian },
+	{ {ACTION_FINISHED_WALKING, 2, 0, 0}, &Room::demon4KirkReachedNauianWithSkull },
+
+	{ {ACTION_USE, OBJECT_IPHASERS, 0x21, 0}, &Room::demon4UsePhaserOnPanel },
+	{ {ACTION_USE, OBJECT_IPHASERS, 0x20, 0}, &Room::demon4UsePhaserOnPattern },
+	{ {ACTION_USE, OBJECT_IPHASERS, OBJECT_MCCOY, 0}, &Room::demon4UsePhaserOnMccoy },
+
+	{ {ACTION_FINISHED_ANIMATION, 5, 0, 0}, &Room::demon4TalkToNauian },
+	{ {ACTION_TALK, 8, 0, 0}, &Room::demon4TalkToNauian },
+
+	{ {ACTION_LOOK, 0x20, 0, 0}, &Room::demon4LookAtPattern },
+	{ {ACTION_LOOK, 8, 0, 0}, &Room::demon4LookAtAlien },
+	{ {ACTION_LOOK, 0xff, 0, 0}, &Room::demon4LookAnywhere },
+	{ {ACTION_LOOK, 0x22, 0, 0}, &Room::demon4LookAtSecurityEquipment },
+	{ {ACTION_LOOK, 0x23, 0, 0}, &Room::demon4LookAtFloor },
+
+	{ {ACTION_LOOK, OBJECT_KIRK, 0, 0}, &Room::demon4LookAtKirk },
+	{ {ACTION_LOOK, OBJECT_MCCOY, 0, 0}, &Room::demon4LookAtMccoy },
+	{ {ACTION_LOOK, OBJECT_SPOCK, 0, 0}, &Room::demon4LookAtSpock },
+	{ {ACTION_LOOK, OBJECT_REDSHIRT, 0, 0}, &Room::demon4LookAtRedshirt },
+
+	{ {ACTION_LOOK, 10, 0, 0}, &Room::demon4LookAtChamber },
+	{ {ACTION_LOOK, 0x21, 0, 0}, &Room::demon4LookAtPanel },
+
+	{ {ACTION_USE, OBJECT_KIRK, 0x21, 0}, &Room::demon4UseKirkOnPanel },
+	{ {ACTION_USE, OBJECT_SPOCK, 0x21, 0}, &Room::demon4UseSpockOnPanel },
+	{ {ACTION_USE, OBJECT_MCCOY, 0x21, 0}, &Room::demon4UseMccoyOnPanel },
+	{ {ACTION_USE, OBJECT_REDSHIRT, 0x21, 0}, &Room::demon4UseRedshirtOnPanel },
+	{ {ACTION_FINISHED_WALKING, 3, 0, 0}, &Room::demon4CrewmanReachedPanel },
+	{ {ACTION_TALK, OBJECT_KIRK, 0, 0}, &Room::demon4TalkToKirk },
+	{ {ACTION_TALK, OBJECT_MCCOY, 0, 0}, &Room::demon4TalkToMccoy },
+	{ {ACTION_TALK, OBJECT_SPOCK, 0, 0}, &Room::demon4TalkToSpock },
+	{ {ACTION_TALK, OBJECT_REDSHIRT, 0, 0}, &Room::demon4TalkToRedshirt },
+	{ {ACTION_USE, OBJECT_ISTRICOR, 10, 0}, &Room::demon4UseSTricorderOnChamber },
+	{ {ACTION_USE, OBJECT_ISTRICOR, 0x20, 0}, &Room::demon4UseSTricorderOnPattern },
+	{ {ACTION_USE, OBJECT_IMTRICOR, 0x20, 0}, &Room::demon4UseMTricorderOnPattern },
+	{ {ACTION_USE, OBJECT_ISTRICOR, 0x21, 0}, &Room::demon4UseSTricorderOnPanel },
+	{ {ACTION_USE, OBJECT_IMTRICOR, 0x21, 0}, &Room::demon4UseMTricorderOnPanel },
+	{ {ACTION_USE, OBJECT_ISTRICOR, 0x23, 0}, &Room::demon4UseSTricorderOnAnything },
+	{ {ACTION_USE, OBJECT_ISTRICOR, 0xff, 0}, &Room::demon4UseSTricorderOnAnything },
+	{ {ACTION_USE, OBJECT_IMTRICOR, 0x23, 0}, &Room::demon4UseMTricorderOnAnything },
+	{ {ACTION_USE, OBJECT_IMTRICOR, 0xff, 0}, &Room::demon4UseMTricorderOnAnything },
+	{ {ACTION_USE, OBJECT_ISTRICOR, 8, 0}, &Room::demon4UseSTricorderOnNauian },
+	{ {ACTION_USE, OBJECT_IMTRICOR, 8, 0}, &Room::demon4UseMTricorderOnNauian },
+	{ {ACTION_USE, OBJECT_ISTRICOR, 0x22, 0}, &Room::demon4UseSTricorderOnSecurityEquipment },
+	{ {ACTION_USE, OBJECT_IMTRICOR, 0x22, 0}, &Room::demon4UseMTricorderOnSecurityEquipment },
+	{ {ACTION_LIST_END, 0, 0, 0}, nullptr }
+};
+
+enum demon4TextIds {
+	TX_SPEAKER_KIRK, TX_SPEAKER_NAUIAN, TX_SPEAKER_MCCOY, TX_SPEAKER_SPOCK, TX_SPEAKER_EVERTS,
+	TX_DEM4_001, TX_DEM4_002, TX_DEM4_003, TX_DEM4_004, TX_DEM4_005,
+	TX_DEM4_006, TX_DEM4_007, TX_DEM4_008, TX_DEM4_009, TX_DEM4_010,
+	TX_DEM4_011, TX_DEM4_012, TX_DEM4_013, TX_DEM4_014, TX_DEM4_015,
+	TX_DEM4_017, TX_DEM4_018, TX_DEM4_019, TX_DEM4_020, TX_DEM4_021,
+	TX_DEM4_022, TX_DEM4_023, TX_DEM4_024, TX_DEM4_025, TX_DEM4_026,
+	TX_DEM4_027, TX_DEM4_029, TX_DEM4_030, TX_DEM4_031, TX_DEM4_032,
+	TX_DEM4_033, TX_DEM4_034, TX_DEM4_035, TX_DEM4_036, TX_DEM4_037,
+	TX_DEM4_038, TX_DEM4_039, TX_DEM4_040, TX_DEM4_041, TX_DEM4_042,
+	TX_DEM4_043, TX_DEM4_044, TX_DEM4_045, TX_DEM4_046, TX_DEM4_047,
+	TX_DEM4N000, TX_DEM4N001, TX_DEM4N002, TX_DEM4N003, TX_DEM4N004,
+	TX_DEM4N005, TX_DEM4N006, TX_DEM4N007, TX_DEM4N008, TX_DEM4N009,
+	TX_DEM4N010, TX_DEM4N011, TX_DEM4N012, TX_DEM4N013, TX_DEM4N014,
+	TX_DIALOG_ERROR
+};
+
+// TODO: Finish floppy offsets
+extern const RoomTextOffsets demon4TextOffsets[] = {
+	{ TX_SPEAKER_KIRK, 3902, 0 },
+	{ TX_SPEAKER_NAUIAN, 3913, 0 },
+	{ TX_SPEAKER_MCCOY, 3920, 0 },
+	{ TX_SPEAKER_SPOCK, 3930, 0 },
+	{ TX_SPEAKER_EVERTS, 3940, 0 },
+	{ TX_DEM4_001, 2980, 0 },
+	{ TX_DEM4_002, 4032, 0 },
+	{ TX_DEM4_003, 9925, 0 },
+	{ TX_DEM4_004, 4097, 0 },
+	{ TX_DEM4_005, 9991, 0 },
+	{ TX_DEM4_006, 9774, 0 },
+	{ TX_DEM4_007, 5073, 0 },
+	{ TX_DEM4_008, 5030, 0 },
+	{ TX_DEM4_009, 4210, 0 },
+	{ TX_DEM4_010,  596, 0 },
+	{ TX_DEM4_011, 1055, 0 },
+	{ TX_DEM4_012, 3195, 0 },
+	{ TX_DEM4_013, 8780, 0 },
+	{ TX_DEM4_014, 7484, 0 },
+	{ TX_DEM4_015, 6822, 0 },
+	{ TX_DEM4_017, 9415, 0 },
+	{ TX_DEM4_018, 8903, 0 },
+	{ TX_DEM4_019, 7104, 0 },
+	{ TX_DEM4_020, 7376, 0 },
+	{ TX_DEM4_021, 7334, 0 },
+	{ TX_DEM4_022, 7172, 0 },
+	{ TX_DEM4_023, 7999, 0 },
+	{ TX_DEM4_024, 6882, 0 },
+	{ TX_DEM4_025, 7756, 0 },
+	{ TX_DEM4_026, 8239, 0 },
+	{ TX_DEM4_027, 8146, 0 },
+	{ TX_DEM4_029, 8429, 0 },
+	{ TX_DEM4_030,  914, 0 },
+	{ TX_DEM4_031, 1971, 0 },
+	{ TX_DEM4_032, 8718, 0 },
+	{ TX_DEM4_033, 8637, 0 },
+	{ TX_DEM4_034, 9051, 0 },
+	{ TX_DEM4_035,  755, 0 },
+	{ TX_DEM4_036, 9539, 0 },
+	{ TX_DEM4_037, 6019, 0 },
+	{ TX_DEM4_038, 5821, 0 },
+	{ TX_DEM4_039, 4845, 0 },
+	{ TX_DEM4_040, 5272, 0 },
+	{ TX_DEM4_041, 5130, 0 },
+	{ TX_DEM4_042, 4310, 0 },
+	{ TX_DEM4_043, 4476, 0 },
+	{ TX_DEM4_044, 3955, 0 },
+	{ TX_DEM4_045, 8836, 0 },
+	{ TX_DEM4_046, 7055, 0 },
+	{ TX_DEM4_047, 7305, 0 },
+	{ TX_DEM4N000, 6576, 0 },
+	{ TX_DEM4N001, 6667, 0 },
+	{ TX_DEM4N002, 6301, 0 },
+	{ TX_DEM4N003, 6765, 0 },
+	{ TX_DEM4N004, 6715, 0 },
+	{ TX_DEM4N005, 6613, 0 },
+	{ TX_DEM4N006, 10194, 0 },
+	{ TX_DEM4N007, 6491, 0 },
+	{ TX_DEM4N008, 6419, 0 },
+	{ TX_DEM4N009, 10116, 0 },
+	{ TX_DEM4N010, 6365, 0 },
+	{ TX_DEM4N011, 8924, 0 },
+	{ TX_DEM4N012, 2666, 0 },
+	{ TX_DEM4N013, 2868, 0 },
+	{ TX_DEM4N014, 1602, 0 },
+	{ TX_DIALOG_ERROR, 10252, 0 },
+	{          -1, 0,    0 }
+};
+
+extern const RoomText demon4Texts[] = {
+	{ -1, Common::UNK_LANG, "" }
+};
+
 // TODO: this room should have animations on computer terminals, but this isn't where
 // they're implemented. Could be related to ".BAN" files which rooms can load?
 
@@ -60,7 +222,7 @@ void Room::demon4FinishedAnimation1() {
 void Room::demon4FinishedAnimation2() {
 	if (!_roomVar.demon.cd) {
 		_roomVar.demon.cd = true;
-		showDescription(11, true);
+		showDescription(TX_DEM4N011);
 	}
 
 	showGameOverMenu();
@@ -72,10 +234,10 @@ void Room::demon4FinishedAnimation2() {
 }
 
 void Room::demon4FinishedAnimation3() {
-	showText(TX_SPEAKER_NAUIAN, 34, true);
-	showText(TX_SPEAKER_KIRK,   10, true);
-	showText(TX_SPEAKER_NAUIAN, 35, true);
-	showText(TX_SPEAKER_SPOCK,  30, true);
+	showText(TX_SPEAKER_NAUIAN, TX_DEM4_034);
+	showText(TX_SPEAKER_KIRK,   TX_DEM4_010);
+	showText(TX_SPEAKER_NAUIAN, TX_DEM4_035);
+	showText(TX_SPEAKER_SPOCK,  TX_DEM4_030);
 
 	_awayMission->disableInput = true;
 	_awayMission->demon.missionScore += 5;
@@ -92,7 +254,7 @@ void Room::demon4Timer0Expired() {
 
 // Mission end
 void Room::demon4Timer1Expired() {
-	showText(TX_SPEAKER_KIRK, 11, true);
+	showText(TX_SPEAKER_KIRK, TX_DEM4_011);
 
 	walkCrewman(OBJECT_KIRK, 0xbe, 0xa5, 4);
 	walkCrewman(OBJECT_SPOCK, 0xb4, 0x9b, 4);
@@ -134,15 +296,15 @@ void Room::demon4Timer5Expired() {
 }
 
 void Room::demon4Timer6Expired() {
-	showText(TX_SPEAKER_MCCOY, 17, true);
+	showText(TX_SPEAKER_MCCOY, TX_DEM4_017);
 }
 
 void Room::demon4UsePhaserOnNauian() {
 	if (!_roomVar.demon.triedToShootNauian) { // Lenient the first time
-		showText(TX_SPEAKER_NAUIAN, 33, true);
+		showText(TX_SPEAKER_NAUIAN, TX_DEM4_033);
 		_roomVar.demon.triedToShootNauian = true;
 	} else { // Murdery the second time
-		showText(TX_SPEAKER_NAUIAN, 32, true);
+		showText(TX_SPEAKER_NAUIAN, TX_DEM4_032);
 		loadActorAnim2(10, "bxfire", 0, 0, 2);
 		playVoc("V0SPOCKT");
 		_awayMission->disableInput = true;
@@ -164,7 +326,7 @@ void Room::demon4KirkReachedSecurityEquipment() {
 
 void Room::demon4KirkFinishedUsingSecurityEquipment() {
 	_awayMission->disableInput = false;
-	showDescription(14, true);
+	showDescription(TX_DEM4N014);
 }
 
 void Room::demon4UseMetalOnNauian() {
@@ -184,10 +346,10 @@ void Room::demon4UseSkullOnNauian() {
 }
 
 void Room::demon4KirkReachedNauianWithSkull() {
-	showText(TX_SPEAKER_NAUIAN, 36, true);
+	showText(TX_SPEAKER_NAUIAN, TX_DEM4_036);
 
-	const TextRef choices[] = { TX_SPEAKER_KIRK, 6, 3, 5, TX_BLANK };
-	int choice = showMultipleTexts(choices, true);
+	const TextRef choices[] = { TX_SPEAKER_KIRK, TX_DEM4_006, TX_DEM4_003, TX_DEM4_005, TX_END };
+	int choice = showMultipleTexts(choices);
 
 	switch (choice) {
 	case 0:
@@ -209,15 +371,15 @@ void Room::demon4KirkReachedNauianWithSkull() {
 }
 
 void Room::demon4UsePhaserOnPanel() {
-	showText(TX_SPEAKER_SPOCK, 13, true);
+	showText(TX_SPEAKER_SPOCK, TX_DEM4_013);
 }
 
 void Room::demon4UsePhaserOnPattern() {
-	showText(TX_SPEAKER_SPOCK, 45, true);
+	showText(TX_SPEAKER_SPOCK, TX_DEM4_045);
 }
 
 void Room::demon4UsePhaserOnMccoy() {
-	showText(TX_SPEAKER_MCCOY, 18, true);
+	showText(TX_SPEAKER_MCCOY, TX_DEM4_018);
 }
 
 void Room::demon4TalkToNauian() {
@@ -225,22 +387,22 @@ void Room::demon4TalkToNauian() {
 
 	if (!_awayMission->demon.metNauian) {
 		_awayMission->demon.metNauian = true;
-		showText(TX_SPEAKER_NAUIAN, 44, true);
+		showText(TX_SPEAKER_NAUIAN, TX_DEM4_044);
 
-		const TextRef choices[] = { TX_SPEAKER_KIRK, 2, 4, 9, TX_BLANK };
-		int choice = showMultipleTexts(choices, true);
+		const TextRef choices[] = { TX_SPEAKER_KIRK, TX_DEM4_002, TX_DEM4_004, TX_DEM4_009, TX_END };
+		int choice = showMultipleTexts(choices);
 
 		switch (choice) {
 		case 0:
 			_awayMission->demon.field2d = true;
-			showText(TX_SPEAKER_NAUIAN, 42, true);
+			showText(TX_SPEAKER_NAUIAN, TX_DEM4_042);
 			break;
 
 		case 1:
 			break;
 
 		case 2:
-			showText(TX_SPEAKER_NAUIAN, 39, true);
+			showText(TX_SPEAKER_NAUIAN, TX_DEM4_039);
 			break;
 
 		default:
@@ -248,15 +410,15 @@ void Room::demon4TalkToNauian() {
 			break;
 		}
 
-		showText(TX_SPEAKER_NAUIAN, 43, true);
+		showText(TX_SPEAKER_NAUIAN, TX_DEM4_043);
 
-		const TextRef choices2[] = { TX_SPEAKER_KIRK, 8, 7, TX_BLANK };
-		choice = showMultipleTexts(choices2, true);
+		const TextRef choices2[] = { TX_SPEAKER_KIRK, TX_DEM4_008, TX_DEM4_007, TX_END };
+		choice = showMultipleTexts(choices2);
 
 		switch (choice) {
 		case 0:
 			_awayMission->demon.field2d = true;
-			showText(TX_SPEAKER_NAUIAN, 41, true);
+			showText(TX_SPEAKER_NAUIAN, TX_DEM4_041);
 			break;
 		case 1:
 			break;
@@ -265,70 +427,70 @@ void Room::demon4TalkToNauian() {
 			break;
 		}
 
-		showText(TX_SPEAKER_NAUIAN, 40, true);
+		showText(TX_SPEAKER_NAUIAN, TX_DEM4_040);
 
 		if (_roomVar.demon.disabledSecurity) { // Impossible condition?
-			showText(TX_SPEAKER_NAUIAN, 37, true);
+			showText(TX_SPEAKER_NAUIAN, TX_DEM4_037);
 
 			// BUGFIX: Originally all of these used no audio, despite the files existing
 			// (being used elsewhere).
-			showText(TX_SPEAKER_KIRK,   10, true);
-			showText(TX_SPEAKER_NAUIAN, 35, true);
-			showText(TX_SPEAKER_SPOCK,  30, true);
+			showText(TX_SPEAKER_KIRK,   TX_DEM4_010);
+			showText(TX_SPEAKER_NAUIAN, TX_DEM4_035);
+			showText(TX_SPEAKER_SPOCK,  TX_DEM4_030);
 
 			_awayMission->disableInput = true;
 			_awayMission->demon.missionScore += 5;
 			_awayMission->timers[1] = 20;
 		} else {
-			showText(TX_SPEAKER_NAUIAN, 38, true);
+			showText(TX_SPEAKER_NAUIAN, TX_DEM4_038);
 		}
 	} else {
-		showText(TX_SPEAKER_NAUIAN, 31, true);
+		showText(TX_SPEAKER_NAUIAN, TX_DEM4_031);
 	}
 }
 
 void Room::demon4LookAtPattern() {
-	showDescription(2, true);
+	showDescription(TX_DEM4N002);
 }
 
 void Room::demon4LookAtAlien() {
-	showDescription(7, true);
+	showDescription(TX_DEM4N007);
 }
 
 void Room::demon4LookAnywhere() {
-	showDescription(4, true);
+	showDescription(TX_DEM4N004);
 }
 
 void Room::demon4LookAtSecurityEquipment() {
-	showDescription(8, true);
+	showDescription(TX_DEM4N008);
 }
 
 void Room::demon4LookAtFloor() {
-	showDescription(9, true);
+	showDescription(TX_DEM4N009);
 }
 
 void Room::demon4LookAtKirk() {
-	showDescription(3, true);
+	showDescription(TX_DEM4N003);
 }
 
 void Room::demon4LookAtMccoy() {
-	showDescription(0, true);
+	showDescription(TX_DEM4N000);
 }
 
 void Room::demon4LookAtSpock() {
-	showDescription(5, true);
+	showDescription(TX_DEM4N005);
 }
 
 void Room::demon4LookAtRedshirt() {
-	showDescription(1, true);
+	showDescription(TX_DEM4N001);
 }
 
 void Room::demon4LookAtChamber() {
-	showDescription(6, true);
+	showDescription(TX_DEM4N006);
 }
 
 void Room::demon4LookAtPanel() {
-	showDescription(12, true);
+	showDescription(TX_DEM4N012);
 }
 
 void Room::demon4UseKirkOnPanel() {
@@ -366,7 +528,7 @@ void Room::demon4CrewmanReachedPanel() {
 		_awayMission->demon.missionScore += 3;
 		_awayMission->timers[0] = 10;
 	} else
-		showDescription(13, true);
+		showDescription(TX_DEM4N013);
 
 	walkCrewman(_roomVar.demon.crewmanUsingPanel, 0xae, 0x93, 0);
 	_awayMission->disableInput = false;
@@ -393,13 +555,13 @@ bool Room::demon4ShowSunPuzzle() {
 		_vm->_gfx->addSprite(&sprites[i]);
 	}
 
-	sprites[0].setBitmap(_vm->loadBitmapFile("levery"));
-	sprites[1].setBitmap(_vm->loadBitmapFile("leverr"));
-	sprites[2].setBitmap(_vm->loadBitmapFile("leverb"));
+	sprites[0].setBitmap(loadBitmapFile("levery"));
+	sprites[1].setBitmap(loadBitmapFile("leverr"));
+	sprites[2].setBitmap(loadBitmapFile("leverb"));
 
-	Bitmap *lightyBitmap = new Bitmap(_vm->loadBitmapFile("lighty"));
-	Bitmap *lightrBitmap = new Bitmap(_vm->loadBitmapFile("lightr"));
-	Bitmap *lightbBitmap = new Bitmap(_vm->loadBitmapFile("lightb"));
+	Bitmap *lightyBitmap = new Bitmap(loadBitmapFile("lighty"));
+	Bitmap *lightrBitmap = new Bitmap(loadBitmapFile("lightr"));
+	Bitmap *lightbBitmap = new Bitmap(loadBitmapFile("lightb"));
 
 	for (int i = 3; i < 9; i++)
 		sprites[i].setBitmap(lightyBitmap);
@@ -411,7 +573,7 @@ bool Room::demon4ShowSunPuzzle() {
 	Sprite doneButtonSprite;
 	_vm->_gfx->addSprite(&doneButtonSprite);
 	doneButtonSprite.setXYAndPriority(0x104, 0x64, 2);
-	doneButtonSprite.setBitmap(_vm->loadBitmapFile("donebutt"));
+	doneButtonSprite.setBitmap(loadBitmapFile("donebutt"));
 	// BUGFIX: use draw mode 2 so the entire button is clickable (not just non-transparent
 	// pixels)
 	doneButtonSprite.drawMode = 2;
@@ -427,43 +589,43 @@ bool Room::demon4ShowSunPuzzle() {
 			sprites[1].setXYAndPriority(0xa8, sliderR + 0x75, 14);
 			sprites[2].setXYAndPriority(0xb0, sliderB + 0x75, 14);
 
-			int var56 = 0x82;
-			int var58 = 0x83;
-			int var5a = 3;
+			int y = 0x82;
+			int x = 0x83;
+			int start = 3;
 			int numSprites = abs(sliderY) / 3;
 			for (int i = 0; i < 6; i++) {
-				sprites[i + var5a].setXYAndPriority(var58, var56, 14);
+				sprites[i + start].setXYAndPriority(x, y, 14);
 			}
-			var56 -= 6;
+			y -= 6;
 			for (int i = 0; i < numSprites; i++) {
-				sprites[i + var5a].setXYAndPriority(var58, var56, 14);
-				var56 -= 6;
+				sprites[i + start].setXYAndPriority(x, y, 14);
+				y -= 6;
 			}
 
-			var56 = 0x82;
-			var58 = 0x8b;
-			var5a = 9;
+			y = 0x82;
+			x = 0x8b;
+			start = 9;
 			numSprites = abs(sliderR) / 3;
 			for (int i = 0; i < 6; i++) {
-				sprites[i + var5a].setXYAndPriority(var58, var56, 14);
+				sprites[i + start].setXYAndPriority(x, y, 14);
 			}
-			var56 -= 6;
+			y -= 6;
 			for (int i = 0; i < numSprites; i++) {
-				sprites[i + var5a].setXYAndPriority(var58, var56, 14);
-				var56 -= 6;
+				sprites[i + start].setXYAndPriority(x, y, 14);
+				y -= 6;
 			}
 
-			var56 = 0x82;
-			var58 = 0x93;
-			var5a = 15;
+			y = 0x82;
+			x = 0x93;
+			start = 15;
 			numSprites = abs(sliderB) / 3;
 			for (int i = 0; i < 6; i++) {
-				sprites[i + var5a].setXYAndPriority(var58, var56, 14);
+				sprites[i + start].setXYAndPriority(x, y, 14);
 			}
-			var56 -= 6;
+			y -= 6;
 			for (int i = 0; i < numSprites; i++) {
-				sprites[i + var5a].setXYAndPriority(var58, var56, 14);
-				var56 -= 6;
+				sprites[i + start].setXYAndPriority(x, y, 14);
+				y -= 6;
 			}
 
 			sliderChanged = false;
@@ -475,11 +637,11 @@ bool Room::demon4ShowSunPuzzle() {
 
 		switch (event.type) {
 		case TREKEVENT_LBUTTONDOWN: {
-lclick:
 			Common::Point mousePos = _vm->_gfx->getMousePos();
-			if (_vm->_gfx->getSpriteAt(mousePos) == &doneButtonSprite)
-				goto done;
-			else {
+			if (_vm->_gfx->getSpriteAt(mousePos) == &doneButtonSprite) {
+				solved = (abs(sliderY) <= 2 && abs(sliderR) <= 2 && abs(sliderB) <= 2);
+				continueLoop = false;
+			} else {
 				if (mousePos.y >= 0x64 && mousePos.y <= 0x86) {
 					if (mousePos.x >= 0xa0 && mousePos.x <= 0xa6)
 						sliderY = mousePos.y - 0x75;
@@ -494,11 +656,7 @@ lclick:
 		}
 
 		case TREKEVENT_RBUTTONDOWN:
-done:
-			if (abs(sliderY) <= 2 && abs(sliderR) <= 2 && abs(sliderB) <= 2)
-				solved = true;
-			else
-				solved = false;
+			solved = (abs(sliderY) <= 2 && abs(sliderR) <= 2 && abs(sliderB) <= 2);
 			continueLoop = false;
 			break;
 
@@ -506,12 +664,30 @@ done:
 			switch (event.kbd.keycode) {
 			case Common::KEYCODE_ESCAPE:
 			case Common::KEYCODE_F2:
-				goto done;
+				solved = (abs(sliderY) <= 2 && abs(sliderR) <= 2 && abs(sliderB) <= 2);
+				continueLoop = false;
+				break;
 
 			case Common::KEYCODE_RETURN:
 			case Common::KEYCODE_KP_ENTER:
-			case Common::KEYCODE_F1:
-				goto lclick;
+			case Common::KEYCODE_F1: {
+				// Same as TREKEVENT_LBUTTONDOWN
+				Common::Point mousePos = _vm->_gfx->getMousePos();
+				if (_vm->_gfx->getSpriteAt(mousePos) == &doneButtonSprite) {
+					solved = (abs(sliderY) <= 2 && abs(sliderR) <= 2 && abs(sliderB) <= 2);
+					continueLoop = false;
+				} else {
+					if (mousePos.y >= 0x64 && mousePos.y <= 0x86) {
+						if (mousePos.x >= 0xa0 && mousePos.x <= 0xa6)
+							sliderY = mousePos.y - 0x75;
+						else if (mousePos.x >= 0xa8 && mousePos.x <= 0xae)
+							sliderR = mousePos.y - 0x75;
+						else if (mousePos.x >= 0xb0 && mousePos.x <= 0xb6)
+							sliderB = mousePos.y - 0x75;
+						sliderChanged = true;
+					}
+				}
+			}
 
 			default:
 				break;
@@ -532,6 +708,10 @@ done:
 	_vm->_gfx->copyBackgroundScreen();
 	_vm->_gfx->forceDrawAllSprites();
 
+	for (int i = 0; i < 21; i++) {
+		sprites[i].bitmap = nullptr;
+	}
+
 	delete lightbBitmap;
 	delete lightrBitmap;
 	delete lightyBitmap;
@@ -540,93 +720,93 @@ done:
 }
 
 void Room::demon4TalkToKirk() {
-	showText(TX_SPEAKER_KIRK, 1, true);
+	showText(TX_SPEAKER_KIRK, TX_DEM4_001);
 }
 
 void Room::demon4TalkToMccoy() {
 	if (_roomVar.demon.nauianEmerged)
-		showText(TX_SPEAKER_MCCOY, 19, true);
+		showText(TX_SPEAKER_MCCOY, TX_DEM4_019);
 	else
-		showText(TX_SPEAKER_MCCOY, 15, true);
+		showText(TX_SPEAKER_MCCOY, TX_DEM4_015);
 }
 
 void Room::demon4TalkToSpock() {
 	if (_roomVar.demon.nauianEmerged)
-		showText(TX_SPEAKER_SPOCK, 22, true);
+		showText(TX_SPEAKER_SPOCK, TX_DEM4_022);
 	else
-		showText(TX_SPEAKER_SPOCK, 24, true);
+		showText(TX_SPEAKER_SPOCK, TX_DEM4_024);
 }
 
 void Room::demon4TalkToRedshirt() {
 	if (_roomVar.demon.nauianEmerged)
-		showText(TX_SPEAKER_EVERTS, 47, true);
+		showText(TX_SPEAKER_EVERTS, TX_DEM4_047);
 	else
-		showText(TX_SPEAKER_EVERTS, 46, true);
+		showText(TX_SPEAKER_EVERTS, TX_DEM4_046);
 }
 
 void Room::demon4UseSTricorderOnChamber() {
 	loadActorAnim2(OBJECT_SPOCK, "sscane", -1, -1, 0);
 	playSoundEffectIndex(4);
-	showText(TX_SPEAKER_SPOCK, 12, true);
+	showText(TX_SPEAKER_SPOCK, TX_DEM4_012);
 }
 
 void Room::demon4UseSTricorderOnPattern() {
 	loadActorAnim2(OBJECT_SPOCK, "sscane", -1, -1, 0);
 	playSoundEffectIndex(4);
-	showText(TX_SPEAKER_SPOCK, 14, true);
-	showText(TX_SPEAKER_SPOCK, 25, true);
+	showText(TX_SPEAKER_SPOCK, TX_DEM4_014);
+	showText(TX_SPEAKER_SPOCK, TX_DEM4_025);
 }
 
 void Room::demon4UseMTricorderOnPattern() {
-	showText(TX_SPEAKER_MCCOY, 21, true);
+	showText(TX_SPEAKER_MCCOY, TX_DEM4_021);
 }
 
 void Room::demon4UseSTricorderOnPanel() {
 	loadActorAnim2(OBJECT_SPOCK, "sscane", -1, -1, 0);
 	playSoundEffectIndex(4);
-	showText(TX_SPEAKER_SPOCK, 27, true);
+	showText(TX_SPEAKER_SPOCK, TX_DEM4_027);
 }
 
 void Room::demon4UseMTricorderOnPanel() {
 	loadActorAnim2(OBJECT_MCCOY, "mscane", -1, -1, 0);
 	playSoundEffectIndex(4);
-	showText(TX_SPEAKER_MCCOY, 27, true); // BUG: Uses spock's voice (though speaker says "Mccoy")
+	showText(TX_SPEAKER_MCCOY, TX_DEM4_027); // BUG: Uses spock's voice (though speaker says "Mccoy")
 }
 
 void Room::demon4UseSTricorderOnAnything() {
 	loadActorAnim2(OBJECT_SPOCK, "sscane", -1, -1, 0);
 	playSoundEffectIndex(4);
-	showText(TX_SPEAKER_SPOCK, 23, true);
+	showText(TX_SPEAKER_SPOCK, TX_DEM4_023);
 }
 
 void Room::demon4UseMTricorderOnAnything() {
 	loadActorAnim2(OBJECT_MCCOY, "mscane", -1, -1, 0);
 	playSoundEffectIndex(4);
-	showText(TX_SPEAKER_MCCOY, 20, true);
+	showText(TX_SPEAKER_MCCOY, TX_DEM4_020);
 }
 
 void Room::demon4UseSTricorderOnNauian() {
 	loadActorAnim2(OBJECT_SPOCK, "sscane", -1, -1, 0);
 	playSoundEffectIndex(4);
-	showText(TX_SPEAKER_SPOCK, 29, true);
+	showText(TX_SPEAKER_SPOCK, TX_DEM4_029);
 }
 
 void Room::demon4UseMTricorderOnNauian() {
 	loadActorAnim2(OBJECT_MCCOY, "mscane", -1, -1, 0);
 	playSoundEffectIndex(4);
-	showText(TX_SPEAKER_SPOCK, 29, true); // BUG: Uses spock's voice (speaker says "Spock" too)
+	showText(TX_SPEAKER_SPOCK, TX_DEM4_029); // BUG: Uses spock's voice (speaker says "Spock" too)
 }
 
 void Room::demon4UseSTricorderOnSecurityEquipment() {
 	loadActorAnim2(OBJECT_SPOCK, "sscane", -1, -1, 0);
 	playSoundEffectIndex(4);
-	showText(TX_SPEAKER_SPOCK, 26, true);
+	showText(TX_SPEAKER_SPOCK, TX_DEM4_026);
 }
 
 void Room::demon4UseMTricorderOnSecurityEquipment() {
 	loadActorAnim2(OBJECT_MCCOY, "mscane", -1, -1, 0);
 	playSoundEffectIndex(4);
-	showText(TX_SPEAKER_SPOCK, 26, true); // BUG: Uses spock's voice (speaker says "Spock" too)
+	showText(TX_SPEAKER_SPOCK, TX_DEM4_026); // BUG: Uses spock's voice (speaker says "Spock" too)
 }
 
-}
+} // namespace StarTrek
