@@ -84,10 +84,87 @@ extern const RoomAction sins1ActionList[] = {
 
 	{ {ACTION_WALK, HOTSPOT_DOOR, 0, 0}, &Room::sins1WalkToDoor },
 	{ {ACTION_WALK, OBJECT_DOOR,  0, 0}, &Room::sins1WalkToDoor },
+	{ {ACTION_LIST_END, 0, 0, 0}, nullptr }
 };
 
-extern const int sins1NumActions = ARRAYSIZE(sins1ActionList);
+enum sins1TextIds {
+	TX_SPEAKER_KIRK, TX_SPEAKER_MCCOY, TX_SPEAKER_SPOCK, TX_SPEAKER_MOSHER,
+	TX_SPEAKER_SCOTT, TX_SPEAKER_UHURA,
+	TX_SIN1_001, TX_SIN1_002, TX_SIN1_003, TX_SIN1_004, TX_SIN1_005,
+	TX_SIN1_006, TX_SIN1_007, TX_SIN1_008, TX_SIN1_009, TX_SIN1_010,
+	TX_SIN1_011, TX_SIN1_012, TX_SIN1_013, TX_SIN1_014, TX_SIN1_015,
+	TX_SIN1_016, TX_SIN1_017, TX_SIN1_018, TX_SIN1_019, TX_SIN1_020,
+	TX_SIN1_021, TX_SIN1_022, TX_SIN1_023, TX_SIN1_024, TX_SIN1_025,
+	TX_SIN1_026, TX_SIN1_027, TX_SIN1_028, TX_SIN1_029, TX_SIN1_030,
+	TX_SIN1_S10, TX_SIN1_S17, TX_SIN1_S18, TX_SIN1_S20, TX_SIN1_S51,
+	TX_SIN1_S85, TX_SIN1U070, TX_SIN1N000, TX_SIN1N001, TX_SIN1N002,
+	TX_SIN1N003, TX_SIN1N004, TX_SIN1N005, TX_SIN1N006, TX_SIN1N007,
+	TX_SIN1N008, TX_SIN1N009, TX_SIN1N010, TX_SIN1N011
+};
 
+// TODO: Finish floppy offsets
+extern const RoomTextOffsets sins1TextOffsets[] = {
+	{ TX_SPEAKER_KIRK, 300, 0 },
+	{ TX_SPEAKER_MCCOY, 312, 0 },
+	{ TX_SPEAKER_SPOCK, 322, 0 },
+	{ TX_SPEAKER_MOSHER, 332, 0 },
+	{ TX_SPEAKER_SCOTT, 356, 0 },
+	{ TX_SPEAKER_UHURA, 346, 0 },
+	{ TX_SIN1_001, 2352, 0 },
+	{ TX_SIN1_002, 5887, 0 },
+	{ TX_SIN1_003, 4101, 0 },
+	{ TX_SIN1_004, 6100, 0 },
+	{ TX_SIN1_005, 3891, 0 },
+	{ TX_SIN1_006, 4283, 0 },
+	{ TX_SIN1_007, 3659, 0 },
+	{ TX_SIN1_008, 5648, 0 },
+	{ TX_SIN1_009, 1571, 0 },
+	{ TX_SIN1_010, 1341, 0 },
+	{ TX_SIN1_011, 2860, 0 },
+	{ TX_SIN1_012, 2268, 0 },
+	{ TX_SIN1_013, 6436, 0 },
+	{ TX_SIN1_014, 6257, 0 },
+	{ TX_SIN1_015, 4577, 0 },
+	{ TX_SIN1_016, 3301, 0 },
+	{ TX_SIN1_017, 3034, 0 },
+	{ TX_SIN1_018, 3428, 0 },
+	{ TX_SIN1_019, 1682, 0 },
+	{ TX_SIN1_020, 1162, 0 },
+	{ TX_SIN1_021, 1454, 0 },
+	{ TX_SIN1_022, 1900, 0 },
+	{ TX_SIN1_023, 1980, 0 },
+	{ TX_SIN1_024, 1801, 0 },
+	{ TX_SIN1_025, 4455, 0 },
+	{ TX_SIN1_026, 4813, 0 },
+	{ TX_SIN1_027, 4365, 0 },
+	{ TX_SIN1_028, 2195, 0 },
+	{ TX_SIN1_029, 4970, 0 },
+	{ TX_SIN1_030, 4713, 0 },
+	{ TX_SIN1_S10, 3583, 0 },
+	{ TX_SIN1_S17, 4180, 0 },
+	{ TX_SIN1_S18, 3706, 0 },
+	{ TX_SIN1_S20, 6016, 0 },
+	{ TX_SIN1_S51, 5702, 0 },
+	{ TX_SIN1_S85, 3974, 0 },
+	{ TX_SIN1U070, 6169, 0 },
+	{ TX_SIN1N000, 5548, 0 },
+	{ TX_SIN1N001, 738, 0 },
+	{ TX_SIN1N002, 5366, 0 },
+	{ TX_SIN1N003, 1014, 0 },
+	{ TX_SIN1N004, 5131, 0 },
+	{ TX_SIN1N005, 5023, 0 },
+	{ TX_SIN1N006, 5266, 0 },
+	{ TX_SIN1N007, 2065, 0 },
+	{ TX_SIN1N008, 5477, 0 },
+	{ TX_SIN1N009, 813, 0 },
+	{ TX_SIN1N010, 893, 0 },
+	{ TX_SIN1N011, 1089, 0 },
+	{          -1, 0,    0 }
+};
+
+extern const RoomText sins1Texts[] = {
+	  { -1, Common::UNK_LANG, "" }
+};
 
 void Room::sins1Tick1() {
 	playVoc("SIN1LOOP");
@@ -117,74 +194,71 @@ void Room::sins1Tick1() {
 }
 
 void Room::sins1LookAnywhere() {
-	showDescription(1, true);
+	showDescription(TX_SIN1N001);
 }
 
 void Room::sins1LookAtLock() {
-	showDescription(9, true);
+	showDescription(TX_SIN1N009);
 }
 
 void Room::sins1LookAtDoor() {
 	// NOTE: This function had two implementations (one unused).
-	if (true)
-		showDescription(10, true);
-	else
-		showDescription(8, true);
+	showDescription(TX_SIN1N010);
 }
 
 void Room::sins1LookAtPanel() {
-	showDescription(3, true);
+	showDescription(TX_SIN1N003);
 }
 
 void Room::sins1LookAtKeypad() {
-	showDescription(11, true);
+	showDescription(TX_SIN1N011);
 }
 
 void Room::sins1UseSTricorderOnPanel() {
-	spockScan(DIR_N, 10, false, true);
+	spockScan(DIR_N, TX_SPEAKER_SPOCK, TX_SIN1_010);
 }
 
 void Room::sins1UseSTricorderOnKeypad() {
-	spockScan(DIR_N, 21, false, true);
+	spockScan(DIR_N, TX_SPEAKER_SPOCK, TX_SIN1_021);
 }
 
 void Room::sins1UseSTricorderOnLock() {
-	spockScan(DIR_N, 9, false, true);
+	spockScan(DIR_N, TX_SPEAKER_SPOCK, TX_SIN1_009);
 }
 
 void Room::sins1UseSTricorderOnDoor() {
 	if (!_awayMission->sins.openedOuterDoor)
-		spockScan(DIR_N, 19, false, true);
+		spockScan(DIR_N, TX_SPEAKER_SPOCK, TX_SIN1_019);
 }
 
 void Room::sins1UseSTricorderAnywhere() {
-	spockScan(DIR_S, 24, false, true);
+	spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_SIN1_024);
 }
 
 void Room::sins1UseSTricorderOnLens() {
 	if (!_awayMission->sins.doorLaserFiredOnce)
-		spockScan(DIR_N, 22, false, true);
+		spockScan(DIR_N, TX_SPEAKER_SPOCK, TX_SIN1_022);
 	else // BUGFIX: Original didn't do the tricorder animation, etc. in this case
-		spockScan(DIR_N, 23, false, true);
+		spockScan(DIR_N, TX_SPEAKER_SPOCK, TX_SIN1_023);
 }
 
 void Room::sins1UseRockOnDoor() {
-	showDescription(7, true);
+	showDescription(TX_SIN1N007);
 }
 
 void Room::sins1UseRedshirtOnKeypad() {
 	if (!_awayMission->sins.openedOuterDoor)
-		showText(TX_SPEAKER_MOSHER, 28, true);
+		showText(TX_SPEAKER_MOSHER, TX_SIN1_028);
 }
 
 void Room::sins1UseMccoyOnKeypad() {
 	if (!_awayMission->sins.openedOuterDoor)
-		showText(TX_SPEAKER_MCCOY, 12, true);
+		showText(TX_SPEAKER_MCCOY, TX_SIN1_012);
 }
 
 void Room::sins1UseKirkOnKeypad() {
 	if (!_awayMission->sins.openedOuterDoor) {
-		showText(TX_SPEAKER_KIRK, 1, true);
+		showText(TX_SPEAKER_KIRK, TX_SIN1_001);
 		sins1UseSpockOnKeypad();
 	}
 }
@@ -228,13 +302,13 @@ void Room::sins1EnteredCorrectCode() {
 }
 
 void Room::sins1DoorDoneOpening() {
-	showText(TX_SPEAKER_SPOCK, 11, true);
+	showText(TX_SPEAKER_SPOCK, TX_SIN1_011);
 }
 
 void Room::sins1EnteredIncorrectCode() {
 	_awayMission->crewDirectionsAfterWalk[OBJECT_SPOCK] = DIR_W;
 	walkCrewman(OBJECT_SPOCK, 0xf3, 0xad);
-	showText(TX_SPEAKER_SPOCK, 17, true);
+	showText(TX_SPEAKER_SPOCK, TX_SIN1_017);
 }
 
 void Room::sins1EnteredSacredSofNumber() {
@@ -242,16 +316,16 @@ void Room::sins1EnteredSacredSofNumber() {
 	_awayMission->crewDirectionsAfterWalk[OBJECT_SPOCK] = DIR_W;
 	walkCrewman(OBJECT_SPOCK, 0xf3, 0xad);
 	loadActorAnimC(OBJECT_9, "s1ph1", 0, 0, &Room::sins1DoorUsedLaser);
-	playSoundEffectIndex(SND_PHASSHOT);
+	playSoundEffectIndex(kSfxPhaser);
 }
 
 void Room::sins1UsePhaserOnDoor() {
-	showText(TX_SPEAKER_SPOCK, 16, true);
+	showText(TX_SPEAKER_SPOCK, TX_SIN1_016);
 }
 
 void Room::sins1DoorUsedLaser() {
 	loadActorStandAnim(OBJECT_9);
-	showText(TX_SPEAKER_SPOCK, 18, true);
+	showText(TX_SPEAKER_SPOCK, TX_SIN1_018);
 
 	_awayMission->sins.field33 = true;
 	_awayMission->sins.doorLaserFiredOnce = true;
@@ -259,13 +333,13 @@ void Room::sins1DoorUsedLaser() {
 
 void Room::sins1Tick40() {
 	if (!_awayMission->sins.scottyInformedKirkAboutVirus) {
-		showText(TX_SPEAKER_SCOTT, 10 + SCOTTY_MESSAGE_OFFSET, true);
-		showText(TX_SPEAKER_KIRK,  7, true);
-		showText(TX_SPEAKER_SCOTT, 18 + SCOTTY_MESSAGE_OFFSET, true);
-		showText(TX_SPEAKER_KIRK,  5, true);
-		showText(TX_SPEAKER_SCOTT, 85 + SCOTTY_MESSAGE_OFFSET, true);
-		showText(TX_SPEAKER_KIRK,  3, true);
-		showText(TX_SPEAKER_SCOTT, 17 + SCOTTY_MESSAGE_OFFSET, true);
+		showText(TX_SPEAKER_SCOTT, TX_SIN1_S10);
+		showText(TX_SPEAKER_KIRK,  TX_SIN1_007);
+		showText(TX_SPEAKER_SCOTT, TX_SIN1_S18);
+		showText(TX_SPEAKER_KIRK,  TX_SIN1_005);
+		showText(TX_SPEAKER_SCOTT, TX_SIN1_S85);
+		showText(TX_SPEAKER_KIRK,  TX_SIN1_003);
+		showText(TX_SPEAKER_SCOTT, TX_SIN1_S17);
 
 		_awayMission->sins.scottyInformedKirkAboutVirus = true;
 		_awayMission->disableInput = false;
@@ -273,67 +347,64 @@ void Room::sins1Tick40() {
 }
 
 void Room::sins1TalkToKirk() {
-	showText(TX_SPEAKER_KIRK,  6, true);
-	showText(TX_SPEAKER_SPOCK, 27, true);
+	showText(TX_SPEAKER_KIRK,  TX_SIN1_006);
+	showText(TX_SPEAKER_SPOCK, TX_SIN1_027);
 }
 
 void Room::sins1TalkToSpock() {
 	// NOTE: This function has two implementations. The first (used) one talks about where
 	// the energy source is coming from. The second (unused) one says to "carefully
 	// consider what we know about this culture".
-	if (true)
-		showText(TX_SPEAKER_SPOCK, 20, true);
-	else
-		showText(TX_SPEAKER_SPOCK, 25, true);
+	showText(TX_SPEAKER_SPOCK, TX_SIN1_020);
 }
 
 void Room::sins1TalkToMccoy() {
-	showText(TX_SPEAKER_MCCOY, 15, true);
+	showText(TX_SPEAKER_MCCOY, TX_SIN1_015);
 }
 
 void Room::sins1TalkToRedshirt() {
-	showText(TX_SPEAKER_MOSHER, 30, true);
-	showText(TX_SPEAKER_SPOCK,  26, true);
-	showText(TX_SPEAKER_MOSHER, 29, true);
+	showText(TX_SPEAKER_MOSHER, TX_SIN1_030);
+	showText(TX_SPEAKER_SPOCK,  TX_SIN1_026);
+	showText(TX_SPEAKER_MOSHER, TX_SIN1_029);
 }
 
 void Room::sins1LookAtKirk() {
-	showDescription(5, true);
+	showDescription(TX_SIN1N005);
 }
 
 void Room::sins1LookAtSpock() {
-	showDescription(4, true);
+	showDescription(TX_SIN1N004);
 }
 
 void Room::sins1LookAtMccoy() {
-	showDescription(6, true);
+	showDescription(TX_SIN1N006);
 }
 
 void Room::sins1LookAtRedshirt() {
-	showDescription(2, true);
+	showDescription(TX_SIN1N002);
 }
 
 void Room::sins1LookAtLens() {
-	showDescription(0, true);
+	showDescription(TX_SIN1N000);
 }
 
 void Room::sins1UseCommunicator() {
 	if (!_awayMission->sins.enteredRoom2FirstTime) {
-		showText(TX_SPEAKER_KIRK,  8, true);
-		showText(TX_SPEAKER_SCOTT, 51 + SCOTTY_MESSAGE_OFFSET, true);
-		showText(TX_SPEAKER_KIRK,  2, true);
-		showText(TX_SPEAKER_SCOTT, 20 + SCOTTY_MESSAGE_OFFSET, true);
-		showText(TX_SPEAKER_KIRK,  4, true);
+		showText(TX_SPEAKER_KIRK,  TX_SIN1_008);
+		showText(TX_SPEAKER_SCOTT, TX_SIN1_S51);
+		showText(TX_SPEAKER_KIRK,  TX_SIN1_002);
+		showText(TX_SPEAKER_SCOTT, TX_SIN1_S20);
+		showText(TX_SPEAKER_KIRK,  TX_SIN1_004);
 	} else
-		showText(TX_SPEAKER_UHURA, 70, true);
+		showText(TX_SPEAKER_UHURA, TX_SIN1U070);
 }
 
 void Room::sins1UseMedkitOnCrewman() {
-	showText(TX_SPEAKER_MCCOY, 14, true);
+	showText(TX_SPEAKER_MCCOY, TX_SIN1_014);
 }
 
 void Room::sins1UseMTricorderOnCrewman() {
-	mccoyScan(DIR_S, 13, false, true);
+	mccoyScan(DIR_S, TX_SPEAKER_SPOCK, TX_SIN1_013);
 }
 
 void Room::sins1WalkToDoor() {
