@@ -120,10 +120,84 @@ extern const RoomAction sins3ActionList[] = {
 	{ {ACTION_USE, OBJECT_IMTRICOR, OBJECT_SPOCK,    0}, &Room::sins3UseMTricorderOnCrewman },
 	{ {ACTION_USE, OBJECT_IMTRICOR, OBJECT_MCCOY,    0}, &Room::sins3UseMTricorderOnCrewman },
 	{ {ACTION_USE, OBJECT_IMTRICOR, OBJECT_REDSHIRT, 0}, &Room::sins3UseMTricorderOnCrewman },
+	{ {ACTION_LIST_END, 0, 0, 0}, nullptr }
 };
 
-extern const int sins3NumActions = ARRAYSIZE(sins3ActionList);
+enum sins3TextIds {
+	TX_SPEAKER_KIRK, TX_SPEAKER_MCCOY, TX_SPEAKER_SPOCK, TX_SPEAKER_MOSHER,
+	TX_SPEAKER_UHURA,
+	TX_SIN3_001, TX_SIN3_002, TX_SIN3_003, TX_SIN3_004, TX_SIN3_005,
+	TX_SIN3_006, TX_SIN3_007, TX_SIN3_008, TX_SIN3_009, TX_SIN3_010,
+	TX_SIN3_011, TX_SIN3_012, TX_SIN3_013, TX_SIN3_014, TX_SIN3_015,
+	TX_SIN3_016, TX_SIN3_017, TX_SIN3_018, TX_SIN3_019, TX_SIN3_020,
+	TX_SIN3_021, TX_SIN3_022, TX_SIN3_023, TX_SIN3_024, TX_SIN3_025,
+	TX_SIN3_026, TX_SIN3_027, TX_SIN3N000, TX_SIN3N001, TX_SIN3N002,
+	TX_SIN3N003, TX_SIN3N004, TX_SIN3N005, TX_SIN3N006, TX_SIN3N007,
+	TX_SIN3N008, TX_SIN3N009, TX_SIN3N010, TX_SIN3N011, TX_SIN3N012,
+	TX_SIN3N013, TX_SIN3N014, TX_SIN3U072,  TX_SIN3_LASERSETTING001,
+	TX_SIN3_LASERSETTING010, TX_SIN3_LASERSETTING100, TX_SIN3_LASERCANCEL
+};
 
+// TODO: Finish floppy offsets
+extern const RoomTextOffsets sins3TextOffsets[] = {
+	{ TX_SPEAKER_KIRK, 289, 0 },
+	{ TX_SPEAKER_MCCOY, 300, 0 },
+	{ TX_SPEAKER_SPOCK, 310, 0 },
+	{ TX_SPEAKER_MOSHER, 320, 0 },
+	{ TX_SPEAKER_UHURA, 334, 0 },
+	{ TX_SIN3_001, 3479, 0 },
+	{ TX_SIN3_002, 5966, 0 },
+	{ TX_SIN3_003, 870, 0 },
+	{ TX_SIN3_004, 6675, 0 },
+	{ TX_SIN3_005, 3812, 0 },
+	{ TX_SIN3_006, 4217, 0 },
+	{ TX_SIN3_007, 7257, 0 },
+	{ TX_SIN3_008, 7154, 0 },
+	{ TX_SIN3_009, 6769, 0 },
+	{ TX_SIN3_010, 7021, 0 },
+	{ TX_SIN3_011, 6146, 0 },
+	{ TX_SIN3_012, 3244, 0 },
+	{ TX_SIN3_013, 3392, 0 },
+	{ TX_SIN3_014, 6325, 0 },
+	{ TX_SIN3_015, 1632, 0 },
+	{ TX_SIN3_016, 1346, 0 },
+	{ TX_SIN3_017, 1158, 0 },
+	{ TX_SIN3_018, 1019, 0 },
+	{ TX_SIN3_019, 1518, 0 },
+	{ TX_SIN3_020, 6029, 0 },
+	{ TX_SIN3_021, 4924, 0 },
+	{ TX_SIN3_022, 6477, 0 },
+	{ TX_SIN3_023, 2190, 0 },
+	{ TX_SIN3_024, 3298, 0 },
+	{ TX_SIN3_025, 6885, 0 },
+	{ TX_SIN3_026, 6257, 0 },
+	{ TX_SIN3_027, 6389, 0 },
+	{ TX_SIN3U072, 6611, 0 },
+	{ TX_SIN3N000, 2293, 0 },
+	{ TX_SIN3N001, 5755, 0 },
+	{ TX_SIN3N002, 5836, 0 },
+	{ TX_SIN3N003, 5572, 0 },
+	{ TX_SIN3N004, 5651, 0 },
+	{ TX_SIN3N005, 2434, 0 },
+	{ TX_SIN3N006, 5307, 0 },
+	{ TX_SIN3N007, 1959, 0 },
+	{ TX_SIN3N008, 2358, 0 },
+	{ TX_SIN3N009, 5022, 0 },
+	{ TX_SIN3N010, 5480, 0 },
+	{ TX_SIN3N011, 1881, 0 },
+	{ TX_SIN3N012, 1816, 0 },
+	{ TX_SIN3N013, 2038, 0 },
+	{ TX_SIN3N014, 5404, 0 },
+	{ TX_SIN3_LASERSETTING001, 3605, 0 },
+	{ TX_SIN3_LASERSETTING100, 3675, 0 },
+	{ TX_SIN3_LASERSETTING010, 3640, 0 },
+	{ TX_SIN3_LASERCANCEL, 3710, 0 },
+	{          -1, 0,    0 }
+};
+
+extern const RoomText sins3Texts[] = {
+	  { -1, Common::UNK_LANG, "" }
+};
 
 void Room::sins3Tick1() {
 	playVoc("SIN3LOOP");
@@ -148,57 +222,57 @@ void Room::sins3Tick1() {
 }
 
 void Room::sins3UseSTricorderOnBox() {
-	spockScan(DIR_S, 3, false, true);
+	spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_SIN3_003);
 }
 
 void Room::sins3UseSTricorderOnMonitor() {
-	spockScan(DIR_N, 18, false, true);
+	spockScan(DIR_N, TX_SPEAKER_SPOCK, TX_SIN3_018);
 }
 
 void Room::sins3UseSTricorderAnywhere() {
-	spockScan(DIR_S, 17, false, true);
+	spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_SIN3_017);
 }
 
 void Room::sins3UseSTricorderOnDrill() {
-	spockScan(DIR_E, 16, false, true);
+	spockScan(DIR_E, TX_SPEAKER_SPOCK, TX_SIN3_016);
 }
 
 void Room::sins3UseSTricorderOnPanel() {
 	if (_awayMission->sins.scannedKeycardLock) {
-		spockScan(DIR_E, 15, false, true);
+		spockScan(DIR_E, TX_SPEAKER_SPOCK, TX_SIN3_015);
 		_awayMission->sins.laserPattern = 1;
 	} else
-		spockScan(DIR_E, 19, false, true);
+		spockScan(DIR_E, TX_SPEAKER_SPOCK, TX_SIN3_019);
 }
 
 void Room::sins3LookAtDrill() {
-	showDescription(12, true);
+	showDescription(TX_SIN3N012);
 }
 
 void Room::sins3LookAtPanel() {
-	showDescription(11, true);
+	showDescription(TX_SIN3N011);
 }
 
 void Room::sins3LookAtMonitor() {
-	showDescription(7, true);
+	showDescription(TX_SIN3N007);
 }
 
 void Room::sins3LookAnywhere() {
-	showDescription(13, true);
+	showDescription(TX_SIN3N013);
 }
 
 void Room::sins3UseSTricorderOnWall() {
 	// NOTE: this event has two implementations (index 23 and 22), one unused.
-	spockScan(DIR_E, 23, false, true);
+	spockScan(DIR_E, TX_SPEAKER_SPOCK, TX_SIN3_023);
 }
 
 void Room::sins3LookAtBox() {
 	if (_awayMission->sins.boxState == 0)
-		showDescription(0, true);
+		showDescription(TX_SIN3N000);
 	else if (_awayMission->sins.boxState == 1)
-		showDescription(8, true);
+		showDescription(TX_SIN3N008);
 	else if (_awayMission->sins.boxState == 2)
-		showDescription(5, true);
+		showDescription(TX_SIN3N005);
 }
 
 void Room::sins3UseKirkOnBox() {
@@ -218,7 +292,6 @@ void Room::sins3KirkReachedBox() {
 
 // Plays a sound effect at a specific time while opening the box
 void Room::sins3Timer0Expired() {
-	playSoundEffectIndex(SND_0c);
 }
 
 void Room::sins3UseSpockOnBox() {
@@ -292,9 +365,9 @@ void Room::sins3KirkGotBoxContents() {
 
 void Room::sins3Tick30() {
 	if (!_awayMission->sins.enteredRoom3FirstTime) {
-		showText(TX_SPEAKER_MCCOY, 12, true);
-		showText(TX_SPEAKER_SPOCK, 24, true);
-		showText(TX_SPEAKER_MCCOY, 13, true);
+		showText(TX_SPEAKER_MCCOY, TX_SIN3_012);
+		showText(TX_SPEAKER_SPOCK, TX_SIN3_024);
+		showText(TX_SPEAKER_MCCOY, TX_SIN3_013);
 		_awayMission->sins.enteredRoom3FirstTime = true;
 		_awayMission->disableInput = false;
 	}
@@ -302,13 +375,13 @@ void Room::sins3Tick30() {
 
 void Room::sins3Tick60() {
 	if (_awayMission->sins.gatheredClues == 7) {
-		showText(TX_SPEAKER_SPOCK, 7, true);
+		showText(TX_SPEAKER_SPOCK, TX_SIN3_007);
 		_awayMission->sins.gatheredClues |= 8;
 	}
 }
 
 void Room::sins3UseKirkOnPanel() {
-	showText(TX_SPEAKER_KIRK, 1, true);
+	showText(TX_SPEAKER_KIRK, TX_SIN3_001);
 	sins3UseSpockOnPanel();
 }
 
@@ -320,7 +393,7 @@ void Room::sins3SpockReachedPanel() {
 	const TextRef choices[] = {
 		TX_SPEAKER_KIRK,
 		TX_SIN3_LASERSETTING001, TX_SIN3_LASERSETTING010, TX_SIN3_LASERSETTING100, TX_SIN3_LASERCANCEL,
-		TX_BLANK
+		TX_END
 	};
 
 	int choice = showMultipleTexts(choices);
@@ -333,7 +406,7 @@ void Room::sins3SpockReachedPanel() {
 		if (_awayMission->sins.laserPattern == 0 && _awayMission->sins.laserSetting == 3)
 			// High setting can't be used until the template pattern has been uploaded to
 			// the machine
-			showText(TX_SPEAKER_SPOCK, 5, true);
+			showText(TX_SPEAKER_SPOCK, TX_SIN3_005);
 		else if (_awayMission->sins.moldState != -1) {
 			if (_awayMission->sins.moldState == 0) { // Mold not yet created
 				loadActorAnim2(OBJECT_SPOCK, "susemn");
@@ -342,17 +415,17 @@ void Room::sins3SpockReachedPanel() {
 				if (_awayMission->sins.laserPattern == 0 && _awayMission->sins.laserSetting == 3) {
 					// This code is unreachable, as the same condition was checked above
 					loadActorAnimC(OBJECT_ITEM, "s3las2", 0, 0, &Room::sins3MadeHoleInRock);
-					playSoundEffectIndex(SND_PHASSHOT);
+					playSoundEffectIndex(kSfxPhaser);
 					_awayMission->sins.moldState = -1;
 				} else if (_awayMission->sins.laserPattern == 1 && _awayMission->sins.laserSetting == 3) {
 					// Strong laser creates the needed mold
 					loadActorAnimC(OBJECT_ITEM, "s3las3", 0, 0, &Room::sins3CreatedTemplateInRock);
-					playSoundEffectIndex(SND_PHASSHOT);
+					playSoundEffectIndex(kSfxPhaser);
 					_awayMission->sins.moldState = 2;
 				} else {
 					// Weak laser does nothing to the rock
 					loadActorAnimC(OBJECT_ITEM, "s3las1", 0, 0, &Room::sins3UsedLowPowerLaserOnRock);
-					playSoundEffectIndex(SND_PHASSHOT);
+					playSoundEffectIndex(kSfxPhaser);
 				}
 			} else if (_awayMission->sins.moldState == 3) { // There's a rock sitting on the mold
 				loadActorAnim2(OBJECT_SPOCK, "susemn");
@@ -361,18 +434,18 @@ void Room::sins3SpockReachedPanel() {
 				if (_awayMission->sins.laserSetting == 1 || _awayMission->sins.laserSetting == 2) {
 					// Weak-setting lasers create the keycard properly
 					loadActorAnimC(OBJECT_ITEM, "s3las4", 0, 0, &Room::sins3RockTurnedIntoIDCard);
-					playSoundEffectIndex(SND_PHASSHOT);
+					playSoundEffectIndex(kSfxPhaser);
 					_awayMission->sins.moldState = 4;
 				} else if (_awayMission->sins.laserSetting == 3) {
 					// High-setting laser vaporizes the rocks
 					loadActorAnimC(OBJECT_ITEM, "s3las5", 0, 0, &Room::sins3RockVaporized);
-					playSoundEffectIndex(SND_PHASSHOT);
+					playSoundEffectIndex(kSfxPhaser);
 					_awayMission->sins.moldState = 2;
 					_awayMission->sins.laserPattern = 1;
 				}
 			} else { // moldState == 2 or 4 (mold created; either keycard is in it, or nothing)
 				// "Template would be damaged from direct fire"
-				showText(TX_SPEAKER_SPOCK, 6, true);
+				showText(TX_SPEAKER_SPOCK, TX_SIN3_006);
 			}
 		}
 	}
@@ -420,12 +493,12 @@ void Room::sins3RockTurnedIntoIDCard() {
 }
 
 void Room::sins3RockVaporized() {
-	showText(TX_SPEAKER_SPOCK, 21, true);
+	showText(TX_SPEAKER_SPOCK, TX_SIN3_021);
 }
 
 void Room::sins3UseDrillAnywhere() {
 	// It isn't possible to "use" a hotspot on something else, so this is never called?
-	showDescription(9, true);
+	showDescription(TX_SIN3N009);
 }
 
 void Room::sins3GetIDCard() {
@@ -449,61 +522,61 @@ void Room::sins3PickedUpIDCard() {
 
 void Room::sins3LookAtItemBeingDrilled() {
 	if (_awayMission->sins.moldState == 2)
-		showDescription(6, true);
+		showDescription(TX_SIN3N006);
 	else if (_awayMission->sins.moldState == 3)
-		showDescription(14, true);
+		showDescription(TX_SIN3N014);
 	else if (_awayMission->sins.moldState == 4)
-		showDescription(10, true);
+		showDescription(TX_SIN3N010);
 }
 
 void Room::sins3LookAtKirk() {
-	showDescription(3, true);
+	showDescription(TX_SIN3N003);
 }
 
 void Room::sins3LookAtSpock() {
-	showDescription(4, true);
+	showDescription(TX_SIN3N004);
 }
 
 void Room::sins3LookAtMccoy() {
-	showDescription(1, true); // BUGFIX: Speaker is "nobody", not Dr. McCoy
+	showDescription(TX_SIN3N001); // BUGFIX: Speaker is "nobody", not Dr. McCoy
 }
 
 void Room::sins3LookAtRedshirt() {
-	showDescription(2, true);
+	showDescription(TX_SIN3N002);
 }
 
 void Room::sins3TalkToKirk() {
-	showText(TX_SPEAKER_KIRK, 2, true);
+	showText(TX_SPEAKER_KIRK, TX_SIN3_002);
 }
 
 void Room::sins3TalkToSpock() {
-	showText(TX_SPEAKER_SPOCK, 20, true);
+	showText(TX_SPEAKER_SPOCK, TX_SIN3_020);
 }
 
 void Room::sins3TalkToMccoy() {
-	showText(TX_SPEAKER_MCCOY, 11, true);
+	showText(TX_SPEAKER_MCCOY, TX_SIN3_011);
 }
 
 void Room::sins3TalkToRedshirt() {
-	showText(TX_SPEAKER_MOSHER, 26, true);
-	showText(TX_SPEAKER_MCCOY,  14, true);
-	showText(TX_SPEAKER_MOSHER, 27, true);
+	showText(TX_SPEAKER_MOSHER, TX_SIN3_026);
+	showText(TX_SPEAKER_MCCOY,  TX_SIN3_014);
+	showText(TX_SPEAKER_MOSHER, TX_SIN3_027);
 }
 
 void Room::sins3UseCommunicator() {
-	showText(TX_SPEAKER_UHURA, 72, true);
+	showText(TX_SPEAKER_UHURA, TX_SIN3U072);
 }
 
 void Room::sins3UseSpockOnDrill() {
-	showText(TX_SPEAKER_SPOCK, 4, true);
+	showText(TX_SPEAKER_SPOCK, TX_SIN3_004);
 }
 
 void Room::sins3UseMccoyOnDrill() {
-	showText(TX_SPEAKER_MCCOY, 9, true);
+	showText(TX_SPEAKER_MCCOY, TX_SIN3_009);
 }
 
 void Room::sins3UseRedshirtOnDrill() {
-	showText(TX_SPEAKER_MOSHER, 25, true);
+	showText(TX_SPEAKER_MOSHER, TX_SIN3_025);
 }
 
 void Room::sins3WalkToDoor() {
@@ -511,11 +584,11 @@ void Room::sins3WalkToDoor() {
 }
 
 void Room::sins3UseMedkitOnCrewman() {
-	showText(TX_SPEAKER_MCCOY, 10, true);
+	showText(TX_SPEAKER_MCCOY, TX_SIN3_010);
 }
 
 void Room::sins3UseMTricorderOnCrewman() {
-	mccoyScan(DIR_S, 8, false, true);
+	mccoyScan(DIR_S, TX_SPEAKER_MCCOY, TX_SIN3_008);
 }
 
 }
