@@ -127,10 +127,102 @@ extern const RoomAction sins5ActionList[] = {
 	{ {ACTION_USE, OBJECT_IMTRICOR, OBJECT_SPOCK,    0}, &Room::sins5UseMTricorderOnCrewman },
 	{ {ACTION_USE, OBJECT_IMTRICOR, OBJECT_MCCOY,    0}, &Room::sins5UseMTricorderOnCrewman },
 	{ {ACTION_USE, OBJECT_IMTRICOR, OBJECT_REDSHIRT, 0}, &Room::sins5UseMTricorderOnCrewman },
+	{ {ACTION_LIST_END, 0, 0, 0}, nullptr }
 };
 
-extern const int sins5NumActions = ARRAYSIZE(sins5ActionList);
+enum sins5TextIds {
+	TX_SPEAKER_KIRK, TX_SPEAKER_MCCOY, TX_SPEAKER_SPOCK, TX_SPEAKER_MOSHER,
+	TX_SPEAKER_SCOTT, TX_SPEAKER_COMPUTER,
+	TX_SIN5_001, TX_SIN5_002, TX_SIN5_003, TX_SIN5_004, TX_SIN5_005,
+	TX_SIN5_006, TX_SIN5_007, TX_SIN5_008, TX_SIN5_009, TX_SIN5_010,
+	TX_SIN5_011, TX_SIN5_012, TX_SIN5_013, TX_SIN5_014, TX_SIN5_015,
+	TX_SIN5_016, TX_SIN5_017, TX_SIN5_018, TX_SIN5_019, TX_SIN5_020,
+	TX_SIN5_021, TX_SIN5_022, TX_SIN5_023, TX_SIN5_024, TX_SIN5_025,
+	TX_SIN5_026, TX_SIN5_027, TX_SIN5_028, TX_SIN5_029, TX_SIN5_030,
+	TX_SIN5_031, TX_SIN5_032, TX_SIN5_033, TX_SIN5_034, TX_SIN5_035,
+	TX_SIN5_036, TX_SIN5_037, TX_SIN5_038, TX_SIN5_039, TX_SIN5_040,
+	TX_SIN5_041, TX_SIN5_042, TX_SIN5_043, TX_SIN5_044, TX_SIN5_045,
+	TX_SIN5_046, TX_SIN5_S19, TX_SIN5N000, TX_SIN5N001, TX_SIN5N002,
+	TX_SIN5N003, TX_SIN5N004, TX_SIN5N005, TX_SIN5N006, TX_SIN5N007,
+	TX_SIN5N008, TX_SIN5N009, TX_SIN5N010, TX_SIN5N011, TX_SIN5N012,
+	TX_SIN5N013
+};
 
+// TODO: Finish floppy offsets
+extern const RoomTextOffsets sins5TextOffsets[] = {
+	{ TX_SPEAKER_KIRK, 291, 0 },
+	{ TX_SPEAKER_MCCOY, 302, 0 },
+	{ TX_SPEAKER_SPOCK, 312, 0 },
+	{ TX_SPEAKER_MOSHER, 322, 0 },
+	{ TX_SPEAKER_SCOTT, 346, 0 },
+	{ TX_SPEAKER_COMPUTER, 356, 0 },
+	{ TX_SIN5_001, 1654, 0 },
+	{ TX_SIN5_002, 7449, 0 },
+	{ TX_SIN5_003, 1470, 0 },
+	{ TX_SIN5_004, 1562, 0 },
+	{ TX_SIN5_005, 3254, 0 },
+	{ TX_SIN5_006, 3938, 0 },
+	{ TX_SIN5_007, 4382, 0 },
+	{ TX_SIN5_008, 3069, 0 },
+	{ TX_SIN5_009, 5927, 0 },
+	{ TX_SIN5_010, 7984, 0 },
+	{ TX_SIN5_011, 8427, 0 },
+	{ TX_SIN5_012, 8584, 0 },
+	{ TX_SIN5_013, 803, 0 },
+	{ TX_SIN5_014, 8958, 0 },
+	{ TX_SIN5_015, 1751, 0 },
+	{ TX_SIN5_016, 7310, 0 },
+	{ TX_SIN5_017, 7201, 0 },
+	{ TX_SIN5_018, 7924, 0 },
+	{ TX_SIN5_019, 7818, 0 },
+	{ TX_SIN5_020, 3843, 0 },
+	{ TX_SIN5_021, 4169, 0 },
+	{ TX_SIN5_022, 5697, 0 },
+	{ TX_SIN5_023, 7621, 0 },
+	{ TX_SIN5_024, 8754, 0 },
+	{ TX_SIN5_025, 2638, 0 },
+	{ TX_SIN5_026, 3341, 0 },
+	{ TX_SIN5_027, 2019, 0 },
+	{ TX_SIN5_028, 1287, 0 },
+	{ TX_SIN5_029, 1119, 0 },
+	{ TX_SIN5_030, 942, 0 },
+	{ TX_SIN5_031, 5819, 0 },
+	{ TX_SIN5_032, 4269, 0 },
+	{ TX_SIN5_033, 7722, 0 },
+	{ TX_SIN5_034, 8228, 0 },
+	{ TX_SIN5_035, 9061, 0 },
+	{ TX_SIN5_036, 3673, 0 },
+	{ TX_SIN5_037, 4034, 0 },
+	{ TX_SIN5_038, 7529, 0 },
+	{ TX_SIN5_039, 2234, 0 },
+	{ TX_SIN5_040, 2785, 0 },
+	{ TX_SIN5_041, 2499, 0 },
+	{ TX_SIN5_042, 1887, 0 },
+	{ TX_SIN5_043, 4758, 0 },
+	{ TX_SIN5_044, 3551, 0 },
+	{ TX_SIN5_045, 9305, 0 },
+	{ TX_SIN5_046, 8108, 0 },
+	{ TX_SIN5_S19, 3149, 0 },
+	{ TX_SIN5N000, 6129, 0 },
+	{ TX_SIN5N001, 6373, 0 },
+	{ TX_SIN5N002, 6462, 0 },
+	{ TX_SIN5N003, 6964, 0 },
+	{ TX_SIN5N004, 4647, 0 },
+	{ TX_SIN5N005, 6017, 0 },
+	{ TX_SIN5N006, 6268, 0 },
+	{ TX_SIN5N007, 6524, 0 },
+	{ TX_SIN5N008, 6709, 0 },
+	{ TX_SIN5N009, 6839, 0 },
+	{ TX_SIN5N010, 6609, 0 },
+	{ TX_SIN5N011, 7092, 0 },
+	{ TX_SIN5N012, 5352, 0 },
+	{ TX_SIN5N013, 5579, 0 },
+	{          -1, 0,    0 }
+};
+
+extern const RoomText sins5Texts[] = {
+	  { -1, Common::UNK_LANG, "" }
+};
 
 void Room::sins5Tick1() {
 	playVoc("SIN5LOOP");
@@ -152,7 +244,7 @@ void Room::sins5Tick1() {
 }
 
 void Room::sins5UseSTricorderAnywhere() {
-	spockScan(DIR_S, 13, false, true);
+	spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_SIN5_013);
 }
 
 void Room::sins5UseSTricorderOnRightComputer() {
@@ -160,7 +252,7 @@ void Room::sins5UseSTricorderOnRightComputer() {
 		_awayMission->sins.missionScore += 1;
 		_awayMission->sins.gotPointsForScanningRightComputer = true; // BUGFIX: add this line to prevent infinite score mechanism
 	}
-	spockScan(DIR_S, 30, false, true);
+	spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_SIN5_030);
 	_awayMission->sins.scannedAndUsedComputers |= 2;
 	sins5CheckGatheredAllClues();
 }
@@ -170,39 +262,39 @@ void Room::sins5UseSTricorderOnLeftComputer() {
 		_awayMission->sins.missionScore += 1;
 		_awayMission->sins.gotPointsForScanningLeftComputer = true; // BUGFIX: add this line to prevent infinite score mechanism
 	}
-	spockScan(DIR_S, 29, false, true);
+	spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_SIN5_029);
 	_awayMission->sins.scannedAndUsedComputers |= 1;
 	sins5CheckGatheredAllClues();
 }
 
 void Room::sins5UseSTricorderOnMiddleComputer() {
-	spockScan(DIR_S, 28, false, true);
+	spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_SIN5_028);
 }
 
 void Room::sins5UseKirkOnRightComputer() {
-	showText(TX_SPEAKER_KIRK, 3, true);
+	showText(TX_SPEAKER_KIRK, TX_SIN5_003);
 	sins5UseSpockOnRightComputer();
 }
 
 void Room::sins5UseKirkOnLeftComputer() {
-	showText(TX_SPEAKER_KIRK, 4, true);
+	showText(TX_SPEAKER_KIRK, TX_SIN5_004);
 	sins5UseSpockOnLeftComputer();
 }
 
 void Room::sins5UseKirkOnMiddleComputer() {
-	showText(TX_SPEAKER_KIRK, 1, true);
+	showText(TX_SPEAKER_KIRK, TX_SIN5_001);
 }
 
 void Room::sins5UseMccoyOnComputer() {
-	showText(TX_SPEAKER_MCCOY, 15, true);
+	showText(TX_SPEAKER_MCCOY, TX_SIN5_015);
 }
 
 void Room::sins5UseRedshirtOnComputer() {
-	showText(TX_SPEAKER_MOSHER, 42, true);
+	showText(TX_SPEAKER_MOSHER, TX_SIN5_042);
 }
 
 void Room::sins5UseSpockOnMiddleComputer() {
-	showText(TX_SPEAKER_SPOCK, 27, true);
+	showText(TX_SPEAKER_SPOCK, TX_SIN5_027);
 }
 
 void Room::sins5UseSpockOnRightComputer() {
@@ -222,7 +314,7 @@ void Room::sins5SpockReachedRightComputer() {
 
 void Room::sins5SpockUsedRightComputer() {
 	_awayMission->disableInput = false;
-	showText(TX_SPEAKER_COMPUTER, 39, true);
+	showText(TX_SPEAKER_COMPUTER, TX_SIN5_039);
 	_awayMission->sins.scannedAndUsedComputers |= 8;
 	sins5CheckGatheredAllClues();
 }
@@ -244,8 +336,8 @@ void Room::sins5SpockReachedLeftComputer() {
 
 void Room::sins5SpockUsedLeftComputer() {
 	if (_awayMission->sins.wireConnected1 && _awayMission->sins.wireConnected2) {
-		showText(TX_SPEAKER_COMPUTER, 41, true);
-		showText(TX_SPEAKER_SPOCK,    25, true);
+		showText(TX_SPEAKER_COMPUTER, TX_SIN5_041);
+		showText(TX_SPEAKER_SPOCK,    TX_SIN5_025);
 
 		walkCrewmanC(OBJECT_KIRK,     0x8c, 0xb5, &Room::sins5CrewmanReadyToBeamOut);
 		walkCrewmanC(OBJECT_SPOCK,    0x82, 0xab, &Room::sins5CrewmanReadyToBeamOut);
@@ -253,7 +345,7 @@ void Room::sins5SpockUsedLeftComputer() {
 		walkCrewmanC(OBJECT_REDSHIRT, 0x91, 0xa1, &Room::sins5CrewmanReadyToBeamOut);
 	} else {
 		_awayMission->disableInput = false;
-		showText(TX_SPEAKER_COMPUTER, 40, true);
+		showText(TX_SPEAKER_COMPUTER, TX_SIN5_040);
 		_awayMission->sins.scannedAndUsedComputers |= 4;
 		sins5CheckGatheredAllClues();
 	}
@@ -261,9 +353,9 @@ void Room::sins5SpockUsedLeftComputer() {
 
 void Room::sins5CrewmanReadyToBeamOut() {
 	if (++_roomVar.sins.numCrewmenReadyToBeamOut == 4) {
-		showText(TX_SPEAKER_KIRK,  8, true);
-		showText(TX_SPEAKER_SCOTT, 19 + SCOTTY_MESSAGE_OFFSET);
-		showText(TX_SPEAKER_KIRK,  5, true);
+		showText(TX_SPEAKER_KIRK,  TX_SIN5_008);
+		showText(TX_SPEAKER_SCOTT, TX_SIN5_S19);
+		showText(TX_SPEAKER_KIRK,  TX_SIN5_005);
 		_awayMission->sins.missionScore += 19;
 		endMission(_awayMission->sins.missionScore, 28, 0);
 	}
@@ -272,7 +364,7 @@ void Room::sins5CrewmanReadyToBeamOut() {
 void Room::sins5Tick20() {
 	if (!_awayMission->sins.enteredRoom5FirstTime) {
 		_awayMission->disableInput = false;
-		showText(TX_SPEAKER_SPOCK, 26, true);
+		showText(TX_SPEAKER_SPOCK, TX_SIN5_026);
 		_awayMission->sins.enteredRoom5FirstTime = true;
 	}
 }
@@ -281,15 +373,15 @@ void Room::sins5Tick20() {
 void Room::sins5CheckGatheredAllClues() {
 	if (_awayMission->sins.scannedAndUsedComputers == 0xf && !_awayMission->sins.discoveredComputersOutOfSync) {
 		_awayMission->sins.discoveredComputersOutOfSync = true;
-		showText(TX_SPEAKER_MOSHER, 44, true);
-		showText(TX_SPEAKER_SPOCK,  36, true);
-		showText(TX_SPEAKER_MCCOY,  20, true);
-		showText(TX_SPEAKER_SPOCK,  35, true);
-		showText(TX_SPEAKER_KIRK,   6, true);
-		showText(TX_SPEAKER_SPOCK,  37, true);
-		showText(TX_SPEAKER_MCCOY,  21, true);
-		showText(TX_SPEAKER_SPOCK,  32, true);
-		showText(TX_SPEAKER_KIRK,   7, true);
+		showText(TX_SPEAKER_MOSHER, TX_SIN5_044);
+		showText(TX_SPEAKER_SPOCK,  TX_SIN5_036);
+		showText(TX_SPEAKER_MCCOY,  TX_SIN5_020);
+		showText(TX_SPEAKER_SPOCK,  TX_SIN5_035);
+		showText(TX_SPEAKER_KIRK,   TX_SIN5_006);
+		showText(TX_SPEAKER_SPOCK,  TX_SIN5_037);
+		showText(TX_SPEAKER_MCCOY,  TX_SIN5_021);
+		showText(TX_SPEAKER_SPOCK,  TX_SIN5_032);
+		showText(TX_SPEAKER_KIRK,   TX_SIN5_007);
 	}
 }
 
@@ -311,7 +403,7 @@ void Room::sins5WireConnected() {
 		_awayMission->sins.wireConnected1 = true;
 		_awayMission->sins.wireConnected2 = true;
 		loadActorAnim2(OBJECT_CABLE, "s5cabl", 0, 0);
-		showDescription(4, true);
+		showDescription(TX_SIN5N004);
 		loseItem(OBJECT_ICONECT);
 		playMidiMusicTracks(MIDITRACK_30, -1);
 	}
@@ -319,7 +411,7 @@ void Room::sins5WireConnected() {
 }
 
 void Room::sins5UseStunPhaserOnComputer() {
-	showText(TX_SPEAKER_MOSHER, 43, true);
+	showText(TX_SPEAKER_MOSHER, TX_SIN5_043);
 }
 
 
@@ -334,7 +426,7 @@ void Room::sins5ReachedPositionToShootLeftComputer() {
 
 void Room::sins5DrewPhaserToShootLeftComputer() {
 	loadActorAnimC(OBJECT_LEFT_COMPUTER_EXPLOSION, "s5phal", 0, 0xaf, &Room::sins5ComputerLaunchesMissiles);
-	playSoundEffectIndex(SND_PHASSHOT);
+	playSoundEffectIndex(kSfxPhaser);
 	_awayMission->timers[3] = 10;
 	_awayMission->timers[0] = 24;
 }
@@ -357,7 +449,7 @@ void Room::sins5ReachedPositionToShootMiddleComputer() {
 
 void Room::sins5DrewPhaserToShootMiddleComputer() {
 	loadActorAnimC(OBJECT_MIDDLE_COMPUTER_EXPLOSION, "s5phac", 0, 0x8c, &Room::sins5ComputerLaunchesMissiles);
-	playSoundEffectIndex(SND_PHASSHOT);
+	playSoundEffectIndex(kSfxPhaser);
 	_awayMission->timers[3] = 10;
 	_awayMission->timers[1] = 24;
 }
@@ -380,7 +472,7 @@ void Room::sins5ReachedPositionToShootRightComputer() {
 
 void Room::sins5DrewPhaserToShootRightComputer() {
 	loadActorAnimC(OBJECT_RIGHT_COMPUTER_EXPLOSION, "s5phar", 0, 0xaf, &Room::sins5ComputerLaunchesMissiles);
-	playSoundEffectIndex(SND_PHASSHOT);
+	playSoundEffectIndex(kSfxPhaser);
 	_awayMission->timers[3] = 10;
 	_awayMission->timers[2] = 24;
 }
@@ -393,65 +485,64 @@ void Room::sins5Timer2Expired() {
 
 void Room::sins5ComputerLaunchesMissiles() {
 	playMidiMusicTracks(MIDITRACK_2, -1);
-	showDescription(12, true);
-	showDescription(13, true);
+	showDescription(TX_SIN5N012);
+	showDescription(TX_SIN5N013);
 	showGameOverMenu();
 }
 
 void Room::sins5Timer3Expired() {
-	playSoundEffectIndex(SND_BLANK_14);
 }
 
 void Room::sins5LookAnywhere() {
-	showDescription(5, true);
+	showDescription(TX_SIN5N005);
 }
 
 void Room::sins5LookAtKirk() {
-	showDescription(0, true);
+	showDescription(TX_SIN5N000);
 }
 
 void Room::sins5LookAtSpock() {
-	showDescription(6, true);
+	showDescription(TX_SIN5N006);
 }
 
 void Room::sins5LookAtMccoy() {
-	showDescription(1, true);
+	showDescription(TX_SIN5N001);
 }
 
 void Room::sins5LookAtRedshirt() {
-	showDescription(2, true);
+	showDescription(TX_SIN5N002);
 }
 
 void Room::sins5LookAtLight() {
-	showDescription(7, true);
+	showDescription(TX_SIN5N007);
 }
 
 void Room::sins5LookAtLeftComputer() {
-	showDescription(10, true);
+	showDescription(TX_SIN5N010);
 }
 
 void Room::sins5LookAtMiddleComputer() {
-	showDescription(8, true);
+	showDescription(TX_SIN5N008);
 }
 
 void Room::sins5LookAtRightComputer() {
-	showDescription(9, true);
+	showDescription(TX_SIN5N009);
 }
 
 void Room::sins5LookAtMissile() {
-	showDescription(3, true);
+	showDescription(TX_SIN5N003);
 }
 
 void Room::sins5LookAtNorthDoor() {
-	showDescription(11, true);
+	showDescription(TX_SIN5N011);
 }
 
 void Room::sins5UseMedkitOnCrewman() {
-	showText(TX_SPEAKER_MCCOY, 17, true);
+	showText(TX_SPEAKER_MCCOY, TX_SIN5_017);
 }
 
 void Room::sins5UseMTricorderAnywhere() {
-	mccoyScan(DIR_S, 16, false, true);
+	mccoyScan(DIR_S, TX_SPEAKER_MCCOY, TX_SIN5_016);
 	if (!_awayMission->sins.gotPointsForScanningRoom5) {
 		_awayMission->sins.missionScore += 1;
 		_awayMission->sins.gotPointsForScanningRoom5 = true; // BUGFIX: add this line to prevent infinite score mechanism
@@ -459,46 +550,38 @@ void Room::sins5UseMTricorderAnywhere() {
 }
 
 void Room::sins5TalkToKirk() {
-	showText(TX_SPEAKER_KIRK, 2, true);
+	showText(TX_SPEAKER_KIRK, TX_SIN5_002);
 }
 
 void Room::sins5TalkToSpock() {
-	showText(TX_SPEAKER_SPOCK, 38, true);
-	showText(TX_SPEAKER_MCCOY, 23, true);
-	showText(TX_SPEAKER_SPOCK, 33, true);
-	showText(TX_SPEAKER_MCCOY, 19, true);
+	showText(TX_SPEAKER_SPOCK, TX_SIN5_038);
+	showText(TX_SPEAKER_MCCOY, TX_SIN5_023);
+	showText(TX_SPEAKER_SPOCK, TX_SIN5_033);
+	showText(TX_SPEAKER_MCCOY, TX_SIN5_019);
 }
 
 void Room::sins5TalkToMccoy() {
-	showText(TX_SPEAKER_MCCOY, 18, true);
-	showText(TX_SPEAKER_KIRK,  10, true);
-
-	// The following code block is unused. It doesn't belong to any function, but would
-	// fit best as an alternative to this one.
-	if (false) {
-		showText(TX_SPEAKER_MCCOY, 22, true);
-		showText(TX_SPEAKER_SPOCK, 31, true);
-		showText(TX_SPEAKER_KIRK,  9, true);
-	}
+	showText(TX_SPEAKER_MCCOY, TX_SIN5_018);
+	showText(TX_SPEAKER_KIRK,  TX_SIN5_010);
 }
 
 void Room::sins5TalkToRedshirt() {
-	showText(TX_SPEAKER_MOSHER, 46, true);
-	showText(TX_SPEAKER_SPOCK,  34, true);
-	showText(TX_SPEAKER_MOSHER, 45, true);
-	showText(TX_SPEAKER_KIRK,   11, true);
+	showText(TX_SPEAKER_MOSHER, TX_SIN5_046);
+	showText(TX_SPEAKER_SPOCK,  TX_SIN5_034);
+	showText(TX_SPEAKER_MOSHER, TX_SIN5_045);
+	showText(TX_SPEAKER_KIRK,   TX_SIN5_011);
 }
 
 void Room::sins5UseSTricorderOnMissile() {
-	spockScan(DIR_S, 12, false, true);
+	spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_SIN5_012);
 }
 
 void Room::sins5UseSTricorderOnNorthDoor() {
-	spockScan(DIR_S, 24, false, true);
+	spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_SIN5_024);
 }
 
 void Room::sins5UseMTricorderOnCrewman() {
-	mccoyScan(DIR_S, 14, false, true);
+	mccoyScan(DIR_S, TX_SPEAKER_SPOCK, TX_SIN5_014);
 }
 
 }
