@@ -158,10 +158,121 @@ extern const RoomAction trial5ActionList[] = {
 	{ {ACTION_USE, OBJECT_IBLUGEM3, HOTSPOT_HOLE3, 0}, &Room::trial5UseBlueGem3OnHole3 },
 
 	{ {ACTION_USE, OBJECT_IMEDKIT, 0xff, 0}, &Room::trial5UseMedkitAnywhere },
+	{ {ACTION_LIST_END, 0, 0, 0}, nullptr }
 };
 
-extern const int trial5NumActions = ARRAYSIZE(trial5ActionList);
+enum trial5TextIds {
+	TX_SPEAKER_KIRK, TX_SPEAKER_MCCOY, TX_SPEAKER_SPOCK, TX_SPEAKER_BENNIE, TX_SPEAKER_UHURA,
+	TX_SPEAKER_BIALBI, TX_SPEAKER_VLICT, TX_SPEAKER_VOICE, TX_SPEAKER_LIGHT_OF_WAR,
+	TX_SPEAKER_LIGHT_OF_KNOWLEDGE, TX_SPEAKER_LIGHT_OF_TRAVEL,
+	TX_TRI5_001, TX_TRI5_002, TX_TRI5_003, TX_TRI5_004, TX_TRI5_005,
+	TX_TRI5_006, TX_TRI5_007, TX_TRI5_008, TX_TRI5_009, TX_TRI5_010,
+	TX_TRI5_011, TX_TRI5_012, TX_TRI5_013, TX_TRI5_014, TX_TRI5_015,
+	TX_TRI5_016, TX_TRI5_017, TX_TRI5_018, TX_TRI5_019, TX_TRI5_020,
+	TX_TRI5_021, TX_TRI5_022, TX_TRI5_023, TX_TRI5_024, TX_TRI5_025,
+	TX_TRI5_026, TX_TRI5_027, TX_TRI5_028, TX_TRI5_029, TX_TRI5_030,
+	TX_TRI5_031, TX_TRI5_032, TX_TRI5_033, TX_TRI5_034, TX_TRI5_035,
+	TX_TRI5_036, TX_TRI5_037, TX_TRI5_038, TX_TRI5_039, TX_TRI5_040,
+	TX_TRI5_041, TX_TRI5_042, TX_TRI5_043, TX_TRI5_044, TX_TRI5_045,
+	TX_TRI5_046, TX_TRI5_047, TX_TRI5_048, TX_TRI5_049, TX_TRI5_050,
+	TX_TRI5_051, TX_TRI5_052, TX_TRI5N002, TX_TRI5N004, TX_TRI5N005,
+	TX_TRI5N006, TX_TRI5N007, TX_TRI5N008, TX_TRI5N009, TX_TRI5N010,
+	TX_TRI5N011, TX_TRI5N012, TX_TRI5N013, TX_TRI5N014, TX_TRI5N015,
+	TX_TRI5N016, TX_TRI5N017, TX_TRI5N018, TX_TRI5N019, TX_TRI5N020,
+	TX_TRI5N021
+};
 
+// TODO: Finish floppy offsets
+extern const RoomTextOffsets trial5TextOffsets[] = {
+	{ TX_SPEAKER_KIRK, 275, 0 },
+	{ TX_SPEAKER_MCCOY, 286, 0 },
+	{ TX_SPEAKER_SPOCK, 296, 0 },
+	{ TX_SPEAKER_BENNIE, 306, 0 },
+	{ TX_SPEAKER_UHURA, 320, 0 },
+	{ TX_SPEAKER_BIALBI, 393, 0 },
+	{ TX_SPEAKER_VLICT, 400, 0 },
+	{ TX_SPEAKER_VOICE, 378, 0 },
+	{ TX_SPEAKER_LIGHT_OF_WAR, 330, 0 },
+	{ TX_SPEAKER_LIGHT_OF_KNOWLEDGE, 343, 0 },
+	{ TX_SPEAKER_LIGHT_OF_TRAVEL, 362, 0 },
+	{ TX_TRI5_001, 7210, 0 },
+	{ TX_TRI5_002, 1082, 0 },
+	{ TX_TRI5_003, 1947, 0 },
+	{ TX_TRI5_004, 3104, 0 },
+	{ TX_TRI5_005, 3664, 0 },
+	{ TX_TRI5_006, 2153, 0 },
+	{ TX_TRI5_007, 2591, 0 },
+	{ TX_TRI5_008, 2043, 0 },
+	{ TX_TRI5_009, 2488, 0 },
+	{ TX_TRI5_010, 5768, 0 },
+	{ TX_TRI5_011, 5944, 0 },
+	{ TX_TRI5_012, 14859, 0 },
+	{ TX_TRI5_013, 7481, 0 },
+	{ TX_TRI5_014, 1010, 0 },
+	{ TX_TRI5_015, 2409, 0 },
+	{ TX_TRI5_016, 7317, 0 },
+	{ TX_TRI5_017, 943, 0 },
+	{ TX_TRI5_018, 1917, 0 },
+	{ TX_TRI5_019, 2950, 0 },
+	{ TX_TRI5_020, 1447, 0 },
+	{ TX_TRI5_021, 3487, 0 },
+	{ TX_TRI5_022, 1699, 0 },
+	{ TX_TRI5_023, 2313, 0 },
+	{ TX_TRI5_024, 4276, 0 },
+	{ TX_TRI5_025, 3004, 0 },
+	{ TX_TRI5_026, 3285, 0 },
+	{ TX_TRI5_027, 1251, 0 },
+	{ TX_TRI5_028, 3554, 0 },
+	{ TX_TRI5_029, 1755, 0 },
+	{ TX_TRI5_030, 3179, 0 },
+	{ TX_TRI5_031, 1500, 0 },
+	{ TX_TRI5_032, 4001, 0 },
+	{ TX_TRI5_033, 3830, 0 },
+	{ TX_TRI5_034, 2752, 0 },
+	{ TX_TRI5_035, 4215, 0 },
+	{ TX_TRI5_036, 13018, 0 },
+	{ TX_TRI5_037, 13608, 0 },
+	{ TX_TRI5_038, 13684, 0 },
+	{ TX_TRI5_039, 13969, 0 },
+	//{ TX_TRI5_039, 12698, 0 },	// Ignore duplicate line
+	{ TX_TRI5_040, 13379, 0 },
+	{ TX_TRI5_041, 13860, 0 },
+	{ TX_TRI5_042, 14630, 0 },
+	{ TX_TRI5_043, 14770, 0 },
+	{ TX_TRI5_044, 14223, 0 },
+	{ TX_TRI5_045, 14131, 0 },
+	{ TX_TRI5_046, 14343, 0 },
+	{ TX_TRI5_047, 13301, 0 },
+	{ TX_TRI5_048, 13150, 0 },
+	{ TX_TRI5_049, 13071, 0 },
+	{ TX_TRI5_050, 12880, 0 },
+	{ TX_TRI5_051, 7549, 0 },
+	{ TX_TRI5_052, 897, 0 },
+	{ TX_TRI5N002, 5594, 0 },
+	{ TX_TRI5N004, 5661, 0 },
+	{ TX_TRI5N005, 5313, 0 },
+	{ TX_TRI5N006, 7119, 0 },
+	{ TX_TRI5N007, 7905, 0 },
+	{ TX_TRI5N008, 5447, 0 },
+	{ TX_TRI5N009, 5381, 0 },
+	{ TX_TRI5N010, 5519, 0 },
+	{ TX_TRI5N011, 7659, 0 },
+	{ TX_TRI5N012, 7778, 0 },
+	{ TX_TRI5N013, 6041, 0 },
+	{ TX_TRI5N014, 6157, 0 },
+	{ TX_TRI5N015, 6273, 0 },
+	{ TX_TRI5N016, 6746, 0 },
+	{ TX_TRI5N017, 6865, 0 },
+	{ TX_TRI5N018, 6984, 0 },
+	{ TX_TRI5N019, 6389, 0 },
+	{ TX_TRI5N020, 6508, 0 },
+	{ TX_TRI5N021, 6627, 0 },
+	{          -1, 0,    0 }
+};
+
+extern const RoomText trial5Texts[] = {
+	{ -1, Common::UNK_LANG, "" }
+};
 
 void Room::trial5Tick1() {
 	playVoc("TRI5LOOP");
@@ -196,7 +307,7 @@ void Room::trial5VlictAppeared() {
 	const TextRef choices[] = {
 		TX_SPEAKER_KIRK,
 		TX_TRI5_003, TX_TRI5_008, TX_TRI5_006,
-		TX_BLANK
+		TX_END
 	};
 	int choice = showMultipleTexts(choices);
 
@@ -207,7 +318,7 @@ void Room::trial5VlictAppeared() {
 		const TextRef choices2[] = {
 			TX_SPEAKER_KIRK,
 			TX_TRI5_009, TX_TRI5_007,
-			TX_BLANK
+			TX_END
 		};
 		choice = showMultipleTexts(choices2);
 
@@ -356,11 +467,11 @@ void Room::trial5LookAtInterface() {
 }
 
 void Room::trial5UseSTricorderOnInterface() {
-	spockScan(DIR_E, TX_TRI5_010, true);
+	spockScan(DIR_E, TX_SPEAKER_SPOCK, TX_TRI5_010, true);
 }
 
 void Room::trial5UseMTricorderOnInterface() {
-	mccoyScan(DIR_E, TX_TRI5_011, true);
+	mccoyScan(DIR_E, TX_SPEAKER_MCCOY, TX_TRI5_011, true);
 }
 
 void Room::trial5LookAtRedGem1() {
@@ -425,12 +536,12 @@ void Room::trial5UsePhaser() {
 
 void Room::trial5UseMTricorderAnywhere() {
 	// BUGFIX: Original had Spock doing the animation, not Mccoy
-	mccoyScan(DIR_S, -1, true);
+	mccoyScan(DIR_S, TX_SPEAKER_MCCOY, - 1, true);
 	showDescription(TX_TRI5N012);
 }
 
 void Room::trial5UseSTricorderAnywhere() {
-	spockScan(DIR_S, -1, true);
+	spockScan(DIR_S, TX_SPEAKER_SPOCK, - 1, true);
 	showDescription(TX_TRI5N012);
 }
 
@@ -577,7 +688,7 @@ void Room::trial5ReachedHoleToPutGem() {
 			showText(TX_SPEAKER_LIGHT_OF_TRAVEL, TX_TRI5_046);
 
 			_awayMission->disableInput = true;
-			playSoundEffectIndex(SND_TRANSDEM);
+			playSoundEffectIndex(kSfxTransporterDematerialize);
 
 			loadActorAnimC(OBJECT_KIRK,  "kteled", -1, -1, &Room::trial5CrewmanBeamedOut);
 			loadActorAnimC(OBJECT_SPOCK, "steled", -1, -1, &Room::trial5CrewmanBeamedOut);
@@ -592,17 +703,17 @@ void Room::trial5ReachedHoleToPutGem() {
 }
 
 void Room::trial5ActivateLightOfWar() {
-	playSoundEffectIndex(SND_TRANSENE);
+	playSoundEffectIndex(kSfxTransporterEnergize);
 	loadActorAnim2(OBJECT_BEAM, "redlit", 0, 0);
 }
 
 void Room::trial5ActivateLightOfKnowledge() {
-	playSoundEffectIndex(SND_TRANSENE);
+	playSoundEffectIndex(kSfxTransporterEnergize);
 	loadActorAnim2(OBJECT_BEAM, "grnlit", 0, 0);
 }
 
 void Room::trial5ActivateLightOfTravel() {
-	playSoundEffectIndex(SND_TRANSENE);
+	playSoundEffectIndex(kSfxTransporterEnergize);
 	loadActorAnim2(OBJECT_BEAM, "blulit", 0, 0);
 }
 
@@ -611,7 +722,7 @@ void Room::trial5RestrictedCombination1() {
 	// "trial5RestrictedCombination2" is that this one doesn't show the light of
 	// knowledge.
 	// It's inconsistent, but I guess we can chalk it up to the aliens being mysterious...
-	playSoundEffectIndex(SND_TRANSENE);
+	playSoundEffectIndex(kSfxTransporterEnergize);
 	showText(TX_SPEAKER_LIGHT_OF_KNOWLEDGE, TX_TRI5_039);
 }
 
