@@ -179,10 +179,253 @@ extern const RoomAction veng2ActionList[] = {
 	{ {ACTION_USE, OBJECT_KIRK, HOTSPOT_TORPEDO_CONTROL,     0}, &Room::veng2UseKirkOnTorpedoButton },
 	// TODO: uncomment
 //	{ {ACTION_USE, OBJECT_ISTRICOR, HOTSPOT_DECK_IO_CONSOLE, 0}, &Room::veng2UseSTricorderOnDeckIOConsole },
+	{ {ACTION_LIST_END, 0, 0, 0}, nullptr }
 };
 
-extern const int veng2NumActions = ARRAYSIZE(veng2ActionList);
+enum veng2TextIds {
+	TX_SPEAKER_KIRK, TX_SPEAKER_MCCOY, TX_SPEAKER_SPOCK, TX_SPEAKER_KIJE, TX_SPEAKER_SCOTT,
+	TX_SPEAKER_CHEKOV, TX_SPEAKER_ELASI_CAPTAIN, TX_SPEAKER_PATTERSON, TX_SPEAKER_UHURA, TX_SPEAKER_ANDRADE,
+	TX_SPEAKER_ELASI_WEAPONS_MASTER, TX_SPEAKER_ELASI_CREWMAN,
+	TX_VEN2_001, TX_VEN2_002, TX_VEN2_003, TX_VEN2_004, TX_VEN2_005,
+	TX_VEN2_006, TX_VEN2_007, TX_VEN2_008, TX_VEN2_009, TX_VEN2_010,
+	TX_VEN2_011, TX_VEN2_012, TX_VEN2_013, TX_VEN2_014, TX_VEN2_015,
+	TX_VEN2_016, TX_VEN2_017, TX_VEN2_018, TX_VEN2_019,	TX_VEN2_020,
+	TX_VEN2_021, TX_VEN2_022, TX_VEN2_023, TX_VEN2_024, TX_VEN2_025,
+	TX_VEN2_026, TX_VEN2_027, TX_VEN2_028, TX_VEN2_029, TX_VEN2_030,
+	TX_VEN2_031, TX_VEN2_032, TX_VEN2_033, TX_VEN2_034, TX_VEN2_035,
+	TX_VEN2_036, TX_VEN2_037, TX_VEN2_038, TX_VEN2_039, TX_VEN2_040,
+	TX_VEN2_041, TX_VEN2_042, TX_VEN2_043, TX_VEN2_044, TX_VEN2_045,
+	TX_VEN2_046, TX_VEN2_047, TX_VEN2_048, TX_VEN2_050, TX_VEN2_051,
+	TX_VEN2_052, TX_VEN2_053, TX_VEN2_054, TX_VEN2_055, TX_VEN2_056,
+	TX_VEN2_057, TX_VEN2_058, TX_VEN2_059, TX_VEN2_060, TX_VEN2_061,
+	TX_VEN2_062, TX_VEN2_063, TX_VEN2_064, TX_VEN2_065, TX_VEN2_066,
+	TX_VEN2_067, TX_VEN2_068, TX_VEN2_069, TX_VEN2_070, TX_VEN2_071,
+	TX_VEN2_072, TX_VEN2_073, TX_VEN2_074, TX_VEN2_075, TX_VEN2_076,
+	TX_VEN2_077, TX_VEN2_078, TX_VEN2_079, TX_VEN2_080, TX_VEN2_081,
+	TX_VEN2_082, TX_VEN2_083, TX_VEN2_084, TX_VEN2_085, TX_VEN2_086,
+	TX_VEN2_087, TX_VEN2_088, TX_VEN2_089, TX_VEN2_091, TX_VEN2_092,
+	TX_VEN2_093, TX_VEN2_094, TX_VEN2_096, TX_VEN2_097, TX_VEN2_098,
+	TX_VEN2_099, TX_VEN2_100, TX_VEN2_101, TX_VEN2_102, TX_VEN2_103,
+	TX_VEN2_104, TX_VEN2_105, TX_VEN2_106, TX_VEN2_107, TX_VEN2_108,
+	TX_VEN2_109, TX_VEN2_110, TX_VEN2_111, TX_VEN2_112, TX_VEN2_113,
+	TX_VEN2_114, TX_VEN2_115, TX_VEN2_ELA, TX_VEN2_ENT, TX_VEN2_F28,
+	TX_VEN2_F29, TX_VEN2_F35, TX_VEN2_S09, TX_VEN2_SHI, TX_VEN2_TRA,
+	TX_VEN2_WEA, TX_VEN4N010, TX_VEN4_017, TX_VEN6N007, TX_VENA_F32,
+	TX_VENA_F34, TX_VENA_F40, TX_MUD4_018, TX_VEN2N000, TX_VEN2N001,
+	TX_VEN2N002, TX_VEN2N003, TX_VEN2N004, TX_VEN2N005, TX_VEN2N006,
+	TX_VEN2N007, TX_VEN2N008, TX_VEN2N009, TX_VEN2N010, TX_VEN2N011,
+	TX_VEN2N012, TX_VEN2N013, TX_VEN2N015, TX_VEN2N016, TX_VEN2N017,
+	TX_VEN2N018, TX_VEN2N019, TX_VEN2N020, TX_VEN2N021, TX_VEN2N022,
+	TX_VEN2N023, TX_VEN2N024, TX_VEN2N025, TX_VEN2N027, TX_VEN2N028,
+	TX_VEN2N029, TX_VEN2N030, TX_VEN2N031, TX_VEN2N032, TX_VEN2N033,
+	TX_VEN2N034, TX_VEN2N035, TX_VEN2N038, TX_VEN2N039, TX_VEN2U093,
+	TX_VEN2U094, TX_VEN2_HAIL_ELASI, TX_VEN2_HAIL_ENT, TX_VEN2_CANCEL,
+	TX_VEN2_090
+};
 
+// TODO: Finish floppy offsets
+extern const RoomTextOffsets veng2TextOffsets[] = {
+	{ TX_SPEAKER_KIRK, 20603, 0 },
+	{ TX_SPEAKER_MCCOY, 20614, 0 },
+	{ TX_SPEAKER_SPOCK, 20624, 0 },
+	{ TX_SPEAKER_KIJE, 20719, 0 },
+	{ TX_SPEAKER_SCOTT, 20634, 0 },
+	{ TX_SPEAKER_CHEKOV, 20644, 0 },
+	{ TX_SPEAKER_ELASI_CAPTAIN, 20731, 0 },
+	{ TX_SPEAKER_PATTERSON, 20677, 0 },
+	{ TX_SPEAKER_UHURA, 20658, 0 },
+	{ TX_SPEAKER_ANDRADE, 20695, 0 },
+	{ TX_SPEAKER_ELASI_WEAPONS_MASTER, 20745, 0 },
+	{ TX_SPEAKER_ELASI_CREWMAN, 20766, 0 },
+	{ TX_VEN2_001, 12332, 0 },
+	{ TX_VEN2_002, 15643, 0 },
+	{ TX_VEN2_003, 13474, 0 },
+	{ TX_VEN2_003, 13295, 0 },
+	{ TX_VEN2_004, 6710, 0 },
+	{ TX_VEN2_005, 6633, 0 },
+	{ TX_VEN2_006, 1862, 0 },
+	{ TX_VEN2_007, 7242, 0 },
+	{ TX_VEN2_008, 2468, 0 },
+	{ TX_VEN2_009, 6954, 0 },
+	{ TX_VEN2_010, 1756, 0 },
+	{ TX_VEN2_011, 22026, 0 },
+	{ TX_VEN2_012, 21967, 0 },
+	{ TX_VEN2_013, 11534, 0 },
+	{ TX_VEN2_014, 11088, 0 },
+	{ TX_VEN2_015, 9563, 0 },
+	{ TX_VEN2_015, 22250, 0 },
+	{ TX_VEN2_016, 1372, 0 },
+	{ TX_VEN2_017, 8039, 0 },
+	{ TX_VEN2_018, 15028, 0 },
+	{ TX_VEN2_019, 1051, 0 },
+	{ TX_VEN2_020, 2081, 0 },
+	{ TX_VEN2_021, 2626, 0 },
+	{ TX_VEN2_022, 3046, 0 },
+	{ TX_VEN2_023, 22533, 0 },
+	{ TX_VEN2_024, 15934, 0 },
+	{ TX_VEN2_025, 10100, 0 },
+	{ TX_VEN2_026, 11332, 0 },
+	{ TX_VEN2_027, 1576, 0 },
+	{ TX_VEN2_028, 8928, 0 },
+	{ TX_VEN2_029, 9654, 0 },
+	{ TX_VEN2_029, 22325, 0 },
+	{ TX_VEN2_030, 17649, 0 },
+	{ TX_VEN2_031, 16748, 0 },
+	{ TX_VEN2_032, 1198, 0 },
+	{ TX_VEN2_033, 14498, 0 },
+	{ TX_VEN2_034, 14871, 0 },
+	{ TX_VEN2_035, 13922, 0 },
+	{ TX_VEN2_036, 22919, 0 },
+	{ TX_VEN2_037, 23214, 0 },
+	{ TX_VEN2_038, 17250, 0 },
+	{ TX_VEN2_039, 7091, 0 },
+	{ TX_VEN2_040, 9261, 0 },
+	{ TX_VEN2_041, 7154, 0 },
+	{ TX_VEN2_042, 1139, 0 },
+	{ TX_VEN2_043, 7956, 0 },
+	{ TX_VEN2_044, 3004, 0 },
+	{ TX_VEN2_045, 16134, 0 },
+	{ TX_VEN2_046, 7637, 0 },
+	{ TX_VEN2_047, 18668, 0 },
+	{ TX_VEN2_047, 19102, 0 },
+	{ TX_VEN2_048, 22718, 0 },
+	{ TX_VEN2_050, 13181, 0 },
+	{ TX_VEN2_051, 18177, 0 },
+	{ TX_VEN2_052, 14307, 0 },
+	{ TX_VEN2_053, 22827, 0 },
+	{ TX_VEN2_054, 10390, 0 },
+	{ TX_VEN2_055, 12792, 0 },
+	{ TX_VEN2_056, 18054, 0 },
+	{ TX_VEN2_057, 13554, 0 },
+	{ TX_VEN2_058, 10271, 0 },
+	{ TX_VEN2_059, 16593, 0 },
+	{ TX_VEN2_060, 18322, 0 },
+	{ TX_VEN2_061, 8589, 0 },
+	{ TX_VEN2_062, 12484, 0 },
+	{ TX_VEN2_063, 13376, 0 },
+	{ TX_VEN2_064, 12699, 0 },
+	{ TX_VEN2_065, 12924, 0 },
+	{ TX_VEN2_066, 9124, 0 },
+	{ TX_VEN2_067, 17887, 0 },
+	{ TX_VEN2_068, 13011, 0 },
+	{ TX_VEN2_069, 13740, 0 },
+	{ TX_VEN2_070, 7834, 0 },
+	{ TX_VEN2_071, 15497, 0 },
+	{ TX_VEN2_072, 2934, 0 },
+	{ TX_VEN2_073, 1295, 0 },
+	{ TX_VEN2_074, 16244, 0 },
+	{ TX_VEN2_075, 6898, 0 },
+	{ TX_VEN2_076, 1100, 0 },
+	{ TX_VEN2_077, 15137, 0 },
+	{ TX_VEN2_078, 7533, 0 },
+	{ TX_VEN2_079, 15779, 0 },
+	{ TX_VEN2_080, 15999, 0 },
+	{ TX_VEN2_081, 8104, 0 },
+	{ TX_VEN2_082, 8295, 0 },
+	{ TX_VEN2_083, 21010, 0 },
+	{ TX_VEN2_084, 21263, 0 },
+	{ TX_VEN2_085, 14671, 0 },
+	{ TX_VEN2_086, 7302, 0 },
+	{ TX_VEN2_087, 15414, 0 },
+	{ TX_VEN2_088, 14226, 0 },
+	{ TX_VEN2_089, 14584, 0 },
+	{ TX_VEN2_091, 14077, 0 },
+	{ TX_VEN2_092, 14813, 0 },
+	{ TX_VEN2_093, 995, 0 },
+	{ TX_VEN2_094, 7375, 0 },
+	{ TX_VEN2_096, 16473, 0 },
+	{ TX_VEN2_097, 21609, 0 },
+	{ TX_VEN2_098, 19583, 0 },
+	{ TX_VEN2_098, 8666, 0 },
+	{ TX_VEN2_099, 2384, 0 },
+	{ TX_VEN2_100, 9831, 0 },
+	{ TX_VEN2_101, 11009, 0 },
+	{ TX_VEN2_102, 2733, 0 },
+	{ TX_VEN2_103, 1799, 0 },
+	{ TX_VEN2_104, 10706, 0 },
+	{ TX_VEN2_105, 2512, 0 },
+	{ TX_VEN2_106, 11136, 0 },
+	{ TX_VEN2_107, 22443, 0 },
+	{ TX_VEN2_108, 9448, 0 },
+	{ TX_VEN2_109, 1454, 0 },
+	{ TX_VEN2_110, 22561, 0 },
+	{ TX_VEN2_111, 1956, 0 },
+	{ TX_VEN2_112, 2187, 0 },
+	{ TX_VEN2_113, 1620, 0 },
+	{ TX_VEN2_114, 9953, 0 },
+	{ TX_VEN2_115, 11383, 0 },
+	{ TX_VEN2_ELA, 22180, 0 },
+	{ TX_VEN2_ENT, 22215, 0 },
+	{ TX_VEN2_F28, 10925, 0 },
+	{ TX_VEN2_F29, 10850, 0 },
+	{ TX_VEN2_F35, 11997, 0 },
+	{ TX_VEN2_S09, 11713, 0 },
+	{ TX_VEN2_SHI, 21908, 0 },
+	{ TX_VEN2_TRA, 21931, 0 },
+	{ TX_VEN2_WEA, 21885, 0 },
+	{ TX_VEN4_017, 6826, 0 },
+	{ TX_VENA_F32, 19813, 0 },
+	{ TX_VENA_F34, 20083, 0 },
+	{ TX_VENA_F40, 19678, 0 },
+	//{ TX_DEM6_015, 20930, 0 },
+	{ TX_VEN2N000, 4402, 0 },
+	{ TX_VEN2N001, 4341, 0 },
+	{ TX_VEN2N002, 3318, 0 },
+	{ TX_VEN2N003, 5479, 0 },
+	{ TX_VEN2N004, 6403, 0 },
+	{ TX_VEN2N005, 5275, 0 },
+	{ TX_VEN2N006, 5363, 0 },
+	{ TX_VEN2N007, 5177, 0 },
+	{ TX_VEN2N008, 4856, 0 },
+	{ TX_VEN2N009, 4957, 0 },
+	{ TX_VEN2N009, 5067, 0 },
+	{ TX_VEN2N010, 6159, 0 },
+	{ TX_VEN2N011, 20781, 0 },
+	{ TX_VEN2N012, 6331, 0 },
+	{ TX_VEN2N013, 19468, 0 },
+	{ TX_VEN2N015, 19034, 0 },
+	{ TX_VEN2N016, 17487, 0 },
+	{ TX_VEN2N017, 17096, 0 },
+	{ TX_VEN2N018, 20823, 0 },
+	{ TX_VEN2N019, 6259, 0 },
+	{ TX_VEN2N020, 4671, 0 },
+	{ TX_VEN2N021, 4553, 0 },
+	{ TX_VEN2N022, 3192, 0 },
+	{ TX_VEN2N023, 5574, 0 },
+	{ TX_VEN2N024, 4064, 0 },
+	{ TX_VEN2N025, 5766, 0 },
+	{ TX_VEN2N027, 3963, 0 },
+	{ TX_VEN2N027, 5673, 0 },
+	{ TX_VEN2N028, 10216, 0 },
+	{ TX_VEN2N029, 5898, 0 },
+	{ TX_VEN2N030, 12131, 0 },
+	{ TX_VEN2N030, 3479, 0 },
+	{ TX_VEN2N031, 6071, 0 },
+	{ TX_VEN2N031, 5983, 0 },
+	{ TX_VEN2N032, 23477, 0 },
+	{ TX_VEN2N032, 3824, 0 },
+	{ TX_VEN2N033, 4173, 0 },
+	{ TX_VEN2N033, 4257, 0 },
+	{ TX_VEN2N034, 4778, 0 },
+	{ TX_VEN2N035, 6492, 0 },
+	{ TX_VEN2N035, 3689, 0 },
+	{ TX_VEN2N038, 20875, 0 },
+	{ TX_VEN2N039, 18582, 0 },
+	{ TX_VEN2U093, 8821, 0 },
+	{ TX_VEN2U094, 11259, 0 },
+	{ TX_VEN4N010, 20237, 0 },
+	{ TX_VEN6N007, 20302, 0 },
+	{ TX_MUD4_018, 8758, 0 },
+	{ TX_VEN2_HAIL_ELASI, 9004, 0 },
+	{ TX_VEN2_HAIL_ENT, 9031, 0 },
+	{ TX_VEN2_CANCEL, 9063, 0 },
+	//TODO: TX_VEN2_090
+	{          -1, 0,    0 }
+};
+
+extern const RoomText veng2Texts[] = {
+	  { -1, Common::UNK_LANG, "" }
+};
 
 #define STRICORDER_POS_X 0x45
 #define STRICORDER_POS_Y 0x71
@@ -202,7 +445,6 @@ extern const int veng2NumActions = ARRAYSIZE(veng2ActionList);
 #define TORPEDO_BUTTON_X 0x97
 #define TORPEDO_BUTTON_Y 0x74
 
-
 void Room::veng2Tick1() {
 	if (!_awayMission->veng.tookRecordDeckFromAuxilaryControl)
 		loadActorAnim2(OBJECT_DECK, "s7r2d1", 0xee, 0x8c);
@@ -256,12 +498,12 @@ void Room::veng2Timer0Expired() { // Elasi decloak if they haven't already
 void Room::veng2ElasiShipDecloaked() {
 	_awayMission->disableInput = false;
 
-	showText(TX_SPEAKER_KIJE,  93, true);
-	showText(TX_SPEAKER_KIRK,  19, true);
-	showText(TX_SPEAKER_SPOCK, 76, true);
-	showText(TX_SPEAKER_MCCOY, 42, true);
+	showText(TX_SPEAKER_KIJE,  TX_VEN2_093);
+	showText(TX_SPEAKER_KIRK,  TX_VEN2_019);
+	showText(TX_SPEAKER_SPOCK, TX_VEN2_076);
+	showText(TX_SPEAKER_MCCOY, TX_VEN2_042);
 	if (_awayMission->veng.poweredSystem != 2) {
-		showText(TX_SPEAKER_SPOCK, 32, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_032);
 		_awayMission->veng.counterUntilElasiBoardWithShieldsDown = 1800;
 	} else
 		veng2Timer2Expired();
@@ -272,38 +514,38 @@ void Room::veng2Timer2Expired() { // Elasi hail the Enterprise if they haven't a
 		return;
 	_awayMission->veng.elasiHailedRepublic = true;
 
-	showText(TX_SPEAKER_SPOCK, 73, true);
-	showText(TX_SPEAKER_KIRK,  16, true);
+	showText(TX_SPEAKER_SPOCK, TX_VEN2_073);
+	showText(TX_SPEAKER_KIRK,  TX_VEN2_016);
 	loadActorAnim2(OBJECT_VIEWSCREEN, "s7r2p1", VIEWSCREEN_X, VIEWSCREEN_Y);
-	showText(TX_SPEAKER_ELASI_CAPTAIN, 109, true);
-	showText(TX_SPEAKER_KIRK,          27, true);
-	showText(TX_SPEAKER_ELASI_CAPTAIN, 113, true);
-	showText(TX_SPEAKER_KIRK,          10, true);
-	showText(TX_SPEAKER_ELASI_CAPTAIN, 103, true);
-	showText(TX_SPEAKER_KIRK,          06, true);
-	showText(TX_SPEAKER_ELASI_CAPTAIN, 111, true);
-	showText(TX_SPEAKER_KIRK,          20, true);
-	showText(TX_SPEAKER_ELASI_CAPTAIN, 112, true);
+	showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_109);
+	showText(TX_SPEAKER_KIRK,          TX_VEN2_027);
+	showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_113);
+	showText(TX_SPEAKER_KIRK,          TX_VEN2_010);
+	showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_103);
+	showText(TX_SPEAKER_KIRK,          TX_VEN2_006);
+	showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_111);
+	showText(TX_SPEAKER_KIRK,          TX_VEN2_020);
+	showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_112);
 
 	const TextRef choices[] = {
 		TX_SPEAKER_KIRK,
-		12, 11,
-		TX_BLANK
+		TX_VEN2_012, TX_VEN2_011,
+		TX_END
 	};
 
-	int choice = showMultipleTexts(choices, true);
+	int choice = showMultipleTexts(choices);
 
 	if (choice == 0) {
-		showText(TX_SPEAKER_ELASI_CAPTAIN, 99, true);
-		showText(TX_SPEAKER_KIRK,           8, true);
+		showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_099);
+		showText(TX_SPEAKER_KIRK,          TX_VEN2_008);
 	}
 
-	showText(TX_SPEAKER_ELASI_CAPTAIN, 105, true);
-	showText(TX_SPEAKER_KIRK,          21, true);
-	showText(TX_SPEAKER_ELASI_CAPTAIN, 102, true);
-	showText(TX_SPEAKER_SPOCK,         72, true);
-	showText(TX_SPEAKER_MCCOY,         44, true);
-	showText(TX_SPEAKER_KIRK,          22, true);
+	showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_105);
+	showText(TX_SPEAKER_KIRK,          TX_VEN2_021);
+	showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_102);
+	showText(TX_SPEAKER_SPOCK,         TX_VEN2_072);
+	showText(TX_SPEAKER_MCCOY,         TX_VEN2_044);
+	showText(TX_SPEAKER_KIRK,          TX_VEN2_022);
 
 	loadActorAnim2(OBJECT_VIEWSCREEN, "s7r2u2", VIEWSCREEN_X, VIEWSCREEN_Y);
 	_awayMission->veng.counterUntilElasiAttack = 27000;
@@ -311,153 +553,153 @@ void Room::veng2Timer2Expired() { // Elasi hail the Enterprise if they haven't a
 }
 
 void Room::veng2TouchedDoor() {
-	playSoundEffectIndex(SND_DOOR1);
+	playSoundEffectIndex(kSfxDoor);
 	_awayMission->rdfStillDoDefaultAction = true;
 }
 
 void Room::veng2LookAtViewscreen() {
 	if (!_awayMission->veng.elasiShipDecloaked)
-		showDescription(22, true);
+		showDescription(TX_VEN2N022);
 	else
-		showDescription( 2, true);
+		showDescription(TX_VEN2N002);
 }
 
 void Room::veng2LookAtMiddleConsole() {
-	showDescription(30, true);
+	showDescription(TX_VEN2N030);
 }
 
 void Room::veng2LookAtDamageDisplay() {
 	if (!_awayMission->veng.impulseEnginesOn)
-		showDescription(35, true);
+		showDescription(TX_VEN2N035);
 	else
-		showDescription(32, true);
+		showDescription(TX_VEN2N032);
 
 	// NOTE: There were originally 2 more cases, where "poweredSystem == 2" or otherwise. For
 	// the case where poweredSystem == 2, it played TX_VEN2N032, but with mismatching text.
 }
 
 void Room::veng2LookAtSTricorder() {
-	showDescription(27, true);
+	showDescription(TX_VEN2N027);
 }
 
 void Room::veng2LookAtMTricorder() {
-	showDescription(24, true);
+	showDescription(TX_VEN2N024);
 }
 
 void Room::veng2LookAtTorpedoButton() {
-	showDescription(33, true);
+	showDescription(TX_VEN2N033);
 }
 
 // TODO: Consider merging "veng2LookAtTorpedoButton" with "veng2LookAtTorpedoControl"
 // (and the same for use actions)
 void Room::veng2LookAtTorpedoControl() {
-	showDescription(33, true);
+	showDescription(TX_VEN2N033);
 
 	if (!_awayMission->veng.impulseEnginesOn)
-		showDescription(1, true); // Unused, since it can't be selected when impulse is off?
+		showDescription(TX_VEN2N001); // Unused, since it can't be selected when impulse is off?
 	else if (!_awayMission->veng.torpedoLoaded) {
-		showDescription(0, true);
+		showDescription(TX_VEN2N000);
 		if (!_awayMission->veng.elasiShipDecloaked)
-			showText(TX_SPEAKER_SPOCK, 36, true);
+			showText(TX_SPEAKER_SPOCK, TX_VEN2_036);
 		else
-			showText(TX_SPEAKER_SPOCK, 37, true);
+			showText(TX_SPEAKER_SPOCK, TX_VEN2_037);
 		_awayMission->veng.examinedTorpedoControl = true;
 	} else if (!_awayMission->veng.firedTorpedo)
-		showDescription(21, true);
+		showDescription(TX_VEN2N021);
 	else
-		showDescription(20, true); // Unused, since after firing the torpedo, the mission ends
+		showDescription(TX_VEN2N020); // Unused, since after firing the torpedo, the mission ends
 }
 
 void Room::veng2LookAtImpulseConsole() {
-	showDescription(34, true);
+	showDescription(TX_VEN2N034);
 
 	if (!_awayMission->veng.impulseEnginesOn)
-		showDescription(8, true);
+		showDescription(TX_VEN2N008);
 	else if (_awayMission->veng.tricordersPluggedIntoComputer != 3)
-		showDescription(9, true);
+		showDescription(TX_VEN2N009);
 	else if (_awayMission->veng.poweredSystem == 0)
-		showDescription(9, true);
+		showDescription(TX_VEN2N009);
 	else if (_awayMission->veng.poweredSystem == 1)
-		showDescription(7, true);
+		showDescription(TX_VEN2N007);
 	else if (_awayMission->veng.poweredSystem == 2)
-		showDescription(5, true);
+		showDescription(TX_VEN2N005);
 	else
-		showDescription(6, true);
+		showDescription(TX_VEN2N006);
 }
 
 void Room::veng2LookAtMainComputer() {
 	if (_awayMission->veng.tricordersPluggedIntoComputer == 0)
-		showDescription( 3, true);
+		showDescription(TX_VEN2N003);
 	else if (_awayMission->veng.tricordersPluggedIntoComputer == 1) // Med tricorder plugged in
-		showDescription(23, true);
+		showDescription(TX_VEN2N023);
 	else if (_awayMission->veng.tricordersPluggedIntoComputer == 2) // Sci tricorder plugged in
-		showDescription(27, true);
+		showDescription(TX_VEN2N027);
 	else // Both
-		showDescription(25, true);
+		showDescription(TX_VEN2N025);
 }
 
 void Room::veng2LookAtRecordDeck() {
-	showDescription(29, true);
+	showDescription(TX_VEN2N029);
 }
 
 void Room::veng2LookAtDeckIOConsole() {
-	showDescription(31, true);
+	showDescription(TX_VEN2N031);
 }
 
 void Room::veng2LookAtKirk() {
-	showDescription(10, true);
+	showDescription(TX_VEN2N010);
 }
 
 void Room::veng2LookAtSpock() {
-	showDescription(19, true);
+	showDescription(TX_VEN2N019);
 }
 
 void Room::veng2LookAtMccoy() {
-	showDescription(12, true);
+	showDescription(TX_VEN2N012);
 }
 
 void Room::veng2LookAtRedshirt() {
-	showDescription( 4, true);
+	showDescription(TX_VEN2N004);
 }
 
 void Room::veng2LookAnywhere() {
-	showDescription(35, true);
+	showDescription(TX_VEN2N035);
 }
 
 void Room::veng2TalkToKirk() {
 	if (_awayMission->veng.countdownStarted)
-		showText(TX_SPEAKER_KIRK, 04, true);
+		showText(TX_SPEAKER_KIRK, TX_VEN2_004);
 	else
-		showText(TX_SPEAKER_KIRK, 5, true);
+		showText(TX_SPEAKER_KIRK, TX_VEN2_005);
 }
 
 void Room::veng2TalkToSpock() {
 	if (_awayMission->veng.countdownStarted) {
-		showText(TX_SPEAKER_SPOCK, 75, true);
-		showText(TX_SPEAKER_KIRK,   9, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_075);
+		showText(TX_SPEAKER_KIRK,  TX_VEN2_009);
 	} else
 		showText(TX_SPEAKER_SPOCK, TX_VEN4_017);
 }
 
 void Room::veng2TalkToMccoy() {
 	if (_awayMission->veng.countdownStarted) {
-		showText(TX_SPEAKER_MCCOY, 41, true);
-		showText(TX_SPEAKER_KIRK,   7, true);
+		showText(TX_SPEAKER_MCCOY, TX_VEN2_041);
+		showText(TX_SPEAKER_KIRK,  TX_VEN2_007);
 	} else
-		showText(TX_SPEAKER_MCCOY, 39, true);
+		showText(TX_SPEAKER_MCCOY, TX_VEN2_039);
 }
 
 void Room::veng2TalkToRedshirt() {
 	if (_awayMission->veng.countdownStarted) {
-		showText(TX_SPEAKER_KIJE,  94, true);
-		showText(TX_SPEAKER_SPOCK, 78, true);
+		showText(TX_SPEAKER_KIJE,  TX_VEN2_094);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_078);
 	} else
-		showText(TX_SPEAKER_KIJE, 86, true);
+		showText(TX_SPEAKER_KIJE, TX_VEN2_086);
 }
 
 void Room::veng2UseTechJournalOnDeckIOConsole() {
 	if (_awayMission->veng.readEngineeringJournal)
-		showText(TX_SPEAKER_SPOCK, 46, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_046);
 	else {
 		_awayMission->disableInput = true;
 		walkCrewmanC(OBJECT_SPOCK, 0x112, 0x98, &Room::veng2ReachedDeckIOWithTechJournal);
@@ -470,10 +712,10 @@ void Room::veng2ReachedDeckIOWithTechJournal() {
 
 void Room::veng2DoneReadingTechJournal() {
 	_awayMission->disableInput = false;
-	showText(TX_SPEAKER_SPOCK, 70, true);
-	showText(TX_SPEAKER_MCCOY, 43, true);
-	showText(TX_SPEAKER_KIRK,  17, true);
-	showText(TX_SPEAKER_SPOCK, 81, true);
+	showText(TX_SPEAKER_SPOCK, TX_VEN2_070);
+	showText(TX_SPEAKER_MCCOY, TX_VEN2_043);
+	showText(TX_SPEAKER_KIRK,  TX_VEN2_017);
+	showText(TX_SPEAKER_SPOCK, TX_VEN2_081);
 	_awayMission->veng.readEngineeringJournal = true;
 }
 
@@ -492,73 +734,73 @@ void Room::veng2LoadedLog() {
 	_awayMission->veng.captainsLogIndex++;
 
 	if (_awayMission->veng.captainsLogIndex == 1)
-		showText(TX_SPEAKER_PATTERSON, 82, true);
+		showText(TX_SPEAKER_PATTERSON, TX_VEN2_082);
 	else if (_awayMission->veng.captainsLogIndex == 2)
-		showText(TX_SPEAKER_PATTERSON, 83, true);
+		showText(TX_SPEAKER_PATTERSON, TX_VEN2_083);
 	else if (_awayMission->veng.captainsLogIndex == 3)
-		showText(TX_SPEAKER_PATTERSON, 84, true);
+		showText(TX_SPEAKER_PATTERSON, TX_VEN2_084);
 	else if (_awayMission->veng.captainsLogIndex == 4) {
-		showText(TX_SPEAKER_ANDRADE, 97, true);
+		showText(TX_SPEAKER_ANDRADE, TX_VEN2_097);
 		_awayMission->veng.readAllLogs = true;
-		showText(TX_SPEAKER_SPOCK, 61, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_061);
 	} else
-		showText(TX_SPEAKER_SPOCK, 61, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_061);
 }
 
 void Room::veng2UseCommunicator() {
 	if (_awayMission->veng.toldElasiToBeamOver)
-		showText(TX_SPEAKER_ELASI_CAPTAIN, 98, true);
+		showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_098);
 	else if (_awayMission->veng.countdownStarted) {
 		const TextRef choices[] = {
 			TX_SPEAKER_KIRK,
 			TX_VEN2_HAIL_ELASI, TX_VEN2_HAIL_ENT, TX_VEN2_CANCEL,
-			TX_BLANK
+			TX_END
 		};
 		int choice = showMultipleTexts(choices);
 
 		if (choice == 0) { // Hail Elasi
 			if (!_awayMission->veng.torpedoLoaded)
-				showText(TX_SPEAKER_MCCOY, 40, true);
+				showText(TX_SPEAKER_MCCOY, TX_VEN2_040);
 			else {
 				loadActorAnim2(OBJECT_VIEWSCREEN, "s7r2p1", VIEWSCREEN_X, VIEWSCREEN_Y);
-				showText(TX_SPEAKER_ELASI_CAPTAIN, 108, true);
+				showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_108);
 
 				const TextRef choices2[] = {
 					TX_SPEAKER_KIRK,
-					15, 29,
-					TX_BLANK
+					TX_VEN2_015, TX_VEN2_029,
+					TX_END
 				};
-				choice = showMultipleTexts(choices2, true);
+				choice = showMultipleTexts(choices2);
 
 				if (choice == 0) { // "We don't have it yet"
-					showText(TX_SPEAKER_ELASI_CAPTAIN, 100, true);
+					showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_100);
 					loadActorAnim2(OBJECT_VIEWSCREEN, "s7r2u2", VIEWSCREEN_X, VIEWSCREEN_Y);
 				} else { // "You'll have to beam over"
-					showText(TX_SPEAKER_ELASI_CAPTAIN, 114, true);
-					showText(TX_SPEAKER_KIRK, 25, true);
+					showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_114);
+					showText(TX_SPEAKER_KIRK, TX_VEN2_025);
 					loadActorAnim2(OBJECT_VIEWSCREEN, "s7r2u2", VIEWSCREEN_X, VIEWSCREEN_Y);
 					_awayMission->veng.counterUntilElasiNagToDisableShields = 1800;
 					_awayMission->veng.toldElasiToBeamOver = true;
 				}
 			}
 		} else if (choice == 1) // Hail enterprise
-			showText(TX_SPEAKER_SPOCK, 66, true);
+			showText(TX_SPEAKER_SPOCK, TX_VEN2_066);
 	} else if (_awayMission->veng.elasiShipDecloaked) {
-		showText(TX_SPEAKER_SPOCK, 66, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_066);
 	} else {
 		showText(TX_SPEAKER_KIRK,  TX_MUD4_018);
 		showText(TX_SPEAKER_UHURA, TX_VEN2U093);
-		showText(TX_SPEAKER_KIRK,  28, true);
+		showText(TX_SPEAKER_KIRK,  TX_VEN2_028);
 	}
 }
 
 void Room::veng2UseKirkOnTorpedoButton() {
 	if (_awayMission->veng.poweredSystem != 1)
-		showDescription(28, true);
+		showDescription(TX_VEN2N028);
 	else if (!_awayMission->veng.torpedoLoaded)
-		showText(TX_SPEAKER_SPOCK, 58, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_058);
 	else if (!_awayMission->veng.elasiShieldsDown)
-		showText(TX_SPEAKER_SPOCK, 54, true); // Probably unused; weapons can't be powered while elasi shields are up?
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_054); // Probably unused; weapons can't be powered while elasi shields are up?
 	else { // Fire on the defenseless Elasi
 		_awayMission->disableInput = true;
 		walkCrewmanC(OBJECT_KIRK, 0x90, 0x95, &Room::veng2UseKirkReachedTorpedoButton);
@@ -577,21 +819,21 @@ void Room::veng2KirkFiredTorpedo() {
 
 void Room::veng2TorpedoStruckElasiShip() {
 	loadActorAnim2(OBJECT_VIEWSCREEN, "s7r2p1", VIEWSCREEN_X, VIEWSCREEN_Y);
-	showText(TX_SPEAKER_ELASI_CAPTAIN, 104, true);
-	showText(TX_SPEAKER_ELASI_WEAPONS_MASTER, 29 + FOLLOWUP_MESSAGE_OFFSET, true);
-	showText(TX_SPEAKER_ELASI_CREWMAN, 28 + FOLLOWUP_MESSAGE_OFFSET, true);
-	showText(TX_SPEAKER_ELASI_CAPTAIN, 101, true);
-	showText(TX_SPEAKER_KIRK, 14, true);
-	showText(TX_SPEAKER_ELASI_CAPTAIN, 106, true);
+	showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_104);
+	showText(TX_SPEAKER_ELASI_WEAPONS_MASTER, TX_VEN2_F29);
+	showText(TX_SPEAKER_ELASI_CREWMAN, TX_VEN2_F28);
+	showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_101);
+	showText(TX_SPEAKER_KIRK, TX_VEN2_014);
+	showText(TX_SPEAKER_ELASI_CAPTAIN, TX_VEN2_106);
 	loadActorAnimC(OBJECT_VIEWSCREEN, "s7r2rc", 0, 0, &Room::veng2ElasiRetreated);
 }
 
 void Room::veng2ElasiRetreated() {
-	showText(TX_SPEAKER_UHURA,  94, true);
-	showText(TX_SPEAKER_KIRK,   26, true);
-	showText(TX_SPEAKER_CHEKOV, 115, true);
-	showText(TX_SPEAKER_KIRK,   13, true);
-	showText(TX_SPEAKER_SCOTT,  9 + SCOTTY_MESSAGE_OFFSET, true);
+	showText(TX_SPEAKER_UHURA,  TX_VEN2U094);
+	showText(TX_SPEAKER_KIRK,   TX_VEN2_026);
+	showText(TX_SPEAKER_CHEKOV, TX_VEN2_115);
+	showText(TX_SPEAKER_KIRK,   TX_VEN2_013);
+	showText(TX_SPEAKER_SCOTT,  TX_VEN2_S09);
 	_awayMission->veng.firedTorpedo = true;
 
 	walkCrewmanC(OBJECT_KIRK,     0xec,  0x9d, &Room::veng2CrewmanInPositionToBeamOut);
@@ -619,51 +861,51 @@ void Room::veng2CrewmanInPositionToBeamOut() {
 }
 
 void Room::veng2UseSTricorderOnTorpedoButton() {
-	spockScan(DIR_N, 35 + FOLLOWUP_MESSAGE_OFFSET, true); // ENHANCEMENT: Use spockScan (don't just show text)
+	spockScan(DIR_N, TX_SPEAKER_SPOCK, TX_VEN2_F35); // ENHANCEMENT: Use spockScan (don't just show text)
 }
 
 void Room::veng2UseSTricorderOnMiddleConsole() {
-	spockScan(DIR_N, -1);
-	showDescription(30, true); // This is a narration, not Spock speaking
+	spockScan(DIR_N, TX_SPEAKER_SPOCK, -1);
+	showDescription(TX_VEN2N030); // This is a narration, not Spock speaking
 }
 
 void Room::veng2UseSTricorderOnTorpedoControl() {
-	showText(TX_SPEAKER_KIRK, 01, true);
-	spockScan(DIR_N, -1); // FIXME: delete this since Spock might not have his tricorder?
+	showText(TX_SPEAKER_KIRK, TX_VEN2_001);
+	spockScan(DIR_N, TX_SPEAKER_SPOCK, -1); // FIXME: delete this since Spock might not have his tricorder?
 
 	if (_awayMission->veng.poweredSystem != 1) { // No power to weapons
 		if (!_awayMission->veng.scannedMainComputer)
-			showText(TX_SPEAKER_SPOCK, 62, true);
+			showText(TX_SPEAKER_SPOCK, TX_VEN2_062);
 		else
-			showText(TX_SPEAKER_SPOCK, 64, true);
+			showText(TX_SPEAKER_SPOCK, TX_VEN2_064);
 	} else if (_awayMission->veng.tricordersPluggedIntoComputer != 3)
-		showText(TX_SPEAKER_SPOCK, 55, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_055);
 #if 0
 	// FIXME: Unused, since the same condition is above. Fix needed?
 	else if (_awayMission->veng.poweredSystem != 1)
-		showText(TX_SPEAKER_SPOCK, 65, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_065);
 #endif
 	else if (!_awayMission->veng.torpedoLoaded) {
-		showText(TX_SPEAKER_SPOCK, 68, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_068);
 		if (!_awayMission->veng.elasiShipDecloaked)
-			showText(TX_SPEAKER_SPOCK, 36, true);
+			showText(TX_SPEAKER_SPOCK, TX_VEN2_036);
 		else
-			showText(TX_SPEAKER_SPOCK, 37, true);
+			showText(TX_SPEAKER_SPOCK, TX_VEN2_037);
 		_awayMission->veng.examinedTorpedoControl = true;
 		// TODO: consider making it easier to trigger the above flag? (using spock on it
 		// won't work once the elasi are there, since you can't power the system; you need
 		// to look at it instead.)
 	} else
-		showText(TX_SPEAKER_SPOCK, 50, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_050);
 }
 
 void Room::veng2UseImpulseConsole() {
 	if (!_awayMission->veng.impulseEnginesOn) {
-		showText(TX_SPEAKER_KIRK,   3, true);
-		showText(TX_SPEAKER_SPOCK, 63, true);
+		showText(TX_SPEAKER_KIRK,  TX_VEN2_003);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_063);
 	} else if (_awayMission->veng.tricordersPluggedIntoComputer != 3) {
-		showText(TX_SPEAKER_KIRK,   3, true);
-		showText(TX_SPEAKER_SPOCK, 57, true);
+		showText(TX_SPEAKER_KIRK,  TX_VEN2_003);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_057);
 	} else {
 		_awayMission->disableInput = true;
 		walkCrewmanC(OBJECT_SPOCK, 0x22, 0x9b, &Room::veng2SpockReachedImpulseConsole);
@@ -674,72 +916,75 @@ void Room::veng2SpockReachedImpulseConsole() {
 	loadActorAnimC(OBJECT_SPOCK, "susemn", -1, -1, &Room::veng2SpockUsedImpulseConsole);
 }
 
+void Room::veng2PowerWeapons() {
+	if (_awayMission->veng.poweredSystem == 2) {
+		playVoc("LD6BMOFF");
+		loadActorAnim2(OBJECT_DAMAGE_DISPLAY_1, "s7r2sh3", DAMAGE_DISPLAY_1_X, DAMAGE_DISPLAY_1_Y);
+	}
+	_awayMission->veng.poweredSystem = 1;
+	showText(TX_SPEAKER_KIJE, TX_VEN2_088);
+	if (_awayMission->veng.toldElasiToBeamOver) {
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_052);
+		_awayMission->veng.elasiShieldsDown = true;
+		_awayMission->veng.counterUntilElasiBoardWithInvitation = 900;
+	}
+	if (_awayMission->veng.elasiShipDecloaked && !_awayMission->veng.elasiHailedRepublic) {
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_033);
+		_awayMission->veng.counterUntilElasiBoardWithShieldsDown = 1800;
+	}
+}
+
 void Room::veng2SpockUsedImpulseConsole() {
 	_awayMission->disableInput = false;
-	showText(TX_SPEAKER_SPOCK, 69, true);
+	showText(TX_SPEAKER_SPOCK, TX_VEN2_069);
 
 	// Choose where to transfer power
 	const TextRef choices[] = {
-		TX_NULL,
+		TX_EMPTY,
 		TX_VEN2_WEA, TX_VEN2_SHI, TX_VEN2_TRA,
-		TX_BLANK
+		TX_END
 	};
 	int choice = showMultipleTexts(choices);
 
 	if (choice == 0) { // Weapons
-		if (_awayMission->veng.toldElasiToBeamOver) {
-powerWeapons:
-			if (_awayMission->veng.poweredSystem == 2) {
-				playVoc("LD6BMOFF");
-				loadActorAnim2(OBJECT_DAMAGE_DISPLAY_1, "s7r2sh3", DAMAGE_DISPLAY_1_X, DAMAGE_DISPLAY_1_Y);
-			}
-			_awayMission->veng.poweredSystem = 1;
-			showText(TX_SPEAKER_KIJE, 88, true);
-			if (_awayMission->veng.toldElasiToBeamOver) {
-				showText(TX_SPEAKER_SPOCK, 52, true);
-				_awayMission->veng.elasiShieldsDown = true;
-				_awayMission->veng.counterUntilElasiBoardWithInvitation = 900;
-			}
-			if (_awayMission->veng.elasiShipDecloaked && !_awayMission->veng.elasiHailedRepublic) {
-				showText(TX_SPEAKER_SPOCK, 33, true);
-				_awayMission->veng.counterUntilElasiBoardWithShieldsDown = 1800;
-			}
-		} else if (_awayMission->veng.countdownStarted)
-			showText(TX_SPEAKER_SPOCK, 35, true);
+		if (_awayMission->veng.toldElasiToBeamOver)
+			veng2PowerWeapons();
+		else if (_awayMission->veng.countdownStarted)
+			showText(TX_SPEAKER_SPOCK, TX_VEN2_035);
 		else if (_awayMission->veng.poweredSystem == 1) // Weapons already powered
-			showText(TX_SPEAKER_KIJE, 91, true);
+			showText(TX_SPEAKER_KIJE, TX_VEN2_091);
 		else
-			goto powerWeapons;
+			veng2PowerWeapons();
 	} else if (choice == 1) { // Shields
 		if (_awayMission->veng.poweredSystem == 2) // Shields already powered
-			showText(TX_SPEAKER_KIJE, 89, true);
+			showText(TX_SPEAKER_KIJE, TX_VEN2_089);
 		else if (_awayMission->veng.toldElasiToBeamOver)
-			showText(TX_SPEAKER_KIJE, 85, true);
+			showText(TX_SPEAKER_KIJE, TX_VEN2_085);
 		else {
 			loadActorAnim2(OBJECT_DAMAGE_DISPLAY_1, "s7r2sh", DAMAGE_DISPLAY_1_X, DAMAGE_DISPLAY_1_Y);
 			_awayMission->veng.poweredSystem = 2;
 			if (_awayMission->veng.elasiShipDecloaked)
 				_awayMission->timers[2] = 45; // Timer until the elasi hail the ship
-			showText(TX_SPEAKER_KIJE, 92, true);
+			showText(TX_SPEAKER_KIJE, TX_VEN2_092);
 		}
 	} else if (choice == 2) { // Transporter
 		if (_awayMission->veng.countdownStarted) {
-			showText(TX_SPEAKER_SPOCK, 34, true);
+			showText(TX_SPEAKER_SPOCK, TX_VEN2_034);
 			if (_awayMission->veng.havePowerPack) {
-				showText(TX_SPEAKER_KIRK,  18, true);
-				showText(TX_SPEAKER_SPOCK, 77, true);
+				showText(TX_SPEAKER_KIRK,  TX_VEN2_018);
+				showText(TX_SPEAKER_SPOCK, TX_VEN2_077);
 			}
 		} else if (_awayMission->veng.poweredSystem == 3) // Transporter already powered
-			showText(TX_SPEAKER_KIJE, 90, true); // BUGFIX: audio didn't play properly
+			showText(TX_SPEAKER_KIJE, TX_VEN2_090); // BUGFIX: audio didn't play properly
 		else {
 			if (_awayMission->veng.poweredSystem == 2) {
 				playVoc("LD6BMOFF"); // ENHANCEMENT: make this consistent with the weapons code
 				loadActorAnim2(OBJECT_DAMAGE_DISPLAY_1, "s7r2sh3", DAMAGE_DISPLAY_1_X, DAMAGE_DISPLAY_1_Y);
 			}
 			_awayMission->veng.poweredSystem = 3;
-			showText(TX_SPEAKER_KIJE, 87, true);
+			showText(TX_SPEAKER_KIJE, TX_VEN2_087);
 			if (_awayMission->veng.elasiShipDecloaked && !_awayMission->veng.elasiHailedRepublic) {
-				showText(TX_SPEAKER_SPOCK, 71, true);
+				showText(TX_SPEAKER_SPOCK, TX_VEN2_071);
 				_awayMission->veng.counterUntilElasiBoardWithShieldsDown = 1800;
 			}
 		}
@@ -748,24 +993,24 @@ powerWeapons:
 }
 
 void Room::veng2UseMainComputer() {
-	showText(TX_SPEAKER_KIRK, 02, true);
+	showText(TX_SPEAKER_KIRK, TX_VEN2_002);
 	if (_awayMission->veng.tricordersPluggedIntoComputer != 3) {
-		spockScan(DIR_W, 79, true);
-		showText(TX_SPEAKER_KIRK,  24, true);
-		showText(TX_SPEAKER_SPOCK, 80, true);
-		showText(TX_SPEAKER_MCCOY, 45, true);
-		showText(TX_SPEAKER_SPOCK, 74, true);
-		showText(TX_SPEAKER_KIJE,  96, true);
+		spockScan(DIR_W, TX_SPEAKER_SPOCK, TX_VEN2_079);
+		showText(TX_SPEAKER_KIRK,  TX_VEN2_024);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_080);
+		showText(TX_SPEAKER_MCCOY, TX_VEN2_045);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_074);
+		showText(TX_SPEAKER_KIJE,  TX_VEN2_096);
 		_awayMission->veng.scannedMainComputer = true;
 	} else
-		showText(TX_SPEAKER_SPOCK, 59, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_059);
 }
 
 void Room::veng2UseSTricorderOnMainComputer() {
 	if (!_awayMission->veng.scannedMainComputer)
 		veng2UseMainComputer();
 	else if (!_awayMission->veng.impulseEnginesOn)
-		showText(TX_SPEAKER_SPOCK, 31, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_031);
 	else {
 		_awayMission->disableInput = true;
 		walkCrewmanC(OBJECT_SPOCK, 0x52, 0x84, &Room::veng2SpockReachedMainComputerToPutTricorder);
@@ -789,7 +1034,7 @@ void Room::veng2AttachedSTricorderToComputer() {
 	loseItem(OBJECT_ISTRICOR);
 	loadActorAnim2(OBJECT_STRICORDER, "s7r2t1", STRICORDER_POS_X, STRICORDER_POS_Y);
 
-	showDescription(17, true);
+	showDescription(TX_VEN2N017);
 
 	walkCrewman(OBJECT_SPOCK, 0x5f, 0xaa);
 	if (_awayMission->veng.tricordersPluggedIntoComputer == 3) // Both tricorders plugged in
@@ -798,7 +1043,7 @@ void Room::veng2AttachedSTricorderToComputer() {
 
 void Room::veng2UseMTricorderOnMainComputer() {
 	if (!_awayMission->veng.impulseEnginesOn)
-		showText(TX_SPEAKER_MCCOY, 38, true);
+		showText(TX_SPEAKER_MCCOY, TX_VEN2_038);
 	else {
 		_awayMission->disableInput = true;
 		walkCrewmanC(OBJECT_SPOCK, 0x52, 0x84, &Room::veng2MccoyReachedMainComputerToPutTricorder);
@@ -822,7 +1067,7 @@ void Room::veng2AttachedMTricorderToComputer() {
 	loseItem(OBJECT_IMTRICOR);
 	loadActorAnim2(OBJECT_MTRICORDER, "s7r2t2", MTRICORDER_POS_X, MTRICORDER_POS_Y);
 
-	showDescription(16, true);
+	showDescription(TX_VEN2N016);
 
 	walkCrewman(OBJECT_SPOCK, 0x5f, 0xaa);
 	if (_awayMission->veng.tricordersPluggedIntoComputer == 3) // Both tricorders plugged in
@@ -831,22 +1076,22 @@ void Room::veng2AttachedMTricorderToComputer() {
 
 void Room::veng2BothTricordersPluggedIn() {
 	loadActorAnim2(OBJECT_MAIN_COMPUTER, "s7r2t3", MAIN_COMPUTER_X, MAIN_COMPUTER_Y);
-	showText(TX_SPEAKER_SPOCK, 30, true);
+	showText(TX_SPEAKER_SPOCK, TX_VEN2_030);
 }
 
 void Room::veng2UseSTricorderOnDeckIOConsole() {
-	spockScan(DIR_E, 67, true);
+	spockScan(DIR_E, TX_SPEAKER_SPOCK, TX_VEN2_067);
 }
 
 void Room::veng2UseSTricorderOnImpulseConsole() {
 	if (!_awayMission->veng.impulseEnginesOn)
-		spockScan(DIR_W, 56, true);
+		spockScan(DIR_W, TX_SPEAKER_SPOCK, TX_VEN2_056);
 	else
-		spockScan(DIR_W, 51, true);
+		spockScan(DIR_W, TX_SPEAKER_SPOCK, TX_VEN2_051);
 }
 
 void Room::veng2UseFusionPackOnMainComputer() {
-	showText(TX_SPEAKER_SPOCK, 60, true);
+	showText(TX_SPEAKER_SPOCK, TX_VEN2_060);
 }
 
 void Room::veng2GetLogDeck() {
@@ -862,13 +1107,13 @@ void Room::veng2PickedUpLogDeck() {
 	loadActorStandAnim(OBJECT_DECK);
 	_awayMission->disableInput = false;
 	_awayMission->veng.tookRecordDeckFromAuxilaryControl = true;
-	showDescription(39, true);
+	showDescription(TX_VEN2N039);
 	giveItem(OBJECT_IDECK);
 }
 
 void Room::veng2GetSTricorder() {
 	if (_awayMission->veng.countdownStarted)
-		showText(TX_SPEAKER_SPOCK, 47, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_047);
 	else {
 		_awayMission->disableInput = true;
 		walkCrewmanC(OBJECT_SPOCK, 0x52, 0x84, &Room::veng2ReachedSTricorderToGet);
@@ -886,12 +1131,12 @@ void Room::veng2PickedUpSTricorder() {
 	loadActorStandAnim(OBJECT_STRICORDER);
 	loadActorStandAnim(OBJECT_MAIN_COMPUTER);
 	walkCrewman(OBJECT_SPOCK, 0x5f, 0xaa);
-	showDescription(15, true);
+	showDescription(TX_VEN2N015);
 }
 
 void Room::veng2GetMTricorder() {
 	if (_awayMission->veng.countdownStarted)
-		showText(TX_SPEAKER_SPOCK, 47, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN2_047);
 	else {
 		_awayMission->disableInput = true;
 		walkCrewmanC(OBJECT_SPOCK, 0x52, 0x84, &Room::veng2ReachedMTricorderToGet);
@@ -909,7 +1154,7 @@ void Room::veng2PickedUpMTricorder() {
 	loadActorStandAnim(OBJECT_MTRICORDER);
 	loadActorStandAnim(OBJECT_MAIN_COMPUTER);
 	walkCrewman(OBJECT_SPOCK, 0x5f, 0xaa);
-	showDescription(13, true);
+	showDescription(TX_VEN2N013);
 }
 
 }
