@@ -129,10 +129,103 @@ extern const RoomAction veng6ActionList[] = {
 
 	// ENHANCEMENT
 	{ {ACTION_USE, OBJECT_ISTRICOR, OBJECT_IMPULSE_ENGINES, 0}, &Room::veng6UseSTricorderOnImpulseEngines },
+	{ {ACTION_LIST_END, 0, 0, 0}, nullptr }
 };
 
-extern const int veng6NumActions = ARRAYSIZE(veng6ActionList);
+enum veng6TextIds {
+	TX_SPEAKER_KIRK, TX_SPEAKER_MCCOY, TX_SPEAKER_SPOCK, TX_SPEAKER_KIJE, TX_SPEAKER_COMPUTER,
+	TX_BRIDU146, TX_COMPA185, TX_DEM3_019, TX_MUD1N014, TX_MUD4_018,
+	TX_VEN0N016, TX_VEN0_016, TX_VEN2U093, TX_VEN2_028,
+	TX_VEN2_066, TX_VEN2_098, TX_VEN4N010, TX_VEN4_016, TX_VEN5N007,
+	TX_VEN6N000, TX_VEN6N001, TX_VEN6N002, TX_VEN6N003, TX_VEN6N005,
+	TX_VEN6N006, TX_VEN6N007, TX_VEN6N008, TX_VEN6N009, TX_VEN6N010,
+	TX_VEN6N011, TX_VEN6N012, TX_VEN6N013, TX_VEN6N015, TX_VEN6N016,
+	TX_VEN6N017, TX_VEN6N018, TX_VEN6N019, TX_VEN6N020, TX_VEN6N022,
+	TX_VEN6N024, TX_VEN6N025, TX_VEN6_001, TX_VEN6_002, TX_VEN6_003,
+	TX_VEN6_005, TX_VEN6_006, TX_VEN6_007, TX_VEN6_008, TX_VEN6_009,
+	TX_VEN6_010, TX_VEN6_011, TX_VEN6_012, TX_VEN6_013, TX_VEN6_014,
+	TX_VEN6_015, TX_VEN6_016, TX_VEN6_017, TX_VEN6_018, TX_VEN6_019,
+	TX_VEN6_020, TX_VEN6_021, TX_VEN6_022, TX_VEN6_023, TX_VENA_F32,
+	TX_VENA_F34, TX_VENA_F40
+};
 
+// TODO: Finish floppy offsets
+extern const RoomTextOffsets veng6TextOffsets[] = {
+	{ TX_SPEAKER_KIRK, 8894, 0 },
+	{ TX_SPEAKER_MCCOY, 8905, 0 },
+	{ TX_SPEAKER_SPOCK, 8915, 0 },
+	{ TX_SPEAKER_KIJE, 8925, 0 },
+	{ TX_SPEAKER_COMPUTER, 8937, 0 },
+	{ TX_BRIDU146, 7831, 0 },
+	{ TX_COMPA185, 4008, 0 },
+	{ TX_DEM3_019, 8315, 0 },
+	{ TX_MUD1N014, 6550, 0 },
+	{ TX_MUD4_018, 7762, 0 },
+	//{ TX_MUD4_018, 7895, 0 },	// Skip duplicate text
+	{ TX_VEN0N016, 2156, 0 },
+	{ TX_VEN0_016, 8552, 0 },
+	//{ TX_VEN0_016, 8611, 0 },	// Skip duplicate text
+	{ TX_VEN2U093, 7963, 0 },
+	{ TX_VEN2_028, 8070, 0 },
+	{ TX_VEN2_066, 8148, 0 },
+	{ TX_VEN2_098, 6958, 0 },
+	{ TX_VEN4N010, 7612, 0 },
+	{ TX_VEN4_016, 8366, 0 },
+	{ TX_VEN5N007, 775, 0 },
+	{ TX_VEN6N000, 2099, 0 },
+	{ TX_VEN6N001, 1781, 0 },
+	{ TX_VEN6N002, 1999, 0 },
+	{ TX_VEN6N003, 1873, 0 },
+	{ TX_VEN6N005, 5276, 0 },
+	{ TX_VEN6N006, 4887, 0 },
+	{ TX_VEN6N007, 4998, 0 },
+	{ TX_VEN6N007, 7677, 0 },
+	{ TX_VEN6N008, 6615, 0 },
+	{ TX_VEN6N009, 1334, 0 },
+	{ TX_VEN6N010, 1253, 0 },
+	{ TX_VEN6N011, 845, 0 },
+	{ TX_VEN6N012, 1425, 0 },
+	{ TX_VEN6N013, 1052, 0 },
+	{ TX_VEN6N015, 976, 0 },
+	{ TX_VEN6N016, 8975, 0 },
+	{ TX_VEN6N018, 9063, 0 },
+	{ TX_VEN6N017, 1139, 0 },
+	{ TX_VEN6N019, 2207, 0 },
+	{ TX_VEN6N020, 3318, 0 },
+	{ TX_VEN6N022, 3710, 0 },
+	{ TX_VEN6N024, 6803, 0 },
+	{ TX_VEN6N025, 1536, 0 },
+	{ TX_VEN6_001, 5699, 0 },
+	{ TX_VEN6_002, 4457, 0 },
+	{ TX_VEN6_003, 4062, 0 },
+	{ TX_VEN6_005, 2298, 0 },
+	{ TX_VEN6_006, 6407, 0 },
+	{ TX_VEN6_007, 5830, 0 },
+	{ TX_VEN6_008, 2674, 0 },
+	{ TX_VEN6_009, 2457, 0 },
+	{ TX_VEN6_010, 5433, 0 },
+	{ TX_VEN6_011, 4737, 0 },
+	{ TX_VEN6_012, 3881, 0 },
+	{ TX_VEN6_013, 5972, 0 },
+	{ TX_VEN6_014, 2534, 0 },
+	{ TX_VEN6_015, 6196, 0 },
+	{ TX_VEN6_016, 4297, 0 },
+	{ TX_VEN6_017, 4105, 0 },
+	{ TX_VEN6_018, 2781, 0 },
+	{ TX_VEN6_019, 4596, 0 },
+	{ TX_VEN6_020, 5500, 0 },
+	{ TX_VEN6_021, 1616, 0 },
+	{ TX_VEN6_022, 9197, 0 },
+	{ TX_VEN6_023, 2954, 0 },
+	{ TX_VENA_F32, 7188, 0 },
+	{ TX_VENA_F34, 7458, 0 },
+	{ TX_VENA_F40, 7053, 0 },
+	{          -1, 0,    0 }
+};
+
+extern const RoomText veng6Texts[] = {
+	  { -1, Common::UNK_LANG, "" }
+};
 
 #define DOOR_X 0x13e
 #define DOOR_Y 0xa8
@@ -180,7 +273,7 @@ void Room::veng6WalkToDoor() {
 
 void Room::veng6ReachedDoor() {
 	_awayMission->disableInput = true;
-	playSoundEffectIndex(SND_DOOR1);
+	playSoundEffectIndex(kSfxDoor);
 	loadActorAnimC(OBJECT_DOOR, "s7r6d1", DOOR_X, DOOR_Y, &Room::veng6DoorOpened);
 }
 
@@ -189,11 +282,11 @@ void Room::veng6DoorOpened() {
 }
 
 void Room::veng6LookAtLeftPort() {
-	showDescription(18, true);
+	showDescription(TX_VEN6N018);
 }
 
 void Room::veng6LookAtRightPort() {
-	showDescription(16, true);
+	showDescription(TX_VEN6N016);
 }
 
 void Room::veng6LookAtDoor() {
@@ -201,52 +294,52 @@ void Room::veng6LookAtDoor() {
 }
 
 void Room::veng6LookAtOilCanister() {
-	showDescription(11, true);
+	showDescription(TX_VEN6N011);
 }
 
 void Room::veng6LookAtCabinet() {
-	showDescription(15, true);
+	showDescription(TX_VEN6N015);
 }
 
 void Room::veng6LookAtCable() {
-	showDescription(13, true);
+	showDescription(TX_VEN6N013);
 }
 
 void Room::veng6LookAtRightConsole() {
-	showDescription(17, true);
+	showDescription(TX_VEN6N017);
 }
 
 void Room::veng6LookAtImpulseEngines() {
-	showDescription(10, true);
+	showDescription(TX_VEN6N010);
 }
 
 void Room::veng6LookAtLeftConsole() {
-	showDescription(9, true);
+	showDescription(TX_VEN6N009);
 }
 
 void Room::veng6LookAtJunctionBox() {
-	showDescription(12, true);
+	showDescription(TX_VEN6N012);
 }
 
 void Room::veng6LookAtJournal() {
-	showDescription(25, true);
-	showText(TX_SPEAKER_SPOCK, 21, true);
+	showDescription(TX_VEN6N025);
+	showText(TX_SPEAKER_SPOCK, TX_VEN6_021);
 }
 
 void Room::veng6LookAtKirk() {
-	showDescription(1, true);
+	showDescription(TX_VEN6N001);
 }
 
 void Room::veng6LookAtSpock() {
-	showDescription(3, true);
+	showDescription(TX_VEN6N003);
 }
 
 void Room::veng6LookAtMccoy() {
-	showDescription(2, true);
+	showDescription(TX_VEN6N002);
 }
 
 void Room::veng6LookAtRedshirt() {
-	showDescription(0, true);
+	showDescription(TX_VEN6N000);
 }
 
 void Room::veng6LookAtDeadGuy() {
@@ -254,25 +347,25 @@ void Room::veng6LookAtDeadGuy() {
 }
 
 void Room::veng6LookAnywhere() {
-	showDescription(19, true);
+	showDescription(TX_VEN6N019);
 }
 
 void Room::veng6TalkToKirk() {
-	showText(TX_SPEAKER_KIRK,   5, true);
-	showText(TX_SPEAKER_MCCOY,  9, true);
+	showText(TX_SPEAKER_KIRK,  TX_VEN6_005);
+	showText(TX_SPEAKER_MCCOY, TX_VEN6_009);
 }
 
 void Room::veng6TalkToSpock() {
-	showText(TX_SPEAKER_SPOCK, 14, true);
+	showText(TX_SPEAKER_SPOCK, TX_VEN6_014);
 }
 
 void Room::veng6TalkToMccoy() {
-	showText(TX_SPEAKER_MCCOY,  8, true);
-	showText(TX_SPEAKER_SPOCK, 18, true);
+	showText(TX_SPEAKER_MCCOY, TX_VEN6_008);
+	showText(TX_SPEAKER_SPOCK, TX_VEN6_018);
 }
 
 void Room::veng6TalkToRedshirt() {
-	showText(TX_SPEAKER_KIJE, 23, true);
+	showText(TX_SPEAKER_KIJE, TX_VEN6_023);
 }
 
 void Room::veng6UseCable1OnLeftPort() {
@@ -303,7 +396,7 @@ void Room::veng6KirkOrSpockReachedLeftPort() {
 
 void Room::veng6AttachedLeftCable() {
 	loadActorAnim(OBJECT_CABLE_1, "s7r6cl", CABLE_1_X, CABLE_1_Y);
-	showDescription(20, true);
+	showDescription(TX_VEN6N020);
 	_awayMission->veng.junctionCablesConnected |= 1;
 	loseItem(_roomVar.veng.cableInUse);
 	_awayMission->disableInput = false;
@@ -337,7 +430,7 @@ void Room::veng6KirkOrSpockReachedRightPort() {
 
 void Room::veng6AttachedRightCable() {
 	loadActorAnim(OBJECT_CABLE_2, "s7r6cr", CABLE_2_X, CABLE_2_Y);
-	showDescription(22, true);
+	showDescription(TX_VEN6N022);
 	_awayMission->veng.junctionCablesConnected |= 2;
 	loseItem(_roomVar.veng.cableInUse);
 	_awayMission->disableInput = false;
@@ -345,19 +438,19 @@ void Room::veng6AttachedRightCable() {
 
 void Room::veng6UseCrewmanOnJunctionBox() {
 	if (_awayMission->veng.impulseEnginesOn)
-		showText(TX_SPEAKER_SPOCK, 12, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN6_012);
 	else if ((_awayMission->veng.junctionCablesConnected & 3) == 3) {
 		showText(TX_SPEAKER_COMPUTER, TX_COMPA185);
-		showText(TX_SPEAKER_KIRK,  3, true);
+		showText(TX_SPEAKER_KIRK, TX_VEN6_003);
 		if (!_awayMission->veng.readEngineeringJournal)
-			showText(TX_SPEAKER_SPOCK, 17, true);
+			showText(TX_SPEAKER_SPOCK, TX_VEN6_017);
 		else {
-			showText(TX_SPEAKER_SPOCK, 16, true);
-			showText(TX_SPEAKER_KIRK,   2, true);
+			showText(TX_SPEAKER_SPOCK, TX_VEN6_016);
+			showText(TX_SPEAKER_KIRK,  TX_VEN6_002);
 			walkCrewmanC(OBJECT_SPOCK, 0x99, 0xb4, &Room::veng6SpockReachedJunctionBox);
 		}
 	} else
-		showText(TX_SPEAKER_SPOCK, 11, true);
+		showText(TX_SPEAKER_SPOCK, TX_VEN6_011);
 }
 
 void Room::veng6SpockReachedJunctionBox() {
@@ -365,7 +458,7 @@ void Room::veng6SpockReachedJunctionBox() {
 }
 
 void Room::veng6SpockAdjustedJunctionBox() {
-	showText(TX_SPEAKER_SPOCK, 19, true);
+	showText(TX_SPEAKER_SPOCK, TX_VEN6_019);
 	loadActorAnim(OBJECT_IMPULSE_ENGINES, "s7r6i1", IMPULSE_ENGINE_X, IMPULSE_ENGINE_Y);
 	_awayMission->veng.impulseEnginesOn = true;
 	stopAllVocSounds();
@@ -374,7 +467,7 @@ void Room::veng6SpockAdjustedJunctionBox() {
 
 void Room::veng6UseHypoOnOilCanister() {
 	if (_awayMission->veng.oilInHypo)
-		showDescription(6, true);
+		showDescription(TX_VEN6N006);
 	else {
 		_awayMission->disableInput = true;
 		walkCrewmanC(OBJECT_KIRK, 0x3c, 0x9e, &Room::veng6ReachedOilCanister);
@@ -387,7 +480,7 @@ void Room::veng6ReachedOilCanister() {
 
 void Room::veng6FilledHypoWithOil() {
 	_awayMission->disableInput = false;
-	showDescription(7, true);
+	showDescription(TX_VEN6N007);
 	_awayMission->veng.oilInHypo = true;
 }
 
@@ -405,40 +498,40 @@ void Room::veng6OpenedOrClosedCabinet() {
 
 	if (_awayMission->veng.engineeringCabinetOpen) {
 		loadActorAnim(OBJECT_CABINET, "s7r6p2", CABINET_X, CABINET_Y);
-		playSoundEffectIndex(SND_DOOR1);
+		playSoundEffectIndex(kSfxDoor);
 		_awayMission->veng.engineeringCabinetOpen = false;
 	} else {
 		loadActorAnim(OBJECT_CABINET, "s7r6p1", CABINET_X, CABINET_Y);
-		playSoundEffectIndex(SND_DOOR1);
+		playSoundEffectIndex(kSfxDoor);
 		_awayMission->veng.engineeringCabinetOpen = true;
 		if (!_awayMission->veng.tookEngineeringJournal)
-			showDescription(5, true);
+			showDescription(TX_VEN6N005);
 	}
 }
 
 void Room::veng6UseSTricorderOnImpulseEngines() {
 	if (_awayMission->veng.impulseEnginesOn)
-		spockScan(DIR_S, 10, false, true);
+		spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_VEN6_010);
 	else {
-		spockScan(DIR_S, 20, false, true);
-		showText(TX_SPEAKER_KIRK,   1, true);
-		showText(TX_SPEAKER_SPOCK, 22, true);
+		spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_VEN6_020);
+		showText(TX_SPEAKER_KIRK,  TX_VEN6_001);
+		showText(TX_SPEAKER_SPOCK, TX_VEN6_022);
 	}
 }
 
 void Room::veng6UseSTricorderOnRightConsole() {
 	if (_awayMission->veng.impulseEnginesOn)
-		spockScan(DIR_S, 13, false, true);
+		spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_VEN6_013);
 	else
-		spockScan(DIR_S,  7, false, true);
+		spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_VEN6_007);
 }
 
 void Room::veng6UseSTricorderOnJunctionBox() {
-	spockScan(DIR_S, 15, false, true);
+	spockScan(DIR_S, TX_SPEAKER_SPOCK, TX_VEN6_015);
 }
 
 void Room::veng6UsePowerPackOnLeftConsole() {
-	showText(TX_SPEAKER_SPOCK,  6, true);
+	showText(TX_SPEAKER_SPOCK, TX_VEN6_006);
 }
 
 void Room::veng6GetJunctionBox() {
@@ -446,7 +539,7 @@ void Room::veng6GetJunctionBox() {
 }
 
 void Room::veng6GetOilCanister() {
-	showDescription(8, true);
+	showDescription(TX_VEN6N008);
 }
 
 void Room::veng6GetEngineeringJournal() {
@@ -461,7 +554,7 @@ void Room::veng6ReachedEngineeringJournal() {
 void Room::veng6TookEngineeringJournal() {
 	loadActorStandAnim(OBJECT_JOURNAL);
 	_awayMission->disableInput = false;
-	showDescription(24, true);
+	showDescription(TX_VEN6N024);
 	_awayMission->veng.tookEngineeringJournal = true;
 	giveItem(OBJECT_ITECH);
 }
