@@ -20,6 +20,7 @@
  *
  */
 
+#include "startrek/resource.h"
 #include "startrek/sound.h"
 
 #include "common/file.h"
@@ -97,6 +98,10 @@ void Sound::playMidiTrack(int track) {
 	if (!_vm->_musicEnabled || !_vm->_musicWorking)
 		return;
 
+	// TODO: Demo music
+	if (_vm->getFeatures() & GF_DEMO)
+		return;
+
 	assert(loadedSoundData != nullptr);
 
 	// Check if a midi slot for this track exists already
@@ -146,6 +151,8 @@ bool Sound::isMidiPlaying() {
 }
 
 void Sound::loadMusicFile(const Common::String &baseSoundName) {
+	bool isDemo = _vm->getFeatures() & GF_DEMO;
+
 	clearAllMidiSlots();
 
 	if (baseSoundName == _loadedMidiFilename)
@@ -153,16 +160,15 @@ void Sound::loadMusicFile(const Common::String &baseSoundName) {
 
 	_loadedMidiFilename = baseSoundName;
 
-	/*
-	if (_vm->getPlatform() == Common::kPlatformAmiga)
-		playAmigaSound(baseSoundName);
-	else if (_vm->getPlatform() == Common::kPlatformMacintosh)
-		playMacSMFSound(baseSoundName);
-	else if (_vm->getFeatures() & GF_DEMO)
-		playSMFSound(baseSoundName);
-	else
-	*/
-	loadPCMusicFile(baseSoundName);
+	if (_vm->getPlatform() == Common::kPlatformDOS && !isDemo) {
+		loadPCMusicFile(baseSoundName);
+	} else if (_vm->getPlatform() == Common::kPlatformDOS && isDemo) {
+		//playSMFSound(baseSoundName);
+	} else if (_vm->getPlatform() == Common::kPlatformAmiga) {
+		//playAmigaSound(baseSoundName);
+	} else if (_vm->getPlatform() == Common::kPlatformMacintosh) {
+		//playMacSMFSound(baseSoundName);
+	}
 }
 
 void Sound::playMidiMusicTracks(int startTrack, int loopTrack) {
@@ -339,6 +345,10 @@ void Sound::playSoundEffectIndex(int index) {
 	}
 }
 
+void Sound::toggleMusic() {
+	setMusicEnabled(!_vm->_musicEnabled);
+}
+
 void Sound::setMusicEnabled(bool enable) {
 	if (!_vm->_musicWorking || _vm->_musicEnabled == enable)
 		return;
@@ -351,6 +361,10 @@ void Sound::setMusicEnabled(bool enable) {
 		clearMidiSlot(0);
 }
 
+void Sound::toggleSfx() {
+	setSfxEnabled(!_vm->_sfxEnabled);
+}
+
 void Sound::setSfxEnabled(bool enable) {
 	if (!_vm->_sfxWorking || _vm->_sfxEnabled == enable)
 		return;
@@ -403,7 +417,7 @@ void Sound::loadPCMusicFile(const Common::String &baseSoundName) {
 	}
 
 	debugC(5, kDebugSound, "Loading midi \'%s\'\n", soundName.c_str());
-	Common::MemoryReadStreamEndian *soundStream = _vm->loadFile(soundName.c_str());
+	Common::MemoryReadStreamEndian *soundStream = _vm->_resource->loadFile(soundName.c_str());
 
 	if (loadedSoundData != nullptr)
 		delete[] loadedSoundData;
