@@ -42,12 +42,13 @@ namespace StarTrek {
 // the rectangle, but ScummVM rects are not. Functions from Trek have been adapted to use
 // ScummVM's rect format. Be wary of off-by-1 errors...
 
-struct Sprite : Common::Serializable {
+class Sprite : Common::Serializable {
+public:
 	Common::Point pos;
 	uint16 drawPriority;
 	uint16 drawPriority2; // If two sprites' drawPriorities are equal, this is checked.
 	Common::String field8;
-	SharedPtr<Bitmap> bitmap;
+	Bitmap *bitmap;
 	uint16 drawMode;
 	uint16 textColor;
 	bool bitmapChanged;
@@ -60,6 +61,7 @@ struct Sprite : Common::Serializable {
 	int16 drawX, drawY;
 
 	Sprite();
+	virtual ~Sprite();
 
 	void setBitmap(Bitmap *b);
 	void setBitmap(Common::MemoryReadStreamEndian *stream);
