@@ -20,16 +20,10 @@
  *
  */
 
-#include "sword1/sword1.h"
-#include "sword1/control.h"
-
 #include "base/plugins.h"
+
 #include "common/fs.h"
 #include "common/gui_options.h"
-#include "common/savefile.h"
-#include "common/system.h"
-#include "graphics/thumbnail.h"
-#include "graphics/surface.h"
 
 #include "engines/metaengine.h"
 
@@ -77,7 +71,7 @@ static const char *const g_filesToCheck[NUM_FILES_TO_CHECK] = { // these files h
 	// the engine needs several more files to work, but checking these should be sufficient
 };
 
-class SwordMetaEngine : public MetaEngine {
+class SwordMetaEngineDetection : public MetaEngineDetection {
 public:
 	const char *getEngineId() const override {
 		return "sword1";
@@ -90,37 +84,12 @@ public:
 		return "Broken Sword: The Shadow of the Templars (C) Revolution";
 	}
 
-	bool hasFeature(MetaEngineFeature f) const override;
 	PlainGameList getSupportedGames() const override;
 	PlainGameDescriptor findGame(const char *gameId) const override;
 	DetectedGames detectGames(const Common::FSList &fslist) const override;
-	SaveStateList listSaves(const char *target) const override;
-	int getMaximumSaveSlot() const override;
-	void removeSaveState(const char *target, int slot) const override;
-	SaveStateDescriptor querySaveMetaInfos(const char *target, int slot) const override;
-
-	Common::Error createInstance(OSystem *syst, Engine **engine) const override;
 };
 
-bool SwordMetaEngine::hasFeature(MetaEngineFeature f) const {
-	return
-	    (f == kSupportsListSaves) ||
-	    (f == kSupportsLoadingDuringStartup) ||
-	    (f == kSupportsDeleteSave) ||
-	    (f == kSavesSupportMetaInfo) ||
-	    (f == kSavesSupportThumbnail) ||
-	    (f == kSavesSupportCreationDate) ||
-	    (f == kSavesSupportPlayTime);
-}
-
-bool Sword1::SwordEngine::hasFeature(EngineFeature f) const {
-	return
-	    (f == kSupportsReturnToLauncher) ||
-	    (f == kSupportsSavingDuringRuntime) ||
-	    (f == kSupportsLoadingDuringRuntime);
-}
-
-PlainGameList SwordMetaEngine::getSupportedGames() const {
+PlainGameList SwordMetaEngineDetection::getSupportedGames() const {
 	PlainGameList games;
 	games.push_back(sword1FullSettings);
 	games.push_back(sword1DemoSettings);
@@ -131,7 +100,7 @@ PlainGameList SwordMetaEngine::getSupportedGames() const {
 	return games;
 }
 
-PlainGameDescriptor SwordMetaEngine::findGame(const char *gameId) const {
+PlainGameDescriptor SwordMetaEngineDetection::findGame(const char *gameId) const {
 	if (0 == scumm_stricmp(gameId, sword1FullSettings.gameId))
 		return sword1FullSettings;
 	if (0 == scumm_stricmp(gameId, sword1DemoSettings.gameId))
@@ -147,24 +116,9 @@ PlainGameDescriptor SwordMetaEngine::findGame(const char *gameId) const {
 	return PlainGameDescriptor::empty();
 }
 
-void Sword1CheckDirectory(const Common::FSList &fslist, bool *filesFound, bool recursion = false) {
+void Sword1CheckDirectory(const Common::FSList &fslist, bool *filesFound) {
 	for (Common::FSList::const_iterator file = fslist.begin(); file != fslist.end(); ++file) {
 		if (!file->isDirectory()) {
-			// The required game data files can be located in the game directory, or in
-			// a subdirectory called "clusters". In the latter case, we don't want to
-			// detect the game in that subdirectory, as this will detect the game twice
-			// when mass add is searching inside a directory. In this case, the first
-			// result (the game directory) will be correct, but the second result (the
-			// clusters subdirectory) will be wrong, as the optional speech, music and
-			// video data files will be ignored. Note that this fix will skip the game
-			// data files if the user has placed them inside a "clusters" subdirectory,
-			// or if he/she points ScummVM directly to the "clusters" directory of the
-			// game CD. Fixes bug #3049346.
-			Common::String directory = file->getParent().getName();
-			directory.toLowercase();
-			if (directory.hasPrefix("clusters") && directory.size() <= 9 && !recursion)
-				continue;
-
 			for (int cnt = 0; cnt < NUM_FILES_TO_CHECK; cnt++)
 				if (scumm_stricmp(file->getName().c_str(), g_filesToCheck[cnt]) == 0)
 					filesFound[cnt] = true;
@@ -173,19 +127,35 @@ void Sword1CheckDirectory(const Common::FSList &fslist, bool *filesFound, bool r
 				if (scumm_stricmp(file->getName().c_str(), g_dirNames[cnt]) == 0) {
 					Common::FSList fslist2;
 					if (file->getChildren(fslist2, Common::FSNode::kListFilesOnly))
-						Sword1CheckDirectory(fslist2, filesFound, true);
+						Sword1CheckDirectory(fslist2, filesFound);
 				}
 		}
 	}
 }
 
-DetectedGames SwordMetaEngine::detectGames(const Common::FSList &fslist) const {
+DetectedGames SwordMetaEngineDetection::detectGames(const Common::FSList &fslist) const {
 	int i, j;
 	DetectedGames detectedGames;
 	bool filesFound[NUM_FILES_TO_CHECK];
 	for (i = 0; i < NUM_FILES_TO_CHECK; i++)
 		filesFound[i] = false;
 
+	// The required game data files can be located in the game directory, or in
+	// a subdirectory called "clusters". In the latter case, we don't want to
+	// detect the game in that subdirectory, as this will detect the game twice
+	// when mass add is searching inside a directory. In this case, the first
+	// result (the game directory) will be correct, but the second result (the
+	// clusters subdirectory) will be wrong, as the optional speech, music and
+	// video data files will be ignored. Note that this fix will skip the game
+	// data files if the user has placed them inside a "clusters" subdirectory,
+	// or if he/she points ScummVM directly to the "clusters" directory of the
+	// game CD. Fixes bug #5274.
+	if (!fslist.empty()) {
+		Common::String directory = fslist[0].getParent().getName();
+		if (directory.hasPrefixIgnoreCase("clusters") && directory.size() <= 9)
+			return detectedGames;
+	}
+
 	Sword1CheckDirectory(fslist, filesFound);
 	bool mainFilesFound = true;
 	bool pcFilesFound = true;
@@ -241,139 +211,11 @@ DetectedGames SwordMetaEngine::detectGames(const Common::FSList &fslist) const {
 	game.appendGUIOptions(getGameGUIOptionsDescriptionLanguage(Common::ES_ESP));
 	game.appendGUIOptions(getGameGUIOptionsDescriptionLanguage(Common::PT_BRA));
 	game.appendGUIOptions(getGameGUIOptionsDescriptionLanguage(Common::CZ_CZE));
+	game.appendGUIOptions(getGameGUIOptionsDescriptionLanguage(Common::HE_ISR));
 
 	detectedGames.push_back(game);
 
 	return detectedGames;
 }
 
-Common::Error SwordMetaEngine::createInstance(OSystem *syst, Engine **engine) const {
-	assert(engine);
-	*engine = new Sword1::SwordEngine(syst);
-	return Common::kNoError;
-}
-
-SaveStateList SwordMetaEngine::listSaves(const char *target) const {
-	Common::SaveFileManager *saveFileMan = g_system->getSavefileManager();
-	SaveStateList saveList;
-	char saveName[40];
-
-	Common::StringArray filenames = saveFileMan->listSavefiles("sword1.###");
-
-	int slotNum = 0;
-	for (Common::StringArray::const_iterator file = filenames.begin(); file != filenames.end(); ++file) {
-		// Obtain the last 3 digits of the filename, since they correspond to the save slot
-		slotNum = atoi(file->c_str() + file->size() - 3);
-
-		if (slotNum >= 0 && slotNum <= 999) {
-			Common::InSaveFile *in = saveFileMan->openForLoading(*file);
-			if (in) {
-				in->readUint32LE(); // header
-				in->read(saveName, 40);
-				saveList.push_back(SaveStateDescriptor(slotNum, saveName));
-				delete in;
-			}
-		}
-	}
-
-	// Sort saves based on slot number.
-	Common::sort(saveList.begin(), saveList.end(), SaveStateDescriptorSlotComparator());
-	return saveList;
-}
-
-int SwordMetaEngine::getMaximumSaveSlot() const { return 999; }
-
-void SwordMetaEngine::removeSaveState(const char *target, int slot) const {
-	g_system->getSavefileManager()->removeSavefile(Common::String::format("sword1.%03d", slot));
-}
-
-SaveStateDescriptor SwordMetaEngine::querySaveMetaInfos(const char *target, int slot) const {
-	Common::String fileName = Common::String::format("sword1.%03d", slot);
-	char name[40];
-	uint32 playTime = 0;
-	byte versionSave;
-
-	Common::InSaveFile *in = g_system->getSavefileManager()->openForLoading(fileName);
-
-	if (in) {
-		in->skip(4);        // header
-		in->read(name, sizeof(name));
-		in->read(&versionSave, 1);      // version
-
-		SaveStateDescriptor desc(slot, name);
-
-		if (versionSave < 2) // These older version of the savegames used a flag to signal presence of thumbnail
-			in->skip(1);
-
-		if (Graphics::checkThumbnailHeader(*in)) {
-			Graphics::Surface *thumbnail;
-			if (!Graphics::loadThumbnail(*in, thumbnail)) {
-				delete in;
-				return SaveStateDescriptor();
-			}
-			desc.setThumbnail(thumbnail);
-		}
-
-		uint32 saveDate = in->readUint32BE();
-		uint16 saveTime = in->readUint16BE();
-		if (versionSave > 1) // Previous versions did not have playtime data
-			playTime = in->readUint32BE();
-
-		int day = (saveDate >> 24) & 0xFF;
-		int month = (saveDate >> 16) & 0xFF;
-		int year = saveDate & 0xFFFF;
-
-		desc.setSaveDate(year, month, day);
-
-		int hour = (saveTime >> 8) & 0xFF;
-		int minutes = saveTime & 0xFF;
-
-		desc.setSaveTime(hour, minutes);
-
-		if (versionSave > 1) {
-			desc.setPlayTime(playTime * 1000);
-		} else { //We have no playtime data
-			desc.setPlayTime(0);
-		}
-
-		delete in;
-
-		return desc;
-	}
-
-	return SaveStateDescriptor();
-}
-
-#if PLUGIN_ENABLED_DYNAMIC(SWORD1)
-	REGISTER_PLUGIN_DYNAMIC(SWORD1, PLUGIN_TYPE_ENGINE, SwordMetaEngine);
-#else
-	REGISTER_PLUGIN_STATIC(SWORD1, PLUGIN_TYPE_ENGINE, SwordMetaEngine);
-#endif
-
-namespace Sword1 {
-
-Common::Error SwordEngine::loadGameState(int slot) {
-	_systemVars.forceRestart = false;
-	_systemVars.controlPanelMode = CP_NORMAL;
-	_control->restoreGameFromFile(slot);
-	reinitialize();
-	_control->doRestore();
-	reinitRes();
-	return Common::kNoError;    // TODO: return success/failure
-}
-
-bool SwordEngine::canLoadGameStateCurrently() {
-	return (mouseIsActive() && !_control->isPanelShown()); // Disable GMM loading when game panel is shown
-}
-
-Common::Error SwordEngine::saveGameState(int slot, const Common::String &desc, bool isAutosave) {
-	_control->setSaveDescription(slot, desc.c_str());
-	_control->saveGameToFile(slot);
-	return Common::kNoError;    // TODO: return success/failure
-}
-
-bool SwordEngine::canSaveGameStateCurrently() {
-	return (mouseIsActive() && !_control->isPanelShown());
-}
-
-} // End of namespace Sword1
+REGISTER_PLUGIN_STATIC(SWORD1_DETECTION, PLUGIN_TYPE_ENGINE_DETECTION, SwordMetaEngineDetection);
