@@ -39,6 +39,7 @@
 #include "common/events.h"
 #include "common/util.h"
 #include "common/random.h"
+#include "sword2/detection.h"
 
 #define	MAX_starts	100
 #define	MAX_description	100
@@ -55,11 +56,6 @@ class OSystem;
  */
 namespace Sword2 {
 
-enum {
-	GF_DEMO	       = 1 << 0,
-	GF_SPANISHDEMO = 1 << 1
-};
-
 class MemoryManager;
 class ResourceManager;
 class Sound;
