@@ -29,7 +29,7 @@ static const ADGameDescription gameDescriptions[] = {
 		AD_ENTRY1s("data.b25c", "f8b6e03ada2d2f6cf27fbc11ad1572e9", 654310588),
 		Common::EN_ANY,
 		Common::kPlatformUnknown,
-		ADGF_TESTING,
+		ADGF_NO_FLAGS,
 		GUIO1(GUIO_NOASPECT)
 	},
 	{
@@ -38,7 +38,7 @@ static const ADGameDescription gameDescriptions[] = {
 		AD_ENTRY1s("lang_fr.b25c", "690caf157387e06d2c3d1ca53c43f428", 1006043),
 		Common::FR_FRA,
 		Common::kPlatformUnknown,
-		ADGF_TESTING,
+		ADGF_NO_FLAGS,
 		GUIO1(GUIO_NOASPECT)
 	},
 	{
@@ -47,7 +47,7 @@ static const ADGameDescription gameDescriptions[] = {
 		AD_ENTRY1s("data.b25c", "f8b6e03ada2d2f6cf27fbc11ad1572e9", 654310588),
 		Common::DE_DEU,
 		Common::kPlatformUnknown,
-		ADGF_TESTING,
+		ADGF_NO_FLAGS,
 		GUIO1(GUIO_NOASPECT)
 	},
 	{
@@ -56,7 +56,7 @@ static const ADGameDescription gameDescriptions[] = {
 		AD_ENTRY1s("lang_hr.b25c", "e881054d1f8ec1e527422fc521c25405", 1273217),
 		Common::HR_HRV,
 		Common::kPlatformUnknown,
-		ADGF_TESTING,
+		ADGF_NO_FLAGS,
 		GUIO1(GUIO_NOASPECT)
 	},
 	{
@@ -65,7 +65,7 @@ static const ADGameDescription gameDescriptions[] = {
 		AD_ENTRY1s("lang_it.b25c", "f3325666da0515cc2b42062e953c0889", 996197),
 		Common::IT_ITA,
 		Common::kPlatformUnknown,
-		ADGF_TESTING,
+		ADGF_NO_FLAGS,
 		GUIO1(GUIO_NOASPECT)
 	},
 	{
@@ -74,7 +74,7 @@ static const ADGameDescription gameDescriptions[] = {
 		AD_ENTRY1s("lang_pl.b25c", "49dc1a20f95391a808e475c49be2bac0", 1281799),
 		Common::PL_POL,
 		Common::kPlatformUnknown,
-		ADGF_TESTING,
+		ADGF_NO_FLAGS,
 		GUIO1(GUIO_NOASPECT)
 	},
 	{
@@ -83,7 +83,7 @@ static const ADGameDescription gameDescriptions[] = {
 		AD_ENTRY1s("lang_pt.b25c", "1df701432f9e13dcefe1adeb890b9c69", 993812),
 		Common::PT_BRA,
 		Common::kPlatformUnknown,
-		ADGF_TESTING,
+		ADGF_NO_FLAGS,
 		GUIO1(GUIO_NOASPECT)
 	},
 	{
@@ -92,7 +92,7 @@ static const ADGameDescription gameDescriptions[] = {
 		AD_ENTRY1s("lang_ru.b25c", "deb33dd2f90a71ff60181918a8ce5063", 1235378),
 		Common::RU_RUS,
 		Common::kPlatformUnknown,
-		ADGF_TESTING,
+		ADGF_NO_FLAGS,
 		GUIO1(GUIO_NOASPECT)
 	},
 	{
@@ -101,18 +101,18 @@ static const ADGameDescription gameDescriptions[] = {
 		AD_ENTRY1s("lang_es.b25c", "384c19072d83725f351bb9ecb4d3f02b", 987965),
 		Common::ES_ESP,
 		Common::kPlatformUnknown,
-		ADGF_TESTING,
+		ADGF_NO_FLAGS,
 		GUIO1(GUIO_NOASPECT)
 	},
 	// Hungarian "psylog" version.
-	// Submitted by goodoldgeorg in bug report #3428644.
+	// Submitted by goodoldgeorg in bug report #5888.
 	{
 		"sword25",
 		"psylog version",
 		AD_ENTRY1s("lang_hu.b25c", "7de51a3b4926a192549e75b1a7d81667", 1864915),
 		Common::HU_HUN,
 		Common::kPlatformUnknown,
-		ADGF_TESTING,
+		ADGF_NO_FLAGS,
 		GUIO1(GUIO_NOASPECT)
 	},
 
@@ -124,21 +124,24 @@ static const ADGameDescription gameDescriptions[] = {
 		 {"boot.lua", 0, 0, -1},
 		 {"kernel.lua", 0, 0, -1},
 		 AD_LISTEND},
-		Common::EN_ANY,
+		Common::UNK_LANG,
 		Common::kPlatformUnknown,
-		GF_EXTRACTED | ADGF_TESTING,
+		GF_EXTRACTED | ADGF_NO_FLAGS,
 		GUIO1(GUIO_NOASPECT)
 	},
 
 	// Distributed by ScummVM
 	// Contains all language packs, English voice-overs and Hungarian version
+	// Mark it as Unknown Language since it contains multiple languages. If we
+	// mark it as English, then changing the language in-game causes the detection
+	// to fail the next time we try to start the engine.
 	{
 		"sword25",
 		"Latest version",
 		AD_ENTRY1s("data.b25c", "880a8a67faf4a4e7ab62cf114b771428", 827397764),
-		Common::EN_ANY,
+		Common::UNK_LANG,
 		Common::kPlatformUnknown,
-		ADGF_TESTING,
+		ADGF_NO_FLAGS,
 		GUIO1(GUIO_NOASPECT)
 	},
 
