@@ -60,77 +60,77 @@ public:
 		AT_JOJO
 	};
 
-	virtual ~Animation();
+	~Animation() override;
 
 	void play();
 	void pause();
 	void stop();
 	void setFrame(uint nr);
 
-	virtual void setPos(int x, int y);
-	virtual void setX(int x);
-	virtual void setY(int y);
+	void setPos(int x, int y) override;
+	void setX(int x) override;
+	void setY(int y) override;
 
-	virtual int getX() const;
-	virtual int getY() const;
-	virtual int getAbsoluteX() const;
-	virtual int getAbsoluteY() const;
+	int getX() const override;
+	int getY() const override;
+	int getAbsoluteX() const override;
+	int getAbsoluteY() const override;
 
 	/**
 	    @brief Setzt den Alphawert der Animation.
 	    @param Alpha der neue Alphawert der Animation (0 = keine Deckung, 255 = volle Deckung).
-	    @remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsAlphaAllowed() true zurckgibt.
+	    @remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsAlphaAllowed() true zurückgibt.
 	*/
 	void setAlpha(int alpha);
 
 	/**
 	    @brief Setzt die Modulationfarbe der Animation.
 	    @param Color eine 24-Bit Farbe, die die Modulationsfarbe der Animation festlegt.
-	    @remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsColorModulationAllowed() true zurckgibt.
+	    @remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsColorModulationAllowed() true zurückgibt.
 	*/
 	void setModulationColor(uint modulationColor);
 
 	/**
 	    @brief Setzt den Skalierungsfaktor der Animation.
 	    @param ScaleFactor der Faktor um den die Animation in beide Richtungen gestreckt werden soll.
-	    @remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsScalingAllowed() true zurckgibt.
+	    @remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsScalingAllowed() true zurückgibt.
 	*/
 	void setScaleFactor(float scaleFactor);
 
 	/**
 	    @brief Setzt den Skalierungsfaktor der Animation auf der X-Achse.
 	    @param ScaleFactor der Faktor um den die Animation in Richtungen der X-Achse gestreckt werden soll.
-	    @remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsScalingAllowed() true zurckgibt.
+	    @remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsScalingAllowed() true zurückgibt.
 	*/
 	void setScaleFactorX(float scaleFactorX);
 
 	/**
 	    @brief Setzt den Skalierungsfaktor der Animation auf der Y-Achse.
 	    @param ScaleFactor der Faktor um den die Animation in Richtungen der Y-Achse gestreckt werden soll.
-	    @remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsScalingAllowed() true zurckgibt.
+	    @remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsScalingAllowed() true zurückgibt.
 	*/
 	void setScaleFactorY(float scaleFactorY);
 
 	/**
-	@brief Gibt den Skalierungsfakter der Animation auf der X-Achse zurck.
-	@remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsScalingAllowed() true zurckgibt.
+	@brief Gibt den Skalierungsfakter der Animation auf der X-Achse zurück.
+	@remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsScalingAllowed() true zurückgibt.
 	*/
 	float getScaleFactorX() const {
 		return _scaleFactorX;
 	}
 
 	/**
-	@brief Gibt den Skalierungsfakter der Animation auf der Y-Achse zurck.
-	@remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsScalingAllowed() true zurckgibt.
+	@brief Gibt den Skalierungsfakter der Animation auf der Y-Achse zurück.
+	@remark Diese Methode darf nur aufgerufen werden, wenn die Methode IsScalingAllowed() true zurückgibt.
 	*/
 	float getScaleFactorY() const {
 		return _scaleFactorY;
 	}
 
-	virtual bool persist(OutputPersistenceBlock &writer);
-	virtual bool unpersist(InputPersistenceBlock &reader);
+	bool persist(OutputPersistenceBlock &writer) override;
+	bool unpersist(InputPersistenceBlock &reader) override;
 
-	virtual void frameNotification(int timeElapsed);
+	void frameNotification(int timeElapsed) override;
 
 	ANIMATION_TYPES     getAnimationType() const;
 	int                 getFPS() const;
@@ -151,7 +151,7 @@ public:
 	void setCallbacks();
 
 protected:
-	virtual bool doRender(RectangleList *updateRects);
+	bool doRender(RectangleList *updateRects) override;
 
 private:
 	enum Direction {
@@ -179,18 +179,18 @@ private:
 
 	/**
 	    @brief Lockt alle Frames.
-	    @return Gibt false zurck, falls nicht alle Frames gelockt werden konnten.
+	    @return Gibt false zurück, falls nicht alle Frames gelockt werden konnten.
 	*/
 	bool lockAllFrames();
 
 	/**
 	    @brief Unlockt alle Frames.
-	    @return Gibt false zurck, falls nicht alles Frames freigegeben werden konnten.
+	    @return Gibt false zurück, falls nicht alles Frames freigegeben werden konnten.
 	*/
 	bool unlockAllFrames();
 
 	/**
-	    @brief Diese Methode aktualisiert die Parameter (Gre, Position) der Animation anhand des aktuellen Frames.
+	    @brief Diese Methode aktualisiert die Parameter (Größe, Position) der Animation anhand des aktuellen Frames.
 
 	    Diese Methode muss bei jedem Framewechsel aufgerufen werden damit der RenderObject-Manager immer aktuelle Daten hat.
 	*/
