@@ -35,10 +35,7 @@
 
 namespace Sword25 {
 
-SWImage::SWImage(const Common::String &filename, bool &result) :
-	_imageDataPtr(0),
-	_width(0),
-	_height(0) {
+SWImage::SWImage(const Common::String &filename, bool &result) : _image() {
 	result = false;
 
 	PackageManager *pPackage = Kernel::getInstance()->getPackage();
@@ -54,9 +51,7 @@ SWImage::SWImage(const Common::String &filename, bool &result) :
 	}
 
 	// Uncompress the image
-	int pitch;
-	byte *pUncompressedData;
-	if (!ImgLoader::decodePNGImage(pFileData, fileSize, pUncompressedData, _width, _height, pitch)) {
+	if (!ImgLoader::decodePNGImage(pFileData, fileSize, &_image)) {
 		error("Could not decode image.");
 		return;
 	}
@@ -64,22 +59,20 @@ SWImage::SWImage(const Common::String &filename, bool &result) :
 	// Cleanup FileData
 	delete[] pFileData;
 
-	_imageDataPtr = (uint *)pUncompressedData;
-
 	result = true;
 	return;
 }
 
 SWImage::~SWImage() {
-	delete[] _imageDataPtr;
+	_image.free();
 }
 
 
 bool SWImage::blit(int posX, int posY,
-                      int flipping,
-                      Common::Rect *pPartRect,
-                      uint color,
-                      int width, int height,
+					  int flipping,
+					  Common::Rect *pPartRect,
+					  uint color,
+					  int width, int height,
 					  RectangleList *updateRects) {
 	error("Blit() is not supported.");
 	return false;
@@ -96,10 +89,13 @@ bool SWImage::setContent(const byte *pixeldata, uint size, uint offset, uint str
 }
 
 uint SWImage::getPixel(int x, int y) {
-	assert(x >= 0 && x < _width);
-	assert(y >= 0 && y < _height);
+	assert(x >= 0 && x < _image.w);
+	assert(y >= 0 && y < _image.h);
 
-	return _imageDataPtr[_width * y + x];
+	byte a, r, g, b;
+	_image.format.colorToARGB(_image.getPixel(0, 0), a, r, g, b);
+
+	return BS_ARGB(a, r, g, b);
 }
 
 } // End of namespace Sword25
