@@ -30,13 +30,13 @@
  */
 
 /*
-    BS_RenderObject
-    ---------------
-    Dieses ist die Klasse die sämtliche sichtbaren Objekte beschreibt. Alle anderen sichtbaren Objekte müssen von ihr abgeleitet werden.
-    Diese Klasse erledigt Aufgaben wie: minimales Neuzeichnen, Renderreihenfolge, Objekthierachie.
-    Alle BS_RenderObject Instanzen werden von einem BS_RenderObjectManager in einem Baum verwaltet.
+	BS_RenderObject
+	---------------
+	Dieses ist die Klasse die sämtliche sichtbaren Objekte beschreibt. Alle anderen sichtbaren Objekte müssen von ihr abgeleitet werden.
+	Diese Klasse erledigt Aufgaben wie: minimales Neuzeichnen, Renderreihenfolge, Objekthierachie.
+	Alle BS_RenderObject Instanzen werden von einem BS_RenderObjectManager in einem Baum verwaltet.
 
-    Autor: Malte Thiesen
+	Autor: Malte Thiesen
 */
 
 #ifndef SWORD25_RENDEROBJECT_H
@@ -45,6 +45,7 @@
 #include "sword25/kernel/common.h"
 #include "sword25/kernel/persistable.h"
 #include "common/rect.h"
+#include "sword25/gfx/graphicengine.h"
 #include "sword25/gfx/renderobjectptr.h"
 
 #include "common/list.h"
@@ -63,11 +64,11 @@ class Text;
 
 // Klassendefinition
 /**
-    @brief  Dieses ist die Klasse die sämtliche sichtbaren Objekte beschreibt.
+	@brief  Dieses ist die Klasse die sämtliche sichtbaren Objekte beschreibt.
 
-    Alle anderen sichtbaren Objekte müssen von ihr abgeleitet werden.
-    Diese Klasse erledigt Aufgaben wie: minimales Neuzeichnen, Renderreihenfolge, Objekthierachie.
-    Alle BS_RenderObject Instanzen werden von einem BS_RenderObjektManager in einem Baum verwaltet.
+	Alle anderen sichtbaren Objekte müssen von ihr abgeleitet werden.
+	Diese Klasse erledigt Aufgaben wie: minimales Neuzeichnen, Renderreihenfolge, Objekthierachie.
+	Alle BS_RenderObject Instanzen werden von einem BS_RenderObjektManager in einem Baum verwaltet.
  */
 class RenderObject {
 public:
@@ -132,7 +133,7 @@ public:
 	            Falls ein Fehler aufgetreten ist wird ein ungültiger BS_RenderObjectPtr zurückgegeben.
 	*/
 
-	RenderObjectPtr<Panel> addPanel(int width, int height, uint color = 0xff000000);
+	RenderObjectPtr<Panel> addPanel(int width, int height, uint color = BS_RGB(0, 0, 0));
 	/**
 	    @brief Erzeugt ein Textobjekt als Kinderobjekt des Renderobjektes.
 	    @param Font der Dateiname des zu verwendenen Fonts
