@@ -87,6 +87,8 @@ private:
 	Common::String _currentDirectory;
 	Common::FSNode _rootFolder;
 	Common::List<ArchiveEntry *> _archiveList;
+	bool _extractedFiles;
+	Common::String _directoryName;
 
 	bool _useEnglishSpeech;
 	Common::String ensureSpeechLang(const Common::String &fileName);
@@ -102,6 +104,15 @@ public:
 		FT_FILE         = (1 << 1)
 	};
 
+	/**
+	 *
+	 * Set the PackageManager to run on extracted game files.s
+	 */
+	void setRunWithExtractedFiles(const Common::String &directoryName) {
+		_extractedFiles = true;
+		_directoryName = directoryName;
+	}
+
 	/**
 	 * Mounts the contents of a package in the directory specified in the directory tree.
 	 * @param FileName      The filename of the package to mount
