@@ -38,6 +38,7 @@
 
 #include "audio/audiostream.h"
 #include "audio/decoders/vorbis.h"
+#include "audio/mididrv.h"
 
 #include "common/system.h"
 #include "common/config-manager.h"
@@ -65,6 +66,15 @@ SoundEngine::SoundEngine(Kernel *pKernel) : ResourceService(pKernel) {
 	_mixer = g_system->getMixer();
 
 	_maxHandleId = 1;
+
+	Common::String selDevStr = ConfMan.hasKey("music_driver") ? ConfMan.get("music_driver") : Common::String("auto");
+	MidiDriver::DeviceHandle dev = MidiDriver::getDeviceHandle(selDevStr.empty() ? Common::String("auto") : selDevStr);
+	_noMusic = (MidiDriver::getMusicType(dev) == MT_NULL || MidiDriver::getMusicType(dev) == MT_INVALID);
+
+	if (_noMusic) {
+		warning("AUDIO: MUSIC IS FORCED TO OFF");
+		ConfMan.setInt("music_volume", 0);
+	}
 }
 
 bool SoundEngine::init(uint sampleRate, uint channels) {
@@ -79,8 +89,10 @@ void SoundEngine::setVolume(float volume, SOUND_TYPES type) {
 
 	switch (type) {
 	case SoundEngine::MUSIC:
-		ConfMan.setInt("music_volume", val);
-		_mixer->setVolumeForSoundType(Audio::Mixer::kMusicSoundType, val);
+		if (!_noMusic) {
+			ConfMan.setInt("music_volume", val);
+			_mixer->setVolumeForSoundType(Audio::Mixer::kMusicSoundType, val);
+		}
 		break;
 	case SoundEngine::SPEECH:
 		ConfMan.setInt("speech_volume", val);
@@ -100,7 +112,7 @@ float SoundEngine::getVolume(SOUND_TYPES type) {
 
 	switch (type) {
 	case SoundEngine::MUSIC:
-		val = ConfMan.getInt("music_volume");
+		val = _noMusic ? 0 : ConfMan.getInt("music_volume");
 		break;
 	case SoundEngine::SPEECH:
 		val = ConfMan.getInt("speech_volume");
@@ -203,6 +215,9 @@ bool SoundEngine::playSound(const Common::String &fileName, SOUND_TYPES type, fl
 }
 
 uint SoundEngine::playSoundEx(const Common::String &fileName, SOUND_TYPES type, float volume, float pan, bool loop, int loopStart, int loopEnd, uint layer, uint handleId) {
+	if (type == MUSIC && _noMusic)
+		return 0;
+
 #ifdef USE_VORBIS
 	Common::SeekableReadStream *in = Kernel::getInstance()->getPackage()->getStream(fileName);
 	Audio::SeekableAudioStream *stream = Audio::makeVorbisStream(in, DisposeAfterUse::YES);
