@@ -27,6 +27,7 @@
 #include "engines/engine.h"
 
 #include "sword25/console.h"
+#include "sword25/detection.h"
 
 namespace Common {
 class Error;
@@ -58,10 +59,6 @@ enum {
 	kDebugResource = 1 << 2
 };
 
-enum GameFlags {
-	GF_EXTRACTED = 1 << 0
-};
-
 #define MESSAGE_BASIC 1
 #define MESSAGE_INTERMEDIATE 2
 #define MESSAGE_DETAILED 3
